@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -49,7 +51,6 @@
 * Prototyping the default Date object
 */
 
-
 /**
  * Function which returns the number of days in a month.
  * If month is given, use this month instead of this.getMonth()
@@ -82,7 +83,6 @@ Date.prototype.getDaysInMonth = function(month, year)
 	return days;
 }
 
-
 /**
  * Function will add one or more days to current date
  * @param	integer		dayCount	number of days to add
@@ -181,7 +181,6 @@ Date.prototype.getWeekNumber = function(){
 /**
  * Get the week number of the month (1 to 5)
  */
- 
 Date.prototype.getWeekNrOfMonth = function()
 {
 	var week = this.getWeekNumber();
@@ -190,7 +189,6 @@ Date.prototype.getWeekNrOfMonth = function()
 	var monthstartweek = monthDate.getWeekNumber();
 	return week - monthstartweek + 1; 
 }
- 
 
 /**
  * Helper function to convert a year to a full year
@@ -277,17 +275,7 @@ Date.prototype.isSameDay = function(day)
  */
 Date.prototype.ceilHalfhour = function()
 {
-	var minutes = parseInt(this.getMinutes(),10);
-	var seconds = parseInt(this.getSeconds(),10);
-	var oldValue = this.getTime();
-	var result = this.getTime();
-	if(minutes != 0 && minutes < 30){
-		result = oldValue+((30-minutes)*60000);
-	}
-	if(minutes > 30 && minutes < 60){
-		result = oldValue+((60-minutes)*60000);
-	}
-	return result-(seconds*1000);
+	return this.ceilMinutes(30).getTime();
 }
 /**
  * Function will convert "14:13" -> "14:00" or "14:32 " -> "14:30"
@@ -295,17 +283,47 @@ Date.prototype.ceilHalfhour = function()
  */
 Date.prototype.floorHalfhour = function()
 {
+	return this.floorMinutes(30).getTime();
+}
+
+/**
+ * Function to ceil timings according to the passed ceil minutes.
+ * @param date ceilTimeValue date time which needs to be ceil (5/10/15/30/60 or so on)
+ * @return number Time number which is unixtimestamp of time.
+ *
+ * Example to understand what the code is actually suppose to do.
+ *	9:12	5min		ceil-9:15
+ *			10min		ceil-9.20
+ *			15min		ceil-9.15
+ *			30min		ceil-9.30
+ *			1hr/60min	ceil-10.00
+ *
+ */ 
+Date.prototype.ceilMinutes = function(ceilTimeValue){
 	var minutes = parseInt(this.getMinutes(),10);
-	var seconds = parseInt(this.getSeconds(),10);
-	var oldValue = this.getTime();
-	var result = this.getTime();
-	if(minutes < 30){
-		result = oldValue-(minutes*60000);
-	}
-	if(minutes > 30 && minutes < 60){
-		result = oldValue-((minutes-30)*60000);
-	}
-	return result-(seconds*1000);
+	// when time is XX:00 then there is no need to ceil the time.
+	if(minutes % ceilTimeValue > 0)
+		this.setMinutes((minutes - (minutes % ceilTimeValue)) + ceilTimeValue);
+	return this;
+}
+
+/**
+ * Function to floor timings according to the passed floor minutes.
+ * @param date floorTimeValue date time which needs to be floor (5/10/15/30/60 or so on)
+ * @return number Time number which is unixtimestamp of time.
+ *
+ * Example to understand what the code is actually suppose to do.
+ *	9:12	5min		floor-9.10
+ *			10min		floor-9.10
+ *			15min		floor-9.00
+ *			30min		floor-9.00
+ *			1hr/60min	floor-9.00
+ *
+ */ 
+Date.prototype.floorMinutes = function(floorTimeValue){
+	var minutes = parseInt(this.getMinutes(),10);
+	this.setMinutes(minutes - (minutes % floorTimeValue));
+	return this;
 }
 
 Date.prototype.getMonthTranslation = function()
@@ -355,7 +373,7 @@ function timeToSeconds(value)
 	 * and Using new Date object get the value
 	 */
 	// parseDate function works with Date value so create current datetime string
-	var tempDateTimeStr = tempDate.getDate() + "-" + tempDate.getMonth() + "-" + tempDate.getYear() + " " + value;
+	var tempDateTimeStr = tempDate.getDate() + "-" + (tempDate.getMonth()+1) + "-" + tempDate.getFullYear() + " " + value;
 
 	// Set the timeformat for parsing.
 	var format = "%d-%m-%Y "+_("%H:%M");
@@ -376,7 +394,8 @@ function secondsToTime(value,fourDigit)
 {
 	// Get current Date and time and set its time to zero
 	var tempDate = new Date();
-	value += timeToZero(tempDate.getTime()/1000);
+	// using dst safe function for time manipulation.
+	value = addHoursToUnixTimeStamp(timeToZero(tempDate.getTime()/1000) , (value / (60*60)));
 
 	// Add time in to today's time stamp and return it.
 	result = strftime(_('%H:%M'),value).toUpperCase();
@@ -455,9 +474,9 @@ Date.prototype.format_callback = function(match0, match1) {
 			return ;*/
 		case 'H': // hour as a decimal number using a 24-hour clock (range 00 to 23)
 			return Date._pad(this.getHours(), 2);
-		case 'I': // hour as a decimal number using a 12-hour clock (range 01 to 12)
+		case 'I': // hour as a decimal number using a 12-hour clock (range 01 to 12).But displays 12 am as 00 am.
 			var hour = Date._pad(this.getHours() % 12, 2);
-			return (hour != "00")?hour:"12";
+			return (hour != "00")?hour: (this.getHours() == "00")?"00":"12";
 		case 'j': // day of the year as a decimal number (range 001 to 366)
 			return Date._pad(this.getMonth() * 30 + Math.ceil(this.getMonth() / 2) + this.getDay() - 2 * (this.getMonth() > 1) + (!(this.getFullYear() % 400) || (!(this.getFullYear() % 4) && this.getFullYear() % 100)), 3);
 		case 'm': // month as a decimal number (range 01 to 12)
@@ -563,6 +582,50 @@ Date.prototype.simpleDiffString = function(otherDate, futureString, pastString)
 	return shellString.sprintf(result);
 }
 
+/**
+* Returns a human readable string for duration property
+* @param		duration		number		duration in minutes
+* @return		result			string		human readable duration string
+* 
+* @TODO this function is not much accurate as compared to OL
+*/
+function simpleDurationString(duration) {
+	var result = false;
+
+	if(duration.constructor != Number || isNaN(duration)) {
+		// invalid argument
+		return "";
+	}
+
+	// now convert duration in minutes
+	duration = Math.round(duration);
+	if (duration <= 59)
+		result = _("%d mins").sprintf(duration);
+
+	// now convert duration in hours
+	duration = duration / 60;
+	if (!result && duration <= 1)
+		result = _("1 hour");
+	if (!result && duration <= 23)
+		result = _("%.1f hours").sprintf(duration);
+
+	// diff in days
+	duration = duration / 24;
+	if (!result && duration <= 1)
+		result = _("1 day");
+	if (!result && duration <= 13)
+		result = _("%.1f days").sprintf(duration);
+
+	// diff in weeks
+	duration = duration / 7;
+	if (!result && duration <= 1)
+		result = _("1 week");
+	if (!result)
+		result = _("%.1f weeks").sprintf(duration);
+
+	return result;
+}
+
 function strftime(format, timestamp) 
 {
 	var t = new Date();
