@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -55,7 +57,6 @@ function DHTML()
 	// a counter used to create unique IDs
 	this.addEvent.guid = 1;
 	this.comboBoxes = new Array();
-	this.clearBodySelectionFlag = false;
 }
 
 /**
@@ -627,7 +628,7 @@ DHTML.prototype.setValue = function(element, value)
 					isValueSet = true;
 					break;
 				case "radio":
-				
+					element.checked = true;
 					break;
 			}
 			break;
@@ -997,7 +998,9 @@ function checkMenuState(moduleObject, element, event)
 	var contextmenu = dhtml.getElementById("contextmenu");
 	
 	if(contextmenu) {
-		dhtml.showHideElement(contextmenu, event.clientX, event.clientY, true);
+		// for Linux-FF dont hide contextmenu on mouseup event of right mousebutton.
+		if(typeof event.hideContextMenu == "undefined" || event.hideContextMenu != false)
+			dhtml.showHideElement(contextmenu, event.clientX, event.clientY, true);
 	}
 	
 	// Check defaultmenu
@@ -1099,28 +1102,64 @@ DHTML.prototype.scrollFrame = function(iframe, id)
 	return;
 }
 
+/**
+ * similar to array.push function, but it can also remove entries
+ * @param		Array			data_array			array to push elements in
+ * @param		String/Number	data				data to push in array
+ * @param		Boolean			removeIfExists		if true then remove from array
+ * @param		Boolean			allowDuplicates		if true then allow duplicate entries
+ * @return		Boolean								returns operation performed or not
+ */
+DHTML.prototype.array_push = function(data_array, data, removeIfExists, allowDuplicates)
+{
+	if(data_array.constructor != Array) {
+		return false;
+	}
+
+	if(typeof removeIfExists == "undefined") {
+		removeIfExists = false;
+	}
+
+	if(typeof allowDuplicates == "undefined") {
+		allowDuplicates = false;
+	}
+
+	for(var key in data_array) {
+		if(data_array[key] == data) {
+			if(removeIfExists) {
+				return data_array.splice(key, 1);
+			} else {
+				if(allowDuplicates) {
+					break;
+				} else {
+					return false;
+				}
+			}
+		}
+	}
+
+	data_array.push(data);
+	return true;
+}
+
 /**
  * Clears the selection on body.
  */
 DHTML.prototype.clearBodySelection = function()
 {
 	if(document.selection) {
-		//cancle the curent selection, sets the selection type to none, and sets the item property to null
-		if(document.selection.type == "None") {
+		if(document.selection.type == "Text") {
 			/**
-			 * If selection is not done on text then clear the seletion,
-			 * and set clearBodySelectionFlag value because some time after
-			 * 'None' seletion type it executer for other selection types like 'Text'
+			 * The selection object provides information about text and elements which are highlighted
+			 * with the mouse,So here we only check for type as Text; and whether the element calling
+			 * for clearBodySelection is a TextEdit Html element or not.So that we can deselect the Object. 
 			 */
-			this.clearBodySelectionFlag = true;
-			document.selection.empty();
-		} else {
-			if(this.clearBodySelectionFlag) {
-				document.selection.empty();
-				this.clearBodySelectionFlag = false;
-			}
+			var el =  window.event.srcElement.isTextEdit;
+			if(!el && document.selection.createRange().text != "") document.selection.empty();
 		}
 	} else if (window.getSelection) {
-		window.getSelection().removeAllRanges();
+		var selectionObject = window.getSelection();
+		var start = selectionObject.focusOffset;
+		if(!selectionObject.isCollapsed && start == 0) selectionObject.removeAllRanges();
 	}
 }
