@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -205,7 +207,34 @@ function sortSelectBox(element)
 	}
 }
 
+// Function will check wheather any type of menu is Open 
+function isMenuOpen()
+{
+	var result = false;
 
+	//context menu
+	var contextmenu = dhtml.getElementById("contextmenu");
+	if(contextmenu && contextmenu != "undefined"){
+		result = true;
+	}
+	
+	//defaultmenu
+	var defaultmenu = dhtml.getElementById("defaultmenu");
+	if(defaultmenu && defaultmenu.style.display == "block"){
+		result = true;
+	}
+
+	//combobox
+	var comboBoxes = dhtml.comboBoxes;
+	for(var i in comboBoxes){
+		var combobox = dhtml.getElementById(comboBoxes[i]);
+		if(combobox && combobox.style.display == "block"){
+			result = true;
+		}
+	}
+
+	return result;
+}
 
 /**
  * Function will make long notation of e-mail address
@@ -214,21 +243,62 @@ function sortSelectBox(element)
  * @param html = "bool" true will return &lg;john.doe@foo.com&gt; 
  * @return "string" like: "John Doe <john.doe@foo.com>" 
  */
-function nameAndEmailToString(name,email,html)
+function nameAndEmailToString(name,email,objecttype,html)
 {
 	var result = "";
-	if(name == email || name == ""){
-		result = email;
+
+	if(objecttype == MAPI_DISTLIST) {
+		// Group
+		result = "[" + name + "]";
 	} else {
-		if(html == true){
-			result = name+" &lt;"+email+"&gt;";
+		// User
+		if(name == email || name == ""){
+			result = email;
 		} else {
-			result = name+" <"+email+">";
+			if(html == true){
+				result = name+" &lt;"+email+"&gt;";
+			} else {
+				result = name+" <"+email+">";
+			}
 		}
 	}
 	return result;
 }
 
+/**
+ * Parse email address into component parts
+ * @param address string to parse
+ * @return Returns array with "fullname", "emailaddress", "objecttype"
+ */
+function stringToEmail(address)
+{
+	var posLeft = address.indexOf("<");
+	var posRight = address.indexOf(">");
+	var result = new Object;
+
+	if(posLeft >= 0 && posRight >= 0) {
+		result["fullname"] = address.substring(0,posLeft).trim();
+		result["emailaddress"] = address.substring(posLeft+1,posRight).trim();
+		result["objecttype"] = MAPI_MAILUSER;
+
+		return result;
+	}
+
+	posLeft = address.indexOf("[");
+	posRight = address.indexOf("]");
+
+	if(posLeft >= 0 && posRight >= 0) {
+		result["emailaddress"] = address.substring(posLeft+1,posRight).trim();
+		result["fullname"] = result["emailaddress"];
+		result["objecttype"] = MAPI_DISTLIST;
+
+		return result;
+	}
+
+	result["fullname"] = address;
+	return result;
+}
+
 /**
  * Function will round "value" with "decimals" 
  * NOTE: Math is a native object and can not be prototyped
@@ -555,7 +625,7 @@ function validateEmailAddress(fieldString, forceSingleAddress, suppressPopupMsg)
 	for(i in data){
 		// check e-mail address
 		var email = data[i].trim();
-		var filter = new RegExp(/^([^<]*<){0,1}(([a-z0-9=_\+\.\-\'\/])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+)>{0,1}$/i);
+		var filter = new RegExp(/^([^<]*<){0,1}(([a-z0-9=_\+\.\-\'\/])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+)>{0,1}$|^\[[^\]]+\]$/i);
 		if(email.length > 0 && !filter.test(email)){
 			result += "\n"+email;
 		}
@@ -642,7 +712,14 @@ function iconIndexToClassName(icon_index,messageClass, isRead)
 			className += "icon_appointment";
 			break;
 		case 1025:
-			className += "icon_appointment_recurring";		
+			switch(messageClass){
+				case "IPM.Schedule.Meeting.Canceled":
+					className += "icon_meetingrequest_canceled";
+					break;
+				default:
+					className += "icon_appointment_recurring";
+					break;
+			}
 			break;
 		case 1027:
 			className += "icon_meeting_recurring";		
@@ -725,6 +802,76 @@ function iconIndexToClassName(icon_index,messageClass, isRead)
 	return className;
 }
 
+/**
+ * This function is used to get class name based on display_type property of users in GAB
+ * this is used only as a hack to show different icons for gab users,
+ * the actual value for display_type and display_type_ex for gab users are different
+ */
+function displayTypeToClassName(displayType)
+{
+	var className = "";
+	switch(parseInt(displayType, 10)) {
+		case DT_MAILUSER:
+			className += "icon_contact";
+			break;
+		case DT_REMOTE_MAILUSER:
+			className += "icon_gab_contact";
+			break;
+		case DT_EQUIPMENT:
+			className += "icon_equipment";
+			break;
+		case DT_ROOM:
+			className += "icon_room";
+			break;
+		case DT_DISTLIST:
+		case DT_SEC_DISTLIST:
+		case DT_AGENT:
+			className += "icon_distributionlist";
+			break;
+		case DT_ORGANIZATION:
+			className += "icon_company";
+			break;
+	}
+
+	return className;
+}
+
+/**
+ * This function can be used to get message type based on message class of an item
+ * and this message type can be used when opening a dialog box for that item
+ */
+function messageClassToMessageType(messageClass)
+{
+	var messageType = false;
+
+	switch(messageClass) {
+		case "ipm_note":
+		case "ipm_appointment":
+		case "ipm_contact":
+		case "ipm_task":
+		case "ipm_distlist":
+		case "ipm_stickynote":
+			messageType = messageClass.substring(4);
+			break;
+		case "ipm_schedule_meeting":
+		case "ipm_schedule_meeting_request":
+		case "ipm_schedule_meeting_resp":
+		case "ipm_schedule_meeting_resp_pos":
+		case "ipm_schedule_meeting_resp_tent":
+		case "ipm_schedule_meeting_resp_neg":
+		case "ipm_schedule_meeting_canceled":
+
+		case "ipm_post":
+		case "report_ipm_note_ndr":
+		case "report_ipm_note_ipnnrn":
+		case "report_ipm_note_ipnrn":
+			messageType = "note";
+			break;
+	}
+
+	return messageType;
+}
+
 function convertPlainToHtml(content)
 {
 	content = content.replace(/</g, "&lt;");
@@ -959,6 +1106,78 @@ function inArray(needle, haystack)
 	}
 	return false;
 }
+/** 
+ * Function which searches the array for a given value 
+ * and returns the corresponding key if successful 
+ * @param mixed needle 
+ * @param array haystack 
+ * @param boolean strict 
+ * @return boolean true needle is found in haystack 
+ */ 
+function array_search(needle, haystack, strict) 
+{ 
+	var strict = !!strict; 
+	var key = ''; 
+
+	for(key in haystack){ 
+		if( (strict && haystack[key] === needle) || (!strict && haystack[key] == needle) ){ 
+			return key; 
+		} 
+	} 
+	return false; 
+} 
+/**
+ * Function which return next element value for a given key
+ * if key itself is last element then return first element of array.
+ * @param mixed needle
+ * @param array haystack
+ * @return mixed next element
+ */
+function array_next(needle, haystack)
+{
+	var returnNext = false;
+	var key = array_indexOf(needle, haystack);
+	
+	for (var i in haystack){
+		if (returnNext) return haystack[i];
+		if (i == key) returnNext = true;
+	}
+	for (var i in haystack) return haystack[i];
+}
+/**
+ * Function which return previous element value for a given key
+ * if key itself is first element then return last element of array.
+ * @param mixed needle
+ * @param array haystack
+ * @return mixed next element
+ */
+function array_prev(needle, haystack)
+{
+	var result = false;
+	var key = array_indexOf(needle, haystack);
+	
+	for (var i in haystack){
+		if (i == key) break;
+		result = haystack[i];
+	}
+	if (!result){
+		for (var i in haystack) result = haystack[i];
+	}
+	return result;
+}
+/**
+ * Function which index for given value
+ * @param mixed needle
+ * @param array haystack
+ * @return mixed index
+ */
+function array_indexOf(needle, haystack)
+{
+	for (var i in haystack){
+		if (haystack[i] == needle) return i;
+	}
+	return false;
+}
 /**
  * Function which generates random strings with default length of 8.
  * @param integer length -length of random string to be generated
@@ -1198,6 +1417,54 @@ function html_entity_decode( string ) {
 		}
 	});
 }
+/**
+ * Function which converts keyCode to char, also for special
+ * keys like Ctrl,Alt and Shift.
+ */
+Number.prototype.fromCharCode = function()
+{
+	var keyCode = parseInt(this);
+	var customKeyStrokes = { 8:"BACKSPACE",
+							 9:"TAB",
+							13:"ENTER",
+							16:"SHIFT",
+							17:"CTRL",
+							18:"ALT",
+							27:"ESCAPE",
+							33:"PAGEUP",
+							34:"PAGEDOWN",
+							35:"END",
+							36:"HOME",
+							37:"LA",
+							38:"UA",
+							39:"RA",
+							40:"DA",
+							45:"INSERT",
+							46:"DEL",
+						   112:"F1",
+						   113:"F2",
+						   114:"F3",
+						   115:"F4",
+						   116:"F5",
+						   117:"F6",
+						   118:"F7",
+						   119:"F8",
+						   120:"F9",
+						   121:"F10",
+						   122:"F11",
+						   123:"F12",
+						   190:".",
+						   188:",",
+						   219:"[",
+						   221:"]"
+	};
+
+	if (customKeyStrokes[keyCode]){
+		return customKeyStrokes[keyCode];
+	} else {
+		return String.fromCharCode(keyCode);
+	}
+}
 
 /**
  * compareEntryIds
@@ -1274,3 +1541,13 @@ function createEntryIdObj(entryid){
 
 	return eidObj;
 }
+
+function checkFieldsForKeycontrol(event)
+{
+	var returnValue = true;
+	var element = event.target;
+	if (inArray(element.tagName.toLowerCase(), new Array("input", "textarea"))) {
+		returnValue = (element.getAttribute("type") == "checkbox") ? true : false;
+	}
+	return returnValue;
+}
\ No newline at end of file
