@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -129,6 +131,18 @@ ViewController.prototype.initView = function(moduleID, view, element, events, da
 		case "multiusercalendarappointmentlist":
 			this.viewObject = new MultiUserCalendarAppointmentListView(moduleID, element, events, data);
 			break;
+		case "today":
+			this.viewObject = new TodayView(moduleID, element, events, data);
+			break;
+		case "todayAppointment":
+			this.viewObject = new TodayCalendarView(moduleID, element, events, data);
+			break;
+		case "todayTask":
+			this.viewObject = new TodayTaskView(moduleID, element, events, data);
+			break;
+		case "todayFolder":
+			this.viewObject = new TodayFolderView(moduleID, element, events, data);
+			break;
 								
 		case "email":
 			var preview = webclient.settings.get("global/previewpane", "right");
