@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -69,6 +71,7 @@ WebClient.prototype.init = function(base_url, modulePrefix, availableModules, se
 	this.base_url = base_url;
 	this.modulePrefix = modulePrefix;
 	this.dialogs = new Object();
+	this.dialogid = 1;
 
 	this.xmlrequest = new XMLRequest(modulePrefix);
 	this.dispatcher = new Dispatcher(availableModules);
@@ -106,6 +109,12 @@ WebClient.prototype.setUserInfo = function(username, fullname, entryid, emailadd
  */ 
 WebClient.prototype.startClient = function()
 {
+	var twarning = dhtml.getElementById("trial_warning");
+	if(twarning && typeof ZARAFA_TRIAL_EXPIRE_PERIOD != "undefined" && ZARAFA_TRIAL_EXPIRE_PERIOD){
+		twarning.style.display = "block";
+		twarning.innerHTML = "TRIAL LICENSE: Your trial period will expire in %s days.".sprintf(ZARAFA_TRIAL_EXPIRE_PERIOD);
+	}
+
 	// disable context menu
 	dhtml.addEvent(-1, document.body, "mousedown", eventBodyMouseDown);
 	dhtml.addEvent(-1, document.body, "mouseup", checkMenuState);
@@ -187,16 +196,43 @@ WebClient.prototype.startClient = function()
 	eventWebClientResize();
 	this.xmlrequest.sendRequest();
 	
+	/**
+	 * mailto handling
+	 * there are two ways for handling mailto links
+	 * 1) by using windows registry to handle mailto protocol - send unencoded data - ?action=mailto&to= ...
+	 * 2) by using firefox to register mailto protocol - send encoded data - ?action=mailto&url= ...
+	 * both method sends different data so we will have to handle it differently
+	 * if user wants to use any special character in subject or body then he has manually encode it in mailto url
+	 * otherwise it will not work properly
+	 */
 	// if action attributes exist then process according to action type
-	var action_url = window.location.search;
-	if(action_url.length > 0) {
+	var actionUrl = new String(window.location.search);
+	// check URL is fully encoded or just its data part is encoded
+	// we can't really tell the difference so we are using two different parameters for that
+	var urlIsDoubleEncoded = actionUrl.search(/\&url\=/i) != -1 ? true : false;
+
+	if(actionUrl.length > 0) {
+		if(urlIsDoubleEncoded) {
+			// decode URI before using it
+			actionUrl = decodeURIComponent(actionUrl);
+		}
+
 		// remove first '?' from the URL
-		action_url = action_url.replace("?", "");
+		actionUrl = actionUrl.replace("?", "");
 
 		// remove '?' in URL that is appended before 'subject' tag
-		action_url = action_url.replace("?", "&");
+		actionUrl = actionUrl.replace("?", "&");
 
-		this.handleURLAction(action_url);
+		this.handleURLAction(actionUrl);
+	}
+	
+	//check if user is set to out of office, then ask user on login, if user wants to set out of office off?
+	if(webclient.settings.get("outofoffice/set","false") == "true"){
+		if(confirm(_("Out of Office currently on. Would you like to turn it off?"))){
+			webclient.settings.set("outofoffice/set","false");
+			webclient.settings.set("outofoffice/subject","");
+			webclient.settings.set("outofoffice/message","");
+		}
 	}
 }
 
@@ -206,45 +242,47 @@ WebClient.prototype.startClient = function()
  *
  * @param string action arguments that are passed in URL
  */
-WebClient.prototype.handleURLAction = function (action_url)
+WebClient.prototype.handleURLAction = function (actionUrl)
 {
-	var keyValuePairs = dhtml.URLToObject(action_url);
+	var keyValuePairs = dhtml.URLToObject(actionUrl);
 
 	// check action type
 	if(typeof keyValuePairs == "object" && keyValuePairs["action"] == "mailto") {
-		if(typeof keyValuePairs["to"] != "undefined") {
+		// @TODO we can remove most of this code when we support , as email seperator ticket #5274
+
+		// if there are more then one email address in TO, CC or BCC field then 
+		// make it semicolon seperated instead of default comma seperated
+		if(typeof keyValuePairs["url"] != "undefined") {
+			// remove 'mailto:' tag from 'url' field
+			keyValuePairs["to"] = keyValuePairs["url"].replace("mailto:", "");
+			keyValuePairs["to"] = keyValuePairs["to"].replace(/,/g, "; ");
+			delete keyValuePairs["url"];
+		} else if(typeof keyValuePairs["to"] != "undefined") {
 			// remove 'mailto:' tag from 'to' field
 			keyValuePairs["to"] = keyValuePairs["to"].replace("mailto:", "");
-
-			// if there are more then one email address in 'to' field then 
-			// make it semicolon seperated instead of default comma seperated
-			keyValuePairs["to"] = keyValuePairs["to"].replace(/[,]/g, "; ");
+			keyValuePairs["to"] = keyValuePairs["to"].replace(/,/g, "; ");
 		}
 
 		// didn't find on internet anything about multiple CC & BCC fields
 		// in mailto links, although its handled here for precaution
 		if(typeof keyValuePairs["cc"] != "undefined") {
-			// if there are more then one email address in 'cc' field then 
-			// make it semicolon seperated instead of default comma seperated
-			keyValuePairs["cc"] = keyValuePairs["cc"].replace(/[,]/g, "; ");
+			keyValuePairs["cc"] = keyValuePairs["cc"].replace(/,/g, "; ");
 		}
 
 		if(typeof keyValuePairs["bcc"] != "undefined") {
-			// if there are more then one email address in 'bcc' field then 
-			// make it semicolon seperated instead of default comma seperated
-			keyValuePairs["bcc"] = keyValuePairs["bcc"].replace(/[,]/g, "; ");
+			keyValuePairs["bcc"] = keyValuePairs["bcc"].replace(/,/g, "; ");
 		}
 
-		var createmail_url = "";
+		var createmailUrl = "";
 		for(var key in keyValuePairs) {
 			if(key != "action") {
 				// action attribute is not needed in creating createmail dialog URL
-				createmail_url = createmail_url + "&" + key + "=" + keyValuePairs[key];
+				createmailUrl = createmailUrl + "&" + key + "=" + keyValuePairs[key];
 			}
 		}
 
 		// open createmail dialog
-		webclient.openWindow(this, "createmail", DIALOG_URL + "task=createmail_standard" + createmail_url);
+		webclient.openWindow(this, "createmail", DIALOG_URL + "task=createmail_standard" + createmailUrl);
 	}
 }
  
@@ -292,6 +330,9 @@ WebClient.prototype.loadModule = function(moduleName, title, position, data, LAY
 		
 		// Update elemens (resize)
 		this.layoutmanager.updateElements(position);
+		
+		// Keep trac of module that is loaded in opened folders
+    	webclient.moduleIdInOpenedFolder = moduleID;
 	}
 	
 	// Resize after loading module.
@@ -375,17 +416,20 @@ WebClient.prototype.addModule = function(module)
 WebClient.prototype.deleteModule = function(module)
 {
 	if(this.modules[this.modulePrefix + "_" + module.id]) {
-		this.modules[this.modulePrefix + "_" + module.id] = false;
-		// Delete module on server
-		this.xmlrequest.deleteModule(this.modulePrefix + "_" + module.id);
-		
 		if(module.destructor) {
 			// Destructor
 			module.destructor();
 		}
-		
 		// Delete element in layout manager
 		this.layoutmanager.deleteElement(module.id);
+		
+		/**
+		 * Since module.destructor also destroys view by calling view.destructor(), so 
+		 * making webclient.getModule(id) usefull in views.
+		 */
+		this.modules[this.modulePrefix + "_" + module.id] = false;
+		// Delete module on server
+		this.xmlrequest.deleteModule(this.modulePrefix + "_" + module.id);
 	}
 }
 
@@ -417,14 +461,15 @@ WebClient.prototype.openWindow = function(moduleObject, name, url, width, height
 		windowresizable = resizable?1:0;
 	}
 
-	name = name + "_" + (new Date().getTime());
-	while(this.dialogs[name]){
-		name += "1";
-	}
-	this.dialogs[name] = new Object();
-	this.dialogs[name]["module"] = moduleObject;
-	this.dialogs[name]["window"] = dialog(url, name, "toolbar=0,scrollbars=0,location=0,status=1,menubar=0,resizable=" + windowresizable + ",width=" + windowwidth + ",height=" + windowheight + ",top=" + ((screen.height / 2) - (windowheight / 2)) + ",left=" + ((screen.width / 2) - (windowwidth / 2)));
-	return this.dialogs[name]["window"];
+	// Make a unique name for the dialog
+	name = window.name + "_" + name + "_" + this.dialogid;
+	this.dialogid++;
+
+	var windowObj = dialog(url, name, "toolbar=0,scrollbars=0,location=0,status=1,menubar=0,resizable=" + windowresizable + ",width=" + windowwidth + ",height=" + windowheight + ",top=" + ((screen.height / 2) - (windowheight / 2)) + ",left=" + ((screen.width / 2) - (windowwidth / 2)));
+
+	this.registerDialog(moduleObject, name, windowObj);
+
+	return windowObj;
 }
 
 /**
@@ -439,18 +484,36 @@ WebClient.prototype.openModalDialog = function(moduleObject, name, url, width, h
 {
 	this.clearDialogs();
 
-	name = name + "_" + (new Date().getTime());
-	while(this.dialogs[name]){
-		name += "1";
-	}
+	// Make a unique name for the dialog
+	name = name + "_" + this.dialogid;
+	this.dialogid++;
+
+	var windowObj = modal(url, name, "toolbar=0,scrollbars=0,location=0,status=1,menubar=0,resizable=0,width=" + width + ",height=" + height + ",dialogWidth=" + width + " px,dialogHeight=" + (height + 50) + " px,top=" + ((screen.height / 2) - (height / 2)) + ",left=" + ((screen.width / 2) - (width / 2)), callback, callbackdata, windowdata);
+
+	this.registerDialog(moduleObject, name, windowObj);
+
+	return windowObj;
+}
+
+/**
+ * Registers the dialog to the webclient so it can be used to relay server responses to the modules 
+ * within the dialogs.
+ * @param Object moduleObj Module Object or Module ID
+ * @param String name The name of the dialog
+ * @param Object windowObj Window Object
+ * @return Object The object that contains the Module Object and the Window Object.
+ */
+WebClient.prototype.registerDialog = function(moduleObj, name, windowObj){
 	this.dialogs[name] = new Object();
-	this.dialogs[name]["module"] = moduleObject;
-	this.dialogs[name]["window"] = modal(url, name, "toolbar=0,scrollbars=0,location=0,status=1,menubar=0,resizable=0,width=" + width + ",height=" + height + ",dialogWidth=" + width + " px,dialogHeight=" + (height + 50) + " px,top=" + ((screen.height / 2) - (height / 2)) + ",left=" + ((screen.width / 2) - (width / 2)), callback, callbackdata, windowdata);
-	return this.dialogs[name]["window"];
+	this.dialogs[name]["module"] = moduleObj;
+	this.dialogs[name]["window"] = windowObj;
+	return this.dialogs[name];
 }
 
 WebClient.prototype.clearDialogs = function()
 {
+	var name;
+
 	for(name in webclient.dialogs){
 		try {
 			if (!webclient.dialogs[name].window || webclient.dialogs[name].window.name!=name){
@@ -481,6 +544,8 @@ WebClient.prototype.onHierarchyChangeFolder = function(storeid, folder)
 {
 	if (webclient.settings.get("global/startup/folder","inbox")=="last"){	
 		webclient.settings.set("global/startup/folder_lastopened",folder["entryid"]);
+	}else if (webclient.settings.get("global/startup/folder","inbox")=="today"){	
+		webclient.settings.set("global/startup/folder_lastopened", this.hierarchy.defaultstore.subtree_entryid);
 	}
 
 	if(!this.folderOpened) {
@@ -512,6 +577,7 @@ WebClient.prototype.openFolder = function(storeid, folder)
 
         moduleName = moduleName + "list";
         name = folder["display_name"];
+		if (typeof folder["userfullname"] != 'undefined' && folder["userfullname"].trim().length > 0) name = folder["userfullname"] +" - "+ folder["display_name"];
     } else {
         moduleName = "maillist";
         name = _("Inbox");
@@ -525,6 +591,7 @@ WebClient.prototype.openFolder = function(storeid, folder)
 		if (!webclient.datepicker){
 			webclient.datepicker = webclient.loadModule("datepickerlist", _("Date picker"), "left", data, BOX_LAYOUT, INSERT_ELEMENT_AT_TOP);
 		}
+		data['title'] = name;
 		webclient.datepicker.loadFolder(folder, data);
 	} else {
 		// this is not an appointment list, so remove (if exists) the datepicker
@@ -533,7 +600,13 @@ WebClient.prototype.openFolder = function(storeid, folder)
 			webclient.datepicker = null;
 			dragdrop.updateTargets("folder");
 		}
-		webclient.loadModule(moduleName, name, "main", data, BORDER_LAYOUT);
+		if (typeof(folder) != "undefined" && webclient.hierarchy.isDefaultStore(folder.storeid) && webclient.hierarchy.isRootFolder){
+			// open view when click on root folder(inbox-username).
+			moduleName = "todaymodule";
+			webclient.loadModule(moduleName, _("Today"), "main", data, BORDER_LAYOUT);
+		} else {
+			webclient.loadModule(moduleName, name, "main", data, BORDER_LAYOUT);
+		}
 	}
 }
 
@@ -590,9 +663,19 @@ function eventWebClientUnload()
 
 function eventBodyMouseDown(moduleObject, element, event)
 {
-    // For FF only
-    if(event.forceDefaultAction)
-        return true;
+	// explicitOriginalTarget is Mozilla-specific property.
+	if(event.explicitOriginalTarget)
+	{
+		var topleft = dhtml.getElementTopLeft(event.explicitOriginalTarget);
+
+		if(event.clientX-topleft[0] > event.explicitOriginalTarget.clientWidth || event.clientY-topleft[1] > event.explicitOriginalTarget.clientHeight) {
+			// Clicking outside viewable area -> must be a click in the scrollbar, allow default action.
+			return true;
+		}
+	}
+	// For FF only
+	if(event.forceDefaultAction)
+		return true;
 	return false;
 }
 
