@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -176,13 +178,20 @@ XMLBuilder.prototype.addNode = function(parent, childName, value, attributes)
 	var child = this.xmlDoc.createElement(childName);
 
 	if(typeof value != "undefined" && value !== false && value !== null) {
-		// Prevent the point in a float to be transformed into a comma when the 
-		// language/location settings of the OS says that they have to use a 
-		// comma in decimal numbers. Somehow in MSIE they think they need to 
-		// change it in the createTextNode method of the ActiveXObject Microsoft.XMLDOM.
-		if(typeof value == "number"){
+		/**
+		 * Prevent the point in a float to be transformed into a comma when the 
+		 * language/location settings of the OS says that they have to use a 
+		 * comma in decimal numbers. Somehow in MSIE they think they need to 
+		 * change it in the createTextNode method of the ActiveXObject Microsoft.XMLDOM.
+		 */
+		/**
+		 * Boolean values need different treatment in IE, convert boolean values to 
+		 * string and then pass in xml, otherwise IE converts true to -1 and false to blank string
+		 */
+		if(typeof value == "number" || typeof value == "boolean"){
 			value = String(value);
 		}
+
 		var textNode = this.xmlDoc.createTextNode(value);
 		child.appendChild(textNode);
 	}
