@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -156,12 +158,14 @@
 				} else if($attachCid) { // Check if attachCid isset
 					// Get the attachment table
 					$attachments = mapi_message_getattachmenttable($message);
-					$attachTable = mapi_table_queryallrows($attachments, Array(PR_ATTACH_NUM, PR_ATTACH_CONTENT_ID));
+					$attachTable = mapi_table_queryallrows($attachments, Array(PR_ATTACH_NUM, PR_ATTACH_CONTENT_ID, PR_ATTACH_CONTENT_LOCATION, PR_ATTACH_FILENAME));
 					
 					foreach($attachTable as $attachRow)
 					{
-						// Check if the CONTENT_ID is equal to attachCid
-						if(isset($attachRow[PR_ATTACH_CONTENT_ID]) && $attachRow[PR_ATTACH_CONTENT_ID] == $attachCid) {
+						// Check if the CONTENT_ID or CONTENT_LOCATION is equal to attachCid
+						if((isset($attachRow[PR_ATTACH_CONTENT_ID]) && $attachRow[PR_ATTACH_CONTENT_ID] == $attachCid)
+							|| (isset($attachRow[PR_ATTACH_CONTENT_LOCATION]) && $attachRow[PR_ATTACH_CONTENT_LOCATION] == $attachCid)
+							|| (isset($attachRow[PR_ATTACH_FILENAME]) && $attachRow[PR_ATTACH_FILENAME] == $attachCid)) {
 							// Open the attachment
 							$attachment = mapi_message_openattach($message, $attachRow[PR_ATTACH_NUM]);
 						}
@@ -187,27 +191,22 @@
 						$filename = $props[PR_DISPLAY_NAME];
 					} 
 			
-					// Set content type
-					if(isset($props[PR_ATTACH_MIME_TAG])) {
-						$contentType = $props[PR_ATTACH_MIME_TAG];
-					} else {
-						// Parse the extension of the filename to get the content type
-						if(strrpos($filename, ".") !== false) {
-							$extension = strtolower(substr($filename, strrpos($filename, ".")));
-							$contentType = "application/octet-stream";
-							if (is_readable("mimetypes.dat")){
-								$fh = fopen("mimetypes.dat","r");
-								$ext_found = false;
-								while (!feof($fh) && !$ext_found){
-									$line = fgets($fh);
-									preg_match("/(\.[a-z0-9]+)[ \t]+([^ \t\n\r]*)/i", $line, $result);
-									if ($extension == $result[1]){
-										$ext_found = true;
-										$contentType = $result[2];
-									}
+					// Parse the extension of the filename to get the content type
+					if(strrpos($filename, ".") !== false) {
+						$extension = strtolower(substr($filename, strrpos($filename, ".")));
+						$contentType = "application/octet-stream";
+						if (is_readable(MIME_TYPES)){
+							$fh = fopen(MIME_TYPES,"r");
+							$ext_found = false;
+							while (!feof($fh) && !$ext_found){
+								$line = fgets($fh);
+								preg_match("/(\.[a-z0-9]+)[ \t]+([^ \t\n\r]*)/i", $line, $result);
+								if ($extension == $result[1]){
+									$ext_found = true;
+									$contentType = $result[2];
 								}
-								fclose($fh);
 							}
+							fclose($fh);
 						}
 					}
 					
