@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -74,13 +76,35 @@ function getJavaScript_onload(){ ?>
 					data["dest"] = "<?=get("dest","anonymous", false, STRING_REGEX)?>";
 					data["type"] = "<?=get("type","fullemail", false, STRING_REGEX)?>";
 					data["source"] = "<?=get("source", "all", false, STRING_REGEX)?>"; // possible values: all, gab
-					data["groups"] = "<?=get("groups", "expand", false, STRING_REGEX)?>"; // possible values: expand, yes, no
+					data["showsendmail"] = "<?=get("showsendmail","false", false, STRING_REGEX)?>"; // Show button for sending mail in addressbook.
+
+					if(typeof window.windowData != "undefined") {
+						// for GAB & addresslists
+						data["hide_companies"] = window.windowData["hide_companies"] || false;		// true, false
+						data["hide_users"] = window.windowData["hide_users"] || false;				// active, non_active, room, equipment, contact, system
+						data["hide_groups"] = window.windowData["hide_groups"] || false;			// normal, security, dynamic, everyone
+					} else {
+						// for contacts folders
+						data["groups"] = "<?=get("groups", "yes", false, STRING_REGEX)?>";			// yes, no
+					}
+
+					// If dialog is opened from topmenubar of webaccess then show "New Message for Contact" button.
+					if (data["showsendmail"] == "true")
+						data["has_no_menu"] = true;
 
 					module.init(moduleID, dhtml.getElementById("items"), false, data);
 					module.setData(data);
 					module.retrieveHierarchy();
 
-					dhtml.addEvent(module.id, dhtml.getElementById("name"), "keypress", addressBookSearchKeyInput);
+					// Set module level GAB Pagination varialble whether it is available or not.
+					<? if(defined('ENABLE_GAB_ALPHABETBAR') && (ENABLE_GAB_ALPHABETBAR == true)) { ?>
+							module.enableGABPagination = true; 
+                    <? } else { ?>
+							module.enableGABPagination = false;
+					<? } ?>
+
+					dhtml.addEvent(module.id, dhtml.getElementById("name"), "keyup", addressBookSearchKeyInput);
+
 					// Put focus on search field
 					dhtml.getElementById("name").focus();
 
@@ -102,6 +126,10 @@ function getJavaScript_onload(){ ?>
 					echo "module.addEventHandler('openitem', false, onOpenItem);\n";
 ?>
 					getAddressBookRecipients(fields);
+
+					// If GAB pagination is set then show pagination.
+					if(module.enableGABPagination)
+						initPagination();
 <?php } // getJavaScript_onload						
 
 function getJavaScript_onresize(){ ?>
@@ -109,17 +137,34 @@ function getJavaScript_onresize(){ ?>
 
 		// Get all dialog elemnts to get their offsetHeight.
 		var titleElement = dhtml.getElementById("windowtitle");
-		var subTitleElement = dhtml.getElementById("subtitle");
+		var menubarTitleElement = dhtml.getElementById("menubar");
 		var searchElement = dhtml.getElementById("search");
 		var tableHeaderElement = dhtml.getElementById("columnbackground");
-		
+
+		// If GAB pagination is set then show alfabet bar column.
+		if(module.enableGABPagination) {
+			var addressbookElement = dhtml.getElementById("addressbook");
+			var alfabetbarElement = dhtml.getElementById("alfabet-bar");
+			addressbookElement.style.width = document.documentElement.offsetWidth - 40 + "px";
+			var availableSpace = document.documentElement.offsetHeight - alfabetbarElement.offsetHeight - titleElement.offsetHeight - menubarTitleElement.offsetHeight - 8;
+			var alfabetbarElementTop = 54;
+			
+			if (availableSpace > 0)
+				alfabetbarElementTop += availableSpace/2;
+
+			alfabetbarElementTop = (alfabetbarElementTop > 100) ? 100 : alfabetbarElementTop;
+
+			// Show alfabetbar column in middle of dialog.
+			alfabetbarElement.style.top = alfabetbarElementTop + "px";
+		}
+
 		var dialogContentElement = dhtml.getElementById("dialog_content");
 		//var toButtonElement = dhtml.getElementsByClassNameInElement(dialogContentElement, "button", "input");
 		var recipientsInputTableElement = dhtml.getElementById("recipientsinputtable");
 		var confirmButtonsElement = dhtml.getElementsByClassNameInElement(dialogContentElement, "confirmbuttons", "div");
 
 		// Count the height for table contents.
-		var tableContentElementHeight = document.documentElement.offsetHeight - titleElement.offsetHeight - subTitleElement.offsetHeight - searchElement.offsetHeight - tableHeaderElement.offsetHeight - confirmButtonsElement[0].offsetHeight - recipientsInputTableElement.offsetHeight - 60;
+		var tableContentElementHeight = document.documentElement.offsetHeight - titleElement.offsetHeight - menubarTitleElement.offsetHeight - searchElement.offsetHeight - tableHeaderElement.offsetHeight - confirmButtonsElement[0].offsetHeight - recipientsInputTableElement.offsetHeight - 60;
 		
 		if(tableContentElementHeight < 50)
 			tableContentElementHeight = 50;
@@ -130,6 +175,7 @@ function getJavaScript_onresize(){ ?>
 
 function getJavaScript_other(){ ?>
 	var fields;
+	var searchKeyInputTimer;
 	
 	
 <?php } // getJavaScript_other
@@ -143,9 +189,9 @@ function getBody(){ ?>
 				</tr>
 				<tr>
 					<td width="150">
-						<input id="name" class="fieldsize" type="text" value="" size="29">
+						<input id="name" class="fieldsize" type="text" value="" size="29" autocomplete="off">
 					</td>
-					<td width="200">
+					<td width="400">
 						<div class="searchbutton" onmouseover="this.className+=' searchbuttonover';" onmouseout="this.className='searchbutton';" onclick="searchAddressBook();">&nbsp;</div>
 					</td>
 					<td>
@@ -200,8 +246,20 @@ function getBody(){ ?>
 					}
 				?>
 			</table>
+			<div id="alfabet-bar" class="alfabet alfabet_bar"></div>
 			
 			<?=createConfirmButtons("addressBookSubmit();window.close();")?>
 		</div>
 <?php } // getBody
+
+function getMenuButtons(){
+	return array(
+			array(
+				'id'=>"newmessagecontact",
+				'name'=>'',
+				'title'=>_("New Message for Contact"),
+				'callback'=>'function(){eventABSendMailTo();}'
+			)
+		);
+} // getMenuButtons
 ?>
