@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -90,6 +92,7 @@ function getJavaScript_onload(){ ?>
 								var option = dhtml.addElement(filelist, "option");
 								option.value = attachment["attach_num"];
 								option.text = attachment["name"];
+								option.className = "attachmentsourcetype_default";
 							}
 						}
 
@@ -167,7 +170,7 @@ function getBody(){ ?>
 						</div>
 						<div class="attach_buttons">
 								<input id="delete" class="button_delete" type="button" value="<?=_("Delete")?>" title="<?=_("Delete selected file")?>" onclick="dhtml.getElementById('action').submit();" /><br/>
-								<input id="save" class="button_save" type="button" value="<?=_("Download")?>" title="<?=_("Download selected file")?>" onclick="location.href='index.php?load=download_attachment&store=<?=htmlentities($_GET["store"])?>&entryid=<?=htmlentities($_GET["entryid"])?>&attachNum[]=' + dhtml.getElementById('filelist').options[dhtml.getElementById('filelist').selectedIndex].value + '&openType=attachment&dialog_attachments=<?=htmlentities($_REQUEST["dialog_attachments"])?>'" />
+								<input id="save" class="button_save" type="button" value="<?=_("Download")?>" title="<?=_("Download selected file")?>" onclick="location.href='index.php?load=download_attachment&store=<?=htmlentities(get("store", false, false, ID_REGEX))?>&entryid=<?=htmlentities(get("entryid", false, false, ID_REGEX))?>&attachNum[]=' + dhtml.getElementById('filelist').options[dhtml.getElementById('filelist').selectedIndex].value + '&openType=attachment&dialog_attachments=<?=htmlentities($_REQUEST["dialog_attachments"])?>'" />
 								<input type="hidden" name="dialog_attachments" value="<?=$_REQUEST["dialog_attachments"]?>" />
 								<input id="deleteattachment" type="hidden" name="deleteattachment" value="" />
 								<input id="type" type="hidden" name="type" value="" />
