@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -77,7 +79,7 @@ function getJavaScript_onload(){ ?>
 						dialogname = window.dialogArguments.dialogName;
 					}
 
-					parentModule = parentWebclient.dialogs[dialogname]["module"];
+					parentModule = windowData.parentModule;
 
 					module.selectFolder("<?=get("parent_entryid", "none", false, ID_REGEX)?>");
 
