@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -80,6 +82,10 @@ function getJavaScript_onload(){ ?>
 
 					// Get recurrence info from parent window
 					var recurrence = window.opener.module.getRecurrence();
+
+					// enable remove recurrence button if recurrence is set.
+					if(recurrence && recurrence.recurring)
+						dhtml.getElementById("remove_recurrence").disabled = false;
 					
 					if(recurrence && recurrence.type) {
 						showRecurrence(recurrence, this);
@@ -300,7 +306,7 @@ function getBody(){ ?>
 	<div class="dialog_buttons">
 		<input type="button" style="width: 80px" value="<?=_("OK")?>" onClick="submitRecurrence(window);">
 		<input type="button" style="width: 80px" value="<?=_("Cancel")?>" onClick="window.close();">
-		<input type="button" value="<?=_("Remove Recurrence")?>" onClick="window.opener.module.setRecurrence();window.close();">
+		<input id="remove_recurrence" disabled="true" type="button" value="<?=_("Remove Recurrence")?>" onClick="window.opener.module.setRecurrence();window.close();">
 	</div>
 </div>
 <?php } // getBody
