@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -65,7 +67,13 @@ function getJavaScript_onload(){ ?>
 					for(var i=0;i<names.length;i++){
 						var fullname = names[i]["fullname"];
 						var email = names[i]["emailaddress"];
-						var optionElement = dhtml.addElement(resolveList,"option","","",fullname+" <"+email+">");
+						if(names[i].objecttype == MAPI_DISTLIST || names[i].message_class == "IPM.DistList"){
+							fullname = "[" + fullname + "]";
+						}else{
+							fullname +=" <"+email+">";
+						}
+						var optionElement = dhtml.addElement(resolveList,"option","","",fullname);
+						
 						optionElement.value = i;
 					}
 <?php } // getJavaScript_onload						
