@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -54,13 +56,53 @@ function getDialogTitle() {
 	return _("Send Meeting Request Mail Confirmation");
 }
 
+function getIncludes(){
+	return array(
+			"client/layout/css/sendMRMailConfirmation.css"
+	);
+}
+
+function getJavaScript_other(){ ?>
+	function editResponse(){
+		var body = dhtml.getElementById("body");
+		if(dhtml.getElementById('editResponse').checked){
+			body.removeAttribute("disabled");
+		}else{
+			body.setAttribute("disabled","disabled");
+		}
+	}
+
+	function sendMRMailConfirmation(){
+		if(dhtml.getElementById('editResponse').checked){
+			var response = new Object;
+			response.body = dhtml.getElementById('body').value;
+			response.type = false;
+			window.resultCallBack(response, window.callBackData);
+		}else{
+			window.resultCallBack(dhtml.getElementById('noResponse').checked, window.callBackData);
+		}
+	}
+<?}
+
 function getBody(){ ?>
 		<div id="sendMRMailConfirmation">
-				
-				<input type="radio" name="action" id="sendResponse"/><label for="sendResponse" checked><?=_("Send a response")?></label><br />
-				<input type="radio" name="action" id="noResponse"/><label for="noResponse"><?=_("Don't send a response")?></label>
+			<div>
+				<input type="radio" name="action" id="editResponse" onclick ="editResponse()" />
+				<label for="editResponse"><?=_("Edit a response before Sending")?></label>
+				<div id="responseBody">
+					<label for="body"><?=_("Type Response Message").":"?></label><br/>
+					<textarea cols=20 rows=5 name="body" id="body" disabled></textarea>
+				</div>
+			</div>
+			<div>
+				<input type="radio" name="action" id="sendResponse" onclick ="editResponse()" checked/>
+				<label for="sendResponse"><?=_("Send a response")?></label>
+			</div>
+			<div>
+				<input type="radio" name="action" id="noResponse" onclick ="editResponse()"/>
+				<label for="noResponse"><?=_("Don't send a response")?></label>
+			</div>
 		</div>
-		
-		<?=createConfirmButtons("window.resultCallBack(dhtml.getElementById('noResponse').checked, window.callBackData);window.close();")?>
+		<?=createConfirmButtons("sendMRMailConfirmation(); window.close();")?>
 <?php } // getBody
 ?>
