@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -61,7 +63,7 @@ function getIncludes(){
 }
 
 function getJavaScript_onload(){ ?>
-		dhtml.getElementById("sharetype_store").checked = true;
+		initSharedFolder();
 		dhtml.getElementById("username").focus();
 <?php } // getJavaScript_onload
 
@@ -72,24 +74,16 @@ function getBody(){ ?>
 					<th><input type="button" value="<?=_("Name")?>..." onclick="openSelectUserDialog(<?=get("storeid","",true, ID_REGEX)?>);"></th>
 					<td><input type="text" value="" id="username"></td>
 				</tr>
+				<tr>
+					<th><legend><?=_("Folder type")?></legend></th>
+					<td><select id="foldertype"></select></td>
+				</tr>
 				<tr>
 					<td colspan="2">
-						<fieldset>
-							<legend><?=_("Folder type")?></legend>
-							<ul>
-								<li><input type="radio" name="sharetype" id="sharetype_store" value="store"><label for="sharetype_store"><?=_("All folders")?></label></li>
-								<li>
-									<input type="radio" name="sharetype" id="sharetype_folder" value="folder">
-									<select id="foldertype" onclick="dhtml.getElementById('sharetype_folder').checked=true;" onchange="dhtml.getElementById('sharetype_folder').checked=true;">
-										<option value="calendar"><?=_("Calendar")?></option>
-										<option value="contact"><?=_("Contacts")?></option>
-										<option value="note"><?=_("Notes")?></option>
-										<option value="inbox"><?=_("Inbox")?></option>
-										<option value="task"><?=_("Tasks")?></option>
-									</select>
-								</li>
-							</ul>
-						</fieldset>
+						<input type="checkbox" id="subfolders_checkbox"></input>
+						<label id="subfolders_label" for="subfolders_checkbox">
+							<?=("Show subfolders")?>
+						</label>
 					</td>
 				</tr>
 			</table>
