@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -87,13 +89,25 @@ function calendar_settings_html(){ ?>
 			<tr>
 				<th><label for="calendar_size"><?=_("Vertical size")?></label></th>
 				<td>
-					<select id="calendar_size">
+					<select id="calendar_size" onchange="calendar_checkcalendarcellsize()">
 						<option value="1"><?=_("Small")?></option>
 						<option value="2"><?=_("Medium")?></option>
 						<option value="3"><?=_("Large")?></option>
 					</select>
 				</td>
 			</tr>
+			<tr>
+				<th><label for="calendar_appointment_size"><?=_("Calendar resolution")?></label></th>
+				<td>
+					<select id="calendar_appointment_size" onchange="calendar_checkcalendarcellsize()">
+						<option value="12"><?=_("5 Minutes")?></option>
+						<option value="6"><?=_("10 Minutes")?></option>
+						<option value="4"><?=_("15 Minutes")?></option>
+						<option value="2"><?=_("30 Minutes")?></option>
+						<option value="1"><?=_("1 Hour")?></option>
+					</select>
+				</td>
+			</tr>
 
 			<tr>
 				<th><input id="calendar_reminder" type="checkbox" class="checkbox"onclick="calendar_checkremindersetting(this)"><label for="calendar_reminder"><?=_("Default Reminder:")?></label></th>
