@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -120,7 +122,10 @@ function preferences_loadSettings(settings){
 	}
 	field.checked = true;
 
-
+	// advanced find refresh frequency
+	value = settings.get("advancedfind/refresh_time", 0);
+	field = dhtml.getElementById("preferences_refresh_searchresults");
+	field.value = value;
 }
 function preferences_saveSettings(settings){
 	var field;
@@ -129,6 +134,10 @@ function preferences_saveSettings(settings){
 	// startup folder
 	field = dhtml.getElementById("preferences_startupfolder");
 	settings.set("global/startup/folder",field.value);
+
+	if (settings.get("global/startup/folder","inbox")=="today"){	
+		settings.set("global/startup/folder_lastopened", parentWebclient.hierarchy.defaultstore.subtree_entryid);
+	}
 	
 	// row count
 	field = dhtml.getElementById("preferences_rowcount");
@@ -192,4 +201,7 @@ function preferences_saveSettings(settings){
 		}
 	}
 
+	// advanced find refresh results
+	field = dhtml.getElementById("preferences_refresh_searchresults");
+	settings.set("advancedfind/refresh_time", field.value);
 }
