@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -109,6 +111,7 @@ function preferences_settings_html(){ ?>
 				<td>
 					<select id="preferences_startupfolder">
 						<option value="inbox"><?=_("Inbox")?></option>
+						<option value="today"><?=_("Today view")?></option>
 						<option value="last"><?=_("Last opened folder")?></option>
 					</select>
 				</td>
@@ -176,7 +179,29 @@ function preferences_settings_html(){ ?>
 			</tr>
 		</table>
 	</fieldset>
-	
+	<fieldset>
+		<legend><?=_("Delegates")?></legend>
+		<table class="options">
+			<tr>
+				<th colspan="2">
+					<input type="button" onclick="webclient.openModalDialog(-1, 'delegates', DIALOG_URL+'&task=delegates_modal', 485, 374);" value="<?=_('Edit delegates')?>..." class="inline_button"/>
+				</th>
+			</tr>
+		</table>
+	</fieldset>
+	<fieldset>
+		<legend><?=_("Advanced Find")?></legend>
+		<table class="options">
+			<tr>
+				<th>
+					<label for="preferences_refresh_searchresults"><?=_("Results refresh every (X) seconds [0: disabled]")?></label>
+				</th>
+				<td>
+					<input id="preferences_refresh_searchresults" type="text" class="text">
+				</td>
+			</tr>
+		</table>
+	</fieldset>
 <?php } 
 
 function preferences_get_themes(){
