@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -140,7 +142,9 @@ function getJavaScript_onload(){
 					if(entryid) {
 						module.open(entryid, entryid, <?=(isset($_GET["basedate"]))?('new Array(\'' . intval(get("basedate", false, false, TIMESTAMP_REGEX)) .'\')') :"false"?>);
 					} else {
-						initDate(<?=isset($_GET["date"]) ? "new Date(".intval(get("date", false, false, TIMESTAMP_REGEX))."*1000)":""?>);
+						var startDateTime = <?=isset($_GET["startdate"]) ? "new Date(".intval(get("startdate", false, false, TIMESTAMP_REGEX))."*1000)":"''"?>; 
+						var endDateTime = <?=isset($_GET["enddate"]) ? "new Date(".intval(get("enddate", false, false, TIMESTAMP_REGEX))."*1000)":"''"?>; 
+						initDate(startDateTime, endDateTime);
 						webclient.menu.showMenu();
 					}
 															
@@ -166,6 +170,10 @@ function getJavaScript_onload(){
 					dhtml.addEvent(false, dhtml.getElementById("location"), "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(false, dhtml.getElementById("html_body"), "contextmenu", forceDefaultActionEvent);
 
+					if (window.location.search.indexOf("allDayEvent=true")>0){
+						onChangeAllDayEvent(true);
+					}
+
 					//checks for default reminder setting  
 					if(parentWebclient.settings.get("calendar/reminder","true") == 'true' && !entryid){
 						
@@ -186,7 +194,7 @@ function getJavaScript_onload(){
 						var suggestEmailModuleID = webclient.addModule(suggestEmailModule);
 						suggestEmailModule.init(suggestEmailModuleID);
 						// Setup TO field
-						suggestlistTO = new suggestionList("meetingrequest_to_fld", dhtml.getElementById("toccbcc"), suggestEmailModule);
+						suggestlistTO = new suggestionList("meetingrequest_to_fld", dhtml.getElementById("toccbcc"), suggestEmailModule, suggestionListCallBackAppointment);
 						suggestEmailModule.addSuggestionList(suggestlistTO);
 					}
 
@@ -271,7 +279,7 @@ function getBody() {
 			<table width="100%" border="0" cellpadding="1" cellspacing="0">
 				<tr>
 					<td class="propertynormal propertywidth">
-						<input type="button" class="button" value="<?=_("To")?>:" onclick="webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&dest=to&fields[to]=<?=urlencode(_("To"))?>&storeid='+module.storeid, 550, 410, abCallBackRecipients);">
+						<input type="button" class="button" value="<?=_("To")?>:" onclick="webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&dest=to&fields[to]=<?=urlencode(_("To"))?>&storeid='+module.storeid, 800, 500, abCallBackRecipients);">
 					</td>
 					<td>
 						<input id="toccbcc" name="recipient" class="field" type="text" onchange="syncRecipientFields();">
@@ -422,10 +430,10 @@ function getBody() {
 		<textarea id="html_body" cols="60" rows="12"></textarea>
 		
 		<div id="categoriesbar">
-			<table width="100%" border="0" cellpadding="2" cellspacing="0">
+			<table width="100%" border="0" cellpadding="2" cellspacing="0" style="table-layout: fixed;">
 				<tr>
 					<td class="propertynormal propertywidth">
-						<input class="button" type="button" value="<?=_("Contacts")?>:" onclick="webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&dest=contacts&fields[contacts]=<?=urlencode(_("Contacts"))?>&storeid='+module.storeid, 550, 410, abCallBackContacts);">
+						<input class="button" type="button" value="<?=_("Contacts")?>:" onclick="webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&dest=contacts&fields[contacts]=<?=urlencode(_("Contacts"))?>&storeid='+module.storeid, 800, 500, abCallBackContacts);">
 					</td>
 					<td>
 						<input id="contacts" class="field" type="text">
@@ -436,10 +444,10 @@ function getBody() {
 					<td>
 						<input id="categories" class="field" type="text">
 					</td>
-					<td width="20" nowrap>
+					<td width="30" nowrap>
 						<label for="checkbox_private"><?=_("Private")?></label>
 					</td>
-					<td width="10">
+					<td width="16">
 						<input id="checkbox_private" type="checkbox">
 					</td>
 				</tr>
@@ -600,7 +608,7 @@ function getMenuButtons(){
 				'id'=>"delete",
 				'name'=>"",
 				'title'=>_("Delete"),
-				'callback'=>"function(){deleteAppointment(false);}"
+				'callback'=>"deleteAppointment"
 			)
 		);
 }
