@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -341,7 +343,7 @@ function getBody() {
 					</tr>
 					<tr>
 						<td class="propertynormal propertywidth" valign="top">
-							<input id="checkbox_mailing_address" type="checkbox" onclick="onChangeMailingAddress();">
+							<input id="checkbox_mailing_address" type="checkbox" onchange="onChangeMailingAddress(this);">
 							<label for="checkbox_mailing_address"><?=_("Use this address for mailing")?>.</label>
 						</td>
 					</tr>
@@ -428,10 +430,10 @@ function getBody() {
 		</div>
 		
 		<div id="categoriesbar">
-			<table width="100%" border="0" cellpadding="2" cellspacing="0">
+			<table width="100%" border="0" cellpadding="2" cellspacing="0" style="table-layout: fixed;">
 				<tr>
 					<td class="propertynormal propertywidth">
-						<input class="button" type="button" value="<?=_("Contacts")?>:" onclick="webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&dest=contacts&fields[contacts]=<?=urlencode(_("Contacts"))?>&storeid='+module.storeid, 550, 410, abCallBack);">
+						<input class="button" type="button" value="<?=_("Contacts")?>:" onclick="webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&dest=contacts&fields[contacts]=<?=urlencode(_("Contacts"))?>&storeid='+module.storeid, 800, 500, abCallBack);">
 					</td>
 					<td>
 						<input id="contacts" class="field" type="text">
@@ -442,10 +444,10 @@ function getBody() {
 					<td>
 						<input id="categories" class="field" type="text">
 					</td>
-					<td width="20" nowrap>
+					<td width="30" nowrap>
 						<label for="checkbox_private"><?=_("Private")?></label>
 					</td>
-					<td width="10">
+					<td width="16">
 						<input id="checkbox_private" type="checkbox">
 					</td>
 				</tr>
