@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -80,6 +82,7 @@ function getJavaScript_onload(){ ?>
 					window.waitForSaveResponse = false;
 					var rootentryid = false;
 					var attachNum = false;
+
 					var data = new Object();
 					data["storeid"] = <?=get("storeid", "false", "'", ID_REGEX)?>;
 					data["parententryid"] = <?=get("parententryid","false", "'", ID_REGEX)?>;
@@ -165,7 +168,7 @@ function getJavaScript_onload(){ ?>
 					}
 
 					if (parentWebclient.settings.get("createmail/always_readreceipt", "false")=="true"){
-						dhtml.getElementById("read_receipt_requested").value = "1";
+						dhtml.getElementById("read_receipt_requested").value = "true";
 						dhtml.addClassName(dhtml.getElementById('read_receipt_button'), "menubuttonselected");
 					}
 
@@ -320,17 +323,29 @@ function getJavaScript_other(){
 
 				/**
 				 * Note: In IE, 'OnSelectionChange' event does not fire on every keystroke,
-				 * but only on some random keystrokes.So, add keydown and mousedown event to trac selection in editor.
+				 * but only on some random keystrokes.So add keydown and mousedown event to trac selection in editor.
+				 *
+				 * Also added few events for handling shortcuts in FCKeditor. DHTML version could be used by that doesnt
+				 * work so adding events using attachEvent/addEventListener.
 				 */
 				if (window.BROWSER_IE) {
 					editorInstance.EditorDocument.attachEvent("onkeydown", IE_tracCursorInEditor);
 					editorInstance.EditorDocument.attachEvent("onmousedown", IE_tracCursorInEditor);
+
 					// Blur event in fckEditor creates problem in IE6 and IE8
 					if (!window.BROWSER_IE8 && !window.BROWSER_IE6)
 						editorInstance.EditorWindow.attachEvent("onblur", IE_tracCursorInEditor);
 
 					// Save initial selection in editor.
 					IE_tracCursorInEditor();
+
+					// Events for shortcuts
+					editorInstance.EditorDocument.attachEvent("onkeyup", handleFCKeditorEvent);
+					editorInstance.EditorDocument.attachEvent("onkeydown", handleFCKeditorEvent);
+				} else {
+					// Events for shortcuts
+					editorInstance.EditorDocument.addEventListener("keydown", handleFCKeditorEvent, true);
+					editorInstance.EditorDocument.addEventListener("keyup", handleFCKeditorEvent, true);
 				}
 			}
 			
@@ -346,7 +361,30 @@ function getJavaScript_other(){
 				dhtml.getElementById(abSelection).select();
 				dhtml.getElementById(abSelection).focus();
 			}
+			
+			function handleFCKeditorEvent(event)
+			{
+				/**
+				 * As DHTML version is not working properly in attaching and catching events in FCKeditor,
+				 * key events are registered using browser defaults, so we also need to handle global event object here.
+				 */
+				event = (event?event:(window.event?fixEvent(window.event):((this.windowObj&&this.windowObj.event)?fixEvent(this.windowObj.event):false)));
 
+				// Set event target
+				if (typeof event.target == "undefined"){
+					event.target = event.srcElement;
+				}
+
+				switch(event.type)
+				{
+					case "keyup":
+						eventInputManagerKeyControlKeyUp(webclient.inputmanager, event.target, event);
+						break;
+					case "keydown":
+						eventInputManagerKeyControlKeyDown(webclient.inputmanager, event.target, event);
+						break;
+				}
+			}
 <?php 
 }
 
@@ -391,7 +429,7 @@ function getBody(){
 				?>
 					<tr>
 						<td class="propertynormal propertywidth" align="center">
-							<input class="button" type="button" value="<?=$recipient?>..." onclick="abSelection='<?=$key?>'; webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&storeid=' + module.storeid + '&<?=$fields?>dest=<?=$key?>', 550, 410, abCallBack);">
+							<input class="button" type="button" value="<?=$recipient?>..." onclick="abSelection='<?=$key?>'; webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&storeid=' + module.storeid + '&<?=$fields?>dest=<?=$key?>', 800, 500, abCallBack);">
 						</td>
 						<td>
 							<input id="<?=$key?>" class="field" type="text">
