@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -246,19 +248,19 @@ function getMenuButtons(){
 				'id'=>"accept",
 				'name'=>_("Accept"),
 				'title'=>_("Accept"),
-				'callback'=>"function(){window.module.acceptMeetingRequest();window.close();}"
+				'callback'=>"function(){webclient.openModalDialog(module, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, sendMRMailConfirmationCallback, 'accept');}"
 			),
 			array(
 				'id'=>"tentative",
 				'name'=>_("Tentative"),
 				'title'=>_("Tentative"),
-				'callback'=>"function(){window.module.tentativeMeetingRequest();window.close();}"
+				'callback'=>"function(){webclient.openModalDialog(module, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, sendMRMailConfirmationCallback, 'tentative');}"
 			),
 			array(
 				'id'=>"decline",
 				'name'=>_("Decline"),
 				'title'=>_("Decline"),
-				'callback'=>"function(){window.module.declineMeetingRequest();window.close();}"
+				'callback'=>"function(){webclient.openModalDialog(module, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, sendMRMailConfirmationCallback, 'decline');}"
 			),
 			array(
 				'id'=>"proposenewtime",
@@ -336,7 +338,7 @@ function getMenuButtons(){
 				'id'=>"flag_status_red",
 				'name'=>"",
 				'title'=>_("Flag"),
-				'callback'=>"function(){webclient.openModalDialog(module, 'flag', DIALOG_URL+'task=flag_modal', 350, 180);}"
+				'callback'=>"function(){webclient.openModalDialog(module, 'flag', DIALOG_URL+'task=flag_modal', 350, 210);}"
 			),
 			array(
 				'id'=>"seperator",
