@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -84,12 +86,20 @@ function getJavaScript_onload(){ ?>
 	module.list();
 	webclient.xmlrequest.sendRequest();
 	
+	//added event handler for radio buttons
+	dhtml.addEvent(module, dhtml.getElementById("message"), "click", loadRecoverableData);
+	dhtml.addEvent(module, dhtml.getElementById("folder"), "click", loadRecoverableData);
+	
 <?php } // getJavaSctipt_onload
 function getJavaScript_other(){ ?>
 	var tableWidget;
 <?php }
 
 function getBody(){ ?>
+	<div class="restore_option_button ">
+		<input  name="recover_options" type="radio" id="message" value="list" checked ><label for="message"><?=_("Message")?></label>
+		<input  name="recover_options" type="radio" id="folder" value="folderlist"><label for="folder"><?=_("Folder")?></label>
+	</div>
 	<input id="entryid" type="hidden">
 	<input id="parent_entryid" type="hidden">
 	<div id="conflict"></div>
