@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -220,6 +222,7 @@
 
 					webclient = new WebClient();
 					webclient.inputmanager = new InputManager();
+					webclient.inputmanager.initKeyControl();
 					webclient.setUserInfo(parentWebclient.username, parentWebclient.fullname, parentWebclient.userEntryid, parentWebclient.emailaddress );
 					webclient.init(parentWebclient.base_url, (window.name)?window.name:"dialog",  Array("suggestEmailAddressModule.js"), null, plugindata);
 
@@ -292,6 +295,15 @@
 				data["plugin"] = <?=(($plugin)?'"'.$plugin.'"':"false")?>;
 				webclient.pluginManager.triggerHook("client.dialog.general.onresize.before", data);
 			}
+
+			window.onbeforeunload = function()
+			{
+<?php
+			if(function_exists("getJavaScript_onbeforeunload")) {
+				echo getJavaScript_onbeforeunload();
+			}
+?>
+			}
 <?php
 
 	if (function_exists("getJavaScript_other")){
