@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -243,6 +245,7 @@ function initAppointment()
 	}
 
 	resizeFreeBusyContainer();
+	
 }
 
 function resizeFreeBusyContainer(){
@@ -362,20 +365,25 @@ function syncRecipientFields(newRecipsInFields){
 
 	// Set fields
 	
-	fields.visible.value = recips.visible.join("; ") + "; ";
-	fields.to.value      = recips.to.join("; ") + "; ";
-	fields.cc.value      = recips.cc.join("; ") + "; ";
-	fields.bcc.value     = recips.bcc.join("; ") + "; ";
+	fields.visible.value = recips.visible.length == 0? "" :recips.visible.join("; ") + "; " ;
+	fields.to.value      = recips.to.length == 0? "" :recips.to.join("; ") + "; ";
+	fields.cc.value      = recips.cc.length == 0? "" :recips.cc.join("; ") + "; ";
+	fields.bcc.value     = recips.bcc.length == 0? "" :recips.bcc.join("; ") + "; ";
 }
 
 
-function initDate(date)
+function initDate(startdate, enddate)
 {
-	if (!date){
-		date = new Date(new Date().ceilHalfhour());
+	var additionalDefaultSeconds = 0;
+	if (!startdate){
+		startdate = new Date(new Date().ceilHalfhour());
 	}
-	appoint_dtp.setStartValue(date.getTime()/1000);
-	appoint_dtp.setEndValue((date.getTime()/1000)+1800);
+	if (!enddate){
+		additionalDefaultSeconds = 1800;
+		enddate = new Date(new Date().ceilHalfhour());
+	}
+	appoint_dtp.setStartValue(startdate.getTime()/1000);
+	appoint_dtp.setEndValue((enddate.getTime()/1000)+additionalDefaultSeconds);
 }
 
 function submitAppointment(send, requestStatus)
@@ -421,16 +429,22 @@ function submitAppointment(send, requestStatus)
 	if(alldayeventset) {
 		dhtml.getElementById("alldayevent").value = "1";
 
+		var startdate = new Date(appoint_dtp.getStartValue()*1000);
+		var enddate = new Date(appoint_dtp.getEndValue()*1000);
+		enddate.addDays(1);
+
 		// Startdate
-		dhtml.getElementById("startdate").value = appoint_dtp.getStartValue();
-		dhtml.getElementById("commonstart").value = appoint_dtp.getStartValue();
+		dhtml.getElementById("startdate").value = startdate.getTime() / 1000;
+		dhtml.getElementById("commonstart").value = startdate.getTime() / 1000;
 		
 		// Duedate
-		dhtml.getElementById("duedate").value = appoint_dtp.getEndValue()+86400;
-		dhtml.getElementById("commonend").value = appoint_dtp.getEndValue()+86400;
+		dhtml.getElementById("duedate").value = enddate.getTime() / 1000;
+		dhtml.getElementById("commonend").value = enddate.getTime() / 1000;
 		
-		// Duration
-		dhtml.getElementById("duration").value = ((appoint_dtp.getEndValue()+86400) - appoint_dtp.getStartValue())/60;
+		// Duration. Apparently this should be the intended duration, which may be longer or shorter than
+		// the actual duration due to DST changes. It is therefore always a multiple of 1440.
+		var days = Math.ceil( (enddate.getTime() - startdate.getTime()) / (1000 * 60 * 60 * 24));
+		dhtml.getElementById("duration").value = 1440 * days;
 	} else {
 		dhtml.getElementById("alldayevent").value = "-1";
 	}
@@ -481,46 +495,55 @@ function submitAppointment(send, requestStatus)
 
 	}
 
-	if(module && validateEmailAddress(dhtml.getElementById("to").value)){
+	if(module){
 		var props = getPropsFromDialog();
-		var recipients = new Object();
-		recipients["recipient"] = createCompatibleRecipientList(getRecipients());
 
-		/**
-		 * Add the proposednewtimes of the existing recipients to the current recipients.
-		 */
-		if(typeof module.itemProps.recipients != "undefined" && typeof module.itemProps.recipients.recipient != "undefined"){
-			var oldRecips = module.itemProps.recipients.recipient;	// Recipients as stored in the module
-			if(typeof oldRecips != "undefined" && oldRecips.length > 0){
-				for(var i=0;i<recipients["recipient"].length;i++){
-					if(recipients["recipient"][i]["address"]){
-						for(var j=0;j<oldRecips.length;j++){
-							if(oldRecips[j]["email_address"] == recipients["recipient"][i]["address"]){
-								if(parseInt(oldRecips[j]["proposednewtime"], 10) == 1){
-									recipients["recipient"][i]["proposednewtime"] = oldRecips[j]["proposednewtime"]
-									recipients["recipient"][i]["proposenewstarttime"] = oldRecips[j]["proposenewstarttime"]
-									recipients["recipient"][i]["proposenewendtime"] = oldRecips[j]["proposenewendtime"]
-									break;
+		if(module.isMeeting && validateEmailAddress(dhtml.getElementById("toccbcc").value)){
+			dhtml.getElementById("meeting").value = "1";
+			if(!module.itemProps.entryid || (module.itemProps.responsestatus && module.itemProps.responsestatus==1))
+				dhtml.getElementById("responsestatus").value = "1";
+		
+			var recipients = new Object();
+			recipients["recipient"] = createCompatibleRecipientList(getRecipients());
+
+			/**
+			 * Add the proposednewtimes of the existing recipients to the current recipients.
+			 */
+			if(typeof module.itemProps.recipients != "undefined" && typeof module.itemProps.recipients.recipient != "undefined"){
+				var oldRecips = module.itemProps.recipients.recipient;	// Recipients as stored in the module
+				if(typeof oldRecips != "undefined" && oldRecips.length > 0){
+					for(var i=0;i<recipients["recipient"].length;i++){
+						if(recipients["recipient"][i]["address"]){
+							for(var j=0;j<oldRecips.length;j++){
+								if(oldRecips[j]["email_address"] == recipients["recipient"][i]["address"]){
+									if(parseInt(oldRecips[j]["proposednewtime"], 10) == 1){
+										recipients["recipient"][i]["proposednewtime"] = oldRecips[j]["proposednewtime"]
+										recipients["recipient"][i]["proposenewstarttime"] = oldRecips[j]["proposenewstarttime"]
+										recipients["recipient"][i]["proposenewendtime"] = oldRecips[j]["proposenewendtime"]
+										break;
+									}
 								}
 							}
 						}
 					}
 				}
 			}
-		}
-		
-		module.save(props, send, recipients, dhtml.getElementById("dialog_attachments").value);
-		module.saving = true;
+			module.save(props, send, recipients, dhtml.getElementById("dialog_attachments").value);
+			module.saving = true;
 
-		/**
-		 * If changes are to be saved for accepting/tentatively
-		 * meeting request, then send response.
-		 * Ask for confirmation to user of sending response to organizer.
-		 */
-		if (requestStatus) {
-			module.savingMeetingRequest = true;
-			// Open send Metting Request Mail Confirmation dialog box.
-			webclient.openModalDialog(module, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 160, sendMRMailConfirmationCallback, requestStatus);
+			/**
+			 * If changes are to be saved for accepting/tentatively
+			 * meeting request, then send response.
+			 * Ask for confirmation to user of sending response to organizer.
+			 */
+			if (requestStatus) {
+				module.savingMeetingRequest = true;
+				// Open send Metting Request Mail Confirmation dialog box.
+				webclient.openModalDialog(module, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, sendMRMailConfirmationCallback, requestStatus);
+			}
+		}else if(!module.isMeeting){
+			module.save(props, send, false, dhtml.getElementById("dialog_attachments").value);
+			module.saving = true;
 		}
 	}
 }
@@ -534,19 +557,25 @@ function sendMRMailConfirmationCallback(noResponse, requestStatus)
 {
 	var basedateEle = dhtml.getElementById("basedate");
 	var basedate = false;
+	var body = false;
 	if(basedateEle && basedateEle.value)
 		basedate = basedateEle.value;
+	
+	if(typeof noResponse == "object"){
+		body = noResponse.body;
+		noResponse = noResponse.type;
+	}
 
 	switch(requestStatus)
 	{
 		case "accept":
-			module.acceptMeetingRequest(noResponse, basedate);
+			module.acceptMeetingRequest(noResponse, basedate, body);
 			break;
 		case "tentative":
-			module.tentativeMeetingRequest(noResponse, basedate);
+			module.tentativeMeetingRequest(noResponse, basedate, body);
 			break;
 		case "decline":
-			module.declineMeetingRequest(basedate);
+			module.declineMeetingRequest(basedate, body);
 			break;
 	}
 	module.savingMeetingRequest = true;
@@ -567,12 +596,11 @@ function cancelInvitation()
 		var isMeeting = module.itemProps.meeting && module.itemProps.meeting==1;
 		var isOrganizer = module.itemProps.responsestatus && module.itemProps.responsestatus==1;
 		if (isMeeting && isOrganizer)
-			send = confirm(_("Would you like to send an update to the attendees regarding cancellation to this meeting?"));
 			var basedate = dhtml.getElementById('basedate').getAttribute('unixtime');
 			if(basedate){
-				webclient.openModalDialog(module,"deleteoccurence", DIALOG_URL+"entryid="+module.messageentryid+"&storeid="+module.storeid+"&task=deleteoccurrence_modal&basedate="+basedate+"&parententryid="+module.parententryid+"&meeting="+1+"&send="+send, 300, 200, callbackdeleteoccurence);
+				webclient.openModalDialog(module,"deleteoccurence", DIALOG_URL+"entryid="+module.messageentryid+"&storeid="+module.storeid+"&task=deleteoccurrence_modal&basedate="+basedate+"&parententryid="+module.parententryid+"&meeting="+1, 300, 200, callbackdeleteoccurence, null, {parentModule: module, parentModuleType: "item"});
 			}else{
-				deleteAppointment(send);
+				deleteAppointment();
 			}
 	} if(responseStatus == 3 || responseStatus == 5) {
 		// We're an attendee, we cannot cancel
@@ -588,11 +616,11 @@ function callbackdeleteoccurence()
 }
 
 // If 'send' is TRUE, then send a cancellation
-function deleteAppointment(send)
+function deleteAppointment()
 {
 	var basedate = dhtml.getElementById("basedate").getAttribute("unixtime");
 	basedate = basedate ? parseInt(basedate, 10) : 0;
-	module.deleteMessage(send, basedate);
+	module.deleteMessage(basedate);
 	window.close();
 }
 
@@ -618,12 +646,16 @@ function onChangeReminder()
 	}
 }
 
-function onChangeAllDayEvent()
+function onChangeAllDayEvent(forceFlag)
 {
 	var checkbox_alldayevent = dhtml.getElementById("checkbox_alldayevent");
 	var text_startdate_time = dhtml.getElementById("text_startdate_time");
 	var text_duedate_time = dhtml.getElementById("text_duedate_time");
-	
+
+	// the flag will be passed for forcefully selecting the appointment as allday event.
+	if(forceFlag)
+		dhtml.getElementById("checkbox_alldayevent").checked = true;
+
 	if(checkbox_alldayevent.checked) {
 		appoint_dtp.startPicker.timeElement.hide();
 		appoint_dtp.endPicker.timeElement.hide();
@@ -810,8 +842,11 @@ function onAppointmentTabChange(newTab,oldTab)
 			fb_module.setUserList(module.getUserList());
 		}
 		// Case in which schedule tab is selected after tracking tab.
-		if(oldTab == "tracking")
-			syncTrackingTabWithAppointmentTab("scheduling", "appointment");
+		if(oldTab == "tracking") {
+			fb_module.setStartMeetingTime(module.getStartTime());
+			fb_module.setEndMeetingTime(module.getEndTime());
+			fb_module.updatePicker();
+		}
 	}
 	if(oldTab == "scheduling"){
 		//update the appointment time in appointment tab
@@ -891,14 +926,12 @@ function showRecurrence()
 			case 10:
 				if(everyn == 1) {
 					recurtext += _("workday");
+				} else if(everyn == 1440) {
+					recurtext += _("day");
 				} else {
-					if(subtype == 1) {
-						recurtext += (everyn / 1440);
-						recurtext += " ";
-						recurtext += _("days");
-					} else {
-						recurtext += _("day");
-					}
+					recurtext += (everyn / 1440);
+					recurtext += " ";
+					recurtext += _("days");
 				}
 				break;
 			case 11:
@@ -959,17 +992,17 @@ function showRecurrence()
 				recurtext += endDate.print(_("%d-%m-%Y"));
 			}
 		}
-
-		recurtext += " ";
-		recurtext += _("from");
-		recurtext += " ";
-		recurtext += secondsToTime(startocc*60)
-		recurtext += " ";
-		recurtext += _("to");
-		recurtext += " ";
-		recurtext += secondsToTime(endocc*60);
-		recurtext += ".";
-		
+		if(startocc != 0 && endocc != 1440){
+			recurtext += " ";
+			recurtext += _("from");
+			recurtext += " ";
+			recurtext += secondsToTime(startocc*60)
+			recurtext += " ";
+			recurtext += _("to");
+			recurtext += " ";
+			recurtext += secondsToTime(endocc*60);
+			recurtext += ".";
+		}
 		dhtml.getElementById("recurtext").innerHTML = recurtext;
 		dhtml.getElementById("fbrecurtext").innerHTML = recurtext;
 		
@@ -1091,13 +1124,13 @@ function updateInfoBox(module){
 		var accepted = 0, tentative = 0, declined = 0;
 		for(var i=0;i<items.length;i++){
 			switch( parseInt(items[i].recipient_status_num.innerHTML, 10) ) {
-				case 2: // tentative
+				case olResponseTentative: // tentative
 					tentative++;
 					break;
-				case 3: //accepted
+				case olResponseAccepted: //accepted
 					accepted++;
 					break;
-				case 4: // declined
+				case olResponseDeclined: // declined
 					declined++;
 					break;
 			}
@@ -1125,40 +1158,38 @@ function syncTrackingTab(){
 		item["display_name"] = {innerHTML : attendeeList[j].fullname};
 		item["email_address"] = {innerHTML : attendeeList[j].emailaddress};
 		switch(attendeeList[j].recipienttype){
-			case 0:
+			case MAPI_ORIG:
 				value = _("Organizer");
 				break;
-			case 1:
+			case MAPI_TO:
 				value = _("Required");
 				break;
-			case 2:
+			case MAPI_CC:
 				value = _("Optional");
 				break;
-			case 3:
+			case MAPI_BCC:
 				value = _("Resource");
 				break;
 		}
 		item["recipient_attendees"] = {innerHTML : value};
 		switch(attendeeList[j].recipient_status_num)
 		{
-			case 0:
-				value = _("No Response");
-				break;
-			case 1:
+			case olResponseOrganized:
 				value = _("Organizer");
 				break;
-			case 2:
+			case olResponseTentative:
 				value = _("Tentative");
 				break;
-			case 3:
+			case olResponseAccepted:
 				value = _("Accepted");
 				break;
-			case 4:
+			case olResponseDeclined:
 				value = _("Declined");
 				break;
-			case 5:
+			case olResponseNotResponded:
 				value = _("Not Responded");
 				break;
+			case olResponseNone:
 			default:
 				value = _("No Response");
 				break;
@@ -1212,18 +1243,18 @@ function createCompatibleUserList(userList)
 	var flag = 0;
 
 	var recipient_type = new Array();
-	recipient_type[_("Organizer")] = 0;
-	recipient_type[_("Required")] = 1;
-	recipient_type[_("Optional")] = 2;
-	recipient_type[_("Resource")] = 3;
+	recipient_type[_("Organizer")] = MAPI_ORIG;
+	recipient_type[_("Required")] = MAPI_TO;
+	recipient_type[_("Optional")] = MAPI_CC;
+	recipient_type[_("Resource")] = MAPI_BCC;
 	
 	var recipient_status_num = new Array();
-	recipient_status_num[_("No Response")] = 0;
-	recipient_status_num[_("Organizer")] = 1;
-	recipient_status_num[_("Tentative")] = 2;
-	recipient_status_num[_("Accepted")] = 3;
-	recipient_status_num[_("Declined")] = 4;
-	recipient_status_num[_("Not Responded")] = 5;
+	recipient_status_num[_("No Response")] = olResponseNone;
+	recipient_status_num[_("Organizer")] = olResponseOrganized;
+	recipient_status_num[_("Tentative")] = olResponseTentative;
+	recipient_status_num[_("Accepted")] = olResponseAccepted;
+	recipient_status_num[_("Declined")] = olResponseDeclined;
+	recipient_status_num[_("Not Responded")] = olResponseNotResponded;
 	
 	var insertnew = 0;
 	var recipients = new Array();
@@ -1362,7 +1393,6 @@ function createCompatibleRecipientList(userList)
 	return recipientList;
 }
 
-
 function eventAppointmentDialogProposeNewTimeClick(moduleObject)
 {
 	// get current date & time of meeting request
@@ -1434,6 +1464,62 @@ function checkNamesCallBackAppointment(resolveObj)
 	}
 }
 
+/*
+ * Keycontrol function which handles edit options on appointment item.
+ */
+function eventAppointmentItemKeyCtrlEdit(moduleObject, element, event)
+{
+	switch(event.keyCombination)
+	{
+		case this.keys["edit_item"]["print"]:
+			webclient.openModalDialog(moduleObject, 'printing', DIALOG_URL +'entryid='+ moduleObject.messageentryid +'&storeid='+ moduleObject.storeid +'&task=printitem_modal', 600, 600);
+			break;
+		case this.keys["edit_item"]["categorize"]:
+			webclient.openModalDialog(moduleObject, 'categories', DIALOG_URL +'task=categories_modal', 350, 370, categoriesCallBack);
+			break;
+	}
+}
+/*
+ * Keycontrol function which responds to appointment item
+ */
+function eventAppointmentItemKeyCtrlRespond(moduleObject, element, event)
+{
+	var send = false;
+	var requestStatus = false;
+	
+	switch(event.keyCombination)
+	{
+		case this.keys["respond_meeting"]["accept"]:
+		case this.keys["respond_meeting"]["tentative"]:
+		case this.keys["respond_meeting"]["decline"]:
+			if (moduleObject.itemProps.responsestatus > 1){
+				send = false;
+				requestStatus = array_search(event.keyCombination, this.keys["respond_meeting"]);
+				submitAppointment(send, requestStatus);
+			}
+			break;
+	}
+}
+/**
+ * Keycontrol function which submits appointments item
+ */
+function eventAppointmentItemKeyCtrlSubmit(moduleObject, element, event)
+{
+	switch(event.keyCombination)
+	{
+		case this.keys["mail"]["save"]:
+			submitAppointment(false);
+			window.close();
+			break;
+		case this.keys["mail"]["send"]:
+			if (moduleObject.itemProps.responsestatus == 1){
+				submitAppointment(true);
+				window.close();
+			}
+			break;
+	}
+}
+
 function eventOpenPrintAppointmentItemDialog(moduleObject)
 {
 	if(moduleObject.attachNum)
@@ -1441,3 +1527,12 @@ function eventOpenPrintAppointmentItemDialog(moduleObject)
 	else
 		webclient.openModalDialog(moduleObject, 'printing', DIALOG_URL+'entryid='+moduleObject.messageentryid+'&storeid='+moduleObject.storeid+'&task=printitem_modal', 600, 600);
 }
+
+/**
+ * Callback function from Suggestionlist widget
+ * Function which synchronizes recipients with other tabs after new recipients are selected from suggestionlist.
+ */
+function suggestionListCallBackAppointment()
+{
+	syncRecipientFields();
+}
\ No newline at end of file
