@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -45,6 +47,7 @@
  * 
  */
 
+
 function initContact()
 {
 	// Fileas
@@ -197,13 +200,18 @@ function submitContact()
 	submit_contact();
 }
 
+/**
+ * this function is used to build fileas select box based on display name and company name properties
+ * it will automatically select option that is previously selected by user or the option that is stored in message
+ */
 function setFileAs()
 {
 	var fileas = dhtml.getElementById("fileas").value;
 	var select_fileas = dhtml.getElementById("select_fileas");
 	var display_name = dhtml.getElementById("display_name");
-	
-	// Save selected index temperory, to set that perticular index after change in values of fileas.
+
+	// store the currently selected option index that will be used to select the same option after
+	// rebuilding the select box
 	var tempIndex = select_fileas.options.selectedIndex;
 
 	// Remove all options in select list
@@ -217,7 +225,7 @@ function setFileAs()
 	// Remove prefix and suffix of name.
 	var name = display_name.value.replace(dhtml.getElementById("display_name_prefix").value, "").replace(dhtml.getElementById("generation").value, "").replace(",", "").replace(" ", NBSP);
 	
-	// Split display name ([0] => SURNAME, [1] => GIVEN NAME, [2] => MIDDLE NAME)
+	// Split display name ([0] => SURNAME, [1] => GIVENNAME, [2] => MIDDLENAME)
 	var names = name.split(NBSP);
 
 	// Remove white spaces in array
@@ -231,7 +239,7 @@ function setFileAs()
 	}
 
 	if(names.length > 0) {
-		// Build up two different options (SURNAME, GIVEN NAME MIDDLE NAME and GIVENNAME MIDDLE NAME SURNAME)
+		// Build up two different options (SURNAME, GIVENNAME MIDDLENAME and GIVENNAME MIDDLENAME SURNAME)
 		var	surname = names.join(NBSP);
 		var givenname = "";
 		if(names.length > 1) {
@@ -267,9 +275,18 @@ function setFileAs()
 			select_fileas.options[select_fileas.options.length] = new Option(givenname + NBSP + "(" + company_name.value + ")", givenname + NBSP + "(" + company_name.value + ")");
 	}
 
-	// Set index of the combobox.
-	if(tempIndex >=0 && tempIndex <= select_fileas.options.length)
+	if(tempIndex >= 0 && tempIndex <= select_fileas.options.length) {
+		// we are rebuilding an existing select box so select previously selected option
 		select_fileas.options[tempIndex].selected = true;
+	} else if(tempIndex == -1 && select_fileas.options.length > -1) {
+		// we are loading this contact first time so select option that is stored in message
+		for(var index=0; index < select_fileas.options.length; index++) {
+			if(select_fileas.options[index].value == fileas) {
+				select_fileas.options[index].selected = true;
+				break;
+			}
+		}
+	}
 }
 
 function onChangeEmailAddress()
@@ -346,12 +363,16 @@ function onChangeAddress()
 	}
 }
 
-function onChangeMailingAddress()
+function onChangeMailingAddress(element)
 {
 	var mailing_address = dhtml.getElementById("mailing_address");
 	var selected_address = dhtml.getElementById("selected_address");
-	
-	mailing_address.value = selected_address.value;
+
+	if(element.checked) {
+		mailing_address.value = selected_address.value;
+	} else {
+		mailing_address.value = 0;
+	}
 }
 
 function eventContactItemSendMailTo()
@@ -750,7 +771,7 @@ function eventOnChangeAddressType(moduleObject, element, event) {
  */
 function updateDisplayName() {
 	// save result of advprompt dialog to hidden variables
-	var display_name;
+	var display_name = "";
 	var display_name_prefix = dhtml.getElementById("display_name_prefix").value;
 	var given_name = dhtml.getElementById("given_name").value;
 	var middle_name = dhtml.getElementById("middle_name").value;
@@ -802,3 +823,15 @@ function updatePhoneNumberFields() {
 		}
 	}
 }
+/**
+ * Keycontrol function which saves contact.
+ */
+function eventContactItemKeyCtrlSave(moduleObject, element, event, keys)
+{
+	switch(event.keyCombination)
+	{
+		case keys["save"]:
+			submitContact();
+			break;
+	}
+}
\ No newline at end of file
