@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -147,6 +149,19 @@ function checkNamesCallBackCreateMail(resolveObj)
 	}
 }
 
+function eventCreateMailItemKeyCtrlSubmit(moduleObject, element, event)
+{
+	switch(event.keyCombination)
+	{
+		case this.keys["mail"]["save"]:
+			submit_createmail();
+			break;
+		case this.keys["mail"]["send"]:
+			submit_createmail(true);
+			break;
+	}
+}
+
 /**
  * Function to set/unset the read reciept for email sending option
  * @param String value previous value of readreceipt setting
@@ -156,12 +171,15 @@ function toggleReadReceipt(value)
    var read_receipt = dhtml.getElementById("read_receipt_requested");
    var read_receipt_button = dhtml.getElementById('read_receipt_button');
    if(read_receipt) {
-		if(value == "false") {
+		var checked = false;
+		if(value == "false" || value == false) {
 			read_receipt.value = "true";
 			dhtml.addClassName(read_receipt_button, "menubuttonselected");
+			checked = true;
 		}else{
 			read_receipt.value = "false";
 			dhtml.removeClassName(read_receipt_button, "menubuttonselected");
 		}
+		read_receipt.checked = checked;
 	}
 }
