@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -209,6 +211,12 @@ Calendar.setup = function (params) {
 					showCalendar = false;
 				}
 			}
+
+			if(element && element.type && element.type.toLowerCase() == "text") {
+				if(element.disabled == true) {
+					showCalendar = false;
+				}
+			}
 		}
 		
 		if(showCalendar) {
