@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -148,13 +150,38 @@ function getPropsFromDialog() {
 	}else{
 		var body = dhtml.getElementById("html_body");
 		if (body) {
-			props["body"] = body.value;
+			props["body"] = filterXSS(body.value);
 		}
 	}
 	
 	return props;
 }
 
+/**
+ * Function will remove unneccessary expression written in style attribute in div element
+ * @param string text content to be filtered.
+ * @return string cleaned string.
+ */
+function filterXSS(text)
+{
+	// filter out and convert unicode characters: \0065, \u0065, \U0065
+	text = text.replace(/\\[uU]?([0-9]+)/mig, function(match, p1) { return String.fromCharCode('0x'+p1); });
+
+	// filter out and convert unicode characters: &#x0065;
+	text = text.replace(/&#x?([0-9]*);/mig, function(match, p1) { return String.fromCharCode('0x'+p1); });
+
+	// filter out comments
+	text = text.replace(/\/\*((?:.|\n)*?\*\/)/mig, '');
+
+	// replace '\[character]' with only '[character]'
+	text = text.replace(/\\(.)/mig, '$1');
+
+	// replace `[property] : expression (` with `[property] : no_expression(` 
+	text = text.replace(/(<div([A-Z0-9]*)\b[^>]*(\w+)\W*:\W*)expression\W*\(/mig, '$1 : no_expression(');
+
+	return text;
+}
+
 function getRecipients() {
 	var recipients = new Array();
 	var types = new Array("to", "cc", "bcc");
@@ -250,9 +277,8 @@ function submit_createmail(send) {
 					window.opener.close();
 				}
 				
-				// close our own window
 				window.messageChanged = false;
-				window.close();
+				// window will be closed after we have received response from server
 			} else if (window.resolveForSendingMessage !== true) {
 				// Set status for the resolver to know he has to call this function again
 				window.resolveForSendingMessage = true;
@@ -270,8 +296,6 @@ function submit_createmail(send) {
 				recipients["recipient"] = recipientList;
 			}
 			
-			window.document.title = _("Create E-Mail");
-			window.messageChanged = false;
 			module.save(props, send, recipients, dhtml.getElementById("dialog_attachments").value, inlineimages);
 		}
 	}
@@ -327,10 +351,15 @@ function submit_task() {
 		text_percent_complete = parseInt(text_percent_complete);
 
 		if(isNaN(text_percent_complete) || text_percent_complete > 100 || text_percent_complete < 0) {
-			alert(_("Precent complete must be a number between 0 and 100"));
+			alert(_("Percent complete must be a number between 0 and 100"));
 			return false;
 		}
 
+		if(props["select_status"] == "2" && props["reminder"] == "1"){
+			alert(_("Since this task is complete, its reminder has been turned off."));
+			props["reminder"] = "0";
+		}
+
 		module.save(props, false, false, dhtml.getElementById("dialog_attachments").value);
 		window.close();
 	}
@@ -522,7 +551,7 @@ function getMailOptions()
 	var read_receipt = dhtml.getElementById("read_receipt");
 	if(read_receipt) {
 		var checked = false;
-		if(parentwindow.dhtml.getElementById("read_receipt_requested").value == "1") {
+		if(parentwindow.dhtml.getElementById("read_receipt_requested").value == "true") {
 			checked = true;
 		}
 		
@@ -564,7 +593,13 @@ function checkNamesCallBack(resolveObj)
 				for(var j=0; j<unResolved.length; j++){
 					unResolved[j] = unResolved[j].trim();
 					if(unResolved[j] == keyword){
-						unResolved[j] = resolveObj[i][keyword]["fullname"]+" <"+resolveObj[i][keyword]["emailaddress"]+">";
+						if(resolveObj[i][keyword]["message_class"] == "IPM.DistList"){
+							// if message class is IPM.DistList (that means a distribution list not group, then we have 
+							// to show the expanded email addresses (of its users) which are in emailaddress already.
+							unResolved[j] = resolveObj[i][keyword]["emailaddress"];
+						}else{
+							unResolved[j] = nameAndEmailToString(resolveObj[i][keyword]["fullname"], resolveObj[i][keyword]["emailaddress"], resolveObj[i][keyword]["objecttype"], false);
+						}
 					}
 				}				
 			}
