@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -528,6 +530,7 @@ function getAction()
         var smtpaddr = action_forward_address.smtpaddr ? action_forward_address.smtpaddr : parsed.smtpaddress;
         var name = action_forward_address.displayname ? action_forward_address.displayname : (parsed.displayname ? parsed.displayname : parsed.emailaddress);
         var entryid = action_forward_address.entryid ? action_forward_address.entryid : createOneOff(name, addrtype, emailaddr);
+		var searchkey = action_forward_address.searchkey ? action_forward_address.searchkey : createSearchKey(addrtype, emailaddr);
 
         action.action = new Object;
         action.action.value = "OP_FORWARD";
@@ -566,7 +569,7 @@ function getAction()
         property.attributes = new Object;
         property.attributes.proptag = "PR_SEARCH_KEY";
         property.attributes.type = "binary";
-        property.value = createSearchKey(addrtype, emailaddr);
+        property.value = searchkey;
         action.adrlist.address.property.push(property);
 
         var property = new Object;
@@ -604,7 +607,7 @@ function getAction()
 	        property.attributes = new Object;
 	        property.attributes.proptag = "PR_RECORD_KEY";
 		    property.attributes.type = "binary";
-			property.value = createSearchKey(addrtype, emailaddr);
+			property.value = searchkey;
 	        action.adrlist.address.property.push(property);
 		}else{
 	        var property = new Object;
@@ -627,7 +630,7 @@ function getFromAddressBook(targetElementId, type)
 	if (typeof(type)=="undefined")
 		type = "fullemail_single";
 
-    webclient.openModalDialog(module, "addressbook", DIALOG_URL+"task=addressbook_modal&type="+type+"&storeid=" + parentwindow.module.storeid, 500, 350, abCallBack, callBackData);
+    webclient.openModalDialog(module, "addressbook", DIALOG_URL+"task=addressbook_modal&type="+type+"&storeid=" + parentwindow.module.storeid, 800, 500, abCallBack, callBackData);
 }
 
 // Called when the addressbook is done getting a user
