@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -210,7 +212,8 @@ function startEditSignature(content, shadow_sigID){
 		if (data["signatures"][shadow_sigID] && data["signatures"][shadow_sigID]["type"] == "plain") {
 			content = convertPlainToHtml(content);
 		}
-		fckeditor.SetHTML(content.replace(/\n/g, "<br />"));
+
+		fckeditor.SetHTML(content.replace(/\n/g, "<br />")); 
 	} else {
 		if (data["signatures"][shadow_sigID] && data["signatures"][shadow_sigID]["type"] == "plain") {
 			// plain text so no need to convert
@@ -232,7 +235,13 @@ function startEditSignature(content, shadow_sigID){
 function getSignatureFromEditor(){
 	// Check if HTML editor is loaded and get the body
 	if (checkEditor() && (fckeditor = FCKeditorAPI.GetInstance("signature_editor"))){
-		return fckeditor.GetHTML();
+
+		// Check the mode of fckeditor before saving the content and if editor is in plain editor mode replace < and > with html entities.
+		if(fckeditor.EditorDocument && fckeditor.EditMode != FCK_EDITMODE_WYSIWYG){
+			return fckeditor.GetHTML(); 
+		}else{
+			return fckeditor.GetHTML();
+		}
 	} else {
 		var editor = dhtml.getElementById("signature_editor", "textarea");
 		if(editor){
@@ -436,7 +445,7 @@ function createSignature(){
 function createSignature_namesig_callback(result, callbackData){
 	if(result && result.signame){
 		// Generate an unique ID that is not yet used in the global Data Object.
-		var uniqueID = (new Date()).getTime();
+		var uniqueID = Math.round(((new Date()).getTime())/1000);
 		while(data["signatures"][ uniqueID ]){
 			uniqueID += "a";	// Appending non-unique ID to make it unique.
 		}
