@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -258,14 +260,17 @@ function submitTask()
 function onChangeStatus()
 {
 	var select_status = dhtml.getElementById("select_status");
-	
 	if(select_status) {
 		var selected = select_status.options[select_status.selectedIndex].value;
 		
 		if(selected == "2") {
 			dhtml.getElementById("text_percent_complete").value = "100%";
+			//check reminder and turn it off
+			setReminderOnComplete();
 		} else {
 			dhtml.getElementById("text_percent_complete").value = (dhtml.getElementById("percent_complete").value * 100) + "%";
+			//check reminder and turn it on
+			setReminderOnComplete(true);
 		}
 		
 		dhtml.getElementById("status").value = selected;
@@ -305,6 +310,8 @@ function completeSpinnerUp()
 		
 		if(percent == 100) {
 			dhtml.setValue(dhtml.getElementById("select_status"), 2);
+			//check reminder and turn it off
+			setReminderOnComplete();
 		} else if(percent < 100) {
 			if(dhtml.getValue(dhtml.getElementById("select_status")) == "0" || 
 			   dhtml.getValue(dhtml.getElementById("select_status")) == "2") {
@@ -348,6 +355,8 @@ function completeSpinnerDown()
 		
 		if(percent < 100) {
 			dhtml.setValue(dhtml.getElementById("select_status"), 1);
+			//check reminder and turn it on
+			setReminderOnComplete(true);
 		}
 	}
 }
@@ -452,10 +461,33 @@ function setTaskCompleted()
 {
 	dhtml.setValue(dhtml.getElementById("select_status"), "2");
 	dhtml.getElementById("text_percent_complete").value = "100%";
-	
+
+	// check reminder and turn it off.
+	setReminderOnComplete();
 	submitTask();
 }
 
+/**
+ * Function which turn off/on the reminde on basis of percentage of task completion.
+ * 100% task complete means the reminder should be turn off else check if that was on then turn on.
+ * @params boolean forceFlag boolean which forcefully turns on the reminder, used when somebody 
+									 is playing via task completion (percentage)
+ */
+function setReminderOnComplete(forceFlag){
+	var reminderCheck = dhtml.getElementById("checkbox_reminder");
+	if(reminderCheck.checked && !forceFlag){
+		dhtml.executeEvent(reminderCheck, "click");
+		reminderCheck.checked = false;
+	}else if(!reminderCheck.checked && forceFlag){
+		if(dhtml.getElementById("previousReminderValue").value != "0"){
+		// called from completion box
+			dhtml.executeEvent(reminderCheck, "click");
+			reminderCheck.checked = true;
+		}
+	}
+	
+}
+
 function categoriesCallBack(categories)
 {
 	moduleObject = webclient.getModulesByName("taskitemmodule")[0];
@@ -481,10 +513,24 @@ function onChangeComplete()
 		// Set status to complete if completion level is 100% or more
 		if(parseInt(percent) >= 100) {
 			dhtml.setValue(dhtml.getElementById("select_status"), 2);
+			// check reminder and turn it off
+			setReminderOnComplete();
         } else if(parseInt(percent) <= 0) {
 			dhtml.setValue(dhtml.getElementById("select_status"), 0);
         } else {
 			dhtml.setValue(dhtml.getElementById("select_status"), 1);
         }
 	}
-}
\ No newline at end of file
+}
+/**
+ * Keycontrol function which saves task.
+ */
+function eventTaskListKeyCtrlSave(moduleObject, element, event, keys)
+{
+	switch(event.keyCombination)
+	{
+		case keys["save"]:
+			submitTask();
+			break;
+	}
+}
