@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -112,7 +114,12 @@ function addUser(){
 	if(usergroup && usergroup.selectedIndex >= 0){
 		data.groupEntryID = usergroup.value;
 
-		webclient.openModalDialog(-1, 'addressbook', DIALOG_URL+'&type=username&source=gab&groups=no&task=addressbook_modal&storeid=' + parentWebclient.hierarchy.defaultstore["id"], 550, 410, mucalendarDialog_addusertogroup_addCallBack, data);
+		var windowData = new Object();
+		windowData["hide_users"] = ["contact"];
+		windowData["hide_groups"] = ["dynamic", "normal", "everyone", "security"];
+		windowData["hide_companies"] = true;
+
+		webclient.openModalDialog(-1, 'addressbook', DIALOG_URL+'&type=username&source=gab&task=addressbook_modal&storeid=' + parentWebclient.hierarchy.defaultstore["id"], 800, 500, mucalendarDialog_addusertogroup_addCallBack, data, windowData);
 	}
 }
 
