@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -66,9 +68,12 @@ addressbooklistmodule.prototype.init = function(id, element, title, data)
 
 	this.enableVariableColumns = false;
 	
-	// We don't want rowcolumn events since it makes it slower
+	// We don't want rowcolumn/quick_edit events since it makes it slower
     delete this.events["rowcolumn"];
-    	
+    delete this.events["insertcolumn"];
+    delete this.events["insertrow"];
+    delete this.events["menu"];
+
 	var items = new Array();
 	items.push(webclient.menu.createMenuItem("select", _("Select"), false, eventListContextMenuOpenMessage));
 	this.contextmenu = items;
@@ -125,30 +130,40 @@ addressbooklistmodule.prototype.execute = function(type, action)
 addressbooklistmodule.prototype.list = function(action, noLoader, restriction)
 {
 	if(this.storeid) {
-		if(action && action != false) {
-			this.action = action;
-		}
-	
 		var data = new Object();
 		data["store"] = this.storeid;
 		data["entryid"] = this.entryid;
+
 		var contactfolder = dhtml.getElementById("addressbookfolders");
 		if(contactfolder && contactfolder.value){
 			data["store"] = contactfolder.options[ contactfolder.selectedIndex ].storeid;
 		}
-		
+
 		this.sort = this.loadSortSettings();
 		if(this.sort) {
 			data["sort"] = new Object();
 			data["sort"]["column"] = this.sort;
 		}
 
+		// Set restriction for search_string/pagination_character.
 		if(restriction) {
-			data["restriction"] = new Object();
-			data["restriction"]["name"] = new Array(restriction);
-		} 
+			data["restriction"] = restriction;
+		}
 
-		if(typeof(this.groups)=="string"){
+		// hiding of users/groups is only for gab & addresslist
+		if(this.action == "globaladdressbook") {
+			if(typeof this.hide_groups != "undefined" && isArray(this.hide_groups) && this.hide_groups.length > 0) {
+				data["hide_groups"] = this.hide_groups;
+			}
+
+			if(typeof this.hide_users != "undefined" && isArray(this.hide_users) && this.hide_users.length > 0) {
+				data["hide_users"] = this.hide_users;
+			}
+
+			if(typeof this.hide_companies != "undefined") {
+				data["hide_companies"] = this.hide_companies;
+			}
+		} else if(typeof this.groups != "undefined") {
 			data["groups"] = this.groups;
 		}
 
