@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -62,6 +64,16 @@ function appointmentitemmodule(id)
 appointmentitemmodule.prototype.init = function(id)
 {
 	appointmentitemmodule.superclass.init.call(this, id);
+
+	this.keys["edit_item"] = KEYS["edit_item"];
+	this.keys["respond_meeting"] = KEYS["respond_meeting"];
+	this.keys["mail"] = KEYS["mail"];
+
+	// Add keycontrol events
+	webclient.inputmanager.addObject(module);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["edit_item"], "keyup", eventAppointmentItemKeyCtrlEdit);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["respond_meeting"], "keyup", eventAppointmentItemKeyCtrlRespond);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["mail"], "keyup", eventAppointmentItemKeyCtrlSubmit);
 }
 
 appointmentitemmodule.prototype.executeOnLoad = function()
@@ -69,17 +81,17 @@ appointmentitemmodule.prototype.executeOnLoad = function()
 	initAppointment();
 	showRecurrence();
 	
-	var meeting = this.itemProps.meeting;
+	var meetingStatus = parseInt(this.itemProps.meeting, 10);
+	var responseStatus = parseInt(this.itemProps.responsestatus, 10);
 	
-	//Show tracking tab if it meeting Appointment.
-	if (meeting == 1){
+	// Show tracking tab only when appointment is a meeting request
+	// and it is in organizer's calendar
+	if(!isNaN(meetingStatus) && meetingStatus == olMeeting) {
 		var tab_tracking = dhtml.getElementById("tab_tracking");
-		if (tab_tracking) {
-			if (webclient.userEntryid == this.itemProps.sent_representing_entryid){
-				dhtml.removeClassName(tab_tracking, "tab_hide");
-			} else {
-				dhtml.addClassName(tab_tracking, "tab_hide");
-			}
+		if(!isNaN(responseStatus) && responseStatus == olResponseOrganized) {
+			dhtml.removeClassName(tab_tracking, "tab_hide");
+		} else {
+			dhtml.addClassName(tab_tracking, "tab_hide");
 		}
 	}
 }
@@ -128,31 +140,10 @@ appointmentitemmodule.prototype.getUserList = function()
 			if(userList[user].trim().length == 0)
 				continue;
 
-			result[index] = new Object();
-			result[index]["recipienttype"] = 1;
+			result[index] = stringToEmail(userList[user].trim());
+			result[index]["recipienttype"] = MAPI_TO;
 			result[index]["recipient_flags"] = 1;	//recipient flag for attendees.
 
-			userList[user] = userList[user].trim();
-
-			var posLeft = userList[user].indexOf("<");
-			var posRight = userList[user].indexOf(">");
-			if(posLeft > 0 && posRight > 0){
-				//take the email address and fullname
-				result[index]["fullname"] = userList[user].substring(0,posLeft).trim();
-				result[index]["emailaddress"] = userList[user].substring(posLeft+1,posRight).trim();
-				// Check if the sent_representing_email_address is set, since this is not the case in a new appointment
-				if(this.itemProps.sent_representing_email_address){
-					if(result[index]["emailaddress"].toLowerCase() == this.itemProps.sent_representing_email_address.toLowerCase()){
-						result[index]["recipienttype"] = 0;
-						result[index]["recipient_flags"] = 3;	//recipient flag for meeting organizer
-					}
-				}
-			}
-			else{
-				if(userList[user].length > 0){
-					result[index]["fullname"] = userList[user];
-				}
-			}
 			index++;
 		}
 	}
@@ -163,24 +154,9 @@ appointmentitemmodule.prototype.getUserList = function()
 			if(userList[user].trim().length == 0)
 				continue;
 				
-			result[index] = new Object();
-			result[index]["recipienttype"] = 2;
+			result[index] = stringToEmail(userList[user].trim());
+			result[index]["recipienttype"] = MAPI_CC;
 			result[index]["recipient_flags"] = 1;
-
-			userList[user] = userList[user].trim();
-
-			var posLeft = userList[user].indexOf("<");
-			var posRight = userList[user].indexOf(">");
-			if(posLeft > 0 && posRight > 0){
-				//take the email address and fullname
-				result[index]["fullname"] = userList[user].substring(0,posLeft).trim();
-				result[index]["emailaddress"] = userList[user].substring(posLeft+1,posRight).trim();
-			}
-			else{
-				if(userList[user].length > 0){
-					result[index]["fullname"] = userList[user];
-				}
-			}
 			index++;
 		}
 	}
@@ -191,23 +167,8 @@ appointmentitemmodule.prototype.getUserList = function()
 			if(userList[user].trim().length == 0)
 				continue;
 				
-			result[index] = new Object();
-			result[index]["recipienttype"] = 3;
-
-			userList[user] = userList[user].trim();
-
-			var posLeft = userList[user].indexOf("<");
-			var posRight = userList[user].indexOf(">");
-			if(posLeft > 0 && posRight > 0){
-				//take the email address and fullname
-				result[index]["fullname"] = userList[user].substring(0,posLeft).trim();
-				result[index]["emailaddress"] = userList[user].substring(posLeft+1,posRight).trim();
-			}
-			else{
-				if(userList[user].length > 0){
-					result[index]["fullname"] = userList[user];
-				}
-			}
+			result[index] = stringToEmail(userList[user].trim());
+			result[index]["recipienttype"] = MAPI_BCC;
 			index++;
 		}
 	}
@@ -245,39 +206,39 @@ appointmentitemmodule.prototype.setUserList = function(inputUserlist)
 			 */
 			if(userData["entryid"].length == 0 || (userData["fullname"] == userData["emailaddress"]) || (userData["fullname"] == userData["entryid"])){
 				switch(userData["recipienttype"]){
-					case 2:
+					case MAPI_CC:
 						resultCC += userData["fullname"]+"; ";
 						break;
-					case 3:
+					case MAPI_BCC:
 						resultBCC += userData["fullname"]+"; ";
 						break;
-					case 0:
+					case MAPI_ORIG:
 						var emailaddress = this.itemProps["sent_representing_email_address"] || userData["emailaddress"];
-						resultTO += userData["fullname"]+" <"+emailaddress+">; ";
+						resultTO += nameAndEmailToString(userData["fullname"], emailaddress, MAPI_MAILUSER, false) + "; ";
 						break;
 					default:
-						resultTO += userData["fullname"]+"; ";
+						resultTO += nameAndEmailToString(userData["fullname"], userData["emailaddress"], userData["objecttype"], false)  + "; ";
 						break;
 				}
-				result += userData["fullname"]+"; ";
+				result += nameAndEmailToString(userData["fullname"], userData["emailaddress"], userData["objecttype"], false)  + "; ";
 			}
 			else{
 				switch(userData["recipienttype"]){
-					case 2:
-						resultCC += userData["fullname"]+" <"+userData["emailaddress"]+">; ";
+					case MAPI_CC:
+						resultCC += nameAndEmailToString(userData["fullname"], userData["emailaddress"], userData["objecttype"], false) + "; ";
 						break;
-					case 3:
-						resultBCC += userData["fullname"]+" <"+userData["emailaddress"]+">; ";
+					case MAPI_BCC:
+						resultBCC += nameAndEmailToString(userData["fullname"], userData["emailaddress"], userData["objecttype"], false) + "; "; 
 						break;
-					case 0:
+					case MAPI_ORIG:
 						var emailaddress = this.itemProps["sent_representing_email_address"] || userData["emailaddress"];
-						resultTO += userData["fullname"]+" <"+emailaddress+">; ";
+						resultTO += nameAndEmailToString(userData["fullname"], emailaddress, MAPI_MAILUSER, false) + "; ";
 						break;
 					default:
-						resultTO += userData["fullname"]+" <"+userData["emailaddress"]+">; ";
+						resultTO += nameAndEmailToString(userData["fullname"], userData["emailaddress"], userData["objecttype"], false) +  "; "; 
 						break;
 				}
-				result += userData["fullname"]+" <"+userData["emailaddress"]+">; ";
+				result += nameAndEmailToString(userData["fullname"], userData["emailaddress"], userData["objecttype"], false) + "; ";
 			}
 		}
 	}
@@ -323,11 +284,13 @@ appointmentitemmodule.prototype.setRecurrence = function(recurrence)
 			dhtml.setValue(dhtml.getElementById("checkbox_alldayevent"), true);
 			onChangeAllDayEvent();
 			dhtml.getElementById("endocc").value = 1440;
+			dhtml.getElementById("startocc").value = 0;
 			dhtml.getElementById("duration").value = 1440;
 		}
 	} else {
 		dhtml.getElementById('recurring').value = 0;
 		dhtml.getElementById('icon_index').value = 1024;
+		dhtml.getElementById('recurring_reset').value = "";
 		dhtml.getElementById('recurtext').innerHTML = "";
 	}
 
@@ -346,27 +309,75 @@ appointmentitemmodule.prototype.setTimezone = function(tz)
 }
 
 // If send is true, send a cancellation
-appointmentitemmodule.prototype.deleteMessage = function (send,basedate)
+appointmentitemmodule.prototype.deleteMessage = function (basedate)
 {
+	var send = false;
+	var meeting = parseInt(this.itemProps["meeting"], 10);
+	var recurring = parseInt(this.itemProps["recurring"], 10);
+
 	if(basedate) {
-		var req = new Object;
-		req['store'] = this.storeid;
-		req['parententryid'] = this.parententryid;
-		req['entryid'] = this.messageentryid;
-		req['delete'] = 1;
-		req['props'] = new Object;
-		req['props']['entryid'] = this.messageentryid;
-		req['props']['basedate'] = parseInt(basedate, 10);
-		parentWebclient.xmlrequest.addData(this, 'save', req, webclient.modulePrefix);
-	} else {
-		if(send) {
+		//occurrence end date
+		var end = dhtml.getElementById("duedate").getAttribute("unixtime");
+		var endtime = new Date(end * 1000);
+		
+		// if occurrence is later then send confirmation message for cancellation message.
+		if(meeting !== 0 && (endtime.getTime() > (new Date().getTime()))) {
+			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+		} else {
+			//directlly delete passed occurrences.
 			var req = new Object;
 			req['store'] = this.storeid;
+			req['parententryid'] = this.parententryid;
 			req['entryid'] = this.messageentryid;
-			// Cancel automatically deletes the item
-			parentWebclient.xmlrequest.addData(this, 'cancelInvitation', req, webclient.modulePrefix);
+			req['delete'] = 1;
+			req['props'] = new Object;
+			req['props']['entryid'] = this.messageentryid;
+			req['props']['basedate'] = parseInt(basedate, 10);
+
+			parentWebclient.xmlrequest.addData(this, 'save', req, webclient.modulePrefix);
+			parentWebclient.xmlrequest.sendRequest(true);
+		}
+
+		if(send) {
+			// delete occurrence and send cancellation message
+			var data = new Array();
+			data["store"] = this.storeid;
+			data["entryid"] = this.messageentryid;
+			data["delete"] = true;
+			data["exception"] = true;
+			data["basedate"] = basedate;
+			
+			parentWebclient.xmlrequest.addData(this, "cancelInvitation", data, webclient.modulePrefix);
+			parentWebclient.xmlrequest.sendRequest(true);
+		}
+	} else {
+		var end = 0;
+		if (recurring == 1) {
+			// Recurrence end date.
+			end = this.itemProps.enddate_recurring;
 		} else {
-			appointmentitemmodule.superclass.deleteMessage.call(this);	
+			// Normal meeting end date.
+			end = this.itemProps.duedate;
+		}
+
+		var endtime = new Date(end * 1000);
+
+		// if recurrence is later then send confirmation message for cancellation message.
+		if(meeting !== 0 && endtime.getTime() > (new Date().getTime())) {
+			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+		} else {
+			//directlly delete passed MRs.
+			appointmentitemmodule.superclass.deleteMessage.call(this);
+		}
+
+		if(send) {
+			// delete MR and send cancellation message
+			var data = new Array();
+			data["store"] = this.storeid;
+			data["entryid"] = this.messageentryid;
+
+			parentWebclient.xmlrequest.addData(this, "cancelInvitation", data, webclient.modulePrefix);
+			parentWebclient.xmlrequest.sendRequest(true);
 		}
 	}
 }
@@ -405,11 +416,7 @@ appointmentitemmodule.prototype.save = function(props, send, recipients, dialog_
 
 	if(this.isMeeting == true && props["entryid"] == ""){
 		// Add human readable BODY Text.
-		props["body"] = _("When") + ": " +  
-						strftime(_("%A, %B %e, %Y %H:%M"), props['startdate']) + " - " +
-						strftime(_("%A, %B %e, %Y %H:%M"), props['duedate']) + "\n" +  
-						_("Where") + ": "  + props['location'] + "\n\n" + 
-						"*~*~*~*~*~*~*~*~*~*\n\n" + props["body"];
+		props["body"] = this.addMeetingTimeInfoToBody(props["body"], props['startdate'], props['duedate'], props['location']);
 	}
 
 	if(this.parententryid)
@@ -467,7 +474,7 @@ appointmentitemmodule.prototype.messageSaved = function(action)
 			var userlist = this.getUserList();
 			var resourcesPlanned = false;
 			for(var i=0;i<userlist.length;i++){
-				if(userlist[i]["recipienttype"] == 3){
+				if(userlist[i]["recipienttype"] == MAPI_BCC){
 					resourcesPlanned = true;
 					break;
 				}
@@ -514,4 +521,4 @@ appointmentitemmodule.prototype.messageSaved = function(action)
 	}
 	module.saving = false;
 	module.savingMeetingRequest = false;
-}
+}
\ No newline at end of file
