@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -82,6 +84,12 @@ createmailitemmodule.prototype.init = function(id)
 
 	this.message_action = false;
 	this.message_action_entryid = false;
+	
+	this.keys["mail"] = KEYS["mail"];
+
+	// Add keycontrol event
+	webclient.inputmanager.addObject(this);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["mail"], "keyup", eventCreateMailItemKeyCtrlSubmit);
 }
 
 
@@ -93,9 +101,23 @@ createmailitemmodule.prototype.execute = function(type, action)
 			webclient.menu.showMenu();
 			this.item(action);
 			break;	
-		
-		case "update":
+		case "update":		// mail saved successfully
 			this.updateMessage(action);
+
+			window.document.title = _("Create E-Mail");
+			window.messageChanged = false;
+			break;
+		case "error":
+			var errorString = dhtml.getXMLValue(action, "message", "");
+			if(errorString.length > 0){
+				alert(errorString);
+			}
+
+			// we got a response from the server so we are ready for another request
+			window.waitForSaveResponse = false;
+			break;
+		case "success":		// mail sent successfully
+			window.close();
 			break;
 	}
 }
@@ -283,23 +305,24 @@ createmailitemmodule.prototype.setDelegatorAsSender = function(message)
 	if(delegateFlag){
 		var delegatorName = "";
 		var delegatorEmail = "";
-		if(message.getElementsByTagName("received_by_name"))
-			delegatorName = message.getElementsByTagName("received_by_name")[0].firstChild.nodeValue;
+		if(dhtml.getXMLNode(message, "received_by_name"))
+			delegatorName = dhtml.getXMLValue(message, "received_by_name");
 
-		if(message.getElementsByTagName("received_by_email_address"))
-			delegatorEmail = message.getElementsByTagName("received_by_email_address")[0].firstChild.nodeValue;
+		if(dhtml.getXMLNode(message, "received_by_email_address"))
+			delegatorEmail = dhtml.getXMLValue(message, "received_by_email_address");
 		
-		var delegateEmailAddress = delegatorName + " <" + delegatorEmail + ">";
-		var fromSelect = dhtml.getElementById("from", "select");
-		if(fromSelect){
-			var fromRow = dhtml.getElementById("from_row", "tr");
-			if(fromRow){
-				fromRow.style.display = "";
+		if(delegatorName && delegatorEmail) {
+			var delegateEmailAddress = delegatorName + " <" + delegatorEmail + ">";
+			var fromSelect = dhtml.getElementById("from", "select");
+			if(fromSelect){
+				var fromRow = dhtml.getElementById("from_row", "tr");
+				if(fromRow){
+					fromRow.style.display = "";
+				}
+				fromSelect.options[fromSelect.options.length] = new Option(delegateEmailAddress, delegateEmailAddress);
+				fromSelect.options[fromSelect.options.length-1].selected = true;
 			}
-			fromSelect.options[fromSelect.options.length] = new Option(delegateEmailAddress, delegateEmailAddress);
-			fromSelect.options[fromSelect.options.length-1].selected = true;
 		}
-		
 	}
 }
 
@@ -375,7 +398,7 @@ createmailitemmodule.prototype.setSender = function(message)
 		var sent_representing_email_address = dhtml.getTextNode(message.getElementsByTagName("sent_representing_email_address")[0],"");		
 		var sent_representing_name = dhtml.getTextNode(message.getElementsByTagName("sent_representing_name")[0],"");
 		
-		element.value = nameAndEmailToString(sent_representing_name,sent_representing_email_address,false) + "; ";
+		element.value = nameAndEmailToString(sent_representing_name,sent_representing_email_address,MAPI_MAILUSER,false) + "; ";
 	}
 }
 
@@ -422,11 +445,12 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 				}
 				
 			var received_by_email_address = dhtml.getTextNode(message.getElementsByTagName("received_by_email_address")[0],"");
-			var subject = dhtml.getTextNode(message.getElementsByTagName("subject")[0],"");
+			// Escaping the HTML tag in subject body
+			var subject = dhtml.getTextNode(message.getElementsByTagName("subject")[0],"").htmlEntities();
 			var body = message.getElementsByTagName("body")[0];
 			var isHTML = dhtml.getTextNode(message.getElementsByTagName("isHTML")[0],false);
 
-			sent_representing_email_address = nameAndEmailToString(sent_representing_name,sent_representing_email_address,htmlFormat);
+			sent_representing_email_address = nameAndEmailToString(sent_representing_name,sent_representing_email_address,MAPI_MAILUSER,htmlFormat);
 			
 			if(body && body.firstChild) {
 				var element = body.firstChild;
@@ -485,6 +509,7 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 					var resDisplayName = dhtml.getTextNode(recipients[i].getElementsByTagName("display_name")[0],"");
 					var resEmailAddress = dhtml.getTextNode(recipients[i].getElementsByTagName("email_address")[0],"");
 					var resType = dhtml.getTextNode(recipients[i].getElementsByTagName("type")[0],"");
+					var resObjectType = dhtml.getTextNode(recipients[i].getElementsByTagName("objecttype")[0],"");
 					if (resType != "bcc"){
 						switch(resType){
 							case "to":
@@ -498,7 +523,7 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 							recipientList[resType] = "";
 						}
 						
-						recipientList[resType] += nameAndEmailToString(resDisplayName,resEmailAddress,htmlFormat)+"; ";
+						recipientList[resType] += nameAndEmailToString(resDisplayName,resEmailAddress,resObjectType,htmlFormat)+"; ";
 					}
 				}
 							
@@ -545,7 +570,7 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 					} else {
 						// convert plain signature to html format
 						signature = convertPlainToHtml(signatureData["content"]);
-						signature_seperator = "<p>&nbsp;<br/>&nbsp;</p>";
+						signature_seperator = "<p><br/></p>";
 					}
 				} else {
 					// signature is stored in html format
@@ -556,7 +581,7 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 					} else {
 						// no conversion
 						signature = signatureData["content"];
-						signature_seperator = "<p>&nbsp;<br/>&nbsp;</p>";
+						signature_seperator = "<p><br/></p>";
 					}
 				}
 				signature = signature_seperator + signature;
