@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -72,6 +74,8 @@ datepickerlistmodule.prototype.init = function(id, element, title, data)
 	this.menuItems.push(webclient.menu.createMenuItem("week", _("Week"), _("Week"), eventDatePickerSwitchCalendarView));
 	this.menuItems.push(webclient.menu.createMenuItem("7days", _("7 Days"), _("7 Days"), eventDatePickerSwitchCalendarView));
 	this.menuItems.push(webclient.menu.createMenuItem("month", _("Month"), _("Month"), eventDatePickerSwitchCalendarView));
+    // this will add list view option in top menu bar
+	this.menuItems.push(webclient.menu.createMenuItem("table", _("List"), _("List"), eventDatePickerSwitchCalendarView));
 	
 	if(webclient.settings.get("calendar/calendar_refresh_button", "true") == "true"){
 		this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
@@ -251,6 +255,15 @@ datepickerlistmodule.prototype.printList = function(entryid)
 	webclient.openModalDialog(this, "printing", DIALOG_URL+"entryid="+entryid+"&storeid="+this.storeid+"&task=printlist_modal", 714, 800, null, null, windowData);
 }
 
+/**
+ * Function which deletes one or more items in the view.
+ * @param object action the action tag 
+ */ 
+datepickerlistmodule.prototype.deleteItems = function(action)
+{
+	this.viewController.viewObject.removeItemOfDay(dhtml.getXMLValue(action, "entryid"));
+}
+
 function eventDatePickerListNextMonth(moduleObject, element, event)
 {
 	var month = false;
