@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -94,6 +96,10 @@ distlistmodule.prototype.resize = function()
 distlistmodule.prototype.executeOnLoad = function()
 {
 	initdistlist();
+	
+	// Add keycontrol event
+	webclient.inputmanager.addObject(this);
+	webclient.inputmanager.bindKeyControlEvent(this, KEYS["mail"], "keyup", eventDistListKeyCtrlSave);
 }
 
 distlistmodule.prototype.list = function()
@@ -339,7 +345,9 @@ distlistmodule.prototype.addItem = function(item)
 	// item: (addrtype), display_name, email_address, entryid, (icon_index), (message_class), (dl_name), (value) 
 
 	var member = new Object;
-	if(item.addrtype=="ZARAFA")
+
+	// if user is GAB user then use smtp address
+	if(item.addrtype == "ZARAFA" || item.objecttype == MAPI_MAILUSER)
 		member.address = {value: item.smtp_address};
 	else
 		member.address = {value: item.email_address};
@@ -347,32 +355,37 @@ distlistmodule.prototype.addItem = function(item)
 	this.newInternalId++;
 	if (item.entryid){
 		member.entryid = {value: item.entryid, attributes: {type: "binary"} };
-		if (item.message_class && item.message_class == "IPM.DistList"){
+		if (item.objecttype && item.objecttype == MAPI_DISTLIST){
+			// ab group
 			member.message_flags = {value: 0};
-			if (item.dl_name){ // real distlist
+			member.distlisttype = {value: "DL_DIST_AB"};
+		} else if(item.objecttype && item.objecttype == MAPI_MESSAGE) {
+			if (item.addrtype == "ZARAFA") {
+				// real distlist
 				member.distlisttype = {value: "DL_DIST"};
-			}else{ // user group
-				member.distlisttype = {value: "DL_DIST_AB"};
-			}
-		}else{
-			if (item.addrtype=="ZARAFA"){
-				member.distlisttype = {value: "DL_USER_AB"};
-			}else{
+			} else {
+				// user in contact folders
 				member.distlisttype = {value: "DL_USER"};
 				if (item.email_address_number && item.email_address_number>1){
 					member.distlisttype.value += item.email_address_number;
 				}
 			}
+		}else{
+			// ab user
+			member.distlisttype = {value: "DL_USER_AB"};
 		}
 	}else{
 		member.entryid = {value: "oneoff_"+this.newInternalId};
 		member.distlisttype = {value: "ONEOFF"};
 	}
-	
-	if (item.icon_index)
-		member.icon_index = {value: item.icon_index};
-	else
-		member.icon_index = {value: 512};
+	if (item.addrtype == "ZARAFA") {
+		member.icon_index = {value: 514};
+	}else{
+		if (item.icon_index)
+			member.icon_index = {value: item.icon_index};
+		else
+			member.icon_index = {value: 512};
+	}
 
 	member.name = {value: item.display_name};
 	member.type = {value: item.addrtype};
