@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -255,23 +257,32 @@ freebusymodule.prototype.addBusyInfo = function(inputUserList)
 {
 	for(var i=0; i < inputUserList.length; i++){
 		var clientuser =  inputUserList[i].getAttribute("clientuser");
-		this.userList[clientuser]["fullname"] =     dhtml.getTextNode(inputUserList[i].getElementsByTagName("fullname")[0],"");
-		this.userList[clientuser]["entryid"] =      dhtml.getTextNode(inputUserList[i].getElementsByTagName("entryid")[0],"");
-		this.userList[clientuser]["username"] =     dhtml.getTextNode(inputUserList[i].getElementsByTagName("username")[0],"");
-		this.userList[clientuser]["emailaddress"] = dhtml.getTextNode(inputUserList[i].getElementsByTagName("email")[0], this.userList[clientuser]["emailaddress"]);
 
-		//put the items in the "userList"
-		this.userList[clientuser]["items"] = new Array();
-		var busyElement = inputUserList[i].getElementsByTagName("item");
+		if(typeof this.userList[clientuser] != "undefined"){
+			this.userList[clientuser]["objecttype"] = parseInt(dhtml.getXMLValue(inputUserList[i], "objecttype"), 10);
+			// Check whether perticular userinfo is there or not.
+			this.userList[clientuser]["fullname"] =     dhtml.getTextNode(inputUserList[i].getElementsByTagName("fullname")[0],"");
+			this.userList[clientuser]["entryid"] =      dhtml.getTextNode(inputUserList[i].getElementsByTagName("entryid")[0],"");
+			this.userList[clientuser]["username"] =     dhtml.getTextNode(inputUserList[i].getElementsByTagName("username")[0],"");
+			this.userList[clientuser]["emailaddress"] = dhtml.getTextNode(inputUserList[i].getElementsByTagName("email")[0], this.userList[clientuser]["emailaddress"]);
+			// only set this property when we are adding user for the first time
+			if(typeof this.userList[clientuser] != "undefined" && typeof this.userList[clientuser]["recipienttype"] == "undefined") {
+				this.userList[clientuser]["recipienttype"] = parseInt(dhtml.getXMLValue(inputUserList[i], "recipienttype"), 10);
+			}
 
-		for(var j=0;j<busyElement.length;j++){
-			var item = new Object();
-			item["status"] = parseInt(busyElement[j].getElementsByTagName("status")[0].firstChild.nodeValue);
-			item["start"] = busyElement[j].getElementsByTagName("start")[0].getAttribute("unixtime");
-			item["end"] = busyElement[j].getElementsByTagName("end")[0].getAttribute("unixtime");
-			this.userList[clientuser]["items"][this.userList[clientuser]["items"].length] = item;
+			//put the items in the "userList"
+			this.userList[clientuser]["items"] = new Array();
+			var busyElement = inputUserList[i].getElementsByTagName("item");
+
+			for(var j=0;j<busyElement.length;j++){
+				var item = new Object();
+				item["status"] = parseInt(busyElement[j].getElementsByTagName("status")[0].firstChild.nodeValue);
+				item["start"] = busyElement[j].getElementsByTagName("start")[0].getAttribute("unixtime");
+				item["end"] = busyElement[j].getElementsByTagName("end")[0].getAttribute("unixtime");
+				this.userList[clientuser]["items"][this.userList[clientuser]["items"].length] = item;
+			}
+			this.updateBusyInfo(clientuser);
 		}
-		this.updateBusyInfo(clientuser);
 	}
 }
 
@@ -301,6 +312,7 @@ freebusymodule.prototype.createUsers = function(inputList)
 		this.userList[clientuser]["emailaddress"] = inputList[i]["emailaddress"];
 		this.userList[clientuser]["recipienttype"] = inputList[i]["recipienttype"];
 		this.userList[clientuser]["recipient_flags"] = inputList[i]["recipient_flags"];
+		this.userList[clientuser]["objecttype"] = inputList[i]["objecttype"];
 		this.userList[clientuser]["items"] = new Array();
 	
 		//send request
@@ -328,8 +340,7 @@ freebusymodule.prototype.createUsers = function(inputList)
  * @param inputList = Array() "see below"
  *   [0] = "user_1"   
  */ 
-freebusymodule.prototype.removeUsers = function (inputList)
-{
+freebusymodule.prototype.removeUsers = function (inputList){
 	for(i in inputList){
 		clientuser = inputList[i];
 		if(this.userList[clientuser]){
@@ -376,7 +387,6 @@ freebusymodule.prototype.execute = function(type, action)
 		this.updateUserListView();
 		this.updateBusyInfoAllAtt();
 		this.resizeGrid();
-
 	}
 }
 
@@ -427,7 +437,7 @@ freebusymodule.prototype.updateBusyInfoAllAtt = function()
 			case "start":
 				if(level == 0){
 					newItemList[i] = new Object();
-					newItemList[i]["status"] = FB_BUSY;
+					newItemList[i]["status"] = fbBusy;
 					newItemList[i]["start"] = ts[line]["time"];
 				}
 				level++;
@@ -551,16 +561,16 @@ freebusymodule.prototype.updateBusyInfo = function(clientuser)
 		
 		var className = "busy_item ";
 		switch(type){
-			case 0:
+			case fbFree:
 				className = className+"fb_free";
 				break;
-			case 1:
+			case fbTentative:
 				className = className+"fb_tentative";
 				break;
-			case 2:
+			case fbBusy:
 				className = className+"fb_busy";
 				break;
-			case 3:
+			case fbOutOfOffice:
 				className = className+"fb_outoffice";
 				break;
 			case -1:
@@ -849,14 +859,16 @@ freebusymodule.prototype.getUserList = function()
 			result[index]["emailaddress"] =  this.userList[user]["emailaddress"];
 			result[index]["recipienttype"] = this.userList[user]["recipienttype"];
 			result[index]["recipient_flags"] = this.userList[user]["recipient_flags"];
+			result[index]["objecttype"] = this.userList[user]["objecttype"];
 			index++;
 		}else if(user == "c_user"){
 			result[index] = new Object();
 			result[index]["fullname"] =  this.userList[user]["fullname"];
 			result[index]["emailaddress"] =  this.userList[user]["emailaddress"];
-			result[index]["recipienttype"] = 0;
+			result[index]["recipienttype"] = MAPI_ORIG;
 			result[index]["entryid"] = "";
 			result[index]["recipient_flags"] = this.userList[user]["recipient_flags"];
+			result[index]["objecttype"] = this.userList[user]["objecttype"];
 			index++;
 		}
 	}
@@ -884,6 +896,7 @@ freebusymodule.prototype.setUserList = function(inputUserlist)
 			 (oldUser != "all" && oldUser != "c_user")){
 				removeList[i] = oldUser;//put user on the remove list
 				i++;
+				break;	// break inner loop to avoid duplicates
 			}
 		}
 	}
@@ -904,6 +917,7 @@ freebusymodule.prototype.setUserList = function(inputUserlist)
 				newUserList[i]["resolvename"] = inputUserlist[userInput]["fullname"];
 				newUserList[i]["recipienttype"] = inputUserlist[userInput]["recipienttype"];
 				newUserList[i]["emailaddress"] = inputUserlist[userInput]["emailaddress"];
+				newUserList[i]["objecttype"] = inputUserlist[userInput]["objecttype"];
 				i++;
 			}
 		}
@@ -968,7 +982,6 @@ function fbViewKeyDownAddNameInputBox(moduleObject, element, event)
 		var newUser = new Array();
 		newUser[0] = new Object();
 		newUser[0]["resolvename"] = dhtml.getElementById("new_name","input",this.element).value;
-		newUser[0]["recipienttype"] = 1;
 		moduleObject.createUsers(newUser);
 		
 		dhtml.getElementById("new_name","input",this.element).value = "";
