@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -69,7 +71,7 @@ hierarchymodule.prototype.init = function(id, element)
 	this.folderIndex = 0;
 	this.folderEvents = new Object();
 	this.folderEvents["mousedown"] = eventHierarchySelectFolder;
-	this.folderEvents["mouseup"] = eventHierarchyChangeFolder;
+	this.folderEvents["click"] = eventHierarchyChangeFolder;
 	this.folderEvents["contextmenu"] = eventHierarchyContextMenu;
 
 	this.treeEvents = new Object();
@@ -95,6 +97,9 @@ hierarchymodule.prototype.init = function(id, element)
 	dhtml.addEvent(this.id, document.body, "mouseup", eventHierarchyCheckSelectedContextFolder);
 	dhtml.addEvent(this.id, this.contentElement, "mousemove", eventHierarchyMouseMoveScroll);
 
+	// List of keys handled by hierarchymodule
+	this.keys["new"] = KEYS["new"];
+	this.keys["open"] = KEYS["open"];
 }
 
 hierarchymodule.prototype.execute = function(type, action)
@@ -140,6 +145,9 @@ hierarchymodule.prototype.execute = function(type, action)
 						case "foldertype":
 							store["foldertype"] = item.nodeValue;
 							break;
+						case "userfullname":
+							store["userfullname"] = item.nodeValue;
+							break;
 					}
 				}
 
@@ -269,6 +277,7 @@ hierarchymodule.prototype.execute = function(type, action)
 								changeType = "move";
 							}
 							
+							this.setDocumentTitle(changedFolder);
 							this.changeFolder(this.stores[i]["tree"], changeType, changedFolder);
 						}
 					}
@@ -406,6 +415,7 @@ hierarchymodule.prototype.setFolder = function(folderobject)
 		var content_count = folderobject.getElementsByTagName("content_count")[0];
 		var content_unread = folderobject.getElementsByTagName("content_unread")[0];
 		var container_class = folderobject.getElementsByTagName("container_class")[0];
+		var store_support_mask = folderobject.getElementsByTagName("store_support_mask")[0];
 		var access = {
 			"modify": folderobject.getElementsByTagName("modify")[0],
 			"read": folderobject.getElementsByTagName("read")[0],
@@ -428,6 +438,7 @@ hierarchymodule.prototype.setFolder = function(folderobject)
 			folder["content_count"] = dhtml.getTextNode(content_count, "0");
 			folder["content_unread"] = dhtml.getTextNode(content_unread, "0");
 			folder["container_class"] = dhtml.getTextNode(container_class,"IPF.Note");
+			folder["store_support_mask"] = dhtml.getTextNode(store_support_mask,"0");
 
 			folder["access"] = new Object();
 			folder["access"]["modify"] = dhtml.getTextNode(access["modify"], "0");
@@ -463,6 +474,7 @@ hierarchymodule.prototype.createHierarchyList = function(load)
 			}
 	
 			var tree = new Tree(this.id, this.contentElement, this.treeEvents);
+			this.tree = tree;
 			store["tree"] = tree;
 			tree.createNode(store["root"]["parent_entryid"], 
 							store["root"]["entryid"], 
@@ -548,6 +560,11 @@ hierarchymodule.prototype.createHierarchyList = function(load)
 	}
 	
 	this.selectLastFolder(load);
+	
+	// Now hierarchy list is created, so bind keycontroller.
+	webclient.inputmanager.addObject(this, this.element);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["new"], "keyup", eventHierarchyKeyCtrlNewItem, false);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["open"], "keyup", eventHierarchyKeyCtrlOpenFolder, false);
 }
 
 /*
@@ -556,16 +573,27 @@ hierarchymodule.prototype.createHierarchyList = function(load)
  */
 hierarchymodule.prototype.selectLastFolder = function(load)
 {
-	var element = dhtml.getElementById(this.selectedFolder);
+	this.selectFolder(load, this.selectedFolder);
+}
+
+/*
+ * Opens folder in hierarchy tree
+ * @param boolean load if true then open folder else select folder
+ * @param string entryid entryid of folder which is to be opened/select
+ */
+hierarchymodule.prototype.selectFolder = function(load, entryid){
+	var element = dhtml.getElementById(entryid);
 	if(!element) {
 		var store = this.defaultstore;
 		if(store) {
 			element = dhtml.getElementById(store["defaultfolders"]["inbox"]);
 			if (webclient.settings && webclient.settings.get("global/startup/folder","inbox")=="last"){
 				element = dhtml.getElementById(webclient.settings.get("global/startup/folder_lastopened",store["defaultfolders"]["inbox"]));
-				if (!element){
-					element = dhtml.getElementById(store["defaultfolders"]["inbox"]);
-				}
+			}else if (webclient.settings.get("global/startup/folder","inbox")=="today"){	
+				element = dhtml.getElementById(webclient.settings.get("global/startup/folder_lastopened", store["subtree_entryid"]));
+			}
+			if (!element){
+				element = dhtml.getElementById(store["defaultfolders"]["inbox"]);
 			}
 		}
 	}
@@ -853,6 +881,11 @@ hierarchymodule.prototype.getStore = function(entryid)
 	return result;
 }
 
+/**
+ * Function will get folder properties from DOM, based on passed entryid of folder
+ * @param			HexString		entryid					entryid of folder
+ * @return			Object			selected_folder			folder properties
+ */
 hierarchymodule.prototype.getFolder = function(entryid)
 {
 	this.isRootFolder = false;
@@ -875,6 +908,7 @@ hierarchymodule.prototype.getFolder = function(entryid)
 					this.folderIndex = j;
 					this.folderstoreid = this.stores[i]["id"];
 					folder["storeid"] = this.folderstoreid;
+					folder["userfullname"] = this.stores[i]["userfullname"];
 					return folder;
 				}
 			}
@@ -998,7 +1032,7 @@ hierarchymodule.prototype.showSharedFolderActions = function()
 	this.resize(); // TODO: via LayoutManager
 }
 
-hierarchymodule.prototype.openSharedFolder = function(username, foldertype)
+hierarchymodule.prototype.openSharedFolder = function(username, foldertype, subfolders)
 {
     username = username.toLowerCase();
 	if (typeof foldertype == "undefined"){
@@ -1026,6 +1060,7 @@ hierarchymodule.prototype.openSharedFolder = function(username, foldertype)
 	var data = new Object();
 	data["username"] = username;
 	data["foldertype"] = foldertype;
+	data["subfolders"] = subfolders;
 	webclient.xmlrequest.addData(this, "opensharedfolder", data);
 	
 	return true;
@@ -1051,6 +1086,24 @@ hierarchymodule.prototype.closeSharedFolder = function(username, foldertype)
 	}
 }
 
+/**
+ * Fucntion which shows folder name and number of unread message in that folder in titlebar of browser.
+ * For example- 'Inbox (9) - Zarafa Webaccess'
+ *@param Object object which specifices properties of opened folder.
+ */
+hierarchymodule.prototype.setDocumentTitle = function (folder)
+{
+	// Check this folder is opened.
+	if (this.selectedFolder === folder["entryid"]) {
+		var folderDisplayName = folder["display_name"];
+
+		// See if user's fullname is defined because we want to distinguish between shared folders.
+		if (typeof folder["userfullname"] != 'undefined' && folder["userfullname"].trim().length > 0) folderDisplayName = folder["userfullname"] +" - "+ folder["display_name"];
+
+		document.title = ((folder["content_unread"] != "0") ? folderDisplayName +" (" + folder["content_unread"] + ") " : folderDisplayName) + " - " + _("Zarafa Webaccess");
+	}
+}
+
 function eventHierarchyCheckSelectedContextFolder(moduleObject, element, event)
 {
 	if(moduleObject.selectedContextFolder) {
@@ -1113,16 +1166,17 @@ function eventHierarchySelectFolder(moduleObject, element, event)
 
 function eventHierarchyShowBranch(moduleObject, element, event)
 {
-	var objBranch = dhtml.getElementById("branch" + element.parentNode.id).style;
-	var display = "block";
-	var state = "open";
+	// The toggleBranch method retuns the new state of the folder
+	var state = this.tree.toggleBranch(element.parentNode.id);
 
-	if(objBranch.display == "block") {
-		display = "none";
-		state = "closed";
+	switch(state){
+		case this.tree.FOLDER_STATE_OPEN:
+			state = "open";
+			break;
+		case this.tree.FOLDER_STATE_CLOSED:
+			state = "closed";
+			break;
 	}
-	
-	objBranch.display = display;
 
 	if(moduleObject.openedFolders) {
 		moduleObject.openedFolders[element.parentNode.id] = state;
@@ -1138,7 +1192,7 @@ function eventHierarchyShowBranch(moduleObject, element, event)
 	if (moduleObject.isParentOfSelected(folder)){
 		var folderElement = element.parentNode.getElementsByTagName("div")[1];
 		dhtml.executeEvent(folderElement, "mousedown");
-		dhtml.executeEvent(folderElement, "mouseup");
+		dhtml.executeEvent(folderElement, "click");
 	}
 }
 
@@ -1166,8 +1220,7 @@ function eventHierarchyChangeFolder(moduleObject, element, event)
 			
 			moduleObject.setNumberItems(folder["content_count"], folder["content_unread"]);
 			moduleObject.sendEvent("changefolder", storeid, folder);
-
-			document.title = (folder["content_unread"] != "0") ? folder["display_name"]+" (" + folder["content_unread"] + ") " : folder["display_name"];
+			moduleObject.setDocumentTitle(folder);
 		}
 	}
 }
@@ -1248,13 +1301,8 @@ function eventHierarchyOpenFolder(moduleObject, element, event)
 {
 	var entryid = element.parentNode.elementid;
 	if(entryid) {
-		var folder = dhtml.getElementById(entryid);
-		var folderName = folder.getElementsByTagName("div")[1];
-		if(folderName) {
-			dhtml.executeEvent(folderName, "mousedown");
-			dhtml.executeEvent(folderName, "mouseup");
-		}
-		
+		moduleObject.selectFolder(true, entryid);
+
 		element.parentNode.style.display = "none";
 	}
 }
@@ -1263,21 +1311,21 @@ function eventHierarchyCopyFolder(moduleObject, element, event)
 {
 	element.parentNode.style.display = "none";
 	var folder = moduleObject.getFolder(moduleObject.selectedContextFolder);
-	webclient.openModalDialog(moduleObject, "copyfolder", DIALOG_URL+"task=copyfolder_modal&source_entryid="+folder.entryid, 300, 400);
+	webclient.openModalDialog(moduleObject, "copyfolder", DIALOG_URL+"task=copyfolder_modal&source_entryid="+folder.entryid, 300, 400, null, null, {parentModule: moduleObject});
 }
 
 function eventHierarchyNewFolder(moduleObject, element, event)
 {
 	element.parentNode.style.display = "none";
 	var folder = moduleObject.getFolder(moduleObject.selectedContextFolder);
-	webclient.openModalDialog(moduleObject, "newfolder", DIALOG_URL+"task=createfolder_modal&parent_entryid="+folder.entryid, 300, 420);
+	webclient.openModalDialog(moduleObject, "newfolder", DIALOG_URL+"task=createfolder_modal&parent_entryid="+folder.entryid, 300, 420, null, null, {parentModule: moduleObject});
 }
 
 function eventHierarchyModifyFolder(moduleObject, element, event)
 {
 	element.parentNode.style.display = "none";
 	var folder = moduleObject.getFolder(moduleObject.selectedContextFolder);
-	webclient.openModalDialog(moduleObject, "modifyfolder", DIALOG_URL+"task=modifyfolder_modal&entryid="+folder.entryid, 300, 150);
+	webclient.openModalDialog(moduleObject, "modifyfolder", DIALOG_URL+"task=modifyfolder_modal&entryid="+folder.entryid, 300, 150, null, null, {parentModule: moduleObject});
 }
 
 function eventHierarchyMarkMessagesRead(moduleObject, element, event)
@@ -1326,11 +1374,12 @@ function eventAdvancedCalendarClick(moduleObject, element, event)
 		dragdrop.updateTargets("folder");
 	}
 	webclient.loadModule("multiusercalendarmodule", "MultiUserCalendar", "main", null, BORDER_LAYOUT);
+	moduleObject.selectedFolder = false;
 }
 
 function callBackSharedFolder(result, module)
 {
-    return module.openSharedFolder(result.username, result.folder);
+    return module.openSharedFolder(result.username, result.folder, result.subfolders);
 }
 
 function eventHierarchyCloseStore(moduleObject, element, event)
@@ -1359,7 +1408,7 @@ function eventHierarchyAddToFavoriteFolder(moduleObject, element, event)
 {
 	element.parentNode.style.display = "none";
 	var folder = moduleObject.getFolder(moduleObject.selectedContextFolder);
-	webclient.openModalDialog(moduleObject, "addtofavorite", DIALOG_URL+"task=addtofavorite_modal&foldername="+folder.display_name+"&entryid="+folder.entryid, 300, 320);
+	webclient.openModalDialog(moduleObject, "addtofavorite", DIALOG_URL+"task=addtofavorite_modal&foldername="+folder.display_name+"&entryid="+folder.entryid, 300, 320, null, null, {parentModule: moduleObject});
 }
 /**
  * Function which check whether entryID is of Favorites folder.
@@ -1378,3 +1427,122 @@ hierarchymodule.prototype.isFavoritesFolder = function(entryID)
 	
 	return result;
 }
+/**
+ * Function which handles keys combinations for creating new item.
+ */
+function eventHierarchyKeyCtrlNewItem(moduleObject, element, event)
+{
+	var extraParams = false;
+	var item = false;
+	var folder = moduleObject.getFolder(moduleObject.selectedFolder);
+	var containerClass = "IPF.Note";
+
+	if (folder && folder.container_class)
+		containerClass = folder.container_class;
+
+	var storeID = folder.storeid;
+	var folderEntryID = folder.entryid;
+	switch (event.keyCombination)
+	{
+		case this.keys["new"]["item"]:			// New Item
+			element = webclient.menu.menuBarLeft.firstChild;
+			dhtml.executeEvent(element, "click");
+			break;
+		case this.keys["new"]["mail"]:			// New Mail
+			if (containerClass.toLowerCase().indexOf("note") == -1) {
+				folderEntryID =  moduleObject.defaultstore.defaultfolders.drafts;
+				storeID = moduleObject.defaultstore.id;
+			}
+			item = "createmail"
+			break;
+		case this.keys["new"]["appointment"]:	// New Appointment
+			item = "appointment";
+			if (containerClass.toLowerCase().indexOf(item) == -1) {
+				folderEntryID = moduleObject.defaultstore.defaultfolders.calendar;
+				storeID = moduleObject.defaultstore.id;
+			}
+			var dtmodule = webclient.getModulesByName("datepickerlistmodule");
+			if (dtmodule[0] && dtmodule[0].selectedDate){
+				newappDate = new Date(dtmodule[0].selectedDate+((webclient.settings.get("calendar/workdaystart",9*60)*ONE_HOUR)/60));
+				extraParams = (extraParams?extraParams+"&":"")+("date="+newappDate.getTime()/1000);
+			}
+			break;
+		case this.keys["new"]["meeting_request"]:		// New Meeting Request
+			item = "appointment";
+			if (containerClass.toLowerCase().indexOf(item) == -1) {
+				folderEntryID = moduleObject.defaultstore.defaultfolders.calendar;
+				storeID = moduleObject.defaultstore.id;
+			}
+			extraParams = "meeting=true";
+			break;
+		case this.keys["new"]["task"]:			// New Task
+		case this.keys["new"]["contact"]:		// New Contact
+		case this.keys["new"]["note"]:			// New Note
+			item = array_search(event.keyCombination, this.keys["new"]);
+			if (containerClass.toLowerCase().indexOf(item) == -1) {
+				folderEntryID = moduleObject.defaultstore.defaultfolders[item];
+				storeID = moduleObject.defaultstore.id;
+			}
+			item = (item == "note")? "stickynote" : item;
+			break;
+		case this.keys["new"]["distlist"]:		// New Distributionlist
+			item = "distlist";
+			if (containerClass.toLowerCase().indexOf("contact") == -1) {
+				folderEntryID = moduleObject.defaultstore.defaultfolders.contact;
+				storeID = moduleObject.defaultstore.id;
+			}
+			break;
+		case this.keys["new"]["folder"]:		// New Folder
+			item = "folder";
+			webclient.openWindow(moduleObject, "folder", DIALOG_URL+"task=createfolder_modal&parent_entryid=" + moduleObject.selectedFolder +(extraParams?"&"+extraParams:""), 300, 400, null, null, null, {parentModule: moduleObject});
+			break;
+	}
+	
+	if (item && item != "folder")
+		webclient.openWindow(-1, item, DIALOG_URL+"task="+ item +"_standard&storeid="+ storeID +"&parententryid="+ folderEntryID + (extraParams?"&"+extraParams:""));
+}
+/**
+ * Function which handles key combinations for opening default folders.
+ */
+function eventHierarchyKeyCtrlOpenFolder(moduleObject, element, event, keys)
+{
+	var folderName = false;
+	var windowData = new Object();
+
+	switch(event.keyCombination)
+	{
+		case this.keys["open"]["inbox"]:		// Jump to default Inbox folder
+		case this.keys["open"]["calendar"]:	// Jump to default Calendar folder
+		case this.keys["open"]["contact"]:	// Jump to default Contacts folder
+		case this.keys["open"]["task"]:		// Jump to default Tasks folder
+		case this.keys["open"]["note"]:		// Jump to default Notes folder
+		case this.keys["open"]["journal"]:	// Jump to default Journal folder
+			folderName = array_search(event.keyCombination, this.keys["open"]);
+			break;
+		case this.keys["open"]["muc"]:
+			if(MUC_AVAILABLE){
+				// Delete the datepicker module when it has been loaded
+				if (webclient.datepicker){
+					webclient.deleteModule(webclient.datepicker);
+					webclient.datepicker = null;
+					dragdrop.updateTargets("folder");
+				}
+				webclient.loadModule("multiusercalendarmodule", "MultiUserCalendar", "main", null, BORDER_LAYOUT);
+			}
+			moduleObject.selectedFolder = false;
+			break;
+		case this.keys["open"]["shared_folder"]:
+			windowData["sharetype"] = "folder";
+			webclient.openModalDialog(moduleObject, "sharedfolder", DIALOG_URL+"task=sharedfolder_modal&storeid="+ moduleObject.defaultstore["id"], 285, 200, callBackSharedFolder, this, windowData);
+			break;
+		case this.keys["open"]["shared_store"]:
+			windowData["sharetype"] = "store";
+			webclient.openModalDialog(moduleObject, "sharedfolder", DIALOG_URL+"task=sharedfolder_modal&storeid="+ moduleObject.defaultstore["id"], 285, 200, callBackSharedFolder, this, windowData);
+			break;
+	}
+
+	// If folder is already opened then do nothing.
+	if (folderName && moduleObject.selectedFolder !== moduleObject.defaultstore.defaultfolders[folderName]){
+		webclient.hierarchy.selectFolder(true, moduleObject.defaultstore.defaultfolders[folderName]);
+	}
+}
\ No newline at end of file
