@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -310,7 +312,7 @@ ItemModule.prototype.addAttachments = function(attachmentsElement, attachments)
 		{
 			var attachment = attachments[i];
 
-			if(attachment["attach_num"] && !attachment["cid"] && !attachment["hidden"]) {
+			if(attachment["attach_num"] && !attachment["hidden"]) {
 				if(typeof(this.deletedattachments[attachment["attach_num"]]) == "undefined" && typeof this.inlineimages[attachments[i]["attach_num"]] == "undefined") {
 					if(name && name.firstChild) {
 						attachment["name"] = name.firstChild.nodeValue;
@@ -554,7 +556,7 @@ ItemModule.prototype.setRecipients = function(message, actionType)
 {
 	var sender_email_address = dhtml.getXMLValue(message, "sent_representing_email_address", "").toLowerCase();
 	var sender_email_name = dhtml.getXMLValue(message, "sent_representing_name", "");
-	var sender_email_address = nameAndEmailToString(sender_email_name, sender_email_address);
+	var sender_email_address = nameAndEmailToString(sender_email_name, sender_email_address, MAPI_MAILUSER);
 	
 	var elemdata = new Array();
 
@@ -569,12 +571,13 @@ ItemModule.prototype.setRecipients = function(message, actionType)
 				var email_address = dhtml.getXMLValue(recipient, "email_address", "").toLowerCase();
 				var type = dhtml.getXMLValue(recipient, "type", "");
 				var entryid = dhtml.getXMLValue(recipient, "entryid", "");
+				var objecttype = dhtml.getXMLValue(recipient, "objecttype", "");
 
-				if (!(actionType && actionType == "replyall" && entryid==webclient.userEntryid)){
+				if (!(actionType && actionType == "replyall" && compareEntryIds(entryid,webclient.userEntryid))){
 					if(type && email_address) {
 					    if(typeof(elemdata[type]) == "undefined") elemdata[type] = new Array();
-					    
-                        elemdata[type].push(nameAndEmailToString(display_name,email_address,false));
+
+                        elemdata[type].push(nameAndEmailToString(display_name,email_address,objecttype,false));
 					} else if(type && display_name) {
 						// if unresolved email address
 						var element = dhtml.getElementById(type);
@@ -639,15 +642,18 @@ ItemModule.prototype.setRecipients = function(message, actionType)
  * Functions to do meeting requests. These are used from various modules, including the readitemmodule, the previewreaditemmodule and the appointmentitemmodule
  * @param boolean sendResponse if it is true than reponse is sent to organizer via mail otherwise it is not sent.
  */
-ItemModule.prototype.sendAcceptMeetingRequest = function(tentative, noResponse, basedate)
+ItemModule.prototype.sendAcceptMeetingRequest = function(tentative, noResponse, basedate, body)
 {
+	// Adding human readable body text that holds the start/duedate and location information.
+	body = this.addMeetingTimeInfoToBody(body, this.itemProps['startdate'], this.itemProps['duedate'], this.itemProps['location']);
+
 	var req = new Object;
-	
 	req['entryid'] = this.messageentryid;
 	req['store'] = this.storeid;
 	req['tentative'] = tentative;
+	req['body'] = body;
 
-	if (typeof basedate != 'undefined' && basedate)
+	if (typeof basedate != 'undefined' && basedate !== "false" && basedate)
 		req['basedate'] = basedate;
 
 	// if sendResponse flag is set then attach sendResponse flag with request data.
@@ -667,6 +673,11 @@ ItemModule.prototype.sendAcceptMeetingRequest = function(tentative, noResponse,
  */
 ItemModule.prototype.sendProposalMeetingRequest = function(start, end, body, basedate)
 {
+	// Adding the newly proposed time information to the body.
+	body += "\n\n\n-----------\n" + _("New Meeting Time Proposed") + " :\n" +
+					strftime(_("%A, %B %e, %Y %H:%M"), start) + " - " +
+					strftime(_("%A, %B %e, %Y %H:%M"), end);
+
 	var req = new Object;
 	var proposalinfo = new String();
 	var gmt = new String(new Date(start));
@@ -684,19 +695,27 @@ ItemModule.prototype.sendProposalMeetingRequest = function(start, end, body, bas
 	if (typeof basedate != 'undefined' && basedate)
 		req['basedate'] = basedate;
 
-	webclient.xmlrequest.addData(this, 'acceptMeetingRequest', req);
-	webclient.xmlrequest.sendRequest();
+	if(typeof parentWebclient != "undefined") {
+		parentWebclient.xmlrequest.addData(this, 'acceptMeetingRequest', req, webclient.modulePrefix);
+		parentWebclient.xmlrequest.sendRequest();
+	} else {
+		webclient.xmlrequest.addData(this, 'acceptMeetingRequest', req);
+		webclient.xmlrequest.sendRequest();
+	}
 }
 
 
-ItemModule.prototype.sendDeclineMeetingRequest = function(basedate)
+ItemModule.prototype.sendDeclineMeetingRequest = function(basedate, body)
 {
+	// Adding human readable body text that holds the start/duedate and location information.
+	body = this.addMeetingTimeInfoToBody(body, this.itemProps['startdate'], this.itemProps['duedate'], this.itemProps['location']);
+
 	var req = new Object;
-	
 	req['entryid'] = this.messageentryid;
 	req['store'] = this.storeid;
+	req['body'] = body;
 
-	if (typeof basedate != 'undefined' && basedate)
+	if (typeof basedate != 'undefined' && basedate !== "false" && basedate)
 		req['basedate'] = basedate;
 
 	if(typeof parentWebclient != "undefined") {
@@ -708,9 +727,29 @@ ItemModule.prototype.sendDeclineMeetingRequest = function(basedate)
 	}
 }
 
-ItemModule.prototype.acceptMeetingRequest = function(noResponse, basedate)
+/**
+ * Adding human readable body text that holds the start/duedate and the location
+ * of the message.
+ * 
+ * @param body String Body of the message
+ * @param start Number Timestamp of the start date
+ * @param due Number Timestamp of the due date
+ * @param location String Location of the message
+ */
+ItemModule.prototype.addMeetingTimeInfoToBody = function(body, start, due, location){
+	location = location || "";
+	body = _("When") + ": " +  
+					strftime(_("%A, %B %e, %Y %H:%M"), start) + " - " +
+					strftime(_("%A, %B %e, %Y %H:%M"), due) + "\n" +  
+					_("Where") + ": "  + location + "\n\n" + 
+					"*~*~*~*~*~*~*~*~*~*\n\n" + (body||"");
+	return body;
+}
+
+
+ItemModule.prototype.acceptMeetingRequest = function(noResponse, basedate, body)
 {
-	this.sendAcceptMeetingRequest(0, noResponse, basedate);
+	this.sendAcceptMeetingRequest(0, noResponse, basedate, body);
 }
 
 ItemModule.prototype.proposalMeetingRequest = function(start, end, body, basedate)
@@ -718,9 +757,9 @@ ItemModule.prototype.proposalMeetingRequest = function(start, end, body, basedat
 	this.sendProposalMeetingRequest(start, end, body, basedate);
 }
 
-ItemModule.prototype.tentativeMeetingRequest = function(noResponse, basedate)
+ItemModule.prototype.tentativeMeetingRequest = function(noResponse, basedate, body)
 {
-	this.sendAcceptMeetingRequest(1, noResponse, basedate);
+	this.sendAcceptMeetingRequest(1, noResponse, basedate, body);
 }
 
 ItemModule.prototype.removeFromCalendar = function()
@@ -801,9 +840,9 @@ ItemModule.prototype.resolveConflict = function()
 	}
 }
 
-ItemModule.prototype.declineMeetingRequest = function(basedate)
+ItemModule.prototype.declineMeetingRequest = function(basedate, body)
 {
-	this.sendDeclineMeetingRequest(basedate);
+	this.sendDeclineMeetingRequest(basedate, body);
 }
 
 ItemModule.prototype.updateItemProps = function(item)
@@ -1104,7 +1143,15 @@ function eventAttachmentClick(moduleObject, element, event)
 	 * new attachments as well.
 	 */
 	if(!attachments && moduleObject.attachments){
-		attachments = moduleObject.attachments;
+		// clone array
+		attachments = new Array();
+		for(var i in moduleObject.attachments){
+			attachments[i] = new Object();
+			for(var j in moduleObject.attachments[i]){
+				attachments[i][j] = moduleObject.attachments[i][j];
+			}
+		}
+
 		if(moduleObject.newattachments){
 			for(var i in moduleObject.newattachments){
 				attachments[attachments.length] = moduleObject.newattachments[i];
@@ -1162,7 +1209,10 @@ function eventAttachmentClick(moduleObject, element, event)
 
 				webclient.openWindow(false, attach_message_class, webclient.base_url + DIALOG_URL +"task="+ attach_message_class +"_standard&storeid=" + moduleObject.storeid + "&rootentryid=" + moduleObject.rootentryid + "&entryid=" + moduleObject.messageentryid + attachNum + "&attachNum[]=" + attach_num);
 			} else {
-				var action = webclient.base_url + "index.php?load=download_attachment&store=" + moduleObject.storeid + "&entryid=" + moduleObject.rootentryid + attachNum + "&attachNum[]=" + attach_num + "&openType=attachment";
+				var action = webclient.base_url + "index.php?load=download_attachment&store=" + moduleObject.storeid + "&attachNum[]=" + attach_num + "&openType=attachment";
+				if(moduleObject.rootentryid) {
+					action += "&entryid=" + moduleObject.rootentryid;
+				}
 
 				/**
 				 * When you have to open a file that is not yet saved to a message, we have to 
