@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -68,9 +70,6 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	this.menuItems.push(webclient.menu.createMenuItem("search", _("Search"), _("Quick Search"), eventMailListSearchBar, "S", true));
 	this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
 	this.menuItems.push(webclient.menu.createMenuItem("rules", _("Rules"), _("Edit e-mail rules"), eventMailListRules));
-	this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
-	//Add one more button to the main menu bar for performing the action of restore items
-	this.menuItems.push(webclient.menu.createMenuItem("restoreitem", _("Restore Items"), _("Restore deleted Items") , eventRestoreItems));
 
 	this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
 	this.menuItems.push(webclient.menu.createMenuItem("send_receive", _("Send/Receive"), _("Send or Receive mails") , eventSendReceiveItems));
@@ -113,6 +112,30 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	// Handle events from listmodule
 	this.addEventHandler("selectitem", this, this.onSelectItem);
 	this.addEventHandler("deletitem", this, this.onDeleteItem);
+	
+	// List of keys that should be handled
+	this.keys["respond_mail"] = KEYS["respond_mail"];
+	this.keys["readingpane"] = KEYS["readingpane"];
+
+	// register object for keycontrol
+	webclient.inputmanager.addObject(this, this.element);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["respond_mail"], "keyup", eventMailListKeyCtrlRespond, true);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["readingpane"], "keyup", eventMailListKeyCtrlToggleReadingPane, false);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["refresh"], "keyup", eventListKeyCtrlRefreshFolder);
+
+	// check for search capabilities of store
+	if(typeof data["entryid"] != "undefined" && data["entryid"] != "") {
+		var selectedFolderProps = webclient.hierarchy.getFolder(data["entryid"]);
+		if(selectedFolderProps && (selectedFolderProps["store_support_mask"] & STORE_SEARCH_OK) == STORE_SEARCH_OK) {
+			this.useSearchFolder = true;
+		}
+	} else {
+		/**
+		 * a special feature of maillistmodule, if entryid is not present then we can say that
+		 * current folder is inbox of user's own store so search folders will always be supported
+		 */
+		 this.useSearchFolder = true;
+	}
 
 	this.initializeView();
 }
@@ -121,7 +144,7 @@ maillistmodule.prototype.execute = function(type, action)
 {
 	webclient.pluginManager.triggerHook('client.module.maillistmodule.execute.before', {type: type, action: action});
 	webclient.menu.showMenu();
-		
+	
 	switch(type)
 	{
 		case "list":
@@ -142,6 +165,9 @@ maillistmodule.prototype.execute = function(type, action)
 		case "failed":
 			this.handleActionFailure(action);
 			break;
+		case "search_error":
+			this.handleSearchError(action);
+			break;
 	}
 }
 
@@ -173,7 +199,6 @@ maillistmodule.prototype.messageList = function(action)
     maillistmodule.superclass.messageList.call(this, action);
 }
 
-
 function eventLayoutSwitchPreviewpane(moduleObject, element, event){
 	element.parentNode.style.display = "none";
 	var previewMode;
@@ -184,10 +209,9 @@ function eventLayoutSwitchPreviewpane(moduleObject, element, event){
 	}else if (dhtml.hasClassName(element, "icon_previewpane_bottom")){
 		previewMode = "bottom";
 	}
-	
 	webclient.settings.set("folders/entryid_"+this.entryid+"/previewpane",previewMode);
 	if(this.isinbox)
-	    webclient.settings.set("folders/entryid_inbox/previewpane",previewMode);
+		webclient.settings.set("folders/entryid_inbox/previewpane",previewMode);
 
 	webclient.hierarchy.selectLastFolder(true); // reload this folder
 }
@@ -197,18 +221,18 @@ maillistmodule.prototype.initializeView = function()
 	if (this.title!=false){
 		this.setTitle(this.title, false, true);
 	}
-	this.topElement = dhtml.addElement(this.element, "div", "listview_topbar", "listview_topbar_"+this.id);
+	this.searchBarContainer = dhtml.addElement(this.element, "div", "listview_topbar", "listview_topbar_"+this.id);
 
 	this.contentElement = dhtml.addElement(this.element, "div");
 
 	this.viewController.initView(this.id, "email", this.contentElement, this.events);
-	
+
 	// If the entryid is not set, then we're viewing the inbox
 	var previewMode = webclient.settings.get("global/previewpane","right"); // global default
 	if(!this.entryid)
-    	previewMode = webclient.settings.get("folders/entryid_inbox/previewpane",previewMode);
-    else
-    	previewMode = webclient.settings.get("folders/entryid_"+this.entryid+"/previewpane",previewMode);
+		previewMode = webclient.settings.get("folders/entryid_inbox/previewpane",previewMode);
+	else
+		previewMode = webclient.settings.get("folders/entryid_"+this.entryid+"/previewpane",previewMode);
 	
 	if (previewMode == "right" || previewMode == "bottom"){
 		this.previewreadmailitemmodule = webclient.dispatcher.loadModule("previewreadmailitemmodule");
@@ -219,8 +243,6 @@ maillistmodule.prototype.initializeView = function()
 			this.previewreadmailitemmodule.setData(this.storeid, this.entryid);
 			if (previewMode == "right") {
 				webclient.layoutmanager.updateElements("right");
-				// Search bar is higher in smaller list view
-				this.topElement.style.height = "45px";
 			}
 		}
 	}else{
@@ -229,87 +251,7 @@ maillistmodule.prototype.initializeView = function()
 
 	this.initSearchBar();
 }
-/**
- * Function which sends a request to the server, with the action "list".
- * @param boolean useTimeOut use a time out for the request 
- */ 
-maillistmodule.prototype.search = function(useTimeOut)
-{
-	if(this.storeid && this.entryid) {
-		var data = new Object();
-		data["store"] = this.storeid;
-		data["entryid"] = this.entryid;
 
-		this.sort = this.loadSortSettings();
-		if(this.sort) {
-			data["sort"] = new Object();
-			data["sort"]["column"] = this.sort;
-		}
-		
-		this.columns = this.loadFieldSettings();
-		
-		if(this.columns) {
-			var tablecolumns = new Array();
-			for(var i = 0; i < this.columns.length; i++)
-			{
-				var column = new Object();
-				column["attributes"] = new Object();
-				column["attributes"]["action"] = this.columns[i]["action"];
-				
-				if(this.columns[i]["order"]) {
-					column["attributes"]["order"] = this.columns[i]["order"];
-				}
-				
-				column["_content"] = this.columns[i]["id"];
-				tablecolumns.push(column);	
-			}
-			
-			data["columns"] = new Object();
-			data["columns"]["column"] = tablecolumns;
-			
-			this.columns = new Array();
-		}
-		
-		
-		data["restriction"] = new Object();
-		
-		if(this.getRestrictionData) {
-			data["restriction"] = this.getRestrictionData(); 
-			if(data["restriction"] == false)
-				return; // Abort list if module requires restriction but has none
-		}
-		
-		data["restriction"]["start"] = this.rowstart;
-
-		data["subfolders"] = this.searchSubfolders;
-
-		// Retrieve data in extended (address cards view, calendar view, etc...) way 
-		// or the normal (table) way.
-		data["data_retrieval"] = (this.viewController.view=="table"?"normal":"extended");
-
-		// Only show searchindicator when using a search folder
-		if(this.storeid == webclient.hierarchy.defaultstore["id"]){
-			this.enableSearchIndicator();
-			this.isSearching = true;
-		}
-
-		webclient.xmlrequest.addData(this, "search", data);
-
-		this.viewController.loadMessage();
-	}
-}
-
-maillistmodule.prototype.enableSearchIndicator = function()
-{
-	var searchButton = dhtml.getElementById("searchfilterbutton");
-	searchButton.className = "searchindicator";
-}
-
-maillistmodule.prototype.disableSearchIndicator = function()
-{
-	var searchButton = dhtml.getElementById("searchfilterbutton");
-	searchButton.className = "searchfilterbutton";
-}
 
 maillistmodule.prototype.loadFieldSettings = function()
 {
@@ -335,70 +277,23 @@ maillistmodule.prototype.loadFieldSettings = function()
 
 maillistmodule.prototype.updateSearch = function(action)
 {
-	var searchfolderentryid = dhtml.getXMLValue(action, "searchfolderentryid", false);
-	var searchstate = dhtml.getXMLValue(action, "searchstate", 0);
-
-	if (this.isSearching || this.finalSearchRequest){
-		this.paging(action); // update paging
-		this.finalSearchRequest = false;
+	var search_error = dhtml.getXMLValue(action, "searcherror", false);
+	if(search_error) {
+		this.clearSearchBar();
+		alert(_("Error in search, please try again"));
 	}
 
-	if (this.isSearching){
-		if ((searchstate & SEARCH_REBUILD) == SEARCH_REBUILD){
-		    var module = this;
-		    setTimeout(function() {
-    			module.getSearchUpdate(searchfolderentryid);
-            }, 1000);
-		}else{
-			// request for the last time an update, because it could happen the search is stopped
-			// at the same time this request was made.
-			this.getSearchUpdate(searchfolderentryid);
-			this.isSearching = false;
-			// This check is used to fetch the last paging result comes back from
-			// the server when the this.isSearching is already set to false.
-			this.finalSearchRequest = true;
-		}
-		this.enableSearchIndicator();
-	}else{
-		this.disableSearchIndicator();
-	}
-}
-
-maillistmodule.prototype.getSearchUpdate = function(searchfolderentryid)
-{
-	var data = new Object();
-	data["store"] = this.storeid;
-	data["entryid"] = searchfolderentryid;
-
-	webclient.xmlrequest.addData(this, "updatesearch", data);
-	webclient.xmlrequest.sendRequest(); // we have to do this since we're not called from an event handler
-}
-
-maillistmodule.prototype.stopSearch = function()
-{
-	this.isSearching = false;
-	this.disableSearchIndicator();
-
-	var data = new Object();
-	data["store"] = this.storeid;
-	data["entryid"] = this.searchfolderentryid;
-
-	webclient.xmlrequest.addData(this, "stopsearch", data);
+	// call parent class' updateSearch() method
+	maillistmodule.superclass.updateSearch.call(this, action);
 }
 
 maillistmodule.prototype.getRestrictionData = function()
 {
 	var result = new Object();
-	if (this.filterRestriction){
-		result["search"] = new Array();
-		var targets = this.filterRestrictionTarget.split(" ");
-		for (var i=0;i<targets.length;i++){
-			var target = new Object();
-			target["property"] = targets[i];
-			target["value"] = this.filterRestriction;
-			result["search"].push(target);
-		}
-	}
+
+	// get search restrictions
+	result = this.getSearchRestrictionData(result);
+
 	return result;
 }
 
@@ -423,6 +318,8 @@ maillistmodule.prototype.replyMail = function(action, messageEntryid)
 
 maillistmodule.prototype.destructor = function()
 {
+	// Unregister from InputManager.
+	webclient.inputmanager.removeObject(this);
 	dhtml.removeEvent(document.body, "click", eventListCheckSelectedContextMessage);
 	
 	this.element.innerHTML = "";
@@ -438,10 +335,10 @@ maillistmodule.prototype.destructor = function()
 maillistmodule.prototype.initSearchBar = function()
 {
 	// create search bar
-	var searchText = dhtml.addElement(this.topElement, "span", false, false, _("Search")+" "+NBSP);
+	var searchText = dhtml.addElement(this.searchBarContainer, "span", false, false, _("Search")+" "+NBSP);
 
 	// create search target selector
-	var filterTarget = dhtml.addElement(this.topElement, "select", "searchfiltertarget");
+	var filterTarget = dhtml.addElement(this.searchBarContainer, "select", "searchfiltertarget");
 	(dhtml.addElement(filterTarget, "option", false, false,_("All text fields"))).value = "subject body sender_name sender_email sent_representing_name sent_representing_email to cc";
 	(dhtml.addElement(filterTarget, "option", false, false,_("Subject"))).value = "subject";
 	(dhtml.addElement(filterTarget, "option", false, false,_("Sender"))).value = "sender_name sender_email sent_representing_name sent_representing_email";
@@ -451,71 +348,77 @@ maillistmodule.prototype.initSearchBar = function()
 
 	var defaultTarget = webclient.settings.get("folders/entryid_"+this.entryid+"/searchbar/target", "0");
 	filterTarget.selectedIndex = defaultTarget;
+	
+	this.searchBarContainer.filterTarget = filterTarget; // add reference tot DOM
 
-	this.topElement.filterTarget = filterTarget; // add reference tot DOM
-
-	dhtml.addTextNode(this.topElement, NBSP+" "+_("for")+" "+NBSP);
+	dhtml.addTextNode(this.searchBarContainer, NBSP+" "+_("for")+" "+NBSP);
 
 	var previewMode = webclient.settings.get("global/previewpane","right"); // global default
-	previewMode = webclient.settings.get("folders/entryid_"+this.entryid+"/previewpane",previewMode);
+	if(!this.entryid)
+		previewMode = webclient.settings.get("folders/entryid_inbox/previewpane",previewMode);
+	else
+		previewMode = webclient.settings.get("folders/entryid_"+this.entryid+"/previewpane",previewMode);
 	
 	if (previewMode == "right"){
 		// Create a two-line search bar
-		dhtml.addElement(this.topElement, "br");
+		dhtml.addElement(this.searchBarContainer, "br");
 
 		// Shift inputbox to be directly under filterTarget
-		var spacer = dhtml.addElement(this.topElement, "div", false, false, NBSP);
+		var spacer = dhtml.addElement(this.searchBarContainer, "div", false, false, NBSP);
 		spacer.style.marginLeft = (searchText.offsetWidth-3) + "px";
 		spacer.style.display = "inline";
 	}
 	
 	// create search input element
-	var filterInputbox = dhtml.addElement(null, "input", "searchfilter");
-	filterInputbox.setAttribute("type", "text");
-	filterInputbox.setAttribute("autocomplete","off"); // workaround for Firefox 1.5 bug with autocomplete and emtpy string: "'Permission denied to get property XULElement.selectedIndex' when calling method: [nsIAutoCompletePopup::selectedIndex]"
-	filterInputbox.value = "";
+	var searchFilterInputBox = dhtml.addElement(null, "input", "searchfilter");
+	searchFilterInputBox.setAttribute("type", "text");
+	searchFilterInputBox.setAttribute("autocomplete","off"); // workaround for Firefox 1.5 bug with autocomplete and emtpy string: "'Permission denied to get property XULElement.selectedIndex' when calling method: [nsIAutoCompletePopup::selectedIndex]"
+	searchFilterInputBox.value = "";
 
-	dhtml.addEvent(this, filterInputbox, "click", eventMailListSearchBarFilterClick);
-	dhtml.addEvent(this, filterInputbox, "mousedown", eventMailListSearchBarFilterClick);
-	dhtml.addEvent(this, filterInputbox, "mousemove", eventMailListSearchBarFilterMouseMove);
-	dhtml.addEvent(this, filterInputbox, "focus", eventMailListSearchBarFilterFocus);
-	dhtml.addEvent(this, filterInputbox, "blur", eventMailListSearchBarFilterFocus);
-	dhtml.addEvent(this, filterInputbox, "keydown", eventMailListSearchBarFilterKey);
-	dhtml.addEvent(this, filterInputbox, "selectstart", eventMailListSearchBarFilterMouseMove);
+	dhtml.addEvent(this, searchFilterInputBox, "click", eventMailListSearchBarFilterClick);
+	dhtml.addEvent(this, searchFilterInputBox, "mousedown", eventMailListSearchBarFilterClick);
+	dhtml.addEvent(this, searchFilterInputBox, "mouseup", eventStopBubbling);
+	dhtml.addEvent(this, searchFilterInputBox, "mousemove", eventMailListSearchBarFilterMouseMove);
+	dhtml.addEvent(this, searchFilterInputBox, "focus", eventMailListSearchBarFilterFocus);
+	dhtml.addEvent(this, searchFilterInputBox, "blur", eventMailListSearchBarFilterFocus);
+	dhtml.addEvent(this, searchFilterInputBox, "keydown", eventMailListSearchBarFilterKey);
+	dhtml.addEvent(this, searchFilterInputBox, "selectstart", eventMailListSearchBarFilterMouseMove);
+	dhtml.addEvent(this, filterTarget, "mousedown", eventStopBubbling);
 
-	this.topElement.appendChild(filterInputbox);
-
-	this.topElement.filterInputbox = filterInputbox; // add reference to DOM
+	this.searchBarContainer.appendChild(searchFilterInputBox);
+	this.searchBarContainer.searchFilterInputBox = searchFilterInputBox; // add reference to DOM
 
 	// subfolder search
-	// Only show subfolders option in own store
-	if(this.storeid == webclient.hierarchy.defaultstore["id"]){
+	// Only show subfolders option when store supports search folders
+	if(this.useSearchFolder){
 		var searchSubfolders = dhtml.addElement(null, "input", "searchsubfolders", "searchsubfolders_"+this.id);
 		searchSubfolders.setAttribute("type", "checkbox");
-		this.topElement.appendChild(searchSubfolders);
-		dhtml.addElement(this.topElement, "label", false, false, _("Subfolders")+NBSP).setAttribute("for","searchsubfolders_"+this.id);
-		this.topElement.searchSubfolders = searchSubfolders;
+		this.searchBarContainer.appendChild(searchSubfolders);
+
+		var label = dhtml.addElement(this.searchBarContainer, "label", false, false, _("Subfolders") + NBSP);
+		label.setAttribute("for", "searchsubfolders_" + this.id);
+		this.searchBarContainer.searchSubfolders = searchSubfolders;
 	}
 
 	// create buttons
-	var filterButton = dhtml.addElement(this.topElement, "button", "searchfilterbutton", "searchfilterbutton", NBSP);
+	var filterButton = dhtml.addElement(this.searchBarContainer, "button", "searchfilterbutton", "searchfilterbutton", NBSP);
 	dhtml.addEvent(this, filterButton, "click", eventMailListSearchBarSearch);
 
-	var clearButton = dhtml.addElement(this.topElement, "button", "searchclearbutton", false, NBSP);
-	dhtml.addEvent(this, clearButton, "click", eventMailListSearchBarClear);
-	this.topElement.clearButton = clearButton; // add reference to DOM
-	this.topElement.clearButton.disabled = true;
+	var searchClearButton = dhtml.addElement(this.searchBarContainer, "button", "searchclearbutton", false, NBSP);
+	dhtml.addEvent(this, searchClearButton, "click", eventMailListSearchBarClear);
+	this.searchBarContainer.searchClearButton = searchClearButton; // add reference to DOM
+	this.searchBarContainer.searchClearButton.disabled = true;
 
 	// set the visibility of the search bar
-	var displaySearch = webclient.settings.get("folders/entryid_"+this.entryid+"/searchbar/show","false");
+	var displaySearchBar = webclient.settings.get("folders/entryid_"+this.entryid+"/searchbar/show","false");
 
-	var searchMenuItem = dhtml.getElementById("search","a",this.menuBarLeft);
-	if (displaySearch=="true"){
-		this.topElement.style.display = "block";
+	var searchMenuItem = dhtml.getElementById("search", "a", this.menuBarLeft);
+	if(displaySearchBar == "true") {
+		this.searchBarContainer.style.display = "block";
 		webclient.menu.toggleItem(searchMenuItem, true);
 		this.resize();
 	}else{
-		this.topElement.style.display = "none";
+		this.searchBarContainer.style.display = "none";
 		webclient.menu.toggleItem(searchMenuItem, false);
 	}
 }
@@ -535,10 +438,7 @@ maillistmodule.prototype.onSelectItem = function(entryid)
 {
 	if(this.previewreadmailitemmodule) {
 		if(this.previewreadmailitemmodule.messageentryid != entryid) {
-			if (this.previewTimer){
-				window.clearTimeout(this.previewTimer);
-			}
-			this.previewTimer = window.setTimeout("eventListPreviewTimer("+this.id+",'"+entryid+"')", 250);
+			eventListPreviewTimer(this.id, entryid);
 		}
 	}
 }
@@ -601,7 +501,7 @@ function eventMailListContextMenuReply(moduleObject, element, event)
 	element.parentNode.style.display = "none";
 	moduleObject.replyMail("reply", moduleObject.entryids[moduleObject.selectedContextMessage]);
 	
-	eventListCheckSelectedContextMessage(this);
+	eventListCheckSelectedContextMessage(moduleObject);
 }
 
 function eventMailListContextMenuReplyAll(moduleObject, element, event)
@@ -609,7 +509,7 @@ function eventMailListContextMenuReplyAll(moduleObject, element, event)
 	element.parentNode.style.display = "none";
 	moduleObject.replyMail("replyall", moduleObject.entryids[moduleObject.selectedContextMessage]);
 	
-	eventListCheckSelectedContextMessage(this);
+	eventListCheckSelectedContextMessage(moduleObject);
 }
 
 function eventMailListContextMenuForward(moduleObject, element, event)
@@ -617,7 +517,7 @@ function eventMailListContextMenuForward(moduleObject, element, event)
 	element.parentNode.style.display = "none";
 	moduleObject.replyMail("forward", moduleObject.entryids[moduleObject.selectedContextMessage]);
 	
-	eventListCheckSelectedContextMessage(this);
+	eventListCheckSelectedContextMessage(moduleObject);
 }
 
 function eventMailListContextMenuMessageFlag(moduleObject, element, event)
@@ -649,9 +549,9 @@ function eventMailListContextMenuRedFlag(moduleObject, element, event)
 	element.parentNode.style.display = "none";
 	var items = moduleObject.getSelectedMessages(element.parentNode.elementid);
 	for(i in items){
-		moduleObject.flagStatus(moduleObject.entryids[items[i]], 2, 6);
+		moduleObject.flagStatus(moduleObject.entryids[items[i]], olFlagMarked, olRedFlagIcon);
 	}
-	eventListCheckSelectedContextMessage(this);
+	eventListCheckSelectedContextMessage(moduleObject);
 }
 
 function eventMailListContextMenuFlagComplete(moduleObject, element, event)
@@ -659,9 +559,9 @@ function eventMailListContextMenuFlagComplete(moduleObject, element, event)
 	element.parentNode.style.display = "none";
 	var items = moduleObject.getSelectedMessages(element.parentNode.elementid);
 	for(i in items){
-		moduleObject.flagStatus(moduleObject.entryids[items[i]], 1, 0);
+		moduleObject.flagStatus(moduleObject.entryids[items[i]], olFlagComplete, olNoFlagIcon);
 	}
-	eventListCheckSelectedContextMessage(this);
+	eventListCheckSelectedContextMessage(moduleObject);
 }
 
 function eventMailListContextMenuDeleteFlag(moduleObject, element, event)
@@ -669,25 +569,60 @@ function eventMailListContextMenuDeleteFlag(moduleObject, element, event)
 	element.parentNode.style.display = "none";
 	var items = moduleObject.getSelectedMessages(element.parentNode.elementid);
 	for(i in items){
-		moduleObject.flagStatus(moduleObject.entryids[items[i]], 0, 0);
+		moduleObject.flagStatus(moduleObject.entryids[items[i]], olNoFlag, olNoFlagIcon);
 	}
-	eventListCheckSelectedContextMessage(this);
+	eventListCheckSelectedContextMessage(moduleObject);
+}
+
+function eventMailListContextMenuMessageFlagChanged(moduleObject, element, event)
+{
+	var flagId = element.id;
+	var elementIcon = 6;
+	if(flagId == "flag_icon_red") {
+		eventMailListContextMenuFlagIcon(moduleObject, element, olRedFlagIcon);
+	} else if(flagId == "flag_icon_blue") {
+		eventMailListContextMenuFlagIcon(moduleObject, element, olBlueFlagIcon);
+	} else if(flagId == "flag_icon_yellow") {
+		eventMailListContextMenuFlagIcon(moduleObject, element, olYellowFlagIcon);
+	} else if(flagId == "flag_icon_green") {
+		eventMailListContextMenuFlagIcon(moduleObject, element, olGreenFlagIcon);
+	} else if(flagId == "flag_icon_orange") {
+		eventMailListContextMenuFlagIcon(moduleObject, element, olOrangeFlagIcon);
+	} else if(flagId == "flag_icon_purple") {
+		eventMailListContextMenuFlagIcon(moduleObject, element, olPurpleFlagIcon);
+	} else if(flagId == "flag_status_complete") {
+		eventMailListContextMenuFlagComplete(moduleObject, element, event);
+	} else if(flagId == "flagno") {
+		eventMailListContextMenuDeleteFlag(moduleObject, element, event);
+	}
+
+	eventListCheckSelectedContextMessage(moduleObject);
+}
+
+function eventMailListContextMenuFlagIcon(moduleObject, element, flagIcon)
+{
+	element.parentNode.style.display = "none";
+	var items = moduleObject.getSelectedMessages(element.parentNode.elementid);
+	for(i in items){
+		moduleObject.flagStatus(moduleObject.entryids[items[i]], olFlagMarked, flagIcon);
+	}
+	eventListCheckSelectedContextMessage(moduleObject);
 }
 
 function eventMailListSearchBar(moduleObject, element, event)
 {
-	if (moduleObject.topElement.style.display=="none"){
+	if (moduleObject.searchBarContainer.style.display=="none"){
 		webclient.menu.toggleItem(element, true);
 		webclient.settings.set("folders/entryid_"+moduleObject.entryid+"/searchbar/show", "true");
-		moduleObject.topElement.style.display = "block";
+		moduleObject.searchBarContainer.style.display = "block";
 	}else{
 		webclient.menu.toggleItem(element, false);
 		webclient.settings.set("folders/entryid_"+moduleObject.entryid+"/searchbar/show", "false");
-		moduleObject.topElement.style.display = "none";
+		moduleObject.searchBarContainer.style.display = "none";
 
 		// when there is a restriction active, remove it and reload maillist
-		if (typeof moduleObject.filterRestriction != "undefined" && moduleObject.filterRestriction != false){
-			eventMailListSearchBarClear(moduleObject, element, event);
+		if(moduleObject.filterRestriction != false){
+			this.clearSearchBar();
 		}
 	}
 	moduleObject.resize();
@@ -718,10 +653,13 @@ function eventMailListSearchBarFilterMouseMove(moduleObject, element, event)
 
 function eventMailListSearchBarFilterKey(moduleObject, element, event)
 {
-	moduleObject.topElement.clearButton.disabled = false;
+	moduleObject.searchBarContainer.searchClearButton.disabled = false;
+
+	// don't send key events to parent div
+	// to prevent firing events registered by table view 
+	event.stopPropagation();
 
 	if (event.keyCode == 13){
-		event.stopPropagation(); // stop other keyboard events
 		eventMailListSearchBarSearch(moduleObject, element, event);
 		return false;
 	}
@@ -730,9 +668,10 @@ function eventMailListSearchBarFilterKey(moduleObject, element, event)
 
 function eventMailListSearchBarSearch(moduleObject, element, event)
 {
-	var input = moduleObject.topElement.filterInputbox;
-	var target = moduleObject.topElement.filterTarget;
-	var subfolders = moduleObject.topElement.searchSubfolders;
+	var input = moduleObject.searchBarContainer.searchFilterInputBox;
+	var target = moduleObject.searchBarContainer.filterTarget;
+	var subfolders = moduleObject.searchBarContainer.searchSubfolders;
+
 	if (input.value.trim() != ""){
 		moduleObject.filterRestriction = input.value;
 		moduleObject.filterRestrictionTarget = target.value;
@@ -741,7 +680,14 @@ function eventMailListSearchBarSearch(moduleObject, element, event)
 		else
 			moduleObject.searchSubfolders = false;
 		moduleObject.rowstart = 0;
+		moduleObject.searchInProgress = true;
 		webclient.settings.set("folders/entryid_"+moduleObject.entryid+"/searchbar/target", target.selectedIndex);
+
+		// enable search indicator
+		if(moduleObject.useSearchFolder) {
+			moduleObject.enableSearchIndicator();
+		}
+
 		moduleObject.search();
 		input.blur();
 	}
@@ -749,15 +695,7 @@ function eventMailListSearchBarSearch(moduleObject, element, event)
 
 function eventMailListSearchBarClear(moduleObject, element, event)
 {
-	moduleObject.stopSearch();
-	var input = moduleObject.topElement.filterInputbox;
-	input.value = "";
-	moduleObject.filterRestriction = false;
-	moduleObject.filterRestrictionTarget = false;
-	moduleObject.rowstart = 0;
-	moduleObject.list();
-	moduleObject.topElement.clearButton.disabled = true;
-	input.blur();
+	moduleObject.clearSearchBar();
 }
 
 function eventMailListRules(moduleObject, element, event)
@@ -765,22 +703,6 @@ function eventMailListRules(moduleObject, element, event)
 	webclient.openModalDialog(moduleObject, "rules", DIALOG_URL+"task=rules_modal&storeid=" + this.storeid, 500, 300);
 }
 
-/**
- * function for handle the restore button on main menu bar of folders.
- * @param object moduleObject Contains all the properties of a module object.
- * @param dom_element element The dom element's reference on which the event gets fired.
- * @param event event Event name
- * return - none, opens a dialog window.
- */
-function eventRestoreItems(moduleObject, element, event){
-	//task name should be "window.name _ standard" // as we are opening a standard dialog box.
-	webclient.openWindow(
-		moduleObject, 
-		"restoreitems", 
-		DIALOG_URL+"task=restoreitems_standard&storeid=" + this.storeid + "&parententryid=" + this.entryid,
-		700, 500, false);
-}
-
 /**
  * function for sent the outbox mails and receive the new mail.
  * @param object moduleObject Contains all the properties of a module object.
@@ -791,3 +713,48 @@ function eventSendReceiveItems(moduleObject, element, event){
 	moduleObject.list();
 }
 
+/**
+ * Keycontrok function which handles respond actions for a selected message.
+ */
+function eventMailListKeyCtrlRespond(moduleObject, element, event)
+{
+	// Check is messages are selected.
+	if(moduleObject && moduleObject.selectedMessages && moduleObject.selectedMessages.length > 0) {
+		var action = false;
+		
+		switch(event.keyCombination)
+		{
+			case this.keys["respond_mail"]["reply"]:
+			case this.keys["respond_mail"]["replyall"]:
+			case this.keys["respond_mail"]["forward"]:
+				action = array_search(event.keyCombination, this.keys["respond_mail"]);
+				break;
+		}
+		// Handle action for a selected message.
+		moduleObject.replyMail(action, moduleObject.entryids[moduleObject.selectedMessages[0]]);
+	}
+}
+/**
+ * Keycontrol function which toggles reading pane.
+ */
+function eventMailListKeyCtrlToggleReadingPane(moduleObject, element, event)
+{
+	if (moduleObject && moduleObject.entryid){
+		// Get reading pane status for folder
+		var currentPreviewMode = webclient.settings.get("folders/entryid_"+ moduleObject.entryid +"/previewpane", "right");
+		var previewMode = "right";
+		
+		if (currentPreviewMode == "right")
+			previewMode = "bottom";
+		else if (currentPreviewMode == "bottom")
+			previewMode = "off";
+		else if (currentPreviewMode == "off")
+			previewMode = "right";
+			
+		webclient.settings.set("folders/entryid_"+ moduleObject.entryid +"/previewpane", previewMode);
+		if(this.isinbox)
+		    webclient.settings.set("folders/entryid_inbox/previewpane", previewMode);
+	
+		webclient.hierarchy.selectLastFolder(true); // reload this folder
+	}
+}
\ No newline at end of file
