@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -83,6 +85,7 @@ Module.prototype.init = function(id, element, title)
 	
 	this.contentElement = false;
 	this.title = title;
+	this.keys = new Array();
 }
 
 /**
@@ -155,8 +158,9 @@ Module.prototype.setTitle = function(title, subtitle, page, viewOptions, selecte
 	
 	if(page) {
 		var pageElement = dhtml.addElement(titleElement, "div", "page", "page_"+this.id);
-		dhtml.addElement(pageElement, "div", "page_title", false, _("Page")+":");
-		dhtml.addElement(pageElement, "div", false, "pagecombobox");
+
+		// add moduleid to pagecombobox element to avoid duplicate element ids
+		dhtml.addElement(pageElement, "div", "", "pageelement_"+this.id);
 	}
 	
 	if(viewOptions) {
