@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -221,6 +223,7 @@ previewreadmailitemmodule.prototype.item = function(action)
 			readmailitemmodule.prototype.setFrom(message);
 			readmailitemmodule.prototype.setRepliedForwardedInfo(message);
 			readmailitemmodule.prototype.setImportanceSensitivityInfo(message);
+			readmailitemmodule.prototype.setConflictAppointmentInfo(message);
 		}
 
 		var isCounterProposal = (dhtml.getXMLValue(message,"counter_proposal", 0) > 0)?true:false;
@@ -290,8 +293,8 @@ previewreadmailitemmodule.prototype.item = function(action)
 					dhtml.getElementById("tentative").style.display = "none";
 					dhtml.getElementById("proposenewtime").style.display = "none";
 					
-					var textMeetingResponseText = _("This meeting request was updated after this message was sent. You Should open a later update or open the item on the calendar.");
-					this.showextrainfo(textMeetingResponseText);
+					var textMeetingResponseText = _("This meeting request was updated after this message was sent. You should open the latest update or open the item from the calendar.");
+					this.showextrainfo(textMeetingResponseText, true);
 				} else {
 					dhtml.getElementById("notcurrent").style.display = "none";
 				}
@@ -340,6 +343,14 @@ previewreadmailitemmodule.prototype.item = function(action)
 		
 	}
 
+	if(dhtml.getXMLValue(message, "delegated_by_rule", false)) {
+		// don't show this message for MRs in sent items of delegator
+		if(dhtml.getXMLValue(message, "rcvd_representing_name", "") != dhtml.getXMLValue(message, "received_by_name", "")) {
+			var receivedString = _("Received for") + NBSP + dhtml.getXMLValue(message, "rcvd_representing_name", "");
+			this.showextrainfo(receivedString);
+		}
+	}
+
 	dhtml.addEvent(this.id, window, "resize", eventPreviewItemResize);
 
 	//this.itemEntryID will save the entryid and will mark it at destructing or next mail as read
@@ -436,6 +447,7 @@ function eventPreviewLoaded(moduleID)
 		html_body.contentWindow.document.body.style.margin = "0";
 		
 		html_body.contentWindow.document.body.onmousedown = eventPreviewItemMouseDown;
+		html_body.contentWindow.document.body.onmouseup = eventPreviewItemMouseUp;
 		html_body.contentWindow.onscroll = eventPreviewItemMouseDown;	
 	}
 
@@ -452,19 +464,37 @@ function eventPreviewItemMouseDown()
 	dhtml.executeEvent(document.body, "mouseup");
 }
 
+/**
+ * This function is used to propagate iframe mouseup event to main
+ * body's mouseup event so when dropping an item to iframe will be handled properly
+ */
+function eventPreviewItemMouseUp()
+{
+	dhtml.executeEvent(document.body, "mouseup");
+}
+
 function eventPreviewItemAcceptClick(moduleObject, element, event)
 {
-	moduleObject.acceptMeetingRequest();
+	var windowData = new Object();
+	windowData['module'] = moduleObject;
+	windowData['requestStatus'] = 'accept';
+	webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, previewreadmailitemSendMRMailConfirmation_dialog_callback, null, windowData);
 }
 
 function eventPreviewItemTentativeClick(moduleObject, element, event)
 {
-	moduleObject.tentativeMeetingRequest();
+	var windowData = new Object();
+	windowData['module'] = moduleObject;
+	windowData['requestStatus'] = 'tentative';
+	webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, previewreadmailitemSendMRMailConfirmation_dialog_callback, null, windowData);
 }
 
 function eventPreviewItemDeclineClick(moduleObject, element, event)
 {
-	moduleObject.declineMeetingRequest();
+	var windowData = new Object();
+	windowData['module'] = moduleObject;
+	windowData['requestStatus'] = 'decline';
+	webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, previewreadmailitemSendMRMailConfirmation_dialog_callback, null, windowData);
 }
 
 function eventPreviewItemProposeNewTimeClick(moduleObject, element, event)
@@ -515,6 +545,32 @@ function previewreadmailitemProposenewtime_dialog_callback(result, callbackData)
 
 }
 
+function previewreadmailitemSendMRMailConfirmation_dialog_callback(noResponse)
+{
+	var body = false;
+	if(typeof noResponse == "object"){
+		body = noResponse.body;
+		noResponse = noResponse.type;
+	}
+
+	if(this.windowData)
+		var moduleObject = this.windowData["module"]; 
+		var requestStatus = this.windowData["requestStatus"]; 
+
+	switch(requestStatus)
+	{
+		case "accept":
+			moduleObject.acceptMeetingRequest(noResponse, false, body);
+			break;
+		case "tentative":
+			moduleObject.tentativeMeetingRequest(noResponse, false, body);
+			break;
+		case "decline":
+			moduleObject.declineMeetingRequest(false, body);
+			break;
+	}
+}
+
 function eventPreviewItemButtonOver(moduleObject, element, event)
 {
 	dhtml.toggleClassName(element, "menubuttonover");
@@ -557,9 +613,14 @@ function eventPreviewItemRemoveFromCalendarClick(moduleObject, element, event)
  * Function which shows extrainfo about the item.
  * @param string value information that is to be shown.
  */
-previewreadmailitemmodule.prototype.showextrainfo = function (value)
+previewreadmailitemmodule.prototype.showextrainfo = function (value, deleteAllChildren)
 {
 	var elemExtraInfo = dhtml.getElementById("extrainfo");
+
+	if (typeof deleteAllChildren != 'undefined' && deleteAllChildren) {
+		dhtml.deleteAllChildren(elemExtraInfo);
+	}
+
 	dhtml.addElement(elemExtraInfo, "p", false, false, value);
 	elemExtraInfo.style.display = "block";
 }
\ No newline at end of file
