@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -63,6 +65,12 @@ printitemmodule.prototype.init = function(id)
 {
 	printitemmodule.superclass.init.call(this, id);
 	this.printpreview = false;
+	
+	// Add keycontrol event
+	webclient.inputmanager.addObject(this);
+
+	this.keys["print"] = KEYS["edit_item"]["print"];
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys, "keyup", eventPrintItemKeyCtrlPrint);
 }
 
 printitemmodule.prototype.item = function(action)
@@ -232,9 +240,19 @@ printitemmodule.prototype.item = function(action)
 			}
 			this.printpreview = new printMessageItem();
 	}
-	
+	//update recipients 
+	this.updateItemProps(message);
+	this.propData["recipients"] = this.itemProps["recipients"];
+
 	// give control to the printpreview object.
 	if (this.printpreview){
 		this.printpreview.init(this, printing_frame);
 	}
 }
+function eventPrintItemKeyCtrlPrint(moduleObject, element, event)
+{
+	if (printing_frame){
+		printing_frame.focus();
+		printing_frame.print();
+	}
+}
\ No newline at end of file
