@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -71,8 +73,14 @@ printlistmodule.prototype.init = function(id, element, title, data) {
 
 	this.data = data;
 	this.element = element;
+	this.keys = new Array();
+	this.keys["print"] = KEYS["edit_item"]["print"];
 
 	this.initializeView(this.data["view"]);
+	
+	// Add keycontrol event
+	webclient.inputmanager.addObject(this);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys, "keyup", eventPrintListKeyCtrlPrint);
 }
 
 /**
@@ -213,6 +221,14 @@ printlistmodule.prototype.list = function() {
 	}
 }
 
+/**
+ * Function which resizes the view.
+ */
+printlistmodule.prototype.resize = function()
+{
+	this.viewObject.resizeView();
+}
+
 /**
  * this function is called on clicking on print button
  * this function will copy all printing contents to iframe and then print the iframe
@@ -243,4 +259,9 @@ printlistmodule.prototype.printIFrame = function() {
 		window.frames["printing_frame"].focus();
 		window.frames["printing_frame"].print();
 	}
+}
+
+function eventPrintListKeyCtrlPrint(moduleObject, element, event)
+{
+	moduleObject.printIFrame();
 }
\ No newline at end of file
