@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -84,12 +86,16 @@ printMessageItem.prototype.createHTML = function()
 	this.doc.writeln('	<body>');
 	this.doc.writeln('		<h1 style="font-family: sans-serif; font-size: 12pt;border-bottom: 3px solid #000;">'+webclient.fullname+'</h1>');
 
+	// populate from/to/cc/bcc fields for name and email address
+	this.populateNameFields();
+
 	// write mail properties (from/to/cc/subject etc)
 	this.doc.writeln('		<table cellspacing=0 cellpadding=0 style="font-family: sans-serif; font-size: 10pt">');
-	this.writeLine(_("From"),"sent_representing_name");
+	this.writeLine(_("From"),"from_email_combined");
 	this.writeLine(_("Sent"),"message_delivery_time");
-	this.writeLine(_("To"),"display_to");
-	this.writeLine(_("CC"),"display_cc");
+	this.writeLine(_("To"),"to_email_combined");
+	this.writeLine(_("CC"),"cc_email_combined");
+	this.writeLine(_("BCC"),"bcc_email_combined");
 	this.writeLine(_("Subject"),"subject");
 	this.writeLine(_("Creation Time"),"creation_time","IPM.StickyNote");
 	this.writeLine(_("Modified"),"last_modification_time");
@@ -186,6 +192,7 @@ printMessageItem.prototype.createHTML = function()
 
 	// write mail
 	this.writeBody();
+	this.doc.body.setAttribute("style","word-wrap:break-word");
 
 	// write footer
 	this.doc.writeln('	</body>');
@@ -214,7 +221,7 @@ printMessageItem.prototype.writeBody = function()
 
 		if (!this.props["isHTML"] || this.props["isHTML"]=="0"){
 			content = convertPlainToHtml(content);
-			content = "<pre style=\"white-space: -moz-pre-wrap; word-wrap: break-word;\">" + content + "</pre>";
+			content = "<pre style=\"white-space: -moz-pre-wrap; white-space: -pre-wrap; white-space: -o-pre-wrap; white-space: pre-wrap; word-wrap: break-word;\">" + content + "</pre>";
 		}
 
 		this.doc.write(content);
@@ -256,4 +263,29 @@ printMessageItem.prototype.writeMembers = function(msgClass) {
 			}
 		}
 	}
+}
+
+/**
+ * Populate the display name with email in a string representing to respective fields.
+ */
+printMessageItem.prototype.populateNameFields = function() {
+	// populate from field
+	if(this.props["sent_representing_name"])
+		this.props["from_email_combined"] = this.props["sent_representing_name"] + " &lt;" + this.props["sent_representing_email_address"] +"&gt;";
+
+	// populate to/cc/bcc fields
+	var tempObj = new Object();
+	if(this.props.recipients && this.props.recipients.recipient){
+		for (var i=0;i<this.props.recipients.recipient.length;i++){
+			var recip = this.props.recipients.recipient[i];
+			var displayName = recip["display_name"] + " &lt;" + recip["email_address"] +"&gt;";
+			var type = recip["type"];
+			if(typeof tempObj[type] == "undefined")
+				tempObj[type] = new Array();
+			tempObj[type].push(displayName);
+		}
+	}
+	if(tempObj["to"]) this.props["to_email_combined"] = tempObj["to"].join(", ");
+	if(tempObj["cc"]) this.props["cc_email_combined"] = tempObj["cc"].join(", ");
+	if(tempObj["bcc"]) this.props["bcc_email_combined"] = tempObj["bcc"].join(", ");
 }
\ No newline at end of file
