@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -323,7 +325,11 @@ function eventPermissionAddUser(moduleObject, element, event)
 	callBackData = new Object;
 	callBackData.module = moduleObject;
 	
-	webclient.openModalDialog(moduleObject, 'addressbook', DIALOG_URL+'task=addressbook_modal&storeid='+moduleObject.store+'&type=displayname&source=gab&', 550, 410, abCallBack, callBackData);
+	var windowData = new Object();
+	windowData["hide_users"] = ["non_active", "contact", "equipment", "room"];
+	windowData["hide_groups"] = ["dynamic", "normal"];
+
+	webclient.openModalDialog(moduleObject, 'addressbook', DIALOG_URL+'task=addressbook_modal&storeid='+moduleObject.store+'&type=displayname&source=gab&', 800, 500, abCallBack, callBackData, windowData);
 }
 
 function abCallBack(userdata, module)
