@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -59,6 +61,15 @@ function readmailitemmodule(id)
 readmailitemmodule.prototype.init = function(id)
 {
 	readmailitemmodule.superclass.init.call(this, id);
+
+	this.keys["respond_mail"] = KEYS["respond_mail"];
+	this.keys["edit_item"] = KEYS["edit_item"];
+	this.keys["respond_meeting"] = KEYS["respond_meeting"];
+
+	// Add keycontrol events
+	webclient.inputmanager.addObject(this);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["respond_mail"], "keyup", eventReadMailItemKeyCtrlRespond);
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["edit_item"], "keyup", eventReadMailItemKeyCtrlEdit);
 }
 
 readmailitemmodule.prototype.item = function(action)
@@ -72,10 +83,24 @@ readmailitemmodule.prototype.item = function(action)
 		this.setRepliedForwardedInfo(message);
 
 		this.setImportanceSensitivityInfo(message);
+
+		if(dhtml.getXMLValue(message, "delegated_by_rule", false)) {
+			// don't show this message for MRs in sent items of delegator
+			if(dhtml.getXMLValue(message, "rcvd_representing_name", "") != dhtml.getXMLValue(message, "received_by_name", "")) {
+				var receivedString = _("Received for") + NBSP + dhtml.getXMLValue(message, "rcvd_representing_name", "");
+				var extrainfo = dhtml.getElementById("extrainfo");
+				if(extrainfo) {
+					dhtml.addElement(extrainfo, "p", false, false, receivedString);
+					extrainfo.style.display = "block";
+				}
+			}
+		}
 	}
 	
 	readmailitemmodule.superclass.item.call(this, action);
 	this.setMeetingrequest(message);
+	this.setConflictAppointmentInfo(message);
+	this.setWindowTitle(message);
 	window.onresize();
 }
 
@@ -241,6 +266,10 @@ readmailitemmodule.prototype.setBody = function(message)
 			html_body.contentWindow.document.open();
 			html_body.contentWindow.document.write(content);
 			html_body.contentWindow.document.close();
+			
+			// Register events for keycontrol
+			dhtml.addEvent(webclient.inputmanager, html_body.contentWindow.document, "keyup", eventInputManagerKeyControlKeyUp);
+			dhtml.addEvent(webclient.inputmanager, html_body.contentWindow.document, "keydown", eventInputManagerKeyControlKeyDown);
 
 			var data = new Object();
 			data["iframedocument"] = html_body.contentWindow.document;
@@ -278,7 +307,7 @@ readmailitemmodule.prototype.setMeetingrequest = function(message)
 				hideMeetingElements.push("decline");
 				hideMeetingElements.push("proposenewtime");
 				
-				var textMeetingResponseText = _("This meeting request was updated after this message was sent. You Should open a later update or open the item on the calendar.");
+				var textMeetingResponseText = _("This meeting request was updated after this message was sent. You should open the latest update or open the item from the calendar.");
 				var elemExtraInfo = dhtml.getElementById("extrainfo");
 				dhtml.addElement(elemExtraInfo, "p", false, false, textMeetingResponseText);
 				elemExtraInfo.style.display = "block";
@@ -297,6 +326,9 @@ readmailitemmodule.prototype.setMeetingrequest = function(message)
 					// Hide proposenewtime buttons when you do NOT have a meeting REQUEST or a recurring one
 					hideMeetingElements.push("proposenewtime");
 				}
+
+				// Since message is a meeting request, so add keycontrol for responding to meeting request.
+				webclient.inputmanager.bindKeyControlEvent(this, this.keys["respond_meeting"], "keyup", eventReadMailItemKeyCtrlRespondMR);
 			}
 		}else{
 			// Hide Accept/Tentative/Decline buttons when NOT a Meeting REQUEST
@@ -480,6 +512,53 @@ readmailitemmodule.prototype.setRecipients = function(message)
 
 	}
 }
+readmailitemmodule.prototype.setReadFlag = function(messageEntryid, flag)
+{
+	if ((this.itemProps.message_flags & MSGFLAG_READ) == MSGFLAG_READ){
+		var data = new Object();
+		data["store"] = this.storeid;
+		data["parententryid"] = this.parententryid;
+		data["entryid"] = messageEntryid;
+	
+		if(flag) {
+			data["flag"] = flag;
+		}
+		
+		if(typeof parentWebclient != "undefined") {
+			parentWebclient.xmlrequest.addData(this, "read_flag", data, webclient.modulePrefix);
+			parentWebclient.xmlrequest.sendRequest(true);
+		} else {
+			webclient.xmlrequest.addData(this, "read_flag", data);
+			webclient.xmlrequest.sendRequest();
+		}
+	}
+}
+readmailitemmodule.prototype.setConflictAppointmentInfo = function(message)
+{
+	var conflictMsg = dhtml.getXMLValue(message, 'meetingconflicting', false);
+
+	if (conflictMsg){
+		var extrainfo = dhtml.getElementById("extrainfo");
+
+		if(extrainfo) {
+			dhtml.deleteAllChildren(extrainfo);
+			dhtml.addElement(extrainfo, "p", false, false, conflictMsg);
+			extrainfo.style.display = "block";
+		}
+	}
+}
+
+readmailitemmodule.prototype.setWindowTitle = function(message){
+	//get the subject value, if subject is empty then set Untitled.
+	var subject = dhtml.getXMLValue(message, "subject", _("Untitled"));
+
+	// if subject length is more than 50 characters then truncate them to 50 characters and add ellipsis
+	if(subject.length > 50)
+		subject = subject.substring(0,50) + "...";
+
+	// set subject as document title.
+	document.title = subject;
+}
 
 function eventReadmailAddressContextMenu(moduleObject, element, event)
 {
