@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -147,6 +149,19 @@ resolvenamesmodule.prototype.verifiedName = function(type,nameid,nameObj)
 	if(!this.returnList[type]){
 		this.returnList[type] = new Object();
 	}
+	if(nameObj["message_class"] == "IPM.DistList"){
+		var tempNames = new Array();
+		for (var i=0; i<nameObj.members.length ; i++){
+			var member = nameObj.members[i];
+			if(member.type == "ZARAFA"){
+				tempNames.push("["+member.fullname+"]");
+			}else{
+				tempNames.push(member.fullname + " <" + member.emailaddress +">");
+			}
+		}
+		nameObj["fullname"] = "";
+		nameObj["emailaddress"] = tempNames.join("; ");
+	}
 	this.returnList[type][nameid] = nameObj;
 	if(this.checkName){
 		this.checkName.close();
@@ -197,6 +212,16 @@ resolvenamesmodule.prototype.addResultToQue = function(items)
 		item["nonactive"] = dhtml.getTextNode(items[i].getElementsByTagName("nonactive")[0],"");
 		item["nameid"] = dhtml.getTextNode(items[i].getElementsByTagName("nameid")[0],"");
 		item["nametype"] = dhtml.getTextNode(items[i].getElementsByTagName("nametype")[0],"");
+		item["objecttype"] = dhtml.getTextNode(items[i].getElementsByTagName("objecttype")[0],"");
+		item["message_class"] = dhtml.getTextNode(items[i].getElementsByTagName("message_class")[0],"");
+		// if item is DistList then get all the members in it and create an array of members.
+		// as we cant send distlist as group, so we have to expand those members details in return.
+		if (item["message_class"] == "IPM.DistList"){
+			var membersData = dhtml.getXMLNode(items[i], "members").getElementsByTagName("member");
+			if(membersData){
+				item["members"] = this.createMembersOfDistlist(membersData);
+			}
+		}
 		
 		var typeEntry = -1;
 		for(var j=0; j<this.resolveQue.length; j++){
@@ -207,6 +232,7 @@ resolvenamesmodule.prototype.addResultToQue = function(items)
 		if(typeEntry == -1){
 			var temp = new Object();
 			temp["value"] = item["nametype"];
+			temp["message_class"] = item["message_class"];
 			temp["names"] = Array();
 			typeEntry = this.resolveQue.length;
 			this.resolveQue.push(temp);
@@ -230,6 +256,22 @@ resolvenamesmodule.prototype.addResultToQue = function(items)
 	}
 }
 
+/**
+ * Function will calculate all members in a distlist
+ */ 
+resolvenamesmodule.prototype.createMembersOfDistlist = function(membersData){
+	var members = new Array();
+	for (var i=0; i < membersData.length ; i++){
+		var memObj = new Object();
+		memObj["fullname"] = dhtml.getXMLValue(membersData[i], "display_name", "");
+		memObj["emailaddress"] = dhtml.getXMLValue(membersData[i], "emailaddress", "");
+		memObj["nameid"] = dhtml.getXMLValue(membersData[i], "nameid", "");
+		memObj["nametype"] = dhtml.getXMLValue(membersData[i], "nametype", "");
+		memObj["type"] = dhtml.getXMLValue(membersData[i], "type", "");
+		members.push(memObj);
+	}
+	return members;
+ }
 /**
  * Function will walk the resolveQue list
  * if there are more then one item is connected to a resolve this function will show popup
