@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -79,7 +81,8 @@ restoreitemslistmodule.prototype.init = function(id, element, title, data)
 /**
  * execute function for restoreItemListModule
  * called to show the message list
- * @param Strin type define the action type [default -> list , delete/deleteall/restore/restoreall]
+ * @param Strin type define the action type [list/delete/deleteall/restore/restoreall/
+ * folderlist/deleteallfolder/deletefolder/restoreallfolder/restorefolder/]
  * @param Object action contains the response data.
  */
 restoreitemslistmodule.prototype.execute = function(type, action){	
@@ -103,8 +106,8 @@ restoreitemslistmodule.prototype.execute = function(type, action){
 	}
 
 	//call the function to create table widget and insert the data in it.
-	initRestoreItems(this.itemProps);
-
+	//second param to function call is added to define the type of restore items.
+	initRestoreItems(this.itemProps, type);
 }
 
 /**
