@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -62,6 +64,7 @@ stickynotelistmodule.prototype.init = function(id, element, title, data)
 	this.defaultview = webclient.settings.get("folders/entryid_"+this.entryid+"/selected_view", "icon");
 	
 	stickynotelistmodule.superclass.init.call(this, id, element, title, data);
+	this.keys["view"] = KEYS["view"];
 	this.initializeView();
 
 	this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
@@ -77,6 +80,9 @@ stickynotelistmodule.prototype.init = function(id, element, title, data)
 	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("delete", _("Delete"), false, eventListContextMenuDeleteMessage));
 	this.contextmenu = items;
+
+	// Used by keycontrol, to switch between views
+	this.availableViews = new Array("icon", "list");
 }
 
 stickynotelistmodule.prototype.initializeView = function(view)
@@ -86,8 +92,15 @@ stickynotelistmodule.prototype.initializeView = function(view)
 	}
 	this.setTitle(this.title, NBSP, true);
 	this.contentElement = dhtml.addElement(this.element, "div");
+	this.selectedview = view;
 	
 	this.viewController.initView(this.id, (view?view:this.defaultview), this.contentElement, this.events, false);
+
+	webclient.inputmanager.addObject(this, this.element);
+	if (!webclient.inputmanager.hasKeyControlEvent(this, "keyup", eventNoteListKeyCtrlChangeView)){
+		webclient.inputmanager.bindKeyControlEvent(this, this.keys["view"], "keyup", eventNoteListKeyCtrlChangeView);
+	}
+	webclient.inputmanager.bindKeyControlEvent(this, this.keys["refresh"], "keyup", eventListKeyCtrlRefreshFolder);
 }
 
 function eventStickynotelistSwitchView(moduleObject, element, event)
@@ -98,3 +111,24 @@ function eventStickynotelistSwitchView(moduleObject, element, event)
 	moduleObject.list();
 	moduleObject.resize();
 }
+/**
+ * Function will change view when keys are presses
+ */
+function eventNoteListKeyCtrlChangeView(moduleObject, element, event, keys)
+{
+	var newView = false;
+
+	// Get next View
+	if (event.keyCombination == this.keys["view"]["prev"]){
+		newView = array_prev(moduleObject.selectedview, moduleObject.availableViews);
+	} else if (event.keyCombination == this.keys["view"]["next"]){
+		newView = array_next(moduleObject.selectedview, moduleObject.availableViews);
+	}
+
+	if (newView){
+		moduleObject.destructor(moduleObject);
+		moduleObject.initializeView(newView);
+		moduleObject.list();
+		moduleObject.resize();
+	}
+}
\ No newline at end of file
