@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -64,6 +66,10 @@ taskitemmodule.prototype.init = function(id)
 taskitemmodule.prototype.executeOnLoad = function()
 {
 	initTask();
+	
+	// Add keycontrol event
+	webclient.inputmanager.addObject(this);
+	webclient.inputmanager.bindKeyControlEvent(this, KEYS["mail"], "keyup", eventTaskListKeyCtrlSave);
 }
 
 taskitemmodule.prototype.item = function(action)
@@ -78,6 +84,9 @@ taskitemmodule.prototype.item = function(action)
 			}
 		}
 	}
+	// set the reminder's default value, which will be used later 
+	// for validating the marking a task (in)/complete and turning on/off reminders.
+	dhtml.getElementById("previousReminderValue").value = dhtml.getXMLValue(action, "reminder", "0");
 
 	taskitemmodule.superclass.item.call(this, action);
 }
