@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -81,9 +83,12 @@ function AddressCardsView(moduleID, element, events, data)
 
 AddressCardsView.prototype.destructor = function()
 {
-	if(this.combobox) {
-		this.combobox.destructor();
-		dhtml.deleteAllChildren(dhtml.getElementById("pagecombobox"));
+	// Unregister module from InputManager
+	webclient.inputmanager.removeObject(webclient.getModule(this.moduleID));
+
+	if(this.pagingTool) {
+		this.pagingTool.destructor();
+		dhtml.deleteAllChildren(dhtml.getElementById("pageelement_"+ this.id));
 	}
 
 	this.element.innerHTML = "";
@@ -124,19 +129,33 @@ AddressCardsView.prototype.initView = function()
 	if(typeof eventTableViewKeyboard != "undefined") {
 		webclient.inputmanager.unbindEvent(module, "keydown", eventTableViewKeyboard);
 	}
+	webclient.inputmanager.bindKeyControlEvent(module, module.keys["select"], "keyup", eventCardsViewKeyCtrlSelectAll, true);
 }
 
-AddressCardsView.prototype.showEmptyView = function()
+AddressCardsView.prototype.showEmptyView = function(message)
 {
-	dhtml.addElement(this.contentElement, "div", "empty_view_message", null, _("There are no contacts to be shown in this view. Click in the right of this screen to view the contacts by letter."));
+	if(typeof message == "undefined") {
+		message = _("There are no contacts to be shown in this view. Click in the right of this screen to view the contacts by letter.");
+	}
+
+	var messageElement = dhtml.getElementById("empty_view_message", "div", this.contentElement);
+
+	if(messageElement) {
+		// remove previously created message element
+		dhtml.deleteElement(messageElement);
+	}
+
+	dhtml.addElement(this.contentElement, "div", "empty_view_message", null, message);
 }
 
 AddressCardsView.prototype.resizeView = function()
 {
 	this.contentElement.style.height = (this.element.clientHeight - 1) + "px";
 	this.contentElement.style.width = (this.element.clientWidth - this.alfabetElement.clientWidth - (document.all?2:1)) + "px";
+
 	this.alfabetElement.style.height = this.element.clientHeight + "px";
-	
+	this.alfabetElement.style.top = this.element.offsetTop + "px";
+
 	var seperators = dhtml.getElementsByClassName("contact_seperator", "div");
 	for(var i = 0; i < seperators.length; i++)
 	{
@@ -154,7 +173,7 @@ AddressCardsView.prototype.resizeView = function()
 		
 		if(contact.id) {
 			// Position contact item
-			if((posY + contact.clientHeight) > this.contentElement.clientHeight) {
+			if((posY + contact.clientHeight + 7) > this.contentElement.clientHeight) {
 				posX += contact.offsetWidth + 5;
 				contact.style.top = "0px";
 				posY = contact.offsetHeight + 7;
@@ -188,8 +207,9 @@ AddressCardsView.prototype.execute = function(items, properties, action)
 	var entryids = new Array();
 	var posX = 0;
 	var posY = 0;
-	
-	if (items.length==0){
+	var moduleObject = webclient.getModule(this.moduleID);
+
+	if (items.length==0 && moduleObject.searchInProgress !== true){
 		this.showEmptyView();
 	}else {
 		for(var i = 0; i < items.length; i++)
@@ -211,9 +231,67 @@ AddressCardsView.prototype.execute = function(items, properties, action)
 	return entryids;
 }
 
-AddressCardsView.prototype.addItem = function(item, properties)
+/**
+ * Function which adds an item in the view.
+ * @param array item the item which is going to be added in view
+ * @param array properties property list
+ * @param object action the XML action
+ * @return object entry of the item
+ */
+AddressCardsView.prototype.addItem = function(item, properties, action)
 {
-	return false;
+	if(item && item.childNodes) {
+		// @TODO contact item is not added in sorted order automatically
+		var pagingElement = dhtml.getElementById("pageelement_" + this.moduleID);
+		if(pagingElement) {
+			var pagingNextButton = dhtml.getElementById("page_next", "td", pagingElement);
+			if(pagingNextButton && !dhtml.hasClassName(pagingNextButton, "nobutton")) {
+				// only add item in view when you are at last page
+				return true;
+			}
+		}
+
+		var selectedCharacter = webclient.getModule(this.moduleID).character;
+		var fileasValue = dhtml.getXMLValue(item, "fileas", false);
+
+		// only add contact when letter filtering matches with the contact's fileas field
+		// if selectedCharacter is "..." then add contact without checking fileas field
+		if(fileasValue && selectedCharacter != "..." && selectedCharacter != "123") {
+			if(fileasValue.substring(0, 1) != selectedCharacter) {
+				return true;
+			}
+		} else if(fileasValue && selectedCharacter == "123"){
+			if(parseInt(fileasValue.substring(0, 1), 10) < 0 || parseInt(fileasValue.subString(0, 1), 10) > 9) {
+				return true;
+			}
+		}
+
+		var entry = new Object();
+		var entryid = dhtml.getXMLValue(item, "entryid", false);
+		var contactElements = dhtml.getElementsByClassNameInElement(this.contentElement, "contact", "div");
+		var elementId = 0;
+
+		if(contactElements.length != 0) {
+			elementId = contactElements[contactElements.length - 1].id;
+			elementId = parseInt(elementId, 10) + 1;
+		} else {
+			// view is empty. then remove empty view message
+			dhtml.deleteAllChildren(this.contentElement);
+		}
+
+		if(entryid) {
+			var contact = this.createContactItem(dhtml.addElement(false, "div"), elementId, item);
+			this.contentElement.appendChild(contact);
+
+			entry["id"] = elementId;
+			entry["entryid"] = entryid;
+		}
+
+		this.resizeView();
+		return entry;
+	} else {
+		return true;
+	}
 }
 
 AddressCardsView.prototype.deleteItems = function(items)
@@ -332,6 +410,21 @@ AddressCardsView.prototype.deleteLoadMessage = function()
 
 AddressCardsView.prototype.pagingElement = TableView.prototype.pagingElement;
 AddressCardsView.prototype.removePagingElement = TableView.prototype.removePagingElement;
+/**
+ * Function which return all card elements
+ * @return array all card elements
+ */
+AddressCardsView.prototype.getAllCardElements = function()
+{
+	var cards = new Array();
+	var elements = this.contentElement.getElementsByTagName("div");
+	for (var i = 0; i < elements.length; i++){
+		if (typeof elements[i].id != "undefined" && dhtml.hasClassName(elements[i], "contact")){
+			cards.push(elements[i]);
+		}
+	}
+	return cards;
+}
 
 // FIXME FIXME this is called with 'mobuleObject' referring not to this view oject, but to our parent module!
 function eventAddressCardsViewKeyboard(moduleObject, element, event)
@@ -347,10 +440,20 @@ function eventAddressCardsViewKeyboard(moduleObject, element, event)
 			if (moduleObject && moduleObject instanceof ListModule && typeof moduleObject.selectedMessages[0] != "undefined"){
 				switch (event.keyCode){
 					case 46: // DELETE
-						moduleObject.deleteMessages(moduleObject.selectedMessages);
+						// event.shiftKey for soft delete if Shift+Del
+						moduleObject.deleteMessages(moduleObject.selectedMessages, event.shiftKey);
 						break;
 				}
 			}
 		}
 	}
+}
+/**
+ * Function which selects all items.
+ */
+function eventCardsViewKeyCtrlSelectAll(moduleObject, element, event)
+{
+	// Retrive all row elements
+	var elements = moduleObject.viewController.viewObject.getAllCardElements();
+	moduleObject.selectMessages(elements, "contactselected");
 }
\ No newline at end of file
