@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -185,6 +187,9 @@ CalendarMonthView.prototype.initView = function()
 			spanElement = dhtml.addElement(dayElement, "span", "day_number","", currentDay.getDate());
 			spanElement.setAttribute("unixtime",(currentDay.getTime()/1000));
 			dhtml.addEvent(this.moduleID,spanElement,"click",eventChangeViewToDay);
+
+			dhtml.addEvent(this.moduleID,dayElement,"contextmenu",eventShowCreateAppointmentContextMenu);
+			dhtml.addEvent(this.moduleID,dayElement,"dblclick",eventCalendarContextMenuClickCreateAppointment);
 			//end day number
 			
 			currentDay.addDays(1);
@@ -194,6 +199,11 @@ CalendarMonthView.prototype.initView = function()
 
 }
 
+CalendarMonthView.prototype.getStartEndTimeOfSelection = function(flag, element){
+	var starttime = element.getAttribute("unixtime");
+	return [starttime, starttime];
+}
+
 CalendarMonthView.prototype.resizeView = function()
 {
 	if(this.tableElement){
@@ -353,100 +363,98 @@ CalendarMonthView.prototype.createItem = function(item,element)
 	// Treat the item as an 'allday' event if it starts on a different day than it ends
 	var alldayevent = today.getTime() != endday.getTime();
 
-	while(today < dueDate){
-		var unixTimeId = startDate.getTime()/1000;
-		var selDay = dhtml.getElementById(parent_entryid+"_"+(today.getTime()/1000));
-	
-		if(selDay){
-			if(element){
-				dhtml.deleteElement(element);
-			}
-			AppointmentElement = dhtml.addElement(selDay,"div");
-			AppointmentElement.is_disabled = dhtml.getTextNode(item.getElementsByTagName("disabled_item")[0],0) != 0; // for private items, no events may be added to this item
-
-			AppointmentElement.setAttribute("id",entryid+"_"+unixTimeId)
-			AppointmentElement.setAttribute("startdate",unixTimeId);
-			AppointmentElement.setAttribute("duedate",unixTimeDue);
-	
-			if(alldayevent){
-				// allday event
-				AppointmentElement.className = "event_item ipm_appointment event_day_item";			
-				AppointmentElement.setAttribute("title",subject);
-			} else{				
-				// normal event
-				AppointmentElement.className = "event_item ipm_appointment";
-				//strftime func calculates starttime and endtime and support both 24/12Hrs Time format according to language settings
-				AppointmentElement.setAttribute("title","["+strftime(_('%H:%M'),unixTimeId)+" - "+strftime(_('%H:%M'),unixTimeDue)+"] "+subject);
-				dhtml.addElement(AppointmentElement,"span","event_time","",strftime(_('%H:%M'),unixTimeId)+NBSP);
-			}	
-			
-			// private item
-			if(privateAppointment == "1") {
-				dhtml.addElement(AppointmentElement, "span", "private", false, NBSP);
-			} else if(privateSensitivity == "2") {
-				dhtml.addElement(AppointmentElement, "span", "private", false, NBSP);
-			}
-
-			// subject
-			dhtml.addElement(AppointmentElement,"span","event_subject","",subject);
-			
-			// meeting
-			var meeting = item.getElementsByTagName("meeting")[0];
-			if(meeting && meeting.firstChild) {
-				var responseStatus = dhtml.getTextNode(item.getElementsByTagName("responsestatus")[0], 0);
-				AppointmentElement.meetingrequest = responseStatus; // store responseStatus in DOM tree
-				switch(meeting.firstChild.nodeValue)
-				{
-					case "1":
-					case "3":
-					case "5":
-						dhtml.addElement(AppointmentElement, "span", "meetingrequest", false, NBSP);
-						break;
+	while(today <= dueDate){
+		// check if there is a zero duration appointment.
+		if(today < dueDate || (dueDate - startDate == 0)){
+			var unixTimeId = startDate.getTime()/1000;
+			var selDay = dhtml.getElementById(parent_entryid+"_"+(today.getTime()/1000));
+		
+			if(selDay){
+				if(element){
+					dhtml.deleteElement(element);
 				}
-			}
+				AppointmentElement = dhtml.addElement(selDay,"div");
+				AppointmentElement.is_disabled = dhtml.getTextNode(item.getElementsByTagName("disabled_item")[0],0) != 0; // for private items, no events may be added to this item
 
-			// Appointment labels
-			if(item.getElementsByTagName("label")[0]){
-				switch(item.getElementsByTagName("label")[0].firstChild.nodeValue){
-					case "1": dhtml.addClassName(AppointmentElement,"label_important"); break;
-					case "2": dhtml.addClassName(AppointmentElement,"label_work"); break;
-					case "3": dhtml.addClassName(AppointmentElement,"label_personal"); break;
-					case "4": dhtml.addClassName(AppointmentElement,"label_holiday"); break;
-					case "5": dhtml.addClassName(AppointmentElement,"label_required"); break;
-					case "6": dhtml.addClassName(AppointmentElement,"label_travel_required"); break;
-					case "7": dhtml.addClassName(AppointmentElement,"label_prepare_required"); break;
-					case "8": dhtml.addClassName(AppointmentElement,"label_birthday"); break;
-					case "9": dhtml.addClassName(AppointmentElement,"label_special_date"); break;
-					case "10": dhtml.addClassName(AppointmentElement,"label_phone_interview"); break;
+				AppointmentElement.setAttribute("id",entryid+"_"+unixTimeId)
+				AppointmentElement.setAttribute("startdate",unixTimeId);
+				AppointmentElement.setAttribute("duedate",unixTimeDue);
+		
+				if(alldayevent){
+					// allday event
+					AppointmentElement.className = "event_item ipm_appointment event_day_item";			
+					AppointmentElement.setAttribute("title",subject);
+				} else{				
+					// normal event
+					AppointmentElement.className = "event_item ipm_appointment";
+					//strftime func calculates starttime and endtime and support both 24/12Hrs Time format according to language settings
+					AppointmentElement.setAttribute("title","["+strftime(_('%H:%M'),unixTimeId)+" - "+strftime(_('%H:%M'),unixTimeDue)+"] "+subject);
+					dhtml.addElement(AppointmentElement,"span","event_time","",strftime(_('%H:%M'),unixTimeId)+NBSP);
+				}	
+				
+				// private item
+				if(privateAppointment == "1") {
+					dhtml.addElement(AppointmentElement, "span", "private", false, NBSP);
+				} else if(privateSensitivity == "2") {
+					dhtml.addElement(AppointmentElement, "span", "private", false, NBSP);
 				}
-			}
-			
-			var recurring = item.getElementsByTagName("recurring")[0];
-			if(recurring && recurring.firstChild) {
-				// Basedate is used for saving
-				var basedate = item.getElementsByTagName("basedate")[0];
-				if(basedate && basedate.firstChild) {
-					AppointmentElement.setAttribute("basedate", basedate.getAttribute("unixtime"));
-				}
-			}
 
-			if (!AppointmentElement.is_disabled){
-				// add events
-				if (this.events && this.events["row"]){
-					dhtml.setEvents(this.moduleID, AppointmentElement, this.events["row"]);
+				// subject
+				dhtml.addElement(AppointmentElement,"span","event_subject","",subject);
+				
+				// meeting
+				var meeting = item.getElementsByTagName("meeting")[0];
+				if(meeting && meeting.firstChild) {
+					var responseStatus = dhtml.getTextNode(item.getElementsByTagName("responsestatus")[0], 0);
+					AppointmentElement.meetingrequest = responseStatus; // store responseStatus in DOM tree
+					switch(meeting.firstChild.nodeValue)
+					{
+						case "1":
+						case "3":
+						case "5":
+							dhtml.addElement(AppointmentElement, "span", "meetingrequest", false, NBSP);
+							break;
+					}
 				}
-			
-				// TODO: check DST
-				if(dueDate-startDate-1 < ONE_DAY){
-					// single click
+
+				// Appointment labels
+				if(item.getElementsByTagName("label")[0]){
+					switch(item.getElementsByTagName("label")[0].firstChild.nodeValue){
+						case "1": dhtml.addClassName(AppointmentElement,"label_important"); break;
+						case "2": dhtml.addClassName(AppointmentElement,"label_work"); break;
+						case "3": dhtml.addClassName(AppointmentElement,"label_personal"); break;
+						case "4": dhtml.addClassName(AppointmentElement,"label_holiday"); break;
+						case "5": dhtml.addClassName(AppointmentElement,"label_required"); break;
+						case "6": dhtml.addClassName(AppointmentElement,"label_travel_required"); break;
+						case "7": dhtml.addClassName(AppointmentElement,"label_prepare_required"); break;
+						case "8": dhtml.addClassName(AppointmentElement,"label_birthday"); break;
+						case "9": dhtml.addClassName(AppointmentElement,"label_special_date"); break;
+						case "10": dhtml.addClassName(AppointmentElement,"label_phone_interview"); break;
+					}
+				}
+				
+				var recurring = item.getElementsByTagName("recurring")[0];
+				if(recurring && recurring.firstChild) {
+					// Basedate is used for saving
+					var basedate = item.getElementsByTagName("basedate")[0];
+					if(basedate && basedate.firstChild) {
+						AppointmentElement.setAttribute("basedate", basedate.getAttribute("unixtime"));
+					}
+				}
+
+				if (!AppointmentElement.is_disabled){
+					// add events
+					if (this.events && this.events["row"]){
+						dhtml.setEvents(this.moduleID, AppointmentElement, this.events["row"]);
+					}
+
 					dragdrop.addDraggable(AppointmentElement,"appointment",true,APPOINTMENT_NOT_RESIZABLE);
 				}
+				
+				entry["id"] = entryid+"_"+unixTimeId;
+				entry["entryid"] = entryid;
 			}
-			
-			entry["id"] = entryid+"_"+unixTimeId;
-			entry["entryid"] = entryid;
 		}
-		
 		// add one_day for more day event
 		today.addDays(1);
 	}
@@ -501,26 +509,29 @@ function eventChangeViewToWorkWeek(moduleObject, element, event)
 
 function eventChangeViewToDay(moduleObject, element, event)
 {
+	event.stopPropagation();
 	var timestamp = element.getAttribute("unixtime");
 	moduleObject.changeView("day",timestamp*1000);
 }
 
 function eventCalenderMonthViewDragDropTarget(moduleObject, targetElement, element, event)
 {	
-	var draggableStartdate = element.getAttribute("startdate");
-	var draggableDuedate = element.getAttribute("duedate");
+	var draggableStartdate = parseInt(element.getAttribute("startdate") || 0);
+	var draggableDuedate = parseInt(element.getAttribute("duedate") || 0);
 	var draggableBasedate = element.getAttribute("basedate");
 	var draggableEntryID = element.getAttribute("id").split("_")[0];
-	var targetDate = new Date(targetElement.getAttribute("unixtime")*1000);
+	var targetDate = new Date(parseInt(targetElement.getAttribute("unixtime") || 0)*1000);
 	var duration = draggableDuedate-draggableStartdate;		
 
 	var newDraggableStartdate = new Date(draggableStartdate*1000);
-	newDraggableStartdate.setDate(targetDate.getDate());
-	newDraggableStartdate.setMonth(targetDate.getMonth());
-	newDraggableStartdate.setFullYear(targetDate.getFullYear());
-	newDraggableStartdate = newDraggableStartdate/1000;//convert to unixtimestamp
-	
-	var newDraggableDuedate = newDraggableStartdate+duration;
+	// inspite of adding date/month/year to draggableSratDate, we will add time to targetDate.
+	// to avoid the moving an appointment from higher days month to lesser days month.
+	var newDragHours = newDraggableStartdate.getHours();
+	var newDragMinutes = newDraggableStartdate.getMinutes();
+	newDraggableStartdate = timeToZero(targetDate.getTime() / 1000);
+	newDraggableStartdate = addHoursToUnixTimeStamp(newDraggableStartdate, newDragHours + (newDragMinutes/60));
+
+	var newDraggableDuedate = addHoursToUnixTimeStamp(newDraggableStartdate, (duration/3600));
 	
 	// move item
 	targetElement.appendChild(element);
