@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -128,6 +130,7 @@ CalendarWeekView.prototype.initView = function()
 	var tmpStart = new Date(this.selecteddate).getStartDateOfWeek();
 	for(var i=0;i < this.dayElements.length;i++){
 		this.dayElements[i].element.id = "day_"+this.moduleID+"_"+(tmpStart.getTime()/1000);
+		this.dayElements[i].element.setAttribute("unixtime",(tmpStart.getTime()/1000));
 		dragdrop.addTarget(this.element,this.dayElements[i].element,"appointment",true);
 		if(i == 6){
 			var dayTitle = dhtml.addElement(this.dayElements[i].element,"span","day_header","",DAYS[0]+" "+tmpStart.getDate()+" "+MONTHS[tmpStart.getMonth()]);
@@ -141,6 +144,11 @@ CalendarWeekView.prototype.initView = function()
 		if(todayCount-1 == i  && tmpStart.isSameDay(new Date()) ){
 			dhtml.addClassName(this.dayElements[i].element, "selectedToday");
 		}
+
+		// attach event for context menu
+		dhtml.addEvent(this.moduleID,this.dayElements[i].element,"contextmenu",eventShowCreateAppointmentContextMenu);
+		dhtml.addEvent(this.moduleID,this.dayElements[i].element,"dblclick",eventCalendarContextMenuClickCreateAppointment);
+
 		tmpStart.addDays(1);
 	}
 
@@ -299,101 +307,104 @@ CalendarWeekView.prototype.createItem = function(item, element)
 	
 	var alldayevent = today.getTime() != endday.getTime();
 
-	while(today < dueDate){
-		var unixTimeId = startDate.getTime()/1000;
-		var parent = dhtml.getElementById("day_"+this.moduleID+"_"+today.getTime()/1000);
-		if(parent){
-			if(element){
-				dhtml.deleteElement(element);
-			}
-			AppointmentElement = dhtml.addElement(parent,"div","event");
-			AppointmentElement.is_disabled = dhtml.getTextNode(item.getElementsByTagName("disabled_item")[0],0) != 0; // for private items, no events may be added to this item
-
-			// set some properties
-			AppointmentElement.id = entryid+"_"+unixTimeId;
-			AppointmentElement.startdate = startDate.getTime()/1000;
-			AppointmentElement.duedate = dueDate.getTime()/1000;
-			
-			// allday event
-			if(alldayevent){
-				dhtml.addClassName(AppointmentElement, "event_day_item");
-			} else {
-				dhtml.addElement(AppointmentElement,"span","event_time","",startDate.toTime()+" "+dueDate.toTime());
-			}
-	
-			// private item
-			if(privateAppointment == "1") {
-				dhtml.addElement(AppointmentElement, "span", "private", false, NBSP);
-			} else if(privateSensitivity == "2") {
-				dhtml.addElement(AppointmentElement, "span", "private", false, NBSP);
-			}
-	
-			
-			// Recurring items
-			if(recurring.length > 0 && basedate.length > 0) {
-				AppointmentElement.setAttribute("basedate", basedate);
-				if(exception && exception.firstChild) {
-					dhtml.addElement(AppointmentElement, "span", "recurring_exception", false, NBSP);			
-				} else if(recurring == "1") {
-					dhtml.addElement(AppointmentElement, "span", "recurring", false, NBSP);
+	while(today <= dueDate){
+		// check if there is a zero duration appointment.
+		if(today < dueDate || (dueDate - startDate == 0)){
+			var unixTimeId = startDate.getTime()/1000;
+			var parent = dhtml.getElementById("day_"+this.moduleID+"_"+today.getTime()/1000);
+			if(parent){
+				if(element){
+					var elemId = element.id;
+					dhtml.deleteElement(element);
+					// for multiday appointments, check if there is any other element remaining with same ID, then delete it
+					if(dhtml.getElementById(elemId)) dhtml.deleteElement(dhtml.getElementById(elemId));
 				}
-			}
-			
-			// add subject
-			if(location.length > 0){
-				dhtml.addElement(AppointmentElement,"span","event_subject","",subject+" ("+location+")");
-			} else {
-				dhtml.addElement(AppointmentElement,"span","event_subject","",subject);
-			}			
+				AppointmentElement = dhtml.addElement(parent,"div","event");
+				AppointmentElement.is_disabled = dhtml.getTextNode(item.getElementsByTagName("disabled_item")[0],0) != 0; // for private items, no events may be added to this item
 
-			// meeting
-			var meeting = item.getElementsByTagName("meeting")[0];
-			if(meeting && meeting.firstChild) {
-				var responseStatus = dhtml.getTextNode(item.getElementsByTagName("responsestatus")[0], 0);
-				AppointmentElement.meetingrequest = responseStatus; // store responseStatus in DOM tree
-				switch(meeting.firstChild.nodeValue)
-				{
-					case "1":
-					case "3":
-					case "5":
-						dhtml.addElement(AppointmentElement, "span", "meetingrequest", false, NBSP);
-						break;
+				// set some properties
+				AppointmentElement.id = entryid+"_"+unixTimeId;
+				AppointmentElement.startdate = startDate.getTime()/1000;
+				AppointmentElement.duedate = dueDate.getTime()/1000;
+				
+				// allday event
+				if(alldayevent){
+					dhtml.addClassName(AppointmentElement, "event_day_item");
+				} else {
+					dhtml.addElement(AppointmentElement,"span","event_time","",startDate.toTime()+" "+dueDate.toTime());
 				}
-			}
-
-			// Appointment labels
-			switch(label){
-				case "1": dhtml.addClassName(AppointmentElement,"label_important"); break;
-				case "2": dhtml.addClassName(AppointmentElement,"label_work"); break;
-				case "3": dhtml.addClassName(AppointmentElement,"label_personal"); break;
-				case "4": dhtml.addClassName(AppointmentElement,"label_holiday"); break;
-				case "5": dhtml.addClassName(AppointmentElement,"label_required"); break;
-				case "6": dhtml.addClassName(AppointmentElement,"label_travel_required"); break;
-				case "7": dhtml.addClassName(AppointmentElement,"label_prepare_required"); break;
-				case "8": dhtml.addClassName(AppointmentElement,"label_birthday"); break;
-				case "9": dhtml.addClassName(AppointmentElement,"label_special_date"); break;
-				case "10": dhtml.addClassName(AppointmentElement,"label_phone_interview"); break;
-			}
-
-			if (!AppointmentElement.is_disabled){
-			
-				// add events
-				if (this.events && this.events["row"]){
-					dhtml.setEvents(this.moduleID, AppointmentElement, this.events["row"]);
+		
+				// private item
+				if(privateAppointment == "1") {
+					dhtml.addElement(AppointmentElement, "span", "private", false, NBSP);
+				} else if(privateSensitivity == "2") {
+					dhtml.addElement(AppointmentElement, "span", "private", false, NBSP);
+				}
+		
+				
+				// Recurring items
+				if(recurring.length > 0 && basedate.length > 0) {
+					AppointmentElement.setAttribute("basedate", basedate);
+					if(exception && exception.firstChild) {
+						dhtml.addElement(AppointmentElement, "span", "recurring_exception", false, NBSP);			
+					} else if(recurring == "1") {
+						dhtml.addElement(AppointmentElement, "span", "recurring", false, NBSP);
+					}
 				}
 				
-				// single click   TODO: check DST
-				if(dueDate-startDate-1 < ONE_DAY){
+				// add subject
+				if(location.length > 0){
+					dhtml.addElement(AppointmentElement,"span","event_subject","",subject+" ("+location+")");
+				} else {
+					dhtml.addElement(AppointmentElement,"span","event_subject","",subject);
+				}			
+
+				// meeting
+				var meeting = item.getElementsByTagName("meeting")[0];
+				if(meeting && meeting.firstChild) {
+					var responseStatus = dhtml.getTextNode(item.getElementsByTagName("responsestatus")[0], 0);
+					AppointmentElement.meetingrequest = responseStatus; // store responseStatus in DOM tree
+					switch(meeting.firstChild.nodeValue)
+					{
+						case "1":
+						case "3":
+						case "5":
+							dhtml.addElement(AppointmentElement, "span", "meetingrequest", false, NBSP);
+							break;
+					}
+				}
+
+				// Appointment labels
+				switch(label){
+					case "1": dhtml.addClassName(AppointmentElement,"label_important"); break;
+					case "2": dhtml.addClassName(AppointmentElement,"label_work"); break;
+					case "3": dhtml.addClassName(AppointmentElement,"label_personal"); break;
+					case "4": dhtml.addClassName(AppointmentElement,"label_holiday"); break;
+					case "5": dhtml.addClassName(AppointmentElement,"label_required"); break;
+					case "6": dhtml.addClassName(AppointmentElement,"label_travel_required"); break;
+					case "7": dhtml.addClassName(AppointmentElement,"label_prepare_required"); break;
+					case "8": dhtml.addClassName(AppointmentElement,"label_birthday"); break;
+					case "9": dhtml.addClassName(AppointmentElement,"label_special_date"); break;
+					case "10": dhtml.addClassName(AppointmentElement,"label_phone_interview"); break;
+				}
+
+				if (!AppointmentElement.is_disabled){
+				
+					// add events
+					if (this.events && this.events["row"]){
+						dhtml.setEvents(this.moduleID, AppointmentElement, this.events["row"]);
+					}
+					
+					// single click   TODO: check DST
 					dragdrop.addDraggable(AppointmentElement,"appointment",true,APPOINTMENT_NOT_RESIZABLE);
 				}
+				
+				entry["id"] = entryid+"_"+unixTimeId;
+				entry["entryid"] = entryid;
 			}
-			
-			entry["id"] = entryid+"_"+unixTimeId;
-			entry["entryid"] = entryid;
-		}
-		
-		// add one_day for more day event
+		}		// add one_day for more day event
 		today.addDays(1);
+	
 	}
 	return entry;
 }
@@ -438,6 +449,11 @@ CalendarWeekView.prototype.deleteLoadMessage = function()
 	document.body.style.cursor = "default";
 }
 
+CalendarWeekView.prototype.getStartEndTimeOfSelection = function(flag, element){
+	var starttime = element.getAttribute("unixtime");
+	return [starttime, starttime];
+}
+
 // EVENTS
 /**
  * Function will change the view to day view
@@ -504,4 +520,4 @@ function eventCalenderWeekViewDragDropTarget(moduleObject, targetElement, elemen
 	if(moveOccAllowFlag){
 		moduleObject.save(props, send);
 	}
-}
+}
\ No newline at end of file
