@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -99,6 +101,7 @@ IconView.prototype.initView = function()
 	if(typeof eventTableViewKeyboard != "undefined") {
 		webclient.inputmanager.unbindEvent(module, "keydown", eventTableViewKeyboard);
 	}
+	webclient.inputmanager.bindKeyControlEvent(module, module.keys["select"], "keyup", eventIconViewKeyCtrlSelectAll, true);
 
 	if(typeof dragdrop != "undefined") dragdrop.addTarget(dragdrop.targets["folder"]["scrollelement"], this.element, "folder");
 }
@@ -240,10 +243,25 @@ function eventIconViewKeyboard(moduleObject, element, event)
 			if (moduleObject && moduleObject instanceof ListModule && typeof moduleObject.selectedMessages[0] != "undefined"){
 				switch (event.keyCode){
 					case 46: // DELETE
-						moduleObject.deleteMessages(moduleObject.selectedMessages);
+						// event.shiftKey for soft delete if Shift+Del
+						moduleObject.deleteMessages(moduleObject.selectedMessages, event.shiftKey);
 						break;
 				}
 			}
 		}
 	}
 }
+/**
+ * Function which selects all items.
+ */
+function eventIconViewKeyCtrlSelectAll(moduleObject, element, event)
+{
+	var elements = new Array();
+	for (var item in moduleObject.itemProps){
+		var element = dhtml.getElementById(moduleObject.id +"_"+ item);
+		if (element){
+			elements.push(element);
+		}
+	}
+	moduleObject.selectMessages(elements, "large_viewselected");
+}
\ No newline at end of file
