@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -245,6 +247,7 @@ PrintCalendarMonthView.prototype.createItem = function(item) {
 			dhtml.addElement(appointmentElement, "span", "event_subject", "", subject);
 
 			// Appointment labels
+			var imageName = "label_default.gif";
 			if(item.getElementsByTagName("label")[0]) {
 				switch(item.getElementsByTagName("label")[0].firstChild.nodeValue) {
 					case "1": imageName = "label_important.gif"; break;
@@ -257,7 +260,6 @@ PrintCalendarMonthView.prototype.createItem = function(item) {
 					case "8": imageName = "label_birthday.gif"; break;
 					case "9": imageName = "label_special_date.gif"; break;
 					case "10": imageName = "label_phone_interview.gif"; break;
-					default: imageName = "label_default.gif"; break;
 				}
 			}
 
@@ -285,74 +287,106 @@ PrintCalendarMonthView.prototype.createItem = function(item) {
 
 /**
  * Function will resize all elements in the view
+ * @param	iframeWindow	iframe	iframe that is used for printing
  */
-PrintCalendarMonthView.prototype.resizeView = function() {
-	var menubarHeight = dhtml.getElementById("menubar").offsetHeight + dhtml.getElementById("menubar").offsetTop;
-	var titleHeight = dhtml.getElementsByClassName("title")[0].offsetHeight;
-	var bodyHeight = document.getElementsByTagName("body")[0].offsetHeight;
+PrintCalendarMonthView.prototype.resizeView = function(iframe) {
+	if(typeof iframe != "undefined") {
+		var iframe = window.frames["printing_frame"];
+		var iframeDoc = iframe.document;
+		var printFooterHeight = iframeDoc.getElementById("print_footer").offsetHeight;
+		var printHeaderHeight = iframeDoc.getElementById("print_header").offsetHeight;
+		var iframeSize = dhtml.getBrowserInnerSize(iframe);
 
-	var dialogContentHeight = bodyHeight - (menubarHeight + titleHeight) + 12;
-	dhtml.getElementById("dialog_content").style.height = dialogContentHeight + "px";
+		// change width of header & footer
+		iframeDoc.getElementById("print_header").style.width = iframeSize["x"];
+		iframeDoc.getElementById("print_footer").style.width = iframeSize["x"];
 
-	var printFooterHeight = dhtml.getElementById("print_footer").offsetHeight;
-	var printHeaderHeight = dhtml.getElementById("print_header").offsetHeight;
-
-	var printCalendarHeight = dialogContentHeight - (printHeaderHeight + printFooterHeight);
-	this.element.style.height = printCalendarHeight + "px";
-
-	if(this.tableElement) {
-		var fixedHeight = 20;
-		var fixedWidth = 20;
-		var flexHeight = Math.floor((this.tableElement.offsetHeight - fixedHeight) / 6);
-		var flexWidth = Math.floor((this.tableElement.offsetWidth - fixedWidth) / 7);
-		var divElement;
-
-		divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "month_header", "div");
-		divElement[0].style.height = fixedHeight + "px";
-		divElement[0].style.width = this.tableElement.offsetWidth + "px";
-
-		divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "month_header_week_nr", "div");
-		divElement[0].style.height = fixedHeight + "px";
-		divElement[0].style.width = fixedWidth + "px";
-
-		divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "month_header_day", "div");
-		for(var i = 0; i < divElement.length - 1; i++) {
-			divElement[i].style.height = fixedHeight + "px";
-			divElement[i].style.width = flexWidth + "px";
-		}
-		divElement[divElement.length - 1].style.height = fixedHeight + "px";
-		divElement[divElement.length - 1].style.width = (this.tableElement.offsetWidth - (divElement[divElement.length - 2].offsetLeft + flexWidth) - 2) + "px";
-
-		divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "month_week_nr", "div");
-		for(var i = 0; i < divElement.length; i++) {
-			divElement[i].style.height = flexHeight + "px";
-			divElement[i].style.width = fixedWidth + "px";
-		}
+		// change width / height of container element
+		iframeElement = iframeDoc.getElementById("print_calendar");
+		var contentAreaHeight = iframeSize["y"] - (printHeaderHeight + printFooterHeight) + "px";
+		iframeElement.style.height = contentAreaHeight;
+		iframeElement.style.width = iframeSize["x"];
 		
-		divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "week", "div");
-		for(var i = 0; i < divElement.length; i++) {
-			divElement[i].style.height = flexHeight + "px";
-			divElement[i].style.width = this.tableElement.offsetWidth + "px";
+		var tableElement = iframeElement.firstChild;
+		tableElement.style.height = contentAreaHeight;
+		tableElement.style.width = iframeSize["x"];
 
-			dayElement = dhtml.getElementsByClassNameInElement(divElement[i], "month_day", "div");
-			for(var j = 0; j < dayElement.length - 1; j++) {
-				dayElement[j].style.height = flexHeight + "px";
-				dayElement[j].style.width = flexWidth + "px";
+		if(tableElement) {
+			var fixedHeight = 20;
+			var fixedWidth = 20;
+			var flexHeight = Math.floor((tableElement.offsetHeight - fixedHeight) / 6);
+			var flexWidth = Math.floor((tableElement.offsetWidth - fixedWidth) / 7);
+			var divElement;
 
-				if(dayElement[j].className == "month_day month_other") {
-					dayElementBack = dhtml.getElementById(dayElement[j].id + "_back");
-					dayElementBack.style.height = dayElement[j].clientHeight + "px";
-					dayElementBack.style.width = dayElement[j].clientWidth + "px";
-					dayElementBack.style.top = dayElement[j].offsetTop + "px";
-					dayElementBack.style.left = dayElement[j].offsetLeft + "px";
+			divElement = dhtml.getElementsByClassNameInElement(tableElement, "month_header", "div");
+			divElement[0].style.height = fixedHeight + "px";
+			divElement[0].style.width = tableElement.offsetWidth + "px";
+
+			divElement = dhtml.getElementsByClassNameInElement(tableElement, "month_header_week_nr", "div");
+			divElement[0].style.height = fixedHeight + "px";
+			divElement[0].style.width = fixedWidth + "px";
+
+			divElement = dhtml.getElementsByClassNameInElement(tableElement, "month_header_day", "div");
+			for(var i = 0; i < divElement.length - 1; i++) {
+				divElement[i].style.height = fixedHeight + "px";
+				divElement[i].style.width = flexWidth + "px";
+			}
+			divElement[divElement.length - 1].style.height = fixedHeight + "px";
+			divElement[divElement.length - 1].style.width = (tableElement.offsetWidth - (divElement[divElement.length - 2].offsetLeft + flexWidth) - 2) + "px";
+
+			divElement = dhtml.getElementsByClassNameInElement(tableElement, "month_week_nr", "div");
+			for(var i = 0; i < divElement.length; i++) {
+				divElement[i].style.height = flexHeight + "px";
+				divElement[i].style.width = fixedWidth + "px";
+			}
+			
+			divElement = dhtml.getElementsByClassNameInElement(tableElement, "week", "div");
+			for(var i = 0; i < divElement.length; i++) {
+				divElement[i].style.height = flexHeight + "px";
+				divElement[i].style.width = tableElement.offsetWidth + "px";
+
+				dayElement = dhtml.getElementsByClassNameInElement(divElement[i], "month_day", "div");
+				for(var j = 0; j < dayElement.length - 1; j++) {
+					dayElement[j].style.height = flexHeight + "px";
+					dayElement[j].style.width = flexWidth + "px";
+
+					if(dayElement[j].className == "month_day month_other") {
+						dayElementBack = dhtml.getElementById(dayElement[j].id + "_back", "div", divElement[i]);
+						dayElementBack.style.height = dayElement[j].clientHeight + "px";
+						dayElementBack.style.width = dayElement[j].clientWidth + "px";
+						dayElementBack.style.top = dayElement[j].offsetTop + "px";
+						dayElementBack.style.left = dayElement[j].offsetLeft + "px";
+					}
+
+					// position divs that will give colors to appointment using images
+					var appointmentElements = dhtml.getElementsByClassNameInElement(dayElement[j], "ipm_appointment", "div");
+					for(var k = 0; k < appointmentElements.length; k++) {
+						var appointmentElement = appointmentElements[k];
+						var appointmentElementBack = dhtml.getElementById(appointmentElement.id + "_back", "div", dayElement[j]);
+
+						appointmentElement.style.height = "14px";
+						appointmentElementBack.style.top = appointmentElement.offsetTop + "px";
+						appointmentElementBack.style.height = appointmentElement.clientHeight + "px";
+						appointmentElementBack.style.width = appointmentElement.clientWidth + "px";
+					}
 				}
 
-				// position divs that will give colors to appointment using images
-				var appointmentElements = dhtml.getElementsByClassNameInElement(dayElement[j], "ipm_appointment", "div");
+				var lastElementInRow = dayElement[dayElement.length - 1];
+				lastElementInRow.style.height = flexHeight + "px";
+				lastElementInRow.style.width = (flexWidth - 8) + "px";
 
+				if(lastElementInRow.className == "month_day month_other") {
+					dayElementBack = dhtml.getElementById(lastElementInRow.id + "_back", "div", divElement[i]);
+					dayElementBack.style.height = lastElementInRow.offsetHeight + "px";
+					dayElementBack.style.width = lastElementInRow.offsetWidth + "px";
+					dayElementBack.style.top = lastElementInRow.offsetTop + "px";
+					dayElementBack.style.left = lastElementInRow.offsetLeft + "px";
+				}
+
+				var appointmentElements = dhtml.getElementsByClassNameInElement(lastElementInRow, "ipm_appointment", "div");
 				for(var k = 0; k < appointmentElements.length; k++) {
 					var appointmentElement = appointmentElements[k];
-					var appointmentElementBack = dhtml.getElementById(appointmentElement.id + "_back", "div", dayElement[j]);
+					var appointmentElementBack = dhtml.getElementById(appointmentElement.id + "_back", "div", lastElementInRow);
 
 					appointmentElement.style.height = "14px";
 					appointmentElementBack.style.top = appointmentElement.offsetTop + "px";
@@ -360,48 +394,139 @@ PrintCalendarMonthView.prototype.resizeView = function() {
 					appointmentElementBack.style.width = appointmentElement.clientWidth + "px";
 				}
 			}
+		}
 
-			var lastElementInRow = dayElement[dayElement.length - 1];
-			lastElementInRow.style.height = flexHeight + "px";
-			lastElementInRow.style.width = (flexWidth - 8) + "px";
+		// convert percentage width into pixels for printing
+		var width = dhtml.getElementsByClassName("month_header", "div")[0].style.width;
+		dhtml.getElementById("print_footer").style.width = width;
+		dhtml.getElementById("print_header").style.width = width;
+		this.element.style.width = width;
+	} else {
+		var menubarHeight = dhtml.getElementById("menubar").offsetHeight + dhtml.getElementById("menubar").offsetTop;
+		var titleHeight = dhtml.getElementsByClassName("title")[0].offsetHeight;
+		var bodyHeight = document.getElementsByTagName("body")[0].offsetHeight;
+		var bodyWidth = document.getElementsByTagName("body")[0].offsetWidth;
 
-			if(lastElementInRow.className == "month_day month_other") {
-				dayElementBack = dhtml.getElementById(lastElementInRow.id + "_back");
-				dayElementBack.style.height = lastElementInRow.offsetHeight + "px";
-				dayElementBack.style.width = lastElementInRow.offsetWidth + "px";
-				dayElementBack.style.top = lastElementInRow.offsetTop + "px";
-				dayElementBack.style.left = lastElementInRow.offsetLeft + "px";
+		var dialogContentHeight = bodyHeight - (menubarHeight + titleHeight);
+		dhtml.getElementById("dialog_content").style.height = dialogContentHeight + "px";
+
+		var printFooterHeight = dhtml.getElementById("print_footer").offsetHeight;
+		var printHeaderHeight = dhtml.getElementById("print_header").offsetHeight;
+
+		var printCalendarHeight = dialogContentHeight - (printHeaderHeight + printFooterHeight) - 7;
+		this.element.style.height = printCalendarHeight + "px";
+		this.element.style.width = dhtml.getElementById("dialog_content").offsetWidth + "px";
+
+		this.tableElement.style.height = printCalendarHeight + "px";
+		this.tableElement.style.width = this.element.offsetWidth;
+
+		if(this.tableElement) {
+			var fixedHeight = 20;
+			var fixedWidth = 20;
+			var flexHeight = Math.floor((this.tableElement.offsetHeight - fixedHeight) / 6);
+			var flexWidth = Math.floor((this.tableElement.offsetWidth - fixedWidth) / 7);
+			var divElement;
+
+			divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "month_header", "div");
+			divElement[0].style.height = fixedHeight + "px";
+			divElement[0].style.width = this.tableElement.offsetWidth + "px";
+
+			divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "month_header_week_nr", "div");
+			divElement[0].style.height = fixedHeight + "px";
+			divElement[0].style.width = fixedWidth + "px";
+
+			divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "month_header_day", "div");
+			for(var i = 0; i < divElement.length - 1; i++) {
+				divElement[i].style.height = fixedHeight + "px";
+				divElement[i].style.width = flexWidth + "px";
 			}
+			divElement[divElement.length - 1].style.height = fixedHeight + "px";
+			divElement[divElement.length - 1].style.width = (this.tableElement.offsetWidth - (divElement[divElement.length - 2].offsetLeft + flexWidth) - 2) + "px";
 
-			var appointmentElements = dhtml.getElementsByClassNameInElement(lastElementInRow, "ipm_appointment", "div");
+			divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "month_week_nr", "div");
+			for(var i = 0; i < divElement.length; i++) {
+				divElement[i].style.height = flexHeight + "px";
+				divElement[i].style.width = fixedWidth + "px";
+			}
+			
+			divElement = dhtml.getElementsByClassNameInElement(this.tableElement, "week", "div");
+			for(var i = 0; i < divElement.length; i++) {
+				divElement[i].style.height = flexHeight + "px";
+				divElement[i].style.width = this.tableElement.offsetWidth + "px";
 
-			for(var k = 0; k < appointmentElements.length; k++) {
-				var appointmentElement = appointmentElements[k];
-				var appointmentElementBack = dhtml.getElementById(appointmentElement.id + "_back", "div", lastElementInRow);
+				dayElement = dhtml.getElementsByClassNameInElement(divElement[i], "month_day", "div");
+				for(var j = 0; j < dayElement.length - 1; j++) {
+					dayElement[j].style.height = flexHeight + "px";
+					dayElement[j].style.width = flexWidth + "px";
 
-				appointmentElement.style.height = "14px";
-				appointmentElementBack.style.top = appointmentElement.offsetTop + "px";
-				appointmentElementBack.style.height = appointmentElement.clientHeight + "px";
-				appointmentElementBack.style.width = appointmentElement.clientWidth + "px";
+					if(dayElement[j].className == "month_day month_other") {
+						dayElementBack = dhtml.getElementById(dayElement[j].id + "_back", "div", divElement[i]);
+						dayElementBack.style.height = dayElement[j].clientHeight + "px";
+						dayElementBack.style.width = dayElement[j].clientWidth + "px";
+						dayElementBack.style.top = dayElement[j].offsetTop + "px";
+						dayElementBack.style.left = dayElement[j].offsetLeft + "px";
+					}
+
+					// position divs that will give colors to appointment using images
+					var appointmentElements = dhtml.getElementsByClassNameInElement(dayElement[j], "ipm_appointment", "div");
+					for(var k = 0; k < appointmentElements.length; k++) {
+						var appointmentElement = appointmentElements[k];
+						var appointmentElementBack = dhtml.getElementById(appointmentElement.id + "_back", "div", dayElement[j]);
+
+						appointmentElement.style.height = "14px";
+						appointmentElementBack.style.top = appointmentElement.offsetTop + "px";
+						appointmentElementBack.style.height = appointmentElement.clientHeight + "px";
+						appointmentElementBack.style.width = appointmentElement.clientWidth + "px";
+					}
+				}
+
+				var lastElementInRow = dayElement[dayElement.length - 1];
+				lastElementInRow.style.height = flexHeight + "px";
+				lastElementInRow.style.width = (flexWidth - 8) + "px";
+
+				if(lastElementInRow.className == "month_day month_other") {
+					dayElementBack = dhtml.getElementById(lastElementInRow.id + "_back", "div", divElement[i]);
+					dayElementBack.style.height = lastElementInRow.offsetHeight + "px";
+					dayElementBack.style.width = lastElementInRow.offsetWidth + "px";
+					dayElementBack.style.top = lastElementInRow.offsetTop + "px";
+					dayElementBack.style.left = lastElementInRow.offsetLeft + "px";
+				}
+
+				var appointmentElements = dhtml.getElementsByClassNameInElement(lastElementInRow, "ipm_appointment", "div");
+				for(var k = 0; k < appointmentElements.length; k++) {
+					var appointmentElement = appointmentElements[k];
+					var appointmentElementBack = dhtml.getElementById(appointmentElement.id + "_back", "div", lastElementInRow);
+
+					appointmentElement.style.height = "14px";
+					appointmentElementBack.style.top = appointmentElement.offsetTop + "px";
+					appointmentElementBack.style.height = appointmentElement.clientHeight + "px";
+					appointmentElementBack.style.width = appointmentElement.clientWidth + "px";
+				}
 			}
 		}
+
+		// convert percentage width into pixels for printing
+		var width = dhtml.getElementsByClassName("month_header", "div")[0].style.width;
+		dhtml.getElementById("print_footer").style.width = width;
+		dhtml.getElementById("print_header").style.width = width;
+		this.element.style.width = width;
 	}
 
-	// convert percentage width into pixels for printing
-	var width = dhtml.getElementsByClassName("month_header", "div")[0].style.width;
-	dhtml.getElementById("print_footer").style.width = width;
-	dhtml.getElementById("print_header").style.width = width;
-	this.element.style.width = width;
-	
-	this.hideOverlappingItems();
+	this.hideOverlappingItems(iframeDoc);
 }
 
 /** 
  * Function is used to add a label in month view if all items are 
  * not visible in particular cell of month view
+ * @param	iframeDocument	iframeDoc	iframe that is used for printing
  */
-PrintCalendarMonthView.prototype.hideOverlappingItems = function() {
-	var dayElement = dhtml.getElementsByClassNameInElement(this.element, "month_day", "div");
+PrintCalendarMonthView.prototype.hideOverlappingItems = function(iframeDoc) {
+	var containerElement = this.element;
+	if(typeof iframeDoc != "undefined") {
+		containerElement = iframeDoc.getElementById("print_calendar");
+	}
+
+	var dayElement = dhtml.getElementsByClassNameInElement(containerElement, "month_day", "div");
 
 	for(var i = 0; i < dayElement.length; i++) {
 		var items = dhtml.getElementsByClassNameInElement(dayElement[i], "event_item", "div");
