@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -218,6 +220,7 @@ PrintView.prototype.createItem = function(item,element) {
 			// only view label colors in week view not in list view
 			if(this.view == "week") {
 				// Appointment labels
+				var imageName = "label_default.gif";
 				switch(label) {
 					case "1": imageName = "label_important.gif"; break;
 					case "2": imageName = "label_work.gif"; break;
@@ -229,7 +232,6 @@ PrintView.prototype.createItem = function(item,element) {
 					case "8": imageName = "label_birthday.gif"; break;
 					case "9": imageName = "label_special_date.gif"; break;
 					case "10": imageName = "label_phone_interview.gif"; break;
-					default: imageName = "label_default.gif"; break;
 				}
 
 				// add div with image, behind appointment div to show it as background color
@@ -257,7 +259,7 @@ PrintView.prototype.createItem = function(item,element) {
 /**
  * Function will resize all elements in the view
  */
-PrintView.prototype.resizeView = function() {
+PrintView.prototype.resizeView = function(iframe) {
 
 }
 
@@ -273,6 +275,7 @@ PrintView.prototype.createHeaderFooter = function() {
 		// header table
 		this.tbl = dhtml.addElement(this.header, "table", "headertbl", "");
 		this.tbl.setAttribute("cellspacing", "0px");
+		this.tbl.setAttribute("width", "100%");
 
 		this.tblBody = dhtml.addElement(this.tbl, "tbody");
 
@@ -318,7 +321,9 @@ PrintView.prototype.createHeaderFooter = function() {
 		events["day"] = function() {};
 		
 		this.dpPrev = new CalendarDatePickerView(-1, this.tblCellMiddle, events, {month:selectedDate.getMonth(), year:selectedDate.getFullYear()});
-		this.dpNext = new CalendarDatePickerView(-1, this.tblCellRight, events, {month:selectedDate.getMonth() + 1, year:selectedDate.getFullYear()});
+		// get next month
+		selectedDate.setMonth(selectedDate.getMonth() + 1);
+		this.dpNext = new CalendarDatePickerView(-1, this.tblCellRight, events, {month:selectedDate.getMonth(), year:selectedDate.getFullYear()});
 	} else {
 		this.header.style.display = "none";
 	}
@@ -372,6 +377,9 @@ PrintView.prototype.createIFrame = function() {
 	if (document.createElement && (iframe =	document.createElement('iframe'))) {
 		iframe.id = iframe.name = "printing_frame";
 		iframe.scrolling = "no";
+		// hardcoded value for A4/Letter size paper (210 x 297 mm / 216  279 mm)
+		iframe.style.height = "259mm";
+		iframe.style.width = "210mm";
 		document.body.appendChild(iframe);
 	}
 
@@ -385,7 +393,7 @@ PrintView.prototype.createIFrame = function() {
 			iframeDoc.write('<html>');
 			iframeDoc.write('	<head>');
 			iframeDoc.write('		<title>' + _('Zarafa WebAccess') + ' - ' + webclient.fullname + '</title>');
-			// need to inlclude css again becuase iframe can not access parent document's css
+			// need to inlclude css again because iframe can not access parent document's css
 			iframeDoc.write('		<link rel="stylesheet" type="text/css" href="client/layout/css/calendar-print.css" />');
 			iframeDoc.write('	</head>');
 			iframeDoc.write('	<body>');
@@ -396,5 +404,13 @@ PrintView.prototype.createIFrame = function() {
 			iframeDoc.write('</html>');
 			iframeDoc.close();
 		}
+
+		var viewObject = this;		// Fix loss-of-scope in setTimeout function
+		setTimeout(function() {
+			// resize frame that is displayed to user
+			viewObject.resizeView();
+			// resize frame that is used for printing
+			viewObject.resizeView(window.frames["printing_frame"]);
+		}, 1000);
 	}
 }
\ No newline at end of file
