@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -116,7 +118,7 @@ TableCompactView.prototype.addRows = function(rows)
 			for(var column in this.events["rowcolumn"]) {
 				// We only support events on the flag_status and icon_index columns
 				switch(column) {
-					case 'flag_status':
+					case 'flag_icon':
 						dhtml.setEvents(this.moduleID, tableElement.rows[i].cells[2], this.events["rowcolumn"][column]);
 						break;
 					case 'icon_index':
