@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -142,8 +144,11 @@ TableView.prototype.initView = function()
 		webclient.inputmanager.unbindEvent(module, "keydown", eventIconViewKeyboard);
 	}
 	webclient.inputmanager.bindEvent(module, "mousedown", eventTableViewMouseDown);
+	webclient.inputmanager.bindKeyControlEvent(module, module.keys["select"], "keyup", eventTableViewKeyCtrlSelectAll, true);
+	webclient.inputmanager.bindKeyControlEvent(module, module.keys["edit_item"], "keyup", eventListKeyCtrlEdit, true);
+	webclient.inputmanager.bindKeyControlEvent(module, module.keys["quick_edit"], "keyup", eventTableViewKeyCtrlQuickEdit, true);
 	
-	if(typeof dragdrop != "undefined") dragdrop.addTarget(dragdrop.targets["folder"]["scrollelement"], this.element, "folder");
+	if(typeof dragdrop != "undefined") dragdrop.addTarget(dhtml.getElementById("hierarchy"), this.element, "folder");
 
 	this.cursorElementL = dhtml.addElement(false, "div", "cursor_left", "cursor_left");
 	this.cursorElementT = dhtml.addElement(false, "div", "cursor_top", "cursor_top");
@@ -185,6 +190,11 @@ TableView.prototype.resizeView = function()
 	} else {
 			this.divElement.style.height = height + "px";
 	}
+	//update dragdrop targets after view has loaded, as datepicker will change position of hierarchy list.
+	// and which cause the isseu of dragging and dropping of elements in wrong target.
+	if(typeof(dragdrop) != "undefined") {
+		dragdrop.updateTargets("folder");
+	}
 }
 
 /**
@@ -234,7 +244,8 @@ TableView.prototype.execute = function(items, properties, action, groupID, input
 		if (inputProperties[i]["type"] == "datepicker"){			
 			setcal("insertprops_module"+ this.moduleID+"_"+inputProperties[i]["id"],"cal_insertprops_module"+ this.moduleID+"_"+inputProperties[i]["id"]);
 		}
-	}		
+	}
+
 	return entryids;
 }
 
@@ -701,21 +712,30 @@ TableView.prototype.renderColumn = function(table, name, title, type, length)
 	{
 		case "hasattach":
 		case "icon_index":
+		case "display_type":
 		case "flag_status":
 		case "flag_icon":
 		case "importance":
 		case "complete":
+		case "recurring":
 			className += " message_icon icon_" + type;
 
 			if(this.sortColumn == type) {
 				id += "_sort_" + this.sortDirection;
 			}
 			break;
+
+		//set column class of columns which display icons and type at column title bar 
+		case "alldayevent":
+		case "reminder":
+			className += " message_title ";	
+			elementValue = name;
+			break;		
 		
 		case "hidden_column":
 			className = "hidden_column";
 			break;
-			
+
 		default:
 			if(typeof(name) == "string")
 				elementValue = name;
@@ -743,6 +763,31 @@ TableView.prototype.renderColumn = function(table, name, title, type, length)
 	table.push("<td id='property_" + id + "' class='" + className + "' title='" + title + "' " + width + "><span class='column_seperator'>&nbsp;</span>" + elementValue + sort + "</td>");
 }
 
+/**
+ * Function generates a string which will be used to show the recipients in list view's attendees coloumn.
+ * @param number recipienttype number which contains the recipient type
+ * @param object item object xml data of each item
+ * @return string result string which contains the recipients name and email
+ */
+TableView.prototype.generateRecipientStringFromXML = function(recipienttype, item)
+{	
+	var result = "";
+	var recipients = item.getElementsByTagName("recipients")[0];
+
+	if(recipients){	
+		var recipient = recipients.getElementsByTagName("recipient");
+		for (var j = 0; j < recipient.length; j++){		
+			var type = dhtml.getXMLValue(recipient[j], "type");
+			var name = dhtml.getXMLValue(recipient[j], "display_name");
+			var email = dhtml.getXMLValue(recipient[j], "email_address");
+
+			if(parseInt(type,10) == recipienttype){
+				result += (result=="")?nameAndEmailToString(name, email, true) + ";": nameAndEmailToString(name, email, true);
+			}
+		}
+	}
+	return result;
+}
 
 TableView.prototype.renderRowColumn = function(table, fieldname, type, length, value, item,rowNumber)
 {
@@ -865,6 +910,27 @@ TableView.prototype.addRow = function(row)
 	return entry;
 }
 
+TableView.prototype.showEmptyView = function(message)
+{
+	var tableElement = this.divElement.getElementsByTagName("table")[0];
+	var rowElement = dhtml.getElementById("empty_view_message", "tr", tableElement);
+	if(typeof message == "undefined") {
+		message = _("There are no items to show in this view") + ".";
+	}
+
+	if(rowElement) {
+		dhtml.deleteElement(rowElement);
+	}
+
+	if(tableElement) {
+		var rowElement = tableElement.insertRow(-1);
+		rowElement.id = "empty_view_message";
+		var cell = rowElement.insertCell(-1);
+		cell.innerHTML = message;
+		cell.style.textAlign = "center";
+	}
+}
+
 TableView.prototype.getRowColumnSettings = function(fieldname, type, length, value, item)
 {
 	var className = "rowcolumn";
@@ -913,6 +979,10 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 
 			className += iconIndexToClassName(iconIndex, messageClass, !messageUnread);
 			break;
+		case "display_type":
+			className += " message_icon ";
+			className += displayTypeToClassName(value);
+			break;
 		case "flag":
 		case "flag_status":
 		case "flag_icon":
@@ -970,6 +1040,7 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 
 		case "folder_name":
 			var folder = webclient.hierarchy.getFolder(value);
+
 			if (folder && typeof(folder["display_name"])=="string"){
 				value = folder["display_name"].htmlEntities();
 			}else{
@@ -979,6 +1050,198 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 			width = 150;
 			break;
 			
+		//recurring	icon	
+		case "recurring":
+			className += " message_icon ";
+			if(parseInt(value,10) == 1) {
+				className += "icon_recurring";
+			}
+			break;
+			
+		//reminder icon	
+		case "reminder":
+			className += " message_title ";
+			if(parseInt(value,10) == 1) {
+				className += "icon_reminder";
+			}
+			break;
+			
+		// to display duration with minutes at postfix
+		case "duration":
+			elementValue = "<div class='rowcolumntext'>" + simpleDurationString(parseInt(value, 10))+ "</div>";
+			break;
+				
+		//all day as chechbox
+		case "alldayevent":
+			var checked = "";
+			className += " message_title ";
+			if(parseInt(value,10) == 1) {
+					checked = "checked='checked'";
+			}
+			elementValue = "<input type='checkbox' disabled='disabled' " + checked + ">";	
+			break;	
+		
+		//to display busy status as a string 		
+		case "meeting":
+		var responsestatus = dhtml.getXMLValue(item, "responsestatus");
+		var meeting = dhtml.getXMLValue(item, "meeting");
+			if(parseInt(meeting,10) == 0){
+				elementValue = "<div class='rowcolumntext'></div>";		
+			}else{ 
+				switch(parseInt(responsestatus,10))
+				{
+					case 0:
+					elementValue = "<div class='rowcolumntext'>"+ _("No Response")+"</div>";		
+					break;
+						
+					case 1:
+					elementValue = "<div class='rowcolumntext'>"+ _("Meeting Organizer")+"</div>";
+					break;	
+						
+					case 2:
+					elementValue = "<div class='rowcolumntext'>"+ _("Tentatively Accepted")+"</div>";
+					break;	
+						
+					case 3:
+					elementValue = "<div class='rowcolumntext'>"+ _("Accepted")+"</div>";
+					break;	
+	
+					case 4:
+					elementValue = "<div class='rowcolumntext'>"+ _("Declined")+"</div>";
+					break;	
+				
+					case 5:
+					elementValue = "<div class='rowcolumntext'>"+ _("Not Yet Responded")+"</div>";
+					break;	
+					
+					default:
+					elementValue = "<div class='rowcolumntext'></div>";
+					break;
+				}
+			}	
+			width = 150;
+			break;
+		
+			//busystatus
+			case "busystatus":
+			switch(parseInt(value,10))
+			{
+				case 0:
+				elementValue = "<div class='rowcolumntext'>"+ _("Free")+"</div>";
+				break; 
+
+				case 1:
+				elementValue = "<div class='rowcolumntext'>"+ _("Tentative")+"</div>"; 
+				break;
+
+				case 2:
+				elementValue = "<div class='rowcolumntext'>"+ _("Busy")+"</div>"; 
+				break;
+
+				case 3:
+				elementValue = "<div class='rowcolumntext'>"+ _("Out of Office")+"</div>";
+				break
+			}
+			width =150; 
+			break;
+
+		//label
+		case "label":
+			switch(parseInt(value,10))
+			{
+				case 0:
+				elementValue = "<div class='rowcolumntext'>"+ _("None")+"</div>";		
+				break;
+					
+				case 1:
+				elementValue = "<div class='rowcolumntext'>"+ _("Important")+"</div>";
+				break;	
+					
+				case 2:
+				elementValue = "<div class='rowcolumntext'>"+ _("Work")+"</div>";
+				break;	
+					
+				case 3:
+				elementValue = "<div class='rowcolumntext'>"+ _("Personal")+"</div>";
+				break;	
+				case 4:
+				elementValue = "<div class='rowcolumntext'>"+ _("Holiday")+"</div>";		
+				break;
+					
+				case 5:
+				elementValue = "<div class='rowcolumntext'>"+ _("Required")+"</div>";
+				break;	
+					
+				case 6:
+				elementValue = "<div class='rowcolumntext'>"+ _("Travel Required")+"</div>";	
+				break;	
+					
+				case 7:
+				elementValue = "<div class='rowcolumntext'>"+ _("Prepare Required")+"</div>";
+				break;	
+				
+				case 5:
+				elementValue = "<div class='rowcolumntext'>"+ _("Birthday")+"</div>";
+				break;	
+					
+				case 8:
+				elementValue = "<div class='rowcolumntext'>"+ _("Special date")+"</div>";
+				break;	
+					
+				case 9:
+				elementValue = "<div class='rowcolumntext'>"+ _("Phone Interview")+"</div>";
+				break;
+				
+				default:
+				elementValue = "<div class='rowcolumntext'></div>";
+				break;
+			}
+			width = 150;
+			break;
+		
+		//sensitivity	
+		case "sensitivity":
+			switch(parseInt(value,10))
+			{	
+				case 0:
+				elementValue = "<div class='rowcolumntext'>"+ _("Normal") +"</div>";		
+				break;
+					
+				case 1:
+				elementValue = "<div class='rowcolumntext'>"+ _("Personal")+"</div>";
+				break;	
+					
+				case 2:
+				elementValue = "<div class='rowcolumntext'>"+ _("Private")+"</div>";
+				break;	
+					
+				case 3:
+				elementValue = "<div class='rowcolumntext'>"+ _("Confidential")+"</div>";
+				break;	
+				
+				default:
+				elementValue = "<div class='rowcolumntext'></div>";
+				break;
+			}
+			width = 150;
+			break;
+			
+		//attendee
+		case "required":
+			elementValue = "<div class='rowcolumntext'>"+this.generateRecipientStringFromXML(MAPI_TO, item)+"<div>" ;
+			width = 150;
+			break;
+			
+		case "optional":
+			elementValue = "<div class='rowcolumntext'>"+this.generateRecipientStringFromXML(MAPI_CC, item)+"<div>" ;
+			width = 150;
+			break;
+			
+		case "resource":
+			elementValue = "<div class='rowcolumntext'>"+this.generateRecipientStringFromXML(MAPI_BCC, item)+"<div>" ;
+			width = 150;
+			break;	
+		
 		default:
 			// fix any HTML characters, because value will be added directly to innerHTML
 			// known bug: if a subject only contains "&nbsp;" it wouldn't display
@@ -1091,9 +1354,9 @@ TableView.prototype.destructor = function()
 {
 	webclient.inputmanager.removeObject(webclient.getModule(this.moduleID));
 
-	if(this.combobox) {
-		this.combobox.destructor();
-		dhtml.deleteAllChildren(dhtml.getElementById("pagecombobox"));
+	if(this.pagingTool) {
+		this.pagingTool.destructor();
+		dhtml.deleteAllChildren(dhtml.getElementById("pageelement_"+this.moduleID));
 	}
 
 	this.element.innerHTML = "";
@@ -1104,16 +1367,14 @@ TableView.prototype.destructor = function()
  */ 
 TableView.prototype.pagingElement = function(totalrowcount, rowcount, rowstart)
 {
-	var selected = false;
-	var comboboxElement = dhtml.getElementById("pagecombobox");
-	dhtml.deleteAllChildren(comboboxElement);
+	var pagingToolElement = dhtml.getElementById("pageelement_"+this.moduleID);
+	dhtml.deleteAllChildren(pagingToolElement);
 
-	if(this.combobox) {
+	if(this.pagingTool) {
 		var pageElement = dhtml.getElementById("page_"+this.moduleID);
-		
 		pageElement.style.display = "none";
-		
-		this.combobox.destructor();
+
+		this.pagingTool.destructor();
 	}
 
 	// Number of pages
@@ -1125,83 +1386,29 @@ TableView.prototype.pagingElement = function(totalrowcount, rowcount, rowstart)
 	// current page
 	var currentPage = Math.floor(rowstart / rowcount);
 
-	// create combobox
-	this.combobox = new ComboBox("paging", eventListChangePage, this.moduleID);
-	dhtml.comboBoxes.push("paging");
+	// create paging element
+	this.pagingTool = new Pagination("paging", eventListChangePage, this.moduleID);
 	
-	var page_start = currentPage - 4;
-	
-	if (page_start<0) {
-		page_start = 0;
-	}
-	
-	// construct combobox items
-	var options = new Array();
-
-	// insert first item
-	if (page_start > 1){
-		var option = new Object();
-		option["id"] = 0;
-		option["value"] = _("First page");
-		options.push(option);
-	}
-
-	for(var i=0; i<9 && (i+page_start)<pages; i++) {
-		var page = page_start + i;
-		
-		var option = new Object();
-		option["id"] = page;
-		option["value"] = (page+1) + " " + _("of") + " " + pages;
-		options.push(option);
-		
-		if (page == currentPage) {
-			selected = option["value"];
-		}
-	}
-
-	// insert last item
-	if ((page_start+9) < pages){
-		var option = new Object();
-		option["id"] = pages-1;
-		option["value"] = _("Last page");
-		options.push(option);
-	}
-
-	// create previous/next button
-	var prevButton = dhtml.addElement(comboboxElement, "div", "paging prev"+(currentPage==0?" nobutton":""));
-	var nextButton = dhtml.addElement(comboboxElement, "div", "paging next"+(currentPage==pages-1?" nobutton":""));
-
-	if (currentPage!=0) {
-		this.hackPaging["prev"] = prevButton;//hack
-		dhtml.addEvent(this.moduleID, prevButton, "click", eventListChangePage);
-		prevButton.setAttribute("title",_("Go to the previous page"));
-	}
-	if (currentPage!=pages-1) {
-		this.hackPaging["next"] = nextButton;//hack
-		dhtml.addEvent(this.moduleID, nextButton, "click", eventListChangePage);
-		nextButton.setAttribute("title",_("Go to the next page"));
-	}
-	
-	if(selected) {
-		this.combobox.createComboBox(comboboxElement, options, selected, 75);
+	if(pages > 0) {
+		this.pagingTool.createPagingElement(pagingToolElement, pages, currentPage);
 		var pageElement = dhtml.getElementById("page_"+this.moduleID);
 		pageElement.style.display = "block";
 	}
 
-	return selected;
+	return true;
 }
 
 TableView.prototype.removePagingElement = function()
 {
-	var comboboxElement = dhtml.getElementById("pagecombobox");
-	dhtml.deleteAllChildren(comboboxElement);
+	var pagingToolElement = dhtml.getElementById("pageelement_"+this.moduleID);
+	dhtml.deleteAllChildren(pagingToolElement);
 
-	if(this.combobox) {
+	if(this.pagingTool) {
 		var pageElement = dhtml.getElementById("page_"+this.moduleID);
 		
 		pageElement.style.display = "none";
 		
-		this.combobox.destructor();
+		this.pagingTool.destructor();
 	}
 }
 
@@ -1279,7 +1486,7 @@ TableView.prototype.getFlagClass = function(flagStatus, flagIcon)
 					className = "icon_flag_complete";
 					break;
 				default:
-					className = "icon_flag_none";
+					className = "icon_flag";
 					break;
 			}
 			break;
@@ -1335,6 +1542,25 @@ TableView.prototype.getCursorPosition = function(id)
 {
 	return this.cursorMessage;
 }
+/**
+ * Function which returns all row elements
+ * @return array all row elements
+ */
+TableView.prototype.getAllRowElements = function()
+{
+	// Get row count
+	var rowCount = this.getRowCount();
+	var elements = new Array();
+	for (var i = 0; i < rowCount; i++){
+		// Get row id
+		var elementID = this.getElemIdByRowNumber(i);
+		var element = dhtml.getElementById(elementID);
+		if (element){
+			elements.push(element);
+		}
+	}
+	return elements;
+}
 
 
 // FIXME FIXME this is called with 'mobuleObject' referring not to this view oject, but to our parent module!
@@ -1417,25 +1643,22 @@ function eventTableViewKeyboard(moduleObject, element, event)
 							eventListDblClickMessage(moduleObject, element, event);
 							break;
 						case 46: // DELETE
-							moduleObject.deleteMessages(moduleObject.getSelectedMessages());
+							// event.shiftKey for soft delete if Shift+Del
+							moduleObject.deleteMessages(moduleObject.getSelectedMessages(), event.shiftKey);
 							break;
 		
 						case 37: // LEFT
-							var viewObj = moduleObject.viewController.viewObject;
-							if (viewObj.hackPaging["prev"]){
-								dhtml.executeEvent(viewObj.hackPaging["prev"], "click");
+							var pagingTool = moduleObject.viewController.viewObject.pagingTool;
+							if (pagingTool.hackPaging["prev"]){
+								dhtml.executeEvent(pagingTool.hackPaging["prev"], "click");
 							}
 							break;
 						case 39: // RIGHT
-							var viewObj = moduleObject.viewController.viewObject;
-							if (viewObj.hackPaging["next"]){
-								dhtml.executeEvent(viewObj.hackPaging["next"], "click");
+							var pagingTool = moduleObject.viewController.viewObject.pagingTool;
+							if (pagingTool.hackPaging["next"]){
+								dhtml.executeEvent(pagingTool.hackPaging["next"], "click");
 							}
 							break;
-							
-						case 27: //ESC
-							moduleObject.removeinputfields(moduleObject, false, event);
-							break;
 					}
 		
 					// when we select an element, we want to scroll the view and set the cursor position
@@ -1457,7 +1680,18 @@ function selectItem(moduleObject, selectedElement, event)
 {
 	if(selectedElement) {
 		eventListMouseDownMessage(moduleObject, selectedElement, event);
-		eventListMouseUpMessage(moduleObject, selectedElement, event);
+		if (moduleObject.previewTimer){
+				window.clearTimeout(moduleObject.previewTimer);
+			}
+		/**
+		 * This delay is used when the user is using the up and down arrow keys
+		 * to browse between the items in the list. When the presses the down key several times
+		 * this delay keeps the WA from loading each item.
+		 * Instead only the last item that is selected will be loaded.
+		 */
+		moduleObject.previewTimer = window.setTimeout(function() {
+											eventListMouseUpMessage(moduleObject, selectedElement, event);
+										}, 250);
 	}
 }
 
@@ -1506,3 +1740,34 @@ function eventTableViewMouseDown(moduleObject, element, event)
 		dhtml.showHideElement(importancemenu, event.clientX, event.clientY, true);
 	}
 }
+/**
+ * Function which selects all items.
+ */
+function eventTableViewKeyCtrlSelectAll(moduleObject, element, event, keys)
+{
+	// Retrive all row elements
+	var elements = moduleObject.viewController.viewObject.getAllRowElements();
+	moduleObject.selectMessages(elements, "rowselected");
+}
+/**
+ * Function which activates/deactivates quick edit mode in list.
+ */
+function eventTableViewKeyCtrlQuickEdit(moduleObject, element, event, keys)
+{
+	if (moduleObject.inputproperties && moduleObject.inputproperties.length > 0
+		&& moduleObject.selectedMessages && moduleObject.selectedMessages.length > 0){
+		switch(event.keyCombination)
+		{
+			case keys["activate"]:
+				var element = dhtml.getElementById(moduleObject.selectedMessages[0]);
+
+				if (element)
+					moduleObject.CreateEditFields(moduleObject, element, event);
+				break;
+			case keys["deactivate"]:
+				if (moduleObject.editMessage)
+					moduleObject.removeinputfields(moduleObject, false, event);
+				break;
+		}
+	}
+}
\ No newline at end of file
