@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -73,7 +75,8 @@
 								"client/layout/css/icons.css",
 								"client/layout/css/tree.css",
 								"client/layout/css/calendar.css",
-								"client/layout/css/date-picker.css"
+								"client/layout/css/date-picker.css",
+								"client/layout/css/today.css"
 							)
 		);
 		if(defined('MUC_AVAILABLE') && MUC_AVAILABLE == true){
@@ -112,6 +115,7 @@
 							"client/views/table.view.js",
 							"client/modules/module.js", 
 							"client/modules/listmodule.js", 
+							"client/modules/todaylistmodule.js", 
 							"client/modules/itemmodule.js",
 							"client/layout/js/date-picker.js",							
 							"client/layout/js/date-picker-language.js",
@@ -120,11 +124,12 @@
 		);
 
 		includeJavaScriptFilesFromDir("core", array("constants.js", "utils.js"));
-		includeJavaScriptFilesFromDir("widgets", array("widget.js"));
+		includeJavaScriptFilesFromDir("widgets", array("widget.js", "tabswidget.js", "searchcriteria.js"));
 		includeJavaScriptFilesFromDir("views", array("table.view.js", "view.js", "print.view.js", 
 													 "print.calendar.dayview.js", "print.calendar.weekview.js", 
 													 "print.calendar.monthview.js", "print.calendar.listview.js"));
-		$modules = includeJavaScriptFilesFromDir("modules", array("module.js", "listmodule.js", "itemmodule.js", "printlistmodule.js"));
+		$modules = includeJavaScriptFilesFromDir("modules", array("module.js", "listmodule.js", "itemmodule.js",
+																  "printlistmodule.js", "advancedfindlistmodule.js", "todaylistmodule.js"));
 
 		$pluginJsFiles = $GLOBALS['PluginManager']->getClientFiles('js', Array('all','main'));
 		if(count($pluginJsFiles) > 0){
@@ -151,12 +156,24 @@
 					window.BROWSER_SAFARI = true;
 			}else if(document.documentMode == 8){
 				window.BROWSER_IE8 = true;
+			}else{
+				ua = navigator.userAgent.toLowerCase();
+				window.BROWSER_OPERA = /opera/.test(ua);
+				window.BROWSER_IE = !window.BROWSER_OPERA & /msie/.test(ua);
+				window.BROWSER_IE7 = window.BROWSER_IE && /msie 7/.test(ua);
+				window.BROWSER_IE8 = window.BROWSER_IE && /msie 8/.test(ua);
+				// The check on IE8 is not that usefull, but is just there to show the way the check works.
+				window.BROWSER_IE6 = window.BROWSER_IE && !window.BROWSER_IE7 && !window.BROWSER_IE8;
 			}
 			var CLIENT_TIMEOUT = <?=CLIENT_TIMEOUT?>;
 			var DIALOG_URL = "<?=DIALOG_URL?>";
 			var MUC_AVAILABLE =<?=(defined('MUC_AVAILABLE')&&MUC_AVAILABLE==true)?'true':'false'?>;
 			var SSO_LOGIN =<?=(isset($_SERVER['REMOTE_USER']))?'true':'false'?>;
 
+			<?php if(checkTrialVersion()){ ?>
+			var ZARAFA_TRIAL_EXPIRE_PERIOD = <?=getDaysLeftOnTrialPeriod();?>; 
+			<?php } ?>
+
 			var webclient;
 			var dhtml;
 			var dragdrop;
@@ -216,6 +233,7 @@
 			<div id="numberitems"></div>
 			<div id="loggedon"></div>
 			<div id="quota_footer"></div>
+			<div id="trial_warning"></div>
 		</div>
 	</body>
 </html>
