@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -193,7 +195,8 @@ function eventDatePickerInputChange(moduleObject, element, event)
 	var obj = element.datePickerObj;
 	// As parseDate function works with Date value and create current datetime string if the Date value is not a valid date.
 	// Thus here we check if the newValue inserted is valid date or any string or invalid date and assign its Value to blank if invalid.
-	var newValue = (new Date(element.value) != "Invalid Date")?Date.parseDate(element.value,_("%d-%m-%Y")):"" ;
+	var valueArr = element.value.trim().split("-"); // get the values as dd - mm - yyyy
+	var newValue = (new Date(valueArr[2], valueArr[1], valueArr[0]) != "Invalid Date")?Date.parseDate(element.value,_("%d-%m-%Y")):"" ;
 	var oldValue = obj.value;
 
 	if(!newValue){
