@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -54,6 +56,7 @@ function DragDrop()
 	this.targets = new Object();
 	this.draggable = false;
 	this.targetover = false;
+	this.hoverTimeout;
 }
 
 /**
@@ -93,6 +96,7 @@ DragDrop.prototype.addTarget = function(scrollElement, element, group, isFixed,
 		this.targets[group]["elementidmap"] = new Array();
 	
 	this.targets[group]["scrollelement"] = scrollElement;
+	dhtml.addEvent(-1, this.targets[group]["scrollelement"], "mouseout", eventDragDropMouseOutDraggable);
 
 	// Add an element ID -> array ID mapping for reverse lookups later
 	var id = this.targets[group]["targets"].push(target)-1;
@@ -130,6 +134,24 @@ DragDrop.prototype.addDraggable = function(element, group, isFixed, resizable, m
 	}
 }
 
+DragDrop.prototype.registerHoverElement = function(element, callback, scope, data){
+	if(element){
+		element.hoverEvent = new Object();
+		element.hoverEvent.callback = callback;
+		element.hoverEvent.scope = scope;
+		element.hoverEvent.data = data;
+		dhtml.addEvent(this, element, "mousemove", eventDragDropHoverMouseMove);
+		dhtml.addEvent(this, element, "mouseout", eventDragDropHoverMouseOut);
+	}
+}
+DragDrop.prototype.unregisterHoverElement = function(element){
+	if(element){
+		delete element.hoverEvent;
+		dhtml.removeEvent(element, "mousemove", eventDragDropHoverMouseMove);
+	}
+}
+
+
 DragDrop.prototype.deleteGroup = function(group)
 {
 	delete this.targets[group];
@@ -244,14 +266,12 @@ DragDrop.prototype.moveElement = function(event)
 DragDrop.prototype.moveDraggable = function(target)
 {
 	if(this.targetover) {
-		if(this.targetover["element"].className.indexOf("dragover") >= 0) {
-			this.targetover["element"].className = this.targetover["element"].className.substring(0, this.targetover["element"].className.indexOf("dragover"));
-		}
+		dhtml.removeClassName(this.targetover["element"], "dragover");
 	}
 	if(target["notallowed"]){
-		target["element"].className += " dragover_not_allowed";
+		dhtml.addClassName(target["element"], "dragover_not_allowed");
 	}else{
-		target["element"].className += " dragover";
+		dhtml.addClassName(target["element"], "dragover");
 	}
 }
 
@@ -396,6 +416,12 @@ function eventDragDropMouseDownDraggable(moduleObject, element, event)
 	return false;
 }
 
+function eventDragDropMouseOutDraggable(moduleObject, element, event)
+{
+	dhtml.removeClassName(dragdrop.targetover["element"], "dragover");
+	dragdrop.targetover = false;
+}
+
 function eventDragDropMouseMoveDraggable(moduleObject, element, event)
 {
 	if(!event) {
@@ -409,8 +435,8 @@ function eventDragDropMouseMoveDraggable(moduleObject, element, event)
 		if(Math.abs(dragdrop.clickX - event.clientX) + Math.abs(dragdrop.clickY - event.clientY) > 10) {
     		if(!isFixed) {
 				dragdrop.draggable.style.display = "block";
-				dragdrop.draggable.style.top = (event.clientY-dragdrop.relClickY) + "px";
-				dragdrop.draggable.style.left = (event.clientX - dragdrop.relClickX) + "px";
+				dragdrop.draggable.style.top = ((event.clientY-dragdrop.relClickY)+20) + "px";
+				dragdrop.draggable.style.left = ((event.clientX - dragdrop.relClickX)+20) + "px";
 
 				if(!dragdrop.attached) {
 					document.body.appendChild(dragdrop.draggable);
@@ -427,6 +453,8 @@ function eventDragDropMouseMoveDraggable(moduleObject, element, event)
 
 function eventDragDropMouseUpDraggable(moduleObject, element, event)
 {
+	var dropped = false;
+
 	// Call event notification method of the moduleObject to let the module know the drag event has been ended.
 	if(moduleObject.dragEventUp){
 		moduleObject.dragEventUp();
@@ -439,10 +467,8 @@ function eventDragDropMouseUpDraggable(moduleObject, element, event)
 			var targetGroup = dragdrop.targets[draggableElem.getAttribute("group")];
 			var target = dragdrop.targetover;
 
-			if(target["element"].className.indexOf("dragover") > 0) {
-				target["element"].className = target["element"].className.substring(0, target["element"].className.indexOf("dragover"));
-			}
-			
+			dhtml.removeClassName(target["element"], "dragover");
+
 			if(!target["notallowed"]){
 				var draggableCallback = false;
 				if(draggableElem.moduleID){
@@ -457,6 +483,9 @@ function eventDragDropMouseUpDraggable(moduleObject, element, event)
 				}else if(targetGroup["moduleID"] && targetGroup["callbackfunction"]) {
 					targetGroup.callbackfunction(webclient.getModule(targetGroup["moduleID"]), target["element"], draggableElem, event);
 				}
+
+				// We dropped something
+				dropped = true;
 			}
 		}
 		
@@ -472,8 +501,11 @@ function eventDragDropMouseUpDraggable(moduleObject, element, event)
 		draggableElem = false;
 		dragdrop.attached = false;
 	}
-	
-	return false;
+
+	// Do not process other mouseup events if we did an actual drop
+	if(dropped)
+		return false;	
+	return true;
 }
 
 function eventDragDropMouseMoveFixedDraggable(moduleObject, element, event)
@@ -494,3 +526,30 @@ function eventDragDropMouseMoveFixedDraggable(moduleObject, element, event)
 	
 	return false;
 }
+
+function eventDragDropHoverMouseMove(widget, element, event){
+	// When the user moves the mouse the timeout is reset meaning that 
+	// the hover event will not yet be fired.
+	if(typeof widget.hoverTimeout != "undefined"){
+		window.clearTimeout(widget.hoverTimeout);
+	}
+
+	if(!dragdrop.draggable){
+		return;
+	}
+
+	widget.hoverTimeout = window.setTimeout(function(){
+		if(element && element.hoverEvent){
+			if(typeof element.hoverEvent.callback == "function"){
+				element.hoverEvent.callback.call(element.hoverEvent.scope, element, element.hoverEvent.data);
+			}
+		}
+	},1000);
+}
+function eventDragDropHoverMouseOut(widget, element, event){
+	// When the user moves the mouse the timeout is reset meaning that 
+	// the hover event will not yet be fired.
+	if(typeof widget.hoverTimeout != "undefined"){
+		window.clearTimeout(widget.hoverTimeout);
+	}
+}
