@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -235,7 +237,7 @@ Menu.prototype.buildContextMenu = function(moduleID, elementid, items, posX, pos
 			var seperator = dhtml.addElement(contextmenu, "div", "icon_menuitemseperator");
 			seperator.style.height = "1px";
 		} else {
-			var menuitem = dhtml.addElement(contextmenu, "div", "menuitem icon_" + items[i]["id"], false, items[i]["name"]);
+			var menuitem = dhtml.addElement(contextmenu, "div", "menuitem icon_" + items[i]["id"], items[i].id, items[i]["name"]);
 			if(items[i]["name"]){
 				menuitem.data = items[i]["data"];
 			}
@@ -418,7 +420,7 @@ function eventMenuNewDefaultMessage(moduleObject, element, event)
 		webclient.openWindow(moduleObject, messageClass, DIALOG_URL+"task=" + messageClass + "_standard&storeid=" + storeID +"&parententryid="+folderEntryID+(extraParams?"&"+extraParams:""));
 	}
 	else{
-		webclient.openWindow(hierarchymodule, messageClass, DIALOG_URL+"task=createfolder_modal&parent_entryid=" + hierarchymodule.selectedFolder+(extraParams?"&"+extraParams:""), 300, 400);
+		webclient.openWindow(hierarchymodule, messageClass, DIALOG_URL+"task=createfolder_modal&parent_entryid=" + hierarchymodule.selectedFolder+(extraParams?"&"+extraParams:""), 300, 400, null, null, null, {parentModule: hierarchymodule});
 	}
 }
 /**
