@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -57,19 +59,20 @@ suggestionList.superclass = Widget.prototype;
  * @param {HtmlElement} element
  * @param {String} sourceModule
  */
-function suggestionList(id,inputfld,sourceModule){
+function suggestionList(id,inputfld,sourceModule, callBackFunction){
 	if(arguments.length > 1) {
-		this.init(id, inputfld, sourceModule);
+		this.init(id, inputfld, sourceModule, callBackFunction);
 	}
 }
 
-suggestionList.prototype.init = function(id, inputfld, sourceModule){
+suggestionList.prototype.init = function(id, inputfld, sourceModule, callBackFunction){
 	this.id = id;
 	this.inputfld = inputfld;
 	this.sourceModule = sourceModule;
 	this.lastSearched = false;
 	this.selected = -1;
 	this.focusSuggestions = new Array();
+	this.callBackFunction = callBackFunction ? callBackFunction : false;
 
 	try{
 		// Disable autocomplete functionality of an input field
@@ -223,7 +226,7 @@ suggestionList.prototype.selectSuggestion = function(selection){
 		// Select the whole section between the both ;  where the cursor is located in between
 		dhtml.setSelectionRange(this.inputfld, l_iPreStringChars, l_iSelectionEndPos);
 		// Replace the typed input and replace it with the selected suggestion.
-		dhtml.textboxReplaceSelection(this.inputfld, " " + this.focusSuggestions[selection] + " ");
+		dhtml.textboxReplaceSelection(this.inputfld, (l_iPreStringChars > 0 ? " " : "") + this.focusSuggestions[selection]);
 		// Test is the last element of the input field has content (= characters excl. spaces)
 		if(this.inputfld.value.split(";").pop().replace(" ", "").length > 0){
 			this.inputfld.value += "; ";
@@ -231,6 +234,11 @@ suggestionList.prototype.selectSuggestion = function(selection){
 		// Move cursor to the end
 		dhtml.setSelectionRange(this.inputfld, this.inputfld.value.length, this.inputfld.value.length);
 		this.removeSuggestionList();
+
+		if (this.callBackFunction){
+			this.callBackFunction();
+		}
+
 		return true;
 	}else{
 		return false;
@@ -322,11 +330,20 @@ function eventSuggestionListOnKeyDown(moduleObj, element, event){
 			 **/
 			if(moduleObj.selectSuggestion(moduleObj.selected)){
 				// Event handler returns false to disable effect of TAB key.
+				if (this.callBackFunction){
+					this.callBackFunction();
+				}
+
 				return false;
 			}
 			break;
 		case 13:	// Enter
-			moduleObj.selectSuggestion(moduleObj.selected);
+			if(moduleObj.selectSuggestion(moduleObj.selected)){
+				// Event handler returns false to disable effect of ENTER key.
+				if (this.callBackFunction){
+					this.callBackFunction();
+				}
+			}
 			break;
 		case 27:	// Esc
 		case 37:	// Left
