@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -53,14 +55,14 @@ TableWidget.prototype = new Widget;
 TableWidget.prototype.constructor = TableWidget;
 TableWidget.superclass = Widget.prototype;
 
-function TableWidget(element, multipleSelect, windowObj)
+function TableWidget(element, multipleSelect, windowObj, noLoader)
 {
-	this.init(element, multipleSelect, windowObj);
+	this.init(element, multipleSelect, windowObj, noLoader);
 }
 
 //TODO: order mapping> this.sortorder = [0=>rowID, 1=>rowID]
 
-TableWidget.prototype.init = function(element, multipleSelect, windowObj)
+TableWidget.prototype.init = function(element, multipleSelect, windowObj, noLoader)
 {
 	TableWidget.superclass.init(this);
 
@@ -75,11 +77,15 @@ TableWidget.prototype.init = function(element, multipleSelect, windowObj)
 	this.selected = new Object();
 	this.numSelected = 0;
 	this.multipleSelect = (typeof multipleSelect != "undefined")? Boolean(multipleSelect) : true;
+	this.noLoader = (typeof noLoader != "undefined")? Boolean(noLoader) : false;
 
 	this.columnResizeListeners = new Array();
 	this.eventRowListeners = new Array();
-	//Show loader.
-	this.showLoader();
+
+	if(!this.noLoader) {
+		// Show loader
+		this.showLoader();
+	}
 
 
 //	// Prevent IE scrolling the pane when user does up/down/pgup/etc
@@ -94,9 +100,40 @@ TableWidget.prototype.init = function(element, multipleSelect, windowObj)
 
 TableWidget.prototype.destructor = function(widgetObject)
 {
+	// remove inputmanager binding
+	webclient.inputmanager.removeObject(this);
+
+	// reset contents of widget
+	this.resetWidget();
+
 	TableWidget.superclass.destructor(this);
 }
 
+/**
+ * Function will reset all contents of table widget, this function is created to
+ * reuse table widget object, when data is changed in table widget, so we don't
+ * have to create new table widget object everytime when results are changed
+ * and also we can empty table widget data
+ */
+TableWidget.prototype.resetWidget = function()
+{
+	// remove events registered with elements
+	dhtml.removeEvents(this.element);
+
+	// remove elements
+	dhtml.deleteAllChildren(this.element);
+
+	// reinitialize variables
+	this.columns = new Array();
+	this.data = new Object();
+	this.htmlrefs["headertable"] = null;
+	this.htmlrefs["contenttable"] = null;
+	this.selected = new Object();
+	this.numSelected = 0;
+	this.eventRowListeners = new Array();
+	this.columnResizeListeners = new Array();
+}
+
 TableWidget.prototype.addColumn = function(id, columnName, columnWidth, columnOrder){
 /**
  * COLUMNDATA:
@@ -132,9 +169,11 @@ Adding classnames for rows/cells when adding data
 }
 
 TableWidget.prototype.generateTable = function(data){
-	//Hide loader
-	this.hideLoader();
-	
+	if(!this.noLoader) {
+		// Hide loader
+		this.hideLoader();
+	}
+
 	if(this.element){
 		// First clear the old table if this is not the initial generation
 		this.htmlrefs["headertable"] = null;
@@ -163,6 +202,7 @@ TableWidget.prototype.generateTable = function(data){
 		content += '<div style="height: 100%;" id="tablewidget['+this.widgetID+'][container]" class="tableview">';
 		content += '<div id="tablewidget['+this.widgetID+'][headercontainer]" class="columnbackground">';
 
+		content += '<table border="0" cellpadding="0" cellspacing="0" width="100%"><tbody><tr><td>';
 		content += '<table border="0" cellpadding="0" cellspacing="0" width="100%" id="tablewidget['+this.widgetID+'][headertable]"><tbody>';
 		content += '<tr class="columns">';
 
@@ -228,8 +268,8 @@ TableWidget.prototype.generateTable = function(data){
 			this.htmlrefs["contenttable"].rows[i].rowID = this.htmlrefs["contenttable"].rows[i].getAttribute("rowID") || "";
 			dhtml.addEvent(this, this.htmlrefs["contenttable"].rows[i], "mousedown", eventTableWidgetClickRow, this.windowObj);
 			dhtml.addEvent(this, this.htmlrefs["contenttable"].rows[i], "dblclick", eventTableWidgetDblClickRow, this.windowObj);
+			dhtml.addEvent(this, this.htmlrefs["contenttable"].rows[i], "contextmenu", eventTableWidgetRowContextMenu, this.windowObj);
 		}
-
 	}
 }
 
@@ -279,7 +319,16 @@ TableWidget.prototype.generateRowColumnsHTML = function(rowData, addWidthData){
 
 				content += '<td class="rowcolumn" '+columnWidth+' columnID="'+this.columns[i]["id"]+'">'+rowData[ this.columns[i]["id"] ]['innerHTML']+'</td>';
 			}else{
-				content += '<td></td>';
+				/**
+				 * if there is no data in a cell for first row then also we have to give
+				 * width to that cell, otherwise it will break layout
+				 */
+				var columnWidth = "";
+				if(addWidthData && parseInt(this.widths[ this.columns[i]["id"] ],10) > 0){
+					columnWidth = ' width="'+this.widths[ this.columns[i]['id'] ]+'" ';
+				}
+
+				content += '<td class="rowcolumn" '+columnWidth+'></td>';
 			}
 		}else{
 			content += '<td></td>';
@@ -298,7 +347,7 @@ rowData[columnID] =
 
 TableWidget.prototype.addRowHTML = function(rowData, insertAt){
 	if(this.htmlrefs["contenttable"]){
-		if(insertAt < 0){
+		if(insertAt < 0 || typeof insertAt == "undefined"){
 			var insertAt = this.htmlrefs["contenttable"].rows.length;
 		}
 
@@ -317,6 +366,7 @@ TableWidget.prototype.addRowHTML = function(rowData, insertAt){
 				newRow.rowID = newRow.getAttribute("rowID") || "";
 				dhtml.addEvent(this, newRow, "mousedown", eventTableWidgetClickRow, this.windowObj);
 				dhtml.addEvent(this, newRow, "dblclick", eventTableWidgetDblClickRow, this.windowObj);
+				dhtml.addEvent(this, newRow, "contextmenu", eventTableWidgetRowContextMenu, this.windowObj);
 
 				// Get reference to current first row so we can strip it of it width data
 				if(insertAt == 0){
@@ -390,7 +440,12 @@ TableWidget.prototype.resize = function(){
 	// Resize vertically
 	var headerContainer = dhtml.getElementById("tablewidget["+this.widgetID+"][headercontainer]", "div", this.element);
 	var contentContainer = dhtml.getElementById("tablewidget["+this.widgetID+"][contentcontainer]", "div", this.element);
-	contentContainer.style.height = this.element.offsetHeight - headerContainer.offsetHeight + "px";
+	if(contentContainer != null) {
+		var contentContainerHeight = this.element.offsetHeight - headerContainer.offsetHeight;
+		if(contentContainerHeight > 0) {
+			contentContainer.style.height = contentContainerHeight + "px";
+		}
+	}
 }
 
 TableWidget.prototype.getColumnData = function(columnID){
@@ -562,10 +617,14 @@ TableWidget.prototype.deselectRow = function(rowID){
 		this.callRowListener("deselect", {change: deselected});
 	}
 }
-TableWidget.prototype.selectRow = function(rowID){
+TableWidget.prototype.selectRow = function(rowID, adjustScroller){
 	var selected = new Array();
 	if(typeof rowID != "object")
 		rowID = [rowID];
+	
+	if(typeof adjustScroller == "undefined" || adjustScroller == null) {
+		adjustScroller = false;
+	}
 
 	for(var i in rowID){
 		if(!this.selected[rowID[i]]){
@@ -578,6 +637,15 @@ TableWidget.prototype.selectRow = function(rowID){
 			}
 		}
 	}
+
+	// change scrollbar position to the selected row
+	if(adjustScroller !== false && row !== false) {
+		var contentContainer = dhtml.getElementById("tablewidget["+this.widgetID+"][contentcontainer]", "div", this.element);
+		if(contentContainer != null) {
+			contentContainer.scrollTop = row.offsetTop;
+		}
+	}
+
 	// Notify external systems of update
 	if(selected.length > 0){
 		this.callRowListener("select", {change: selected});
@@ -642,6 +710,11 @@ TableWidget.prototype.callRowListener = function(type, data){
 			args[2] = data.rowID || false;	// rowID of double clicked row
 			args[3] = data.event || false;	// event object
 			break;
+		case "contextmenu":
+			args[1] = "contextmenu";		// type
+			args[2] = data.rowID || false;	// rowID of selected row
+			args[3] = data.event || false;	// event object
+			break;
 	}
 	for(var i in this.eventRowListeners){
 		if(this.eventRowListeners[i]['type'] == 'all' || this.eventRowListeners[i]['type'] == type){
@@ -746,6 +819,22 @@ function eventTableWidgetDblClickRow(moduleObject, element, event){
 		moduleObject.callRowListener("dblclick", {rowID: rowID, event: event});
 	}
 }
+
+/**
+ * Global event function
+ * this function is registered with contextemenu event of table widget,
+ * and it will call external event that is registered with table widget 
+ * for context menu handling
+ */
+function eventTableWidgetRowContextMenu(moduleObject, element, event){
+	if(typeof moduleObject == "undefined")
+		return false;
+
+	if(element.getAttribute("rowID")){
+		var rowID = element.getAttribute("rowID");
+		moduleObject.callRowListener("contextmenu", {rowID: rowID, event: event});
+	}
+}
 /**
  * Function which shows loader.
  */
@@ -761,3 +850,27 @@ TableWidget.prototype.hideLoader = function ()
 	var loader = dhtml.getElementById("tablewidget_loader["+ this.widgetID +"]");
 	dhtml.deleteElement(loader);
 }
+
+/**
+ * Function which shows a message when table widget contains zero rows.
+ */
+TableWidget.prototype.showZeroResultMessage = function ()
+{
+	var msgElement = dhtml.getElementById("tablewidget_message["+ this.widgetID +"]");
+
+	if(!msgElement) {
+		dhtml.addElement(this.element, "center", false, "tablewidget_message["+ this.widgetID +"]", _("There are no items to show in this view."), this.windowObj);
+	}
+}
+
+/**
+ * Function which hides message which is shown when tablewidget contains zero rows.
+ */
+TableWidget.prototype.hideZeroResultMessage = function ()
+{
+	var msgElement = dhtml.getElementById("tablewidget_message["+ this.widgetID +"]");
+
+	if(msgElement) {
+		dhtml.deleteElement(msgElement);
+	}
+}
\ No newline at end of file
