@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -215,9 +217,13 @@ function eventTimePickerInputChange(moduleObject, element, event)
 		}
 	}
 	else{
-		dtpObj.setValue(timeToSeconds(newValue));
+		dtpObj.setValue(timeToSeconds(newValue),dtpObj);
+		// here we check if the value to time is hours in greater the 24hrs [one day]
+		// if it is we have to add one Day in datepicker as well. 
+		if(parseInt(newValue.substring(0,2), 10) >= 24)
+			dtpObj.dayValue = 1;
 		if(dtpObj.onchange)
-			dtpObj.onchange(dtpObj, oldValue);
+			dtpObj.onchange(dtpObj, oldValue, dtpObj.dayValue);
 	}
 }
 
