@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -170,10 +172,10 @@
 
 		if($_GET && array_key_exists("logon", $_GET)) {
 			$GLOBALS['PluginManager']->triggerHook("server.index.login.success");
-			if($_GET && $_GET["action_url"] != "") {
+			if(isset($_POST) && isset($_POST["action_url"]) && $_POST["action_url"] != "") {
 				// if action attributes are passed in POST variable then append it to URL for
 				// further processing
-				$url = "index.php" . $_GET["action_url"];
+				$url = "index.php" . $_POST["action_url"];
 				header("Refresh: 0; url=$url");
 				exit;
 			} else {
