@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -69,7 +71,7 @@
 		 * @param string $entryid MAPI message entryid, is used for the inline attachments and new mail
 		 * @return string safe html		
 		 */		 		
-		function safeHTML($html, $storeid, $entryid)
+		function safeHTML($html, $storeid = false, $entryid = false)
 		{
 			// Save all "<" symbols
 			$html = preg_replace("/<(?=[^a-zA-Z\/\!\?\%])/", "&lt;", $html); 
@@ -79,11 +81,21 @@
 			// Filter '<script>'
 			$html = $this->filterScripts($html);
 			
+			if($storeid && $entryid){
+				// Set GLOBALS for preg_replace_callback functions.
+				$GLOBALS["preg_replace"] = array();
+				$GLOBALS["preg_replace"]["storeid"] = $storeid;
+				$GLOBALS["preg_replace"]["entryid"] = $entryid;
+			}
+
 			// Set GLOBALS for preg_replace_callback functions.
 			$GLOBALS["preg_replace"] = array();
 			$GLOBALS["preg_replace"]["storeid"] = $storeid;
 			$GLOBALS["preg_replace"]["entryid"] = $entryid;
 			
+			// Inline image attachments can also be specified without 'cid:' so fetch all img tag and replace with link to attachment
+			$html = preg_replace_callback('/(<\s*img\b[^>].*?src\s*=\s*[\"\'])(\w+\.\w+)([\"\']\s*[\w+\W*?]*?\s*\/*\s*>)/msi', "inline_img_attachments", $html);
+
 			// Replace all 'cid:...' with correct link to attachment.
 			$html = preg_replace_callback("/=[\"']?(cid:)([^\"'>]+)[\"']?/msi", "inline_attachments", $html);
 			
