@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -92,7 +94,7 @@
 		* 1. Available to the server's locale system
 		* 2. In the UTF-8 charset
 		*
-		* For example, nl_NL.utf-8
+		* For example, nl_NL.UTF-8
 		*
 		*/
 		function loadLanguages()
@@ -122,11 +124,27 @@
 		* For setLanguage() to success, the language has to have been loaded via loadLanguages() AND
 		* the gettext system on the system must 'know' the language specified.
 		*
-		* @param string $lang Language (eg nl_NL.utf-8)
+		* @param string $lang Language (eg nl_NL.UTF-8)
 		*/
 		function setLanguage($lang)
 		{
 			$lang = (empty($lang)||$lang=="C")?LANG:$lang; // default language fix
+
+			/**
+			 * for backward compatibility
+			 * convert all locale from utf-8 strings to UTF-8 string because locales are case sensitive and
+			 * older WA settings can contain utf-8, so we have to convert it to UTF-8 before using
+			 * otherwise languiage will be reseted to english
+			 */
+			if(strpos($lang, "utf-8") !== false) {
+				$lang = str_replace("utf-8", "UTF-8", $lang);		// case sensitive replace
+
+				// change it in settings also
+				if(strcmp($GLOBALS["settings"]->get("global/language", ""), $lang)) {		// case insensitive compare
+					$GLOBALS["settings"]->set("global/language", $lang);
+				}
+			}
+
 			if ($this->is_language($lang)){
 				$this->lang = $lang;
 		
