@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -121,6 +123,28 @@
 			}
 		}
 		
+		/**
+		 * Returns the properties for Recipients in a message
+		 * @return array properties for Recipient.
+		 */
+		function getRecipientProperties()
+		{
+			$this->Init();
+			
+			$properties = array();
+			$properties["entryid"] = PR_ENTRYID;
+			$properties["display_name"] = PR_DISPLAY_NAME;
+			$properties["email_address"] = PR_EMAIL_ADDRESS;
+			$properties["recipient_flags"] = PR_RECIPIENT_FLAGS;
+			$properties["type"] = PR_RECIPIENT_TYPE;
+			$properties["recipient_attendees"] =PR_RECIPIENT_FLAGS;
+			$properties["recipient_status"] = PR_RECIPIENT_TRACKSTATUS;
+			$properties["recipient_status_num"] = PR_RECIPIENT_TRACKSTATUS_TIME;
+			$properties["objecttype"] = PR_OBJECT_TYPE;
+			
+			return getPropIdsFromStrings($this->store, $properties);
+		}
+		
 		/**
 		 * Returns the properties for an appointment.
 		 * @return array properties for an appointment.		 
@@ -171,9 +195,13 @@
 			$properties["basedate"] = "PT_SYSTIME:PSETID_Appointment:0x8228";
 			$properties["timezone_data"] = "PT_BINARY:PSETID_Appointment:0x8233";
 			$properties["commonassign"] = "PT_LONG:PSETID_Common:0x8518";
+			$properties["last_modification_time"] = PR_LAST_MODIFICATION_TIME;
+			$properties["creation_time"] = PR_CREATION_TIME;
 			$properties["remindertime"] = "PT_SYSTIME:PSETID_Common:0x8502";
+			$properties["body"] = PR_BODY;
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
+			// 
 			
 			// Propose new time properties
 			$properties["proposed_start_whole"] = "PT_SYSTIME:PSETID_Appointment:0x8250";
@@ -258,6 +286,7 @@
 			$properties["contacts"] = "PT_MV_STRING8:PSETID_Common:0x853a";
 			$properties["contacts_string"] = "PT_STRING8:PSETID_Common:0x8586";
 			$properties["categories"] = "PT_MV_STRING8:PS_PUBLIC_STRINGS:Keywords";
+			$properties["last_modification_time"] = PR_LAST_MODIFICATION_TIME;
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
 			$properties["deleted_on"] = PR_DELETED_ON;
@@ -339,6 +368,7 @@
 			$properties["message_flags"] = PR_MESSAGE_FLAGS;
 			$properties["display_name"] = PR_DISPLAY_NAME;
 			$properties["smtp_address"] = PR_SMTP_ADDRESS;
+			$properties["objecttype"] = PR_OBJECT_TYPE;
 			$properties["fileas"] = "PT_STRING8:PSETID_Address:0x8005";
 			$properties["email_address_1"] = "PT_STRING8:PSETID_Address:0x8083";
 			$properties["email_address_display_name_1"] = "PT_STRING8:PSETID_Address:0x8080";
@@ -370,6 +400,7 @@
 
 			return getPropIdsFromStrings($this->store, $properties);
 		}
+
 		/**
 		 * Returns the properties for a distribution list.
 		 * @return array properties for a distribution list.
@@ -401,7 +432,34 @@
 
 			return getPropIdsFromStrings($this->store, $properties);
 		}
-		
+
+		/**
+		 * Returns the properties for a contact in the addressbook.
+		 * @return array properties for a contact.
+		 */
+		function getAddressBookProperties()
+		{
+			$this->Init();
+			
+			$properties = array();
+			$properties["entryid"] = PR_ENTRYID;
+			$properties["smtp_address"] = PR_SMTP_ADDRESS;
+			$properties["email_address"] = PR_EMAIL_ADDRESS;
+			$properties["display_name"] = PR_DISPLAY_NAME;
+			$properties["display_type"] = PR_DISPLAY_TYPE;
+			$properties["display_type_ex"] = PR_DISPLAY_TYPE_EX;
+			$properties["account"] = PR_ACCOUNT;
+			$properties["addrtype"] = PR_ADDRTYPE;
+			$properties["objecttype"] = PR_OBJECT_TYPE;
+			$properties["search_key"] = PR_SEARCH_KEY;
+			$properties["office_phone"] = PR_OFFICE_TELEPHONE_NUMBER;
+			$properties["location"] = PR_OFFICE_LOCATION;
+			$properties["fax"] = PR_PRIMARY_FAX_NUMBER;
+			$properties["department"] = PR_ORGANIZATIONAL_ID_NUMBER;
+
+			return getPropIdsFromStrings($this->store, $properties);
+		}
+
 		/**
 		 * Returns the properties for an email.
 		 * @return array properties for an email.		 
@@ -418,6 +476,7 @@
 			$properties["icon_index"] = PR_ICON_INDEX;
 			$properties["display_to"] = PR_DISPLAY_TO;
 			$properties["display_cc"] = PR_DISPLAY_CC;
+			$properties["display_bcc"] = PR_DISPLAY_BCC;
 			$properties["subject"] = PR_SUBJECT;
 			$properties["importance"] = PR_IMPORTANCE;
 			$properties["sent_representing_name"] = PR_SENT_REPRESENTING_NAME;
@@ -471,6 +530,10 @@
 			$properties["updatecounter"] = "PT_LONG:PSETID_Appointment:0x8201";
 			$properties["hideattachments"] = "PT_BOOLEAN:PSETID_Common:0x8514";
 
+			// meeting request properties, which will be set when mr is auto forwarded using delegate meeting request rule
+			$properties["rcvd_representing_name"] = PR_RCVD_REPRESENTING_NAME;
+			$properties["delegated_by_rule"] = PR_DELEGATED_BY_RULE;
+
 			return getPropIdsFromStrings($this->store, $properties);
 		}
 		
@@ -603,6 +666,8 @@
 //			$properties["parent_display_name"] = PR_DISPLAY_NAME; // will be filled in by module
 			$properties["message_size"] = PR_MESSAGE_SIZE; // will be filled in by module if not exists
 			
+			$properties["deleted_on"] = PR_DELETED_ON;
+
 			return $properties;
 		}
 		
@@ -632,7 +697,7 @@
 
 			$properties["appointment_recurring"] = "PT_BOOLEAN:PSETID_Appointment:0x8223";			// PidLidRecurring
 			$properties["appointment_startdate"] = "PT_SYSTIME:PSETID_Appointment:0x820d";
-			$properties["appointment_recurring"] = "PT_BOOLEAN:PSETID_Appointment:0x8223";
+			$properties["appointment_enddate"] = "PT_SYSTIME:PSETID_Appointment:0x820e";
 			$properties["appointment_recurring_data"] = "PT_BINARY:PSETID_Appointment:0x8216";
 			$properties["appointment_timezone_data"] = "PT_BINARY:PSETID_Appointment:0x8233";
 			$properties["appointment_startdate_recurring"] = "PT_SYSTIME:PSETID_Appointment:0x8235";
