@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -157,21 +159,30 @@
         */	
 		function delete($path)
 		{
+
 			$this->Init();
 			$path = explode("/", $path);
-			$tmp = $this->settings;
-			$eval_string = 'unset($this->settings';
+			$tmp =& $this->settings;
+			// We have to get the second to last level to unset the value through a reference.
+			$prevEntry = null;
+
 			foreach($path as $pointer){
 				if (!empty($pointer)){
 					if (!isset($tmp[$pointer])){
 						return;
 					}
-					$tmp = $tmp[$pointer];
-					$eval_string .= '["'.$pointer.'"]';
+					$prevEntry =& $tmp;
+					$tmp =& $tmp[$pointer];
 				}
 			}
-			$eval_string .= ');';
-			eval($eval_string);
+
+			/**
+			 * If we do unset($tmp) the reference is removed and not the value 
+			 * it points to. If we do $prevEntry[$pointer] we change a value 
+			 * inside the reference. In that case it will work.
+			 */
+			unset($prevEntry[$pointer]);
+
 			$this->saveSettings();
 		}
 	
@@ -200,7 +211,9 @@
 				} else {
 					if (!preg_match("/^([1-9][0-9]*|0)$/", $value)){
 						// escape quotes and line ends
-						$value = "\"".str_replace(array("\\","\"","\n", "\r"),array("\\\\","\\\"","\\n", "\\r"),$value)."\"";
+						// We have to escape < as well. When they are loaded in the main window, a 
+						// </script>-tag will end the javascript block prematurely. Replaced to "\x3C".
+						$value = "\"".str_replace(array("\\","\"","\n", "\r", "<"),array("\\\\","\\\"","\\n", "\\r", "\\x3C"),$value)."\"";
 					}
 					$output .= $indenting.$base."[\"".$key."\"]"." = ".$value.";\n";
 				}
