@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -61,20 +63,11 @@
 		function AddressbookListModule($id, $data)
 		{
 			$this->properties = $GLOBALS["properties"]->getContactABProperties();
+			$this->ab_properties = $GLOBALS["properties"]->getAddressBookProperties();
 		
 			// Default Columns
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "icon_index", true, 0, _("Icon"), _("Sort on Icon"));
-			$this->addColumn($this->tablecolumns, "fileas", true, 1, _("File as"), _("Sort on File As"), "30%");
-			$this->addColumn($this->tablecolumns, "display_name", true, 2, _("Display Name"), _("Sort on Display Name"), "35%");
-			$this->addColumn($this->tablecolumns, "email_address", true, 3, _("Email Address"), _("Sort on Email Address"), PERCENTAGE);
-			$this->addColumn($this->tablecolumns, "entryid", false);
-			$this->addColumn($this->tablecolumns, "email_address_display_name_1", false);
-			$this->addColumn($this->tablecolumns, "email_address_2", false);
-			$this->addColumn($this->tablecolumns, "email_address_display_name_2", false);
-			$this->addColumn($this->tablecolumns, "email_address_3", false);
-			$this->addColumn($this->tablecolumns, "email_address_display_name_3", false);
-			$this->addColumn($this->tablecolumns, "message_class", false);
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getContactABListTableColumns();
+			$this->ab_tablecolumns = $GLOBALS["TableColumns"]->getAddressBookListTableColumns();
 
 			parent::ListModule($id, $data, array());
 
@@ -172,8 +165,8 @@
 				}
 
 				if(isset($action["restriction"])) {
-					$searchPerformed = true;
-					if(isset($action["restriction"]["name"])) {
+					if(isset($action["restriction"]["searchstring"])) {
+						$searchPerformed = true;
 						$restrictions = array();
 						$props = array($this->properties["fileas"], 
 									   $this->properties["display_name"],
@@ -189,12 +182,20 @@
 							array_push($restrictions, array(RES_CONTENT,
 															array(FUZZYLEVEL => FL_SUBSTRING|FL_IGNORECASE,
 																ULPROPTAG => $property,
-																VALUE => u2w($action["restriction"]["name"]))));
+																VALUE => u2w($action["restriction"]["searchstring"]))));
 						}
 
 						$restrictions = array(RES_OR, $restrictions);
 						$restriction = array(RES_AND, array($restriction, $restrictions));
-					}
+					} else if (isset($action["restriction"]["pagination_character"]) && $action["restriction"]["pagination_character"] != "...") {
+						// If request is for gab pagination then set pagination restriction.
+						$searchPerformed = true;
+
+						// Get pagination restriction and add it in restriction array.
+						$paginationRestriction = $this->getPaginationRestriction($action);
+						if($paginationRestriction)
+							$restriction = array(RES_AND, array($restriction, $paginationRestriction));
+ 					}
 				}
 				
 				if(isset($action["sort"]) && isset($action["sort"]["column"])) {
@@ -299,6 +300,7 @@
 									case "IPM.DistList":
 										$entryid = hex2bin($item["entryid"]); // need real entryid here
 										$item["email_address"] = $item["display_name"];
+										$item["addrtype"] = "ZARAFA";
 										$item["members"] = array("member"=>$this->expandDistributionList($store, $entryid));
 
 										array_push($items, $item);
@@ -326,9 +328,7 @@
 						$data = array_merge($data, array("item" => $items));
 					}else{
 						// Provide clue that full contactlist is disabled.
-						$disable_clist_treshold = array();
-						$disable_clist_treshold["value"] = true;
-						$data = array_merge($data, array("disable_full_gab"=>$disable_clist_treshold));
+						$data = array_merge($data, array("disable_full_gab" => true));
 					}
 
 					array_push($this->responseData["action"], $data);
@@ -349,13 +349,22 @@
 		 */
 		function GABUsers($action)
 		{
-			$name = "";
+			$searchstring = "";
+			$paginationCharacter = "";
 			if(isset($action["restriction"])) {
-				if(isset($action["restriction"]["name"])) {
-					$name = $action["restriction"]["name"];
+				if(isset($action["restriction"]["searchstring"])) {
+					// Get search string for searching in AB.
+					$searchstring = $action["restriction"]["searchstring"];
+				} else if (isset($action["restriction"]["pagination_character"])) {
+					// Get pagination character for AB.
+					$paginationCharacter = $action["restriction"]["pagination_character"];
 				}
 			}
 
+			$hide_users = isset($action["hide_users"]) ? $action["hide_users"] : false;
+			$hide_groups = isset($action["hide_groups"]) ? $action["hide_groups"] : false;
+			$hide_companies = isset($action["hide_companies"]) && $action["hide_companies"] == "true" ? true : false;
+
 			$items = array();
 
 			$data["page"] = array();
@@ -365,34 +374,27 @@
 
 			$data = array();
 			$data["attributes"] = array("type" => "list");
-
-			$columns = array();
-			$this->addColumn($columns, "icon_index", true, 0, _("Icon"), _("Sort on Icon"));
-			$this->addColumn($columns, "fileas", true, 1, _("File as"), _("Sort on File As"), "30%");
-			$this->addColumn($columns, "display_name", true, 2, _("Display Name"), _("Sort on Display Name"), "35%");
-			$this->addColumn($columns, "smtp_address", true, 3, _("Email Address"), _("Sort on Email Address"), PERCENTAGE);
-			$this->addColumn($columns, "entryid", false);
-			$this->addColumn($columns, "message_class", false);
-
-			$data["column"] = $columns;
+			$data["column"] = $this->ab_tablecolumns;
 
 			$this->sort = array();
-			$this->sort[PR_ACCOUNT] = TABLE_SORT_ASCEND;
+			$this->sort[$this->ab_properties['account']] = TABLE_SORT_ASCEND;
 			
 			$firstSortColumn = array_shift(array_keys($this->sort));
 
 			$map = array();
-			$map["fileas"] = PR_ACCOUNT;
-			
+			$map["fileas"] = $this->ab_properties['account'];
+
 			// Parse incoming sort order
-			$this->parseSortOrder($action, $map, true);
-			
+			$this->parseSortOrder($action, $map, true, $this->ab_properties);
+
 			// Generate output sort
 			$data["sort"] = array();
-			$data["sort"] = $this->generateSortOrder($map);
+			$data["sort"] = $this->generateSortOrder($map, $this->ab_properties);
 
-			if(!DISABLE_FULL_GAB || strlen($name) > 0) {
-				
+			if($paginationCharacter == "...")
+				$paginationCharacter = "";
+
+			if(!DISABLE_FULL_GAB || strlen($searchstring) > 0 || strlen($paginationCharacter) > 0) {
 				$ab = $GLOBALS["mapisession"]->getAddressbook();
 
 				if (isset($action["entryid"]) && $action["entryid"] != "") {
@@ -409,100 +411,118 @@
 				$table = mapi_folder_getcontentstable($dir);
 
 				$restriction = false;
-				if(strlen($name) > 0){
-					// only return users from who the displayName or the username starts with $name
+				$tempRestriction = false;
+				$userGroupRestriction = false;
+
+				if($hide_users || $hide_groups || $hide_companies) {
+					$usersRestriction = $this->createUsersRestriction($hide_users);
+					$groupsRestriction = $this->createGroupsRestriction($hide_groups);
+					$companyRestriction = $this->createCompanyRestriction($hide_companies);
+
+					if($companyRestriction) {
+						$userGroupRestriction = Array(RES_OR, Array($usersRestriction, $groupsRestriction, $companyRestriction));
+					} else {
+						$userGroupRestriction = Array(RES_OR, Array($usersRestriction, $groupsRestriction));
+					}
+				}
+
+				if(strlen($searchstring) > 0){
+					// create restriction for search
+					// only return users from who the displayName or the username starts with $searchstring
 					// TODO: use PR_ANR for this restriction instead of PR_DISPLAY_NAME and PR_ACCOUNT
-					$restriction = 	array(RES_OR, 
+					$tempRestriction = 	array(RES_OR, 
 										array(
 											array(
 												RES_CONTENT,
 													array(FUZZYLEVEL => FL_SUBSTRING|FL_IGNORECASE,
-														ULPROPTAG=>PR_DISPLAY_NAME,
-														VALUE=>u2w($name)
+														ULPROPTAG => PR_DISPLAY_NAME,
+														VALUE => u2w($searchstring)
 													)
 												),
 											array(
 												RES_CONTENT,
 													array(FUZZYLEVEL => FL_SUBSTRING|FL_IGNORECASE,
-														ULPROPTAG=>PR_ACCOUNT,
-														VALUE=>u2w($name)
+														ULPROPTAG => PR_ACCOUNT,
+														VALUE => u2w($searchstring)
 													)
 												),
 										),
 									);
-				}
-				if(isset($action["groups"]) && $action["groups"]=="no"){
-					// filter out all groups
-					$restrictionGroups = array(RES_AND,
-										array(
-											array(
-												RES_PROPERTY,
-													array(RELOP => RELOP_NE,
-														ULPROPTAG=>PR_OBJECT_TYPE,
-														VALUE=>array(
-																PR_OBJECT_TYPE=>MAPI_DISTLIST
-														)
-													)
-												),
-												// Here comes the name restriction if it is set.
+				} else if(strlen($paginationCharacter) > 0) {
+					// create restriction for alphabet bar
+					$tempRestriction = $this->getPaginationRestriction($action);
+ 				}
+
+				if($tempRestriction && $userGroupRestriction) {
+					$restriction = Array(
+										RES_AND,
+											Array(
+												$tempRestriction,				// restriction for search/alphabet bar
+												$userGroupRestriction			// restriction for hiding users/groups
 											)
 									);
-					// When we have a restriction to search on name add it in the no-groups restriction.
-					if($restriction){
-						$restrictionGroups[1][] = $restriction;
-					}
-					$restriction = $restrictionGroups;
+				} else if($tempRestriction) {
+					$restriction = $tempRestriction;							// restriction for search/alphabet bar
+				} else {
+					$restriction = $userGroupRestriction;						// restriction for hiding users/groups
 				}
 
+				// Only add restriction when it is used
+				if($restriction) {
+					mapi_table_restrict($table, $restriction);
+				}
+				mapi_table_sort($table, $this->sort);
+
 				// todo: fix paging stuff
 
 				$data["page"]["start"] = 0;
 				$data["page"]["rowcount"] = mapi_table_getrowcount($table);
 				$data["page"]["totalrowcount"] = $data["page"]["rowcount"];
-				
-				// Only add restriction when it is used
-				mapi_table_restrict($table, ($restriction)?$restriction:Array());
-				mapi_table_sort($table, $this->sort);
-				
-				$rows = mapi_table_queryrows($table, array(PR_ACCOUNT, PR_DISPLAY_NAME, PR_ENTRYID, PR_OBJECT_TYPE, PR_EMAIL_ADDRESS, PR_SMTP_ADDRESS, PR_ADDRTYPE, PR_DISPLAY_TYPE, PR_SEARCH_KEY), 0, 0x7fffffff);
+
+				$rows = mapi_table_queryrows($table, $this->ab_properties, 0, 0x7fffffff);
 				
                 for ($i = 0; $i < count($rows); $i++) {
                     $user_data = $rows[$i];
                     $item = array();
-                    $item["entryid"] = bin2hex($user_data[PR_ENTRYID]);
-                    $item["display_name"] = w2u($user_data[PR_DISPLAY_NAME]);
-                    $item["fileas"] = w2u($user_data[PR_ACCOUNT]);
+                    $item["entryid"] = bin2hex($user_data[$this->ab_properties["entryid"]]);
+                    $item["display_name"] = w2u($user_data[$this->ab_properties["display_name"]]);
+                    $item["fileas"] = w2u($user_data[$this->ab_properties["account"]]);
+                    $item["objecttype"] = $user_data[$this->ab_properties["objecttype"]];
 
-                    switch($user_data[PR_DISPLAY_TYPE]){
+					switch($user_data[PR_DISPLAY_TYPE]){
                         case DT_ORGANIZATION:
-                            $item["icon_index"] = 0;
-                            $item["message_class"] = "IPM.DistList.Organization";
-                            $item["email_address"] = w2u($user_data[PR_ACCOUNT]);
+							$item["display_type"] = $user_data[PR_DISPLAY_TYPE];
+                            $item["email_address"] = w2u($user_data[$this->ab_properties["account"]]);
                             $item["message_flags"] = 0; // FIXME: we want companies to show "bold", so in fact this is some kind of a hack ;)
-
-                            // FIXME: this must be at the end of the list because of an issue with getElementsByTagName()
-                            $item["members"] = array("member"=>$this->expandGroup($user_data[PR_ENTRYID]));
+							$item["addrtype"] = "ZARAFA";
+							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
                             break;
 
                         case DT_DISTLIST:
-                            $item["icon_index"] = 514;
-                            $item["message_class"] = "IPM.DistList";
-                            $item["email_address"] = w2u($user_data[PR_ACCOUNT]);
-                            $item["message_flags"] = 0; // FIXME: we want dist lists to show "bold", so in fact this is some kind of a hack ;)
-
-                            // FIXME: this must be at the end of the list because of an issue with getElementsByTagName()
-                            $item["members"] = array("member"=>$this->expandGroup($user_data[PR_ENTRYID]));
-                            break;
+							// remove DTE_FLAG_ACL_CAPABLE flag from display_type_ex property
+							$item["display_type"] = DTE_IS_ACL_CAPABLE($user_data[PR_DISPLAY_TYPE_EX]) ? $user_data[PR_DISPLAY_TYPE_EX] & ~DTE_FLAG_ACL_CAPABLE : $user_data[PR_DISPLAY_TYPE_EX];		// DT_AGENT or DT_DISTLIST or DT_SEC_DISTLIST
+							$item["email_address"] = w2u($user_data[$this->ab_properties["account"]]);
+							$item["smtp_address"] = isset($user_data[$this->ab_properties["smtp_address"]]) ? $user_data[$this->ab_properties["smtp_address"]] : "";
+							$item["message_flags"] = 0; // FIXME: we want dist lists to show "bold", so in fact this is some kind of a hack ;)
+							$item["addrtype"] = "ZARAFA";
+							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
+							break;
 
                         case DT_MAILUSER:
                         default:
-                            $item["icon_index"] = 512;
-                            $item["message_class"] = "IPM.Contact";
-                            $item["email_address"] = w2u($user_data[PR_EMAIL_ADDRESS]);
-                            $item["smtp_address"] = w2u($user_data[PR_SMTP_ADDRESS]);
-                            $item["search_key"] = bin2hex($user_data[PR_SEARCH_KEY]);
-                            $item["addrtype"] = w2u($user_data[PR_ADDRTYPE]);
-                            $item["message_flags"] = MSGFLAG_READ; // FIXME: setting message_flags to read, to fix the view
+							// remove DTE_FLAG_ACL_CAPABLE flag from display_type_ex property
+							$item["display_type"] = DTE_IS_ACL_CAPABLE($user_data[PR_DISPLAY_TYPE_EX]) ? $user_data[PR_DISPLAY_TYPE_EX] & ~DTE_FLAG_ACL_CAPABLE : $user_data[PR_DISPLAY_TYPE_EX];		// DT_ROOM or DT_EQUIPMENT or DT_MAILUSER
+							$item["email_address"] = w2u($user_data[$this->ab_properties["email_address"]]);
+							$item["smtp_address"] = w2u($user_data[$this->ab_properties["smtp_address"]]);
+							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
+							$item["addrtype"] = w2u($user_data[$this->ab_properties["addrtype"]]);
+							$item["message_flags"] = MSGFLAG_READ;	// FIXME: setting message_flags to read, to fix the view
+							$item["department"] = isset($user_data[$this->ab_properties["department"]]) ? w2u($user_data[$this->ab_properties["department"]]) : "";
+							$item["office_phone"] = isset($user_data[$this->ab_properties["office_phone"]]) ? $user_data[$this->ab_properties["office_phone"]] : "";
+							$item["location"] = isset($user_data[$this->ab_properties["location"]]) ? w2u($user_data[$this->ab_properties["location"]]) : "";
+							$item["fax"] = isset($user_data[$this->ab_properties["fax"]]) ? $user_data[$this->ab_properties["fax"]] : "";
+							$item["addrtype"] = "SMTP";
+							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
                             break;
                     }
 
@@ -511,9 +531,7 @@
                 }
             } else {
 	           	// Provide clue that full GAB is disabled.
-            	$disable_GAB = array();
-            	$disable_GAB["value"] = DISABLE_FULL_GAB;
-            	$data = array_merge($data, array("disable_full_gab"=>$disable_GAB));
+            	$data = array_merge($data, array("disable_full_gab" => DISABLE_FULL_GAB));
             }
 			$data = array_merge($data, array("item"=>$items));
 
@@ -521,7 +539,325 @@
 			$GLOBALS["bus"]->addData($this->responseData);
 			return true;
 		}
-		
+
+		/**
+		 *	Function will create a restriction based on parameters passed for hiding users
+		 *	@param		Array				$hide_users		list of users that should not be shown
+		 *	@return		restrictionObject					restriction for hiding provided users
+		 */
+		function createUsersRestriction($hide_users) {
+			$tempRestrictions = Array();
+
+			// check we should hide users or not
+			if($hide_users) {
+				// wrap parameters in an array
+				if(!is_array($hide_users)) {
+					$hide_users = Array($hide_users);
+				}
+
+				if(in_array("room", $hide_users)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE_EX,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE_EX => DT_ROOM
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array("equipment", $hide_users)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE_EX,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE_EX => DT_EQUIPMENT
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array("active", $hide_users)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE_EX,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE_EX => DTE_FLAG_ACL_CAPABLE
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array("non_active", $hide_users)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE_EX,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE_EX => DT_MAILUSER
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array("contact", $hide_users)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE_EX,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE_EX => DT_REMOTE_MAILUSER
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array("system", $hide_users)) {
+					array_push($tempRestrictions, Array(
+													RES_NOT,
+														Array(
+															Array(
+																RES_CONTENT,
+																	Array(
+																		FUZZYLEVEL => FL_FULLSTRING,
+																		ULPROPTAG => PR_ACCOUNT,
+																		VALUE => Array(
+																				PR_ACCOUNT => "SYSTEM"
+																		)
+																	)
+															)
+														)
+													)
+							);
+				}
+			}
+
+			if(count($tempRestrictions) > 0) {
+				$usersRestriction = Array(
+										RES_AND,
+											Array(
+												Array(
+													RES_OR,
+														Array(
+															Array(
+																RES_PROPERTY,
+																	Array(
+																		RELOP => RELOP_EQ,
+																		ULPROPTAG => PR_DISPLAY_TYPE,
+																		VALUE => Array(
+																				PR_DISPLAY_TYPE => DT_MAILUSER
+																		)
+																	)
+															),
+															Array(
+																RES_PROPERTY,
+																	Array(
+																		RELOP => RELOP_EQ,
+																		ULPROPTAG => PR_DISPLAY_TYPE,
+																		VALUE => Array(
+																				PR_DISPLAY_TYPE => DT_REMOTE_MAILUSER
+																		)
+																	)
+															)
+														)
+												),
+												Array(
+													RES_AND,
+													$tempRestrictions					// all user restrictions
+												)
+											)
+									);
+			} else {
+				$usersRestriction = Array(
+										RES_AND,
+											Array(
+												Array(
+													RES_OR,
+														Array(
+															Array(
+																RES_PROPERTY,
+																	Array(
+																		RELOP => RELOP_EQ,
+																		ULPROPTAG => PR_DISPLAY_TYPE,
+																		VALUE => Array(
+																				PR_DISPLAY_TYPE => DT_MAILUSER
+																		)
+																	)
+															),
+															Array(
+																RES_PROPERTY,
+																	Array(
+																		RELOP => RELOP_EQ,
+																		ULPROPTAG => PR_DISPLAY_TYPE,
+																		VALUE => Array(
+																				PR_DISPLAY_TYPE => DT_REMOTE_MAILUSER
+																		)
+																	)
+															)
+														)
+												)
+											)
+									);
+			}
+
+			return $usersRestriction;
+		}
+
+		/**
+		 *	Function will create a restriction based on parameters passed for hiding groups
+		 *	@param		Array				$hide_groups	list of groups that should not be shown
+		 *	@return		restrictionObject					restriction for hiding provided users
+		 */
+		function createGroupsRestriction($hide_groups) {
+			$tempRestrictions = Array();
+
+			// check we should hide groups or not
+			if($hide_groups) {
+				// wrap parameters in an array
+				if(!is_array($hide_groups)) {
+					$hide_groups = Array($hide_groups);
+				}
+
+				if(in_array("normal", $hide_groups)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE_EX,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE_EX => DT_DISTLIST
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array("security", $hide_groups)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE_EX,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE_EX => (DT_SEC_DISTLIST | DTE_FLAG_ACL_CAPABLE)
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array("dynamic", $hide_groups)) {
+					array_push($tempRestrictions, Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_NE,
+															ULPROPTAG => PR_DISPLAY_TYPE_EX,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE_EX => DT_AGENT
+															)
+														)
+													)
+							);
+				}
+
+				if(in_array("everyone", $hide_groups)) {
+					array_push($tempRestrictions, Array(
+													RES_NOT,
+														Array(
+															Array(
+																RES_CONTENT,
+																	Array(
+																		FUZZYLEVEL => FL_FULLSTRING,
+																		ULPROPTAG => PR_ACCOUNT,
+																		VALUE => Array(
+																				PR_ACCOUNT => "Everyone"
+																		)
+																	)
+															)
+														)
+													)
+							);
+				}
+			}
+
+			if(count($tempRestrictions) > 0) {
+				$groupsRestriction = Array(
+										RES_AND,
+											Array(
+												Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_EQ,
+															ULPROPTAG => PR_DISPLAY_TYPE,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE => DT_DISTLIST
+															)
+														)
+												),
+												Array(
+													RES_AND,
+													$tempRestrictions					// all group restrictions
+												)
+											)
+									);
+			} else {
+				$groupsRestriction = Array(
+										RES_AND,
+											Array(
+												Array(
+													RES_PROPERTY,
+														Array(
+															RELOP => RELOP_EQ,
+															ULPROPTAG => PR_DISPLAY_TYPE,
+															VALUE => Array(
+																	PR_DISPLAY_TYPE => DT_DISTLIST
+															)
+														)
+													)
+											)
+									);
+			}
+
+			return $groupsRestriction;
+		}
+
+		/**
+		 *	Function will create a restriction to get company information
+		 *	@param		Boolean				$hide_companies	true/false
+		 *	@return		restrictionObject					restriction for getting company info
+		 */
+		function createCompanyRestriction($hide_companies) {
+			$companyRestriction = false;
+
+			if(!$hide_companies) {
+				$companyRestriction =	Array(
+											RES_PROPERTY,
+												Array(
+													RELOP => RELOP_EQ,
+													ULPROPTAG => PR_DISPLAY_TYPE,
+													VALUE => Array(
+															PR_DISPLAY_TYPE => DT_ORGANIZATION
+													)
+												)
+										);
+			}
+
+			return $companyRestriction;
+		}
+
 		function getHierarchy($action)
 		{
 			$data = array();
@@ -552,15 +888,15 @@
 			$result = array();
 			$group = mapi_ab_openentry($GLOBALS["mapisession"]->getAddressbook(), $entryid);
 			$table = mapi_folder_getcontentstable($group);
-			$items = mapi_table_queryallrows($table,array(PR_ACCOUNT, PR_ENTRYID, PR_DISPLAY_NAME, PR_ADDRTYPE, PR_SMTP_ADDRESS));
+			$items = mapi_table_queryallrows($table, $this->ab_properties);
 			foreach($items as $item){
-				if (isset($item[PR_SMTP_ADDRESS])){
+				if($item[$this->ab_properties["display_type"]] == DT_MAILUSER && isset($item[$this->ab_properties["smtp_address"]])) {
 					$result[] = array(
-							"entryid"=>array("attributes"=>array("type"=>"binary"),"_content"=>bin2hex($item[PR_ENTRYID])),
-							"fileas"=>w2u($item[PR_ACCOUNT]),
-							"display_name"=>w2u($item[PR_DISPLAY_NAME]),
-							"addrtype"=>w2u($item[PR_ADDRTYPE]),
-							"email_address"=>w2u($item[PR_SMTP_ADDRESS]),
+							"entryid"=>array("attributes"=>array("type"=>"binary"),"_content"=>bin2hex($item[$this->ab_properties["entryid"]])),
+							"fileas"=>w2u($item[$this->ab_properties["account"]]),
+							"display_name"=>w2u($item[$this->ab_properties["display_name"]]),
+							"addrtype"=>w2u($item[$this->ab_properties["addrtype"]]),
+							"email_address"=>w2u($item[$this->ab_properties["smtp_address"]]),
 						);
 				}
 			}
@@ -583,7 +919,7 @@
 			$listEntryIDs[] = $entryid;
 
 			$message = mapi_msgstore_openentry($store, $entryid);
-			
+
 			if($message) {
 				$props = mapi_getprops($message, array($this->properties["oneoff_members"], $this->properties["members"]));
 	
@@ -621,27 +957,28 @@
 									$item["entryid"] = bin2hex($parts["entryid"]);
 									$item["fileas"] = w2u($msgProps[$this->properties["fileas"]]);
 									$item["display_name"] = w2u($msgProps[$this->properties["display_name"]]);
+									$item["email_address"] = w2u($msgProps[$this->properties["email_address_1"]]);
+									$item["objecttype"] = $msgProps[$this->ab_properties["objecttype"]];
 
 									// use the email adress from the OneOff entry	
 									$item["addrtype"] = w2u($oneoffmembers[$key]["type"]);
-									$item["email_address"] = w2u($oneoffmembers[$key]["address"]);
-
 									$items[] = $item;		
 									break;
-								case DL_USER_AB: // user
+								case DL_USER_AB: // ab user
 									$ab = $GLOBALS["mapisession"]->getAddressbook();
 									$msg = mapi_ab_openentry($ab,$parts["entryid"]);
 									if (mapi_last_hresult()!=NOERROR) // user could be deleted, skip item
 										continue;
-									$msgProps = mapi_getprops($msg, array(PR_ENTRYID, PR_ACCOUNT, PR_DISPLAY_NAME, PR_SMTP_ADDRESS));
+									$msgProps = mapi_getprops($msg, $this->ab_properties);
 									$item = array();
 									$item["entryid"] = bin2hex($parts["entryid"]);
-									$item["fileas"] = w2u($msgProps[PR_ACCOUNT]);
-									$item["display_name"] = w2u($msgProps[PR_DISPLAY_NAME]);
+									$item["fileas"] = w2u($msgProps[$this->ab_properties["account"]]);
+									$item["display_name"] = w2u($msgProps[$this->ab_properties["display_name"]]);
 
 									// don't use the email adress from the OneOff entry because it will give a ZARAFA mail address, and in the webaccess we currently only support SMTP addresses
 									$item["addrtype"] = "SMTP";
-									$item["email_address"] = w2u($msgProps[PR_SMTP_ADDRESS]);
+									$item["email_address"] = w2u($msgProps[$this->ab_properties["smtp_address"]]);
+									$item["objecttype"] = $msgProps[$this->ab_properties["objecttype"]];
 
 									$items[] = $item;
 									break;
@@ -651,7 +988,17 @@
 									break;
 
 								case DL_DIST_AB: // group
-									$items = $items + $this->expandGroup($parts["entryid"]);
+									$group = mapi_ab_openentry($GLOBALS["mapisession"]->getAddressbook(), $parts["entryid"]);
+									$groupProps = mapi_getprops($group, $this->ab_properties);
+									
+									$item = array();
+									$item["entryid"] = bin2hex($parts["entryid"]);
+									$item["fileas"] = w2u($groupProps[$this->ab_properties["account"]]);
+									$item["display_name"] = w2u($groupProps[$this->ab_properties["display_name"]]);
+									$item["addrtype"] = "ZARAFA";
+									$item["email_address"] = w2u($groupProps[$this->ab_properties["email_address"]]);
+									$item["objecttype"] = $groupProps[$this->ab_properties["objecttype"]];
+									$items[] = $item;
 									break;
 							}
 						}
@@ -661,6 +1008,128 @@
 			}
 			return array();
 		}
+
+		/**
+		 * Function will return restriction used in GAB pagination.
+		 * @param array $action the action data, sent by the client
+		 * @return array paginationRestriction returns restriction used in pagination.
+		 */
+		function getPaginationRestriction($action)
+		{
+			if(isset($action["restriction"]["pagination_character"])) {
+				// Get sorting column to provide pagination on it.
+				if(isset($action["sort"]) && isset($action["sort"]["column"]))
+					$sortColumn = $action["sort"]["column"][0]["_content"];
+
+				$paginationColumnProperties = array();
+				// Get Pagination column Properties.
+				if($action["attributes"]["type"] == "contacts") {
+					array_push($paginationColumnProperties, $this->properties["fileas"]);
+					array_push($paginationColumnProperties, $this->properties["display_name"]);
+					array_push($paginationColumnProperties, $this->properties["email_address_1"]);
+					array_push($paginationColumnProperties, $this->properties["email_address_display_name_1"]);
+					array_push($paginationColumnProperties, $this->properties["email_address_2"]);
+					array_push($paginationColumnProperties, $this->properties["email_address_display_name_2"]);
+					array_push($paginationColumnProperties, $this->properties["email_address_3"]);
+					array_push($paginationColumnProperties, $this->properties["email_address_display_name_3"]);
+				} else if ($action["attributes"]["type"] == "globaladdressbook") {
+					array_push($paginationColumnProperties, $this->ab_properties["account"]);
+					array_push($paginationColumnProperties, $this->ab_properties["display_name"]);
+					array_push($paginationColumnProperties, $this->ab_properties["smtp_address"]);
+					array_push($paginationColumnProperties, $this->ab_properties["department"]);
+					array_push($paginationColumnProperties, $this->ab_properties["location"]);
+				}
+
+				// Get Pagination character.
+				$paginationCharacter = $action["restriction"]["pagination_character"];
+				
+				// Create restriction according to paginationColumn
+				$restrictions = array();
+				foreach ($paginationColumnProperties as $paginationColumnProperty)
+				{
+					switch ($paginationCharacter){
+						case "123":
+							array_push($restrictions,
+												array(
+														RES_AND,
+														array(
+															array(
+																RES_PROPERTY,
+																array(
+																	RELOP => RELOP_GE,
+																	ULPROPTAG =>  $paginationColumnProperty,
+																	VALUE => array(
+																		$paginationColumnProperty => "0"
+																	)
+																)
+															),
+															array(
+																RES_PROPERTY,
+																array(
+																	RELOP => RELOP_LE,
+																	ULPROPTAG => $paginationColumnProperty,
+																	VALUE => array(
+																		$paginationColumnProperty => "9"
+																	)
+																)
+															)
+														)
+													)
+												);
+						break;
+
+						case "z":
+							array_push($restrictions,
+											array(
+												RES_PROPERTY,
+												array(RELOP => RELOP_GE,
+													ULPROPTAG => $paginationColumnProperty,
+													VALUE => array(
+														$paginationColumnProperty => "z" 
+														)
+													)
+												)
+											);
+						break;
+
+						default:
+							array_push($restrictions,
+													array(
+															RES_AND,
+															array(
+																array(
+																	RES_PROPERTY,
+																	array(
+																		RELOP => RELOP_GE,
+																		ULPROPTAG =>  $paginationColumnProperty,
+																		VALUE => array(
+																			$paginationColumnProperty => $paginationCharacter
+																		)
+																	)
+																),
+																array(
+																	RES_PROPERTY,
+																	array(
+																		RELOP => RELOP_LT,
+																		ULPROPTAG => $paginationColumnProperty,
+																		VALUE => array(
+																			$paginationColumnProperty => chr(ord($paginationCharacter) + 1)
+																		)
+																	)
+																)
+															)
+														)
+													);
+					}
+				}
+				$paginationRestriction = array(RES_OR, $restrictions);
+			}
+
+			if($paginationRestriction)
+				return $paginationRestriction;
+			else
+				return false;
+		}
 	}
 
 ?>
