@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -75,7 +77,7 @@
 		 * @var date end interval of view visible
 		 */
 		var $enddate;
-	
+		
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -85,14 +87,7 @@
 		{
 			$this->properties = $GLOBALS["properties"]->getAppointmentProperties();
 
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "icon_index", true, 0, _("Icon Index"), _("Sort on Icon Index"));
-			$this->addColumn($this->tablecolumns, "subject", true, 1, _("Subject"), _("Sort on Subject"), PERCENTAGE);
-			$this->addColumn($this->tablecolumns, "start", true, 2, _("Startdate"), _("Sort on Startdate"));
-			$this->addColumn($this->tablecolumns, "end", true, 3, _("Enddate"), _("Sort on Enddate"));
-			$this->addColumn($this->tablecolumns, "recurring", true, 4, _("Recurring"), _("Sort on Recurring"));
-			$this->addColumn($this->tablecolumns, "busystatus", true, 5, _("Busy Status"), _("Sort on Busy Status")); 
-			$this->addColumn($this->tablecolumns, "categories", false, 4, _("Categories"), _("Sort On Categories"));
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getAppointmentListTableColumns();
 
 			parent::ListModule($id, $data, array(OBJECT_SAVE, TABLE_SAVE, TABLE_DELETE));
 
@@ -135,6 +130,13 @@
 	
 					array_push($this->responseData["action"], $data);
 					$GLOBALS["bus"]->addData($this->responseData);
+				}else{
+					//for list view in calendar as startdate and enddate in passed as false
+					//this will set sorting and paging for items in listview.
+					
+					//to generate recipient xml for appointments  
+					$this->generateRecipient = true;
+					$result = parent::messageList($store, $entryid, $action);
 				}
 			}
 			
@@ -155,7 +157,7 @@
 		
 			$restriction = 
 						// OR
-						// (item[end] >= start && item[start] <= end) ||
+						// (item[end] >= start && item[start] < end) ||
 						Array(RES_OR,
 								 Array(
 									   Array(RES_AND,
@@ -167,7 +169,7 @@
 															   )
 														 ),
 												   Array(RES_PROPERTY,
-														 Array(RELOP => RELOP_LE,
+														 Array(RELOP => RELOP_LT,
 															   ULPROPTAG => $this->properties["startdate"],
 															   VALUE => $end
 															   )
@@ -350,7 +352,9 @@
 				$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
 
 				if($entryids) {
-					$result = $GLOBALS["operations"]->deleteMessages($store, $parententryid, $entryids);
+					// If softdelete is set then set it in softDelete variable and pass it for deleteing message.
+					$softDelete = $action["softdelete"] ? $action["softdelete"] : false;
+					$result = $GLOBALS["operations"]->deleteMessages($store, $parententryid, $entryids, $softDelete);
 				} else if(isset($action["exception"])) {
 					$result = $this->recurrence->saveException($store, $action["exception"]);
 					
@@ -390,7 +394,14 @@
 						if(isset($props[PR_ENTRYID])) {
 							$message = $GLOBALS["operations"]->openMessage($store, $props[PR_ENTRYID]);
 							$messageProps = mapi_getprops($message, $this->properties);
-							if (isset($messageProps[$this->properties['recurring']]) && $messageProps[$this->properties['recurring']]){
+							
+							/**
+							 * in calendar list view recurring items are not multi instances objects
+							 * so we don't have to do any special handling for that just check
+							 * startdate and enddate are false then the request has come from calednar list view 
+							 * so just update item in a normal way
+							 */
+							if ($this->startdate && $this->enddate && isset($messageProps[$this->properties['recurring']]) && $messageProps[$this->properties['recurring']]){
 								// Because this is a multi-instanced object, we have to send a DELETE first to delete all occurring items
 								// before re-adding the updated items.
 								$data["attributes"] = array("type" => "delete");
@@ -439,6 +450,7 @@
 					break;
 				case TABLE_DELETE:
 					if(isset($props[PR_ENTRYID]) && isset($props[PR_PARENT_ENTRYID])) {
+
 						// Get items, which are shown under the table.
 						$store = $GLOBALS["mapisession"]->openMessageStore($props[PR_STORE_ENTRYID]);
 						
@@ -451,8 +463,8 @@
 							$deletedrows = count($props[PR_ENTRYID]);
 						}
 
-						$this->start = ($this->start + (int)$GLOBALS["settings"]->get("global/rowcount", 50)) - $deletedrows;
-						$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $props[PR_PARENT_ENTRYID], $this->properties, $this->sort, $this->start, $deletedrows));
+						$newItemsStart = ($this->start + (int)$GLOBALS["settings"]->get("global/rowcount", 50)) - $deletedrows;
+						$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $props[PR_PARENT_ENTRYID], $this->properties, $this->sort, $newItemsStart, $deletedrows));
 
 						array_push($this->responseData["action"], $data);
 						
