@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -62,46 +64,7 @@
 		{
 			$this->properties = $GLOBALS["properties"]->getContactProperties();
 
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "icon_index", true, 0, _("Icon"), _("Sort On Icon"));
-			$this->addColumn($this->tablecolumns, "fileas", true, 1, _("File As"), _("Sort On File As"));
-			$this->addColumn($this->tablecolumns, "display_name", true, 2, _("Full Name"), _("Sort On Display Name"), PERCENTAGE);
-			$this->addColumn($this->tablecolumns, "email_address_1", true, 3, _("Email Address 1"), _("Sort On Email Address 1"));
-			$this->addColumn($this->tablecolumns, "email_address_2", false, 3, _("Email Address 2"), _("Sort On Email Address 2"));
-			$this->addColumn($this->tablecolumns, "email_address_3", false, 3, _("Email Address 3"), _("Sort On Email Address 3"));
-			$this->addColumn($this->tablecolumns, "home_telephone_number", true, 4, _("Home Telephonenumber"), _("Sort On Home Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "cellular_telephone_number", true, 5, _("Cellular Telephonenumber"), _("Sort On Cellular Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "categories", false, 4, _("Categories"), _("Sort On Categories"));
-
-			$this->addColumn($this->tablecolumns, "business_telephone_number", false, 99, _("Business Telephonenumber"), _("Sort On Business Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "office_telephone_number", false, 99, _("Office Telephonenumber"), _("Sort On Office Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "business_fax_number", false, 99, _("Business Faxnumber"), _("Sort On Business Faxnumber"));
-			$this->addColumn($this->tablecolumns, "title", false, 99, _("Function"), _("Sort On Function"));
-			$this->addColumn($this->tablecolumns, "company_name", false, 99, _("Company Name"), _("Sort On Company Name"));
-			$this->addColumn($this->tablecolumns, "department_name", false, 99, _("Department Name"), _("Sort On Department Name"));
-			$this->addColumn($this->tablecolumns, "office_location", false, 99, _("Office Location"), _("Sort On Office Location"));
-			$this->addColumn($this->tablecolumns, "profession", false, 99, _("Profession"), _("Sort On Profession"));
-			$this->addColumn($this->tablecolumns, "manager_name", false, 99, _("Manager name"), _("Sort On Manager Name"));
-			$this->addColumn($this->tablecolumns, "assistant", false, 99, _("Assistant"), _("Sort On Assistant"));
-			$this->addColumn($this->tablecolumns, "nickname", false, 99, _("Nickname"), _("Sort On Nickname"));
-			$this->addColumn($this->tablecolumns, "spouse_name", false, 99, _("Spouse Name"), _("Sort On Spouse Name"));
-			$this->addColumn($this->tablecolumns, "birthday", false, 99, _("Birthday"), _("Sort On Birthday"));
-			$this->addColumn($this->tablecolumns, "business_address", false, 99, _("Business Address"), _("Sort On Business Address"));
-			$this->addColumn($this->tablecolumns, "home_address", false, 99, _("Home Address"), _("Sort On Home Address"));
-			$this->addColumn($this->tablecolumns, "other_address", false, 99, _("Office Address"), _("Sort On Other Address"));
-			$this->addColumn($this->tablecolumns, "mailing_address", false, 99, _("Mailing Address"), _("Sort On Mailing Address"));
-			$this->addColumn($this->tablecolumns, "im", false, 99, _("IM"), _("Sort On IM"));
-			$this->addColumn($this->tablecolumns, "webpage", false, 99, _("Webpage"), _("Sort On Webpage"));
-			$this->addColumn($this->tablecolumns, "assistant_telephone_number", false, 99, _("Assistant Telephonenumber"), _("Sort On Assistant Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "business2_telephone_number", false, 99, _("Business Telephonenumber 2"), _("Sort On Business Telephonenumber 2"));
-			$this->addColumn($this->tablecolumns, "callback_telephone_number", false, 99, _("Callback Telephonenumber"), _("Sort On Callback Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "car_telephone_number", false, 99, _("Car Telephonenumber"), _("Sort On Car Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "company_telephone_number", false, 99, _("Company Telephonenumber"), _("Sort On Company Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "home2_telephone_number", false, 99, _("Home Telephonenumber 2"), _("Sort On Home Telephonenumber 2"));
-			$this->addColumn($this->tablecolumns, "home_fax_number", false, 99, _("Home Faxnumber"), _("Sort On Home Faxnumber"));
-			$this->addColumn($this->tablecolumns, "isdn_number", false, 99, _("ISDN Number"), _("Sort On ISDN number"));
-			$this->addColumn($this->tablecolumns, "other_telephone_number", false, 99, _("Other Telephonenumber"), _("Sort On Other Telephonenumber"));
-			$this->addColumn($this->tablecolumns, "pager_telephone_number", false, 99, _("Pager Telephonenumber"), _("Sort On Pager Telephonenumber"));
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getContactListTableColumns();
 
 			parent::ListModule($id, $data, array(OBJECT_SAVE, TABLE_SAVE, TABLE_DELETE));
 
@@ -110,24 +73,86 @@
 			
 			$this->start = 0;
 		}
-		
+
 		/**
-		 * Function which retrieves a list of contacts in a contact folder. It uses
-		 * a restriction (start letter).		 
+		 * Executes all the actions in the $data variable.
+		 * @return boolean true on success of false on fialure.
+		 */
+		function execute()
+		{
+			$result = false;
+
+			foreach($this->data as $action)
+			{
+				if(isset($action["attributes"]) && isset($action["attributes"]["type"])) {
+					$store = $this->getActionStore($action);
+					$parententryid = $this->getActionParentEntryID($action);
+					$entryid = $this->getActionEntryID($action);
+
+					switch($action["attributes"]["type"])
+					{
+						case "list":
+							if ($this->searchActive) {
+								// if search is active then send results from search folder
+								$result = $this->search($store, $entryid, $action);
+							} else {
+								$result = $this->messageList($store, $entryid, $action);
+							}
+							break;
+						case "search":
+							$result = $this->search($store, $entryid, $action);
+							break;
+						case "updatesearch":
+							$result = $this->updatesearch($store, $entryid, $action);
+							break;
+						case "stopsearch":
+							$result = $this->stopSearch($store, $entryid, $action);
+							break;
+						case "save":
+							$result = $this->save($store, $parententryid, $action);
+							break;
+						case "read_flag":
+							$result = $this->setReadFlag($store, $entryid, $action);
+							break;
+						case "delete":
+							$result = $this->delete($store, $parententryid, $entryid, $action);
+							break;
+						case "copy":
+							$result = $this->copy($store, $parententryid, $entryid, $action);
+							break;
+					}
+				}
+			}
+
+			return $result;
+		}
+
+		/**
+		 * Function which retrieves a list of contacts in a contact folder.
+		 * search restriction if present then it will overwrite character restriction
 		 * @param object $store MAPI Message Store Object
 		 * @param string $entryid entryid of the folder
 		 * @param array $action the action data, sent by the client
-		 * @return boolean true on success or false on failure		 		 
+		 * @return boolean true on success or false on failure
 		 */
 		function messageList($store, $entryid, $action)
 		{
 			$result = false;
+			$this->searchFolderList = false; // Set to indicate this is not the search result, but a normal folder content
+
+			// When it is a searchfolder, we want the folder name column
+			if($this->searchActive) {
+				$GLOBALS["TableColumns"]->changeColumnPropertyValue($this->tablecolumns, "parent_entryid", "visible", true);
+			} else {
+				$GLOBALS["TableColumns"]->changeColumnPropertyValue($this->tablecolumns, "parent_entryid", "visible", false);
+			}
 
-			// Retrieve the data for a normal table view with rows.
 			if(isset($action["data_retrieval"]) && $action["data_retrieval"] == "normal") {
+				// Retrieve the data for a normal table view with rows
 				// Use the parent class "messageList" method
 				$result = parent::messageList($store, $entryid, $action);
-			} else { // Retrieve the data for the address cards view
+			} else { 
+				// Retrieve the data for the address cards view
 				if($store && $entryid) {
 					$character = "a";
 					if(isset($action["restriction"])) {
@@ -139,7 +164,7 @@
 							$this->start = (int) $action["restriction"]["start"];
 						}
 					}
-					
+
 					$restriction = array();
 					if($character != "...") {
 						switch ($character){
@@ -205,31 +230,144 @@
 													)
 												)
 											);
-							break;
+								break;
 						}
 					}
 
+					// overwrite character restriction if search restriction exists
+					$this->parseSearchRestriction($action);
+					if($this->searchRestriction != false) {
+						$restriction = $this->searchRestriction;
+					}
+
 					$sort = array($this->properties["fileas"]=>TABLE_SORT_ASCEND);
 
 					$data = array();
 					$data["attributes"] = array("type" => "list");
-					
+
 					$firstSortColumn = reset(array_keys($this->sort)); // get first key of the sort array
 					$data["sort"] = array();
 					$data["sort"]["attributes"] = array();
 					$data["sort"]["attributes"]["direction"] = (isset($this->sort[$firstSortColumn]) && $this->sort[$firstSortColumn] == TABLE_SORT_ASCEND) ? "asc" : "desc";
 					$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
-	
+
 					$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $sort, $this->start, false, $restriction));
-					
+
 					array_push($this->responseData["action"], $data);
 					$GLOBALS["bus"]->addData($this->responseData);
-					
+
 					$result = true;
 				} 
 			}
 			
 			return $result;
 		}
+
+		/**
+		 *	Function will create search restriction based on restriction array
+		 *	@param object $action the action data, sent by the client
+		 */
+		function parseSearchRestriction($action)
+		{
+			if(isset($action["restriction"])) {
+				if(isset($action["restriction"]["start"])) {
+					// Set start variable
+					$this->start = (int) $action["restriction"]["start"];
+				}
+
+				if(isset($action["restriction"]["search"])) {
+					// if the restriction is a associative array, it means that only one property is requested
+					// so we must build an non-associative array arround it
+					if (is_assoc_array($action["restriction"]["search"])){
+						$action["restriction"]["search"] = Array($action["restriction"]["search"]);
+					}
+
+					// create restriction array
+					$res_or = Array();
+
+					foreach($action["restriction"]["search"] as $i => $search) {
+						$prop = false;
+
+						// convert search property to MAPI property
+						switch($search["property"]) {
+							case "full_name":
+								$prop = PR_DISPLAY_NAME;
+								break;
+							case "prefix":
+								$prop = PR_DISPLAY_NAME_PREFIX;
+								break;
+							case "suffix":
+								$prop = PR_GENERATION;
+								break;
+							case "file_as":
+								$prop = $this->properties["fileas"];
+								break;
+							case "company_name":
+								$prop = PR_COMPANY_NAME;
+								break;
+							case "email_address_display_name_1":
+								$prop = $this->properties["email_address_display_name_1"];
+								break;
+							case "email_address_display_name_2":
+								$prop = $this->properties["email_address_display_name_2"];
+								break;
+							case "email_address_display_name_3":
+								$prop = $this->properties["email_address_display_name_3"];
+								break;
+							case "home_telephone_number":
+								$prop = PR_HOME_TELEPHONE_NUMBER;
+								break;
+							case "cellular_telephone_number":
+								$prop = PR_CELLULAR_TELEPHONE_NUMBER;
+								break;
+							case "office_telephone_number":
+								$prop = PR_OFFICE_TELEPHONE_NUMBER;
+								break;
+							case "business_fax_number":
+								$prop = PR_BUSINESS_FAX_NUMBER;
+								break;
+							case "business_address":
+								$prop = $this->properties["business_address"];
+								break;
+							case "home_address":
+								$prop = $this->properties["home_address"];
+								break;
+							case "other_address":
+								$prop = $this->properties["other_address"];
+								break;
+						}
+
+						// build restriction
+						if($prop !== false) {
+							array_push($res_or, Array(RES_AND,
+													Array(
+														Array(RES_EXIST, // check first if the property exists
+															Array(
+																ULPROPTAG => $prop
+															)
+														),
+														Array(RES_CONTENT,
+															Array(
+																FUZZYLEVEL => FL_SUBSTRING|FL_IGNORECASE,
+																ULPROPTAG => $prop,
+																VALUE => u2w($search["value"])
+															)
+														)
+													)
+												)
+										);
+						}
+					}
+
+					if(count($res_or) > 0) {
+						$this->searchRestriction = Array(RES_OR, $res_or);
+					} else {
+						$this->searchRestriction = false;
+					}
+				} else {
+					$this->searchRestriction = false;
+				}
+			}
+		}
 	}
 ?>
