@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -169,6 +171,7 @@
 					$copyAttachmentsStore = false;
 					$copy_only_inline_attachments = false;
 					$replyOrigMessageDetails = false;
+					$send_as_onbehalf = true;
 					if(isset($action["message_action"]) && isset($action["message_action"]["action_type"])) {
 						/** we need to copy the original attachments when it is an forwarded message
 						 *  OR
@@ -217,7 +220,7 @@
 						} else if(!$action["props"]["from"]) {
 							// if from address is not specified and we are sending mail from
 							// delegate's mailbox then don't send mail on behalf of
-							$store = false;
+							$send_as_onbehalf = false;
 						}
 
 						if(!$store) {
@@ -225,11 +228,11 @@
 						}
 
 						$parententryid = $this->getDefaultFolderEntryID($store, $action["props"]["message_class"]);
-						$result = $GLOBALS["operations"]->submitMessage($store, Conversion::mapXML2MAPI($this->properties, $action["props"]), $action["recipients"]["recipient"], $action["dialog_attachments"], $messageProps, $copyAttachments, $copyAttachmentsStore, $add_inline_attachments, $delete_inline_attachments, $copy_only_inline_attachments, $replyOrigMessageDetails);
+						$result = $GLOBALS["operations"]->submitMessage($store, Conversion::mapXML2MAPI($this->properties, $action["props"]), $action["recipients"]["recipient"], $action["dialog_attachments"], $messageProps, $copyAttachments, $copyAttachmentsStore, $add_inline_attachments, $delete_inline_attachments, $copy_only_inline_attachments, $replyOrigMessageDetails, $send_as_onbehalf);
 						
 						// If draft is send from the drafts folder, delete notification
 						if($result) {
-							if(isset($action["props"]["entryid"])) {
+							if(isset($action["props"]["entryid"]) && $action["props"]["entryid"] != "") {
 								$props = array();
 								$props[PR_ENTRYID] = hex2bin($action["props"]["entryid"]);
 								$props[PR_PARENT_ENTRYID] = $parententryid;
@@ -358,6 +361,11 @@
 				if($result && !$send) {
 					$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
 				}
+
+				// Send success message to client, only when you are sending a mail, not when saving it
+				if($send) {
+					$this->sendFeedback(true);
+				}
 			}
 			
 			return $result;
