@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -70,8 +72,8 @@
 				switch($type){
 					case("add"):
 						//get info from MAPI
-						$userData = $this->getUserData(utf8_to_windows1252($selUser["username"]));
-						
+						$userData = $this->getUserData(utf8_to_windows1252($selUser["username"]), $selUser["clientuser"] == "c_user" ? true : false);
+
 						if($userData){
 							$data = array();
 							$data["attributes"] = array("type" => "add");
@@ -84,6 +86,8 @@
 							$user["entryid"] = bin2hex($userData["entryid"]);
 							$user["fullname"] = $userData["fullname"];
 							$user["email"] = $userData["emailaddress"];
+							$user["recipienttype"] = $userData["recipienttype"];
+							$user["objecttype"] = $userData["objecttype"];
 
 							$busyArray = $this->getFreeBusyInfo($userData["entryid"],$selUser["start"],$selUser["end"]);
 
@@ -127,7 +131,7 @@
 							$user["username"] = $selUser["username"];
 							$user["entryid"] = $selUser["username"];
 							$user["fullname"] = $selUser["username"];
-							$user["email"] = "";
+							$user["email"] = $selUser["username"];
 
 							//add busy time
 							$busy = array();
@@ -160,8 +164,9 @@
 		* This function must be replaced by the resolve user module
 		*
 		*@param $query The search query, case is ignored
+		*@param $organizer true/false
 		*/
-		function getUserData($query)
+		function getUserData($query, $organizer)
 		{
 			$result = false;
 			
@@ -226,15 +231,31 @@
 
 			if (is_array($rows) && count($rows)>0) {
 				$abitem = mapi_ab_openentry($ab, $rows[0][PR_ENTRYID]);
-				
-				$user_data = mapi_getprops($abitem, array(PR_ACCOUNT, PR_DISPLAY_NAME, PR_ENTRYID, PR_EMAIL_ADDRESS, PR_SMTP_ADDRESS));
+				$user_data = mapi_getprops($abitem, array(PR_ACCOUNT, PR_DISPLAY_NAME, PR_DISPLAY_TYPE_EX, PR_ENTRYID, PR_EMAIL_ADDRESS, PR_SMTP_ADDRESS, PR_OBJECT_TYPE));
 				
 				$result = array();
 				$result["entryid"] = $user_data[PR_ENTRYID];
 				$result["username"] = windows1252_to_utf8($user_data[PR_ACCOUNT]);
 				$result["fullname"] = windows1252_to_utf8($user_data[PR_DISPLAY_NAME]);
-				$result["emailaddress"] = windows1252_to_utf8($user_data[PR_SMTP_ADDRESS]);
-				$result["recipienttype"] = 1;
+				$result["emailaddress"] = $user_data[PR_SMTP_ADDRESS] ? $user_data[PR_SMTP_ADDRESS] : w2u($user_data[PR_EMAIL_ADDRESS]);
+				$result["objecttype"] = $user_data[PR_OBJECT_TYPE];
+				/**
+				 * user type --> PR_DISPLAY_TYPE_EX value
+				 * active user --> DT_MAILUSER | DTE_FLAG_ACL_CAPABLE
+				 * non-active user --> DT_MAILUSER
+				 * room --> DT_ROOM
+				 * equipment --> DT_EQUIPMENT
+				 * contact --> DT_REMOTE_MAILUSER
+				 */
+				if(DTE_IS_ACL_CAPABLE($user_data[PR_DISPLAY_TYPE_EX]) === false && (DTE_LOCAL($user_data[PR_DISPLAY_TYPE_EX]) == DT_ROOM || DTE_LOCAL($user_data[PR_DISPLAY_TYPE_EX]) == DT_EQUIPMENT || DTE_LOCAL($user_data[PR_DISPLAY_TYPE_EX]) == DT_MAILUSER)) {
+					$result["recipienttype"] = MAPI_BCC;		// resource
+				} else {
+					if($organizer) {
+						$result["recipienttype"] = MAPI_ORIG;			// organizer
+					} else {
+						$result["recipienttype"] = MAPI_TO;				// required attendee
+					}
+				}
 				$result["nameid"] = $query;
 			}
 			
