@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -184,9 +186,10 @@
 						
 						case "opensharedfolder":
 							$result = false;
-							$store = $GLOBALS["mapisession"]->addUserStore($action["username"], $action["foldertype"]);
+							$store = $GLOBALS["mapisession"]->addUserStore($action["username"]);
+							$openingItem = ($action["foldertype"] == "all") ? _("store") : _("folder");
 							if ($store){
-								$data = $GLOBALS["operations"]->getHierarchyList($this->columns, HIERARCHY_GET_ONE, $store);
+								$data = $GLOBALS["operations"]->getHierarchyList($this->columns, HIERARCHY_GET_ONE, $store, $action["subfolders"]);
 								if(!mapi_is_error(mapi_last_hresult()) && (is_array($data["store"]) && count($data["store"]) > 0)) {
 									array_push($this->responseData["action"], $data);
 									$GLOBALS["bus"]->addData($this->responseData);	
@@ -197,18 +200,22 @@
 									$data["error"] = array();
 									$data["error"]["hresult"] = mapi_last_hresult();
 									$data["error"]["hresult_name"] = get_mapi_error_name();
-									$data["error"]["message"] = _("Unable to display the store. Access denied");
+									$data["error"]["message"] = _("You have insufficient privileges to open this ") . $openingItem . ".";
 									$data["error"]["username"] = $action["username"];
 									array_push($this->responseData["action"], $data);								
 									$GLOBALS["bus"]->addData($this->responseData);
 								}
 							} else {
-								// store no exist								
+								// store no exist
 								$data["attributes"] = array("type" => "error");
 								$data["error"] = array();
 								$data["error"]["hresult"] = mapi_last_hresult();
 								$data["error"]["hresult_name"] = get_mapi_error_name();
-								$data["error"]["message"] = _("Unable to display the store. Access denied");
+								if(mapi_last_hresult() == MAPI_E_NOT_FOUND) {
+									$data["error"]["message"] = _("User could not be resolved") . ".";
+								} else {
+									$data["error"]["message"] = _("You have insufficient privileges to open this ") . $openingItem . ".";
+								}
 								$data["error"]["username"] = $action["username"];
 								array_push($this->responseData["action"], $data);								
 								$GLOBALS["bus"]->addData($this->responseData);
