@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -80,7 +82,22 @@
 
 					$parententryid = $this->getActionParentEntryID($action);
 					$entryid = $this->getActionEntryID($action);
-				
+
+					$overQouta = $this->checkOverQoutaRestriction($store, $action);
+					if(!empty($overQouta)) {
+						if($overQouta == "quota_hard") {
+							$errorMessage = _("The message store has exceeded its hard quota limit.") . "\n\n" . 
+											_("To reduce the amount of data in this message store, select some items that you no longer need, and permanently (SHIFT + DEL) delete them.");
+						} else if($overQouta == "quota_soft") {
+							$errorMessage = _("The message store has exceeded its soft quota limit.") . "\n\n" .
+											_("To reduce the amount of data in this message store, select some items that you no longer need, and permanently (SHIFT + DEL) delete them.");
+						}
+
+						$this->sendFeedback(false, $errorMessage);
+
+						continue;
+					}
+
 					switch($action["attributes"]["type"])
 					{
 						case "open":
@@ -127,11 +144,11 @@
 
 								// When accepting occurrence by opening occurrence itself , we dont move occurrence.
 								$move = (stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false) ? true : false;
-								
-								// get the new entry id 
-								$newEntryid = $req->doAccept($tentative, $sendResponse, $move, $newProposedStartTime, $newProposedEndTime, $body, true, $store, $basedate);
+
+								$req->doAccept($tentative, $sendResponse, $move, $newProposedStartTime, $newProposedEndTime, $body, true, $store, $basedate);
 							} else {
-								$delete = $req->doDecline(true, $store, $basedate);
+								$body = isset($action["body"]) ? $action["body"] : false;
+								$delete = $req->doDecline(true, $store, $basedate, $body);
 							}
 
 
@@ -306,6 +323,18 @@
 
 						// We received a meeting request, show it to the user
 						$data["item"]["ismeetingrequest"] = 1;
+						// Show user whether meeting request conflict with other appointment or not.
+						$meetingConflicts = $req->isMeetingConflicting();
+						/**
+						 * if $meetingConflicts is boolean and true then its a normal meeting.
+						 * if $meetingConflictis is integer then it indicates no of instances of a recurring meeting which conflicts with Calendar.
+						 */
+						if (is_bool($meetingConflicts) && $meetingConflicts) {
+							$data["item"]["meetingconflicting"] = _('Conflicts with another appointment on your Calendar.');
+						} else if ($meetingConflicts) {
+							if ($meetingConflicts > 1) $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instances of this recurring appointment conflicts with other appointments on your Calendar.');
+							else $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instance of this recurring appointment conflicts with other appointment on your Calendar.');
+						}
 					}
 				} else if($req->isMeetingCancellation()) {
 					if(!$req->isLocalOrganiser()) {
@@ -328,6 +357,16 @@
 					$data["item"]["body"] = $GLOBALS["operations"]->getNDRbody($GLOBALS["operations"]->openMessage($store, $entryid));
 				}
 								
+				// Allowing to hook in just before the data sent away to be sent to the client
+				$GLOBALS['PluginManager']->triggerHook("server.module.itemmodule.open.after", array(
+					'moduleObject' =>& $this,
+					'store' => $store,
+					'entryid' => $entryid,
+					'action' => $action,
+					'message' =>& $message,
+					'data' =>& $data
+					));
+
 				array_push($this->responseData["action"], $data);
 				$GLOBALS["bus"]->addData($this->responseData);
 				
