@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -65,6 +67,11 @@
 		 */
 		var $tablecolumns;
 		
+		/**
+		 * @var array list of columns which are shown in the table view for quick edit.
+		 */
+		var $insertcolumns;
+		
 		/**
 		 * @var array list of columns which are shown in the table view.
 		 */
@@ -90,6 +97,38 @@
 		 */
 		var $searchFolderList;
 
+		/**
+		 * @var bool returns search restriction is active or not
+		 */
+		var $searchActive;
+
+		/**
+		 * @var hexString entryid of the created search folder
+		 */
+		var $searchFolderEntryId;
+
+		/**
+		 * @var array stores search criteria of previous request
+		 */
+		var $searchCriteriaCheck;
+
+		/**
+		 * @var array stores entryids and last modification time of 
+		 * messages that are already sent to the server
+		 */
+		var $searchResults;
+
+		/**
+		 * @var bool returns search folder should be used or not
+		 */
+		var $useSearchFolder;
+
+		/**
+		 * @var bool checks whether to look for recipients in appointmentlistmodule
+		 *  and add them in items or just get items without recipients tag. 
+		 */
+		var $generateRecipient;
+
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -98,8 +137,15 @@
 		function ListModule($id, $data, $events = false)
 		{
 			$this->start = 0;
+			
 			$this->searchRestriction = false;
 			$this->searchFolderList = false;
+			$this->searchActive = false;
+			$this->searchFolderEntryId = false;
+			$this->searchCriteriaCheck = false;
+			$this->useSearchFolder = false;
+			$this->generateRecipient = false;
+
 			$this->sort = array();
 			
 			parent::Module($id, $data, $events);
@@ -160,7 +206,6 @@
 			$result = false;
 
 			if($store && $entryid) {
-
 				// Restriction
 				$this->parseSearchRestriction($action);
 
@@ -168,14 +213,27 @@
 				$this->parseSortOrder($action, null, true);
 				
 				// List columns visible
-				$this->parseVisibleColumns($action);
+				$GLOBALS["TableColumns"]->parseVisibleColumns($this->tablecolumns, $action);
 				
+				// When it is a searchfolder, we want the folder name column
+				if(isset($this->searchActive) && $this->searchActive) {
+					// check column is already added or not
+					if($GLOBALS["TableColumns"]->getColumn($this->tablecolumns, "parent_entryid") === false) {
+						$GLOBALS["TableColumns"]->addColumn($this->tablecolumns, "parent_entryid", true, 6, _("In Folder"), _("Sort Folder"), 90, "folder_name");
+					}
+				} else {
+					$GLOBALS["TableColumns"]->removeColumn($this->tablecolumns, "parent_entryid");
+				}
+
 				// Create the data array, which will be send back to the client
 				$data = array();
 				$data["attributes"] = array("type" => "list");
 				$data["column"] = $this->tablecolumns;
-				
-				$data["insertcolumn"] = $this->insertcolumns;
+
+				if(is_array($this->insertcolumns) && count($this->insertcolumns) > 0) {
+					// insertcolumns are used for quick edit functionality
+					$data["insertcolumn"] = $this->insertcolumns;
+				}
 				
 				$firstSortColumn = reset(array_keys($this->sort)); // get first key of the sort array
 				$data["sort"] = array();
@@ -184,7 +242,7 @@
 				$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
 				
 				// Get the table and merge the arrays
-				$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction));
+				$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction, $this->generateRecipient));
 				
 				array_push($this->responseData["action"], $data);
 				$GLOBALS["bus"]->addData($this->responseData);
@@ -195,103 +253,427 @@
 			return $result;
 		}
 
+		/**
+		 *	Function will set search restrictions on search folder and start search process
+		 *	and it will also parse visible columns and sorting data when sending results to client
+		 *	@param		object		$store		MAPI Message Store Object
+		 *	@param		hexString	$entryid	entryid of the folder
+		 *	@param		object		$action		the action data, sent by the client
+		 */
+		function search($store, $entryid, $action)
+		{
+			if(!isset($action["use_searchfolder"]) || $action["use_searchfolder"] == null) {
+				/**
+				 * store doesn't support search folders so we can't use this
+				 * method instead we will pass restriction to messageList and
+				 * it will give us the restricted results
+				 */
+				$this->useSearchFolder = false;
+				return $this->messageList($store, $entryid, $action);
+			}
+
+			$this->searchFolderList = true; // Set to indicate this is not the normal folder, but a search folder
+			$this->searchRestriction = false;
+			$this->isSearching = true;	// flag used to indicate that search has been stopped by user
+
+			// Parse Restriction
+			$this->parseSearchRestriction($action);
+			if($this->searchRestriction == false) {
+				// if error in creating restriction then send error to client
+				$errorInfo = array();
+				$errorInfo["error_message"] = _("Error in search, please try again") . ".";
+				$errorInfo["original_error_message"] = "Error in parsing restrictions.";
+
+				return $this->sendSearchErrorToClient($store, $entryid, $action, $errorInfo);
+			}
+
+			// create or open search folder
+			$searchFolder = $this->createSearchFolder($store);
+			if($searchFolder === false) {
+				// if error in creating search folder then send error to client
+				$errorInfo = array();
+				$errorInfo["error_message"] = _("Error in search, please try again") . ".";
+				$errorInfo["original_error_message"] = "Error in creating search folder.";
+
+				return $this->sendSearchErrorToClient($store, $entryid, $action, $errorInfo);
+			}
+
+			$subfolder_flag = 0;
+			if(isset($action["subfolders"]) && $action["subfolders"] == "true") {
+				$subfolder_flag = RECURSIVE_SEARCH;
+			}
+
+			if(!is_array($entryid)) {
+				$entryids = array($entryid);
+			} else {
+				$entryids = $entryid;
+			}
+
+			// check if searchcriteria has changed
+			$restrictionCheck = md5(serialize($this->searchRestriction) . serialize($entryids) . $subfolder_flag);
+
+			// check if there is need to set searchcriteria again
+			if($restrictionCheck != $this->searchCriteriaCheck) {
+				mapi_folder_setsearchcriteria($searchFolder, $this->searchRestriction, $entryids, $subfolder_flag);
+				$this->searchCriteriaCheck = $restrictionCheck;
+
+				if(mapi_last_hresult() != NOERROR) {
+					// if error in creating restriction then send error to client
+					$errorInfo = array();
+					$errorInfo["error_message"] = _("Error in search, please try again") . ".";
+					$errorInfo["original_error_message"] = "Error in parsing restrictions.";
+
+					return $this->sendSearchErrorToClient($store, $entryid, $action, $errorInfo);
+				}
+			}
+
+			unset($action["restriction"]);
+
+			$this->searchActive = true;
+
+			// Sort
+			$this->parseSortOrder($action);
+
+			// List columns visible
+			$GLOBALS["TableColumns"]->parseVisibleColumns($this->tablecolumns, $action);
+
+			// add folder name column if its not present
+			if($GLOBALS["TableColumns"]->getColumn($this->tablecolumns, "parent_entryid") === false) {
+				$GLOBALS["TableColumns"]->addColumn($this->tablecolumns, "parent_entryid", true, 6, _("In Folder"), _("Sort Folder"), 90, "folder_name");
+			}
+
+			// Create the data array, which will be send back to the client
+			$data = array();
+			$data["attributes"] = array("type" => "list");
+			$data["column"] = $this->tablecolumns;
+
+			// Generate output sort
+			$data["sort"] = array();
+			$data["sort"] = $this->generateSortOrder(array());		// we don't want any custom mapping of properties
+																	// so pass empty array in parameter
+
+			// Wait until we have some data, no point in returning before we have data. Stop waiting after 10 seconds
+			$start = time();
+			$table = mapi_folder_getcontentstable($searchFolder);
+			
+			while(time() - $start < 10) {
+				$count = mapi_table_getrowcount($table);
+				$result = mapi_folder_getsearchcriteria($searchFolder);
+
+				// Stop looping if we have data or the search is finished
+				if($count > 0)
+					break;
+					
+				if(($result["searchstate"] & SEARCH_REBUILD) == 0)
+					break; // Search is done
+				
+				sleep(1);
+			}
+
+			// Get the table and merge the arrays
+			$rowcount = $GLOBALS["settings"]->get("global/rowcount", 50);
+			$table = $GLOBALS["operations"]->getTable($store, hex2bin($this->searchFolderEntryId), $this->properties, $this->sort, $this->start, $rowcount, false, $this->generateRecipient);
+			$data = array_merge($data, $table);
+
+			// remember which entryid's are send to the client
+			$this->searchResults = array();
+			foreach($table["item"] as $item) {
+				// store entryid => last_modification_time mapping
+				$this->searchResults[$item["entryid"]["_content"]] = $item["last_modification_time"]["_content"];
+			}
+			array_push($this->responseData["action"], $data);
+
+			$result = mapi_folder_getsearchcriteria($searchFolder);
+
+			$data = array();
+			$data["attributes"] = array("type" => "search");
+			$data["searchfolderentryid"] = array("attributes" => array("type" => "binary"), "_content" => $this->searchFolderEntryId);
+			$data["searchstate"] = $result["searchstate"];
+			$data["results"] = count($this->searchResults);
+
+			array_push($this->responseData["action"], $data);
+			$GLOBALS["bus"]->addData($this->responseData);
+
+			return true;
+		}
+
+		/**
+		 *	Function will check for the status of the search on server
+		 *	and it will also send intermediate results of search, so we don't have to wait
+		 *	untill search is finished on server to send results
+		 *	@param		object		$store		MAPI Message Store Object
+		 *	@param		hexString	$entryid	entryid of the folder
+		 *	@param		object		$action		the action data, sent by the client
+		 */
+		function updatesearch($store, $entryid, $action)
+		{
+			// Only allow to return anything if the search is still going on
+			if(!$this->isSearching){
+				return true;
+			}
+
+			if(bin2hex($entryid) != $this->searchFolderEntryId) {
+				// entryids not matched
+				$data = array();
+				$data["attributes"] = array("type" => "search");
+				$data["searcherror"] = _("Error in search") . ".";
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+				return true;
+			}
+
+			$folder = mapi_msgstore_openentry($store, hex2bin($this->searchFolderEntryId));
+			$searchResult = mapi_folder_getsearchcriteria($folder);
+			$searchState = $searchResult["searchstate"];
+			$table = mapi_folder_getcontentstable($folder);
+
+			if(is_array($this->sort) && count($this->sort) > 0) {
+				// this sorting will be done on currently fetched results, not all results
+				// @TODO find a way to do sorting on all search results
+				mapi_table_sort($table, $this->sort);
+			}
+
+			$rowCount = $GLOBALS["settings"]->get("global/rowcount", 50);
+			$numberOfResults = count($this->searchResults);		// searchResults contains entryids of messages
+																// that are already sent to the server
+
+			$data = array();
+			if($numberOfResults < $rowCount) {
+				$items = mapi_table_queryallrows($table, array(PR_ENTRYID, PR_LAST_MODIFICATION_TIME));
+
+				foreach($items as $props) {
+					$sendItemToClient = false;
+
+					if(!array_key_exists(bin2hex($props[PR_ENTRYID]), $this->searchResults)) {
+						$sendItemToClient = true;
+					} else {
+						/**
+						 * it could happen that an item in search folder has been changed
+						 * after we have sent it to client, so we have to again send it
+						 * so we will have to use last_modification_time of item to check
+						 * that item has been modified since we have sent it to client
+						 */
+						// TODO if any item is deleted from search folder it will be not notified to client
+						if($this->searchResults[bin2hex($props[PR_ENTRYID])] < $props[PR_LAST_MODIFICATION_TIME]) {
+							$sendItemToClient = true;
+						}
+					}
+
+					if($sendItemToClient) {
+						$data = array();
+						$data["attributes"] = array("type" => "item", "searchfolder" => $this->searchFolderEntryId);
+						$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $GLOBALS["operations"]->openMessage($store, $props[PR_ENTRYID]), $this->properties);
+						// store entryid => last_modification_time mapping
+						$this->searchResults[bin2hex($props[PR_ENTRYID])] = $props[PR_LAST_MODIFICATION_TIME];
+						array_push($this->responseData["action"], $data);
+					}
+
+					// when we have more results then fit in the client, we break here,
+					// we only need to update the counters from this point
+					$numberOfResults = count($this->searchResults);
+					if($numberOfResults >= $rowCount) {
+						break; 
+					}
+				}
+			}
+
+			$numberOfResults = mapi_table_getrowcount($table);
+
+			$data = array();
+			$data["attributes"] = array("type" => "search");
+			$data["searchfolderentryid"] = array("attributes" => array("type" => "binary"), "_content" => $this->searchFolderEntryId);
+			$data["searchstate"] = $searchState;
+			$data["results"] = $numberOfResults;
+
+			$data["page"] = array();
+			$data["page"]["start"] = 0;
+			$data["page"]["rowcount"] = $rowCount;
+			$data["page"]["totalrowcount"] = $numberOfResults;
+
+			array_push($this->responseData["action"], $data);
+			$GLOBALS["bus"]->addData($this->responseData);
+
+			return true;
+		}
+
+		/**
+		 *	Function will stop search on the server if search folder exists
+		 *	@param		object		$store		MAPI Message Store Object
+		 *	@param		hexString	$entryid	entryid of the folder
+		 *	@param		object		$action		the action data, sent by the client
+		 */
+		function stopSearch($store, $entryid, $action)
+		{
+			if(isset($this->isSearching) && $this->isSearching == true) {
+				$this->isSearching = false;
+				$this->searchActive = false;
+
+				$searchFolder = mapi_msgstore_openentry($store, $entryid);
+				$searchResult = mapi_folder_getsearchcriteria($searchFolder);
+
+				// check if search folder exists and search is in progress
+				if(mapi_last_hresult() == NOERROR && $searchResult !== false) {
+					mapi_folder_setsearchcriteria($searchFolder, $searchResult['restriction'], $searchResult['folderlist'], STOP_SEARCH);
+				}
+
+				/**
+				 * when stopping search process, we have to remove search folder also,
+				 * so next search request with same restriction will not get uncompleted results
+				 */
+				if(method_exists($this, "deleteSearchFolder")) {
+					$this->deleteSearchFolder($store, $entryid, $action);
+				}
+			}
+		}
+
+		/**
+		 *	Function will create a search folder in FINDER_ROOT folder
+		 *	if folder exists then it will open it
+		 *	@param		object				$store			MAPI Message Store Object
+		 *	@param		boolean				$openIfExists	open if folder exists
+		 *	@return		mapiFolderObject	$folder			created search folder
+		 */
+		function createSearchFolder($store, $openIfExists = true)
+		{
+			if($this->searchFolderEntryId && $openIfExists) {
+				$searchFolder = mapi_msgstore_openentry($store, hex2bin($this->searchFolderEntryId));
+				if($searchFolder !== false && mapi_last_hresult() == NOERROR) {
+					// search folder exists, don't create new search folder
+					return $searchFolder;
+				}
+			}
+
+			// create new search folder
+			$searchFolderRoot = $this->getSearchFoldersRoot($store);
+			if($searchFolderRoot === false) {
+				// error in finding search root folder
+				// or store doesn't support search folders
+				return false;
+			}
+
+			// check for folder name conflict, if conflicts then function will return new name
+			$folderName = $GLOBALS["operations"]->checkFolderNameConflict($store, $searchFolderRoot, "WebAccess Search Folder");
+			$searchFolder = mapi_folder_createfolder($searchFolderRoot, $folderName, null, 0, FOLDER_SEARCH);
+
+			if($searchFolder !== false && mapi_last_hresult() == NOERROR) {
+				$props = mapi_getprops($searchFolder, array(PR_ENTRYID));
+				$this->searchFolderEntryId = bin2hex($props[PR_ENTRYID]);
+				return $searchFolder;
+			} else {
+				return false;
+			}
+		}
+
+		/**
+		 *	Function will open FINDER_ROOT folder in root container
+		 *	public folder's don't have FINDER_ROOT folder
+		 *	@param		object				$store		MAPI message store object
+		 *	@return		mapiFolderObject	root		folder for search folders
+		 */
+		function getSearchFoldersRoot($store)
+		{
+			$searchRootFolder = true;
+
+			// check if we can create search folders
+			$storeProps = mapi_getprops($store, array(PR_STORE_SUPPORT_MASK, PR_FINDER_ENTRYID));
+			if(($storeProps[PR_STORE_SUPPORT_MASK] & STORE_SEARCH_OK) != STORE_SEARCH_OK) {
+				// store doesn't support search folders
+				// public store don't have FINDER_ROOT folder
+				$searchRootFolder = false;
+			}
+
+			if($searchRootFolder) {
+				// open search folders root
+				$searchRootFolder = mapi_msgstore_openentry($store, $storeProps[PR_FINDER_ENTRYID]);
+				if(mapi_last_hresult() != NOERROR) {
+					$searchRootFolder = false;
+				}
+			}
+
+			return $searchRootFolder;
+		}
+
+		/**
+		 *	Function will send error message to client if any error has occured in search
+		 *	@param		object		$store		MAPI Message Store Object
+		 *	@param		hexString	$entryid	entryid of the folder
+		 *	@param		object		$action		the action data, sent by the client
+		 *	@param		object		$errorInfo	the error information object
+		 */
+		function sendSearchErrorToClient($store, $entryid, $action, $errorInfo)
+		{
+			if($errorInfo) {
+				$data = array();
+				$data["attributes"] = array("type" => "search_error");
+				$data["error_message"] = $errorInfo["error_message"];
+				if(isset($errorInfo["searchfolderentryid"]) && $errorInfo["searchfolderentryid"]) {
+					$data["searchfolderentryid"] = array("attributes" => array("type" => "binary"), "_content" => $errorInfo["searchfolderentryid"]);
+				}
+
+				if(isset($errorInfo["original_error_message"]) && $errorInfo["original_error_message"]) {
+					dump($errorInfo["original_error_message"]);
+					$data["original_error_message"] = $errorInfo["original_error_message"];
+				}
+
+				if(mapi_last_hresult() != NOERROR) {
+					// if mapi error then send that data also
+					$data["hresult"] = mapi_last_hresult();
+					$data["hresult_name"] = get_mapi_error_name();
+				}
+
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+
+				// after sending error, remove error data
+				$errorInfo = array();
+			}
+
+			return false;
+		}
+
+		/**
+		 *	Function will create search restriction based on restriction array
+		 *	if search is not implemented in module then it will not have this function,
+		 *	therefore creating a fallback function that will parse start restriction
+		 *	instead of search restriction
+		 *	@param		object		$action		the action data, sent by the client
+		 */
 		function parseSearchRestriction($action)
 		{
-			// TODO: let javascript generate the MAPI restriction just as with the rules
-
 			if(isset($action["restriction"])) {
 				if(isset($action["restriction"]["start"])) {
 					// Set start variable
 					$this->start = (int) $action["restriction"]["start"];
 				}
-				if(isset($action["restriction"]["search"])) {
-					// if the restriction is a associative array, it means that only one property is requested
-					// so we must build an non-associative array arround it
-					if (is_assoc_array($action["restriction"]["search"])){
-						$action["restriction"]["search"] = Array($action["restriction"]["search"]);
-					}
-
-					$res_or = Array();
-					foreach($action["restriction"]["search"] as $i=>$search){
-						$prop = false;
-						// convert search property to MAPI property
-						switch($search["property"]){
-							case "subject":
-								$prop = PR_SUBJECT;
-								break;
-							case "body":
-								$prop = PR_BODY;
-								break;
-							case "to":
-								$prop = PR_DISPLAY_TO;
-								break;
-							case "cc":
-								$prop = PR_DISPLAY_CC;
-								break;
-							case "sender_name":
-								$prop = PR_SENDER_NAME;
-								break;
-							case "sender_email":
-								$prop = PR_SENDER_EMAIL_ADDRESS;
-								break;
-							case "sent_representing_name":
-								$prop = PR_SENT_REPRESENTING_NAME;
-								break;
-							case "sent_representing_email":
-								$prop = PR_SENT_REPRESENTING_EMAIL_ADDRESS;
-								break;
-						}
-						// build restriction
-						if ($prop !== false){
-							array_push($res_or, Array(RES_AND,
-													Array(
-														Array(RES_EXIST, // check first if the property exists
-															Array(ULPROPTAG=>$prop
-															)
-														),
-														Array(RES_CONTENT,
-															Array(FUZZYLEVEL => FL_SUBSTRING|FL_IGNORECASE,
-																ULPROPTAG=>$prop,
-																VALUE => utf8_to_windows1252($search["value"])
-															)
-														)
-													)
-												)
-								); // array_push: $res_or
-						}
-					}
-					if (count($res_or)>0){
-						$this->searchRestriction = Array(RES_OR,$res_or);
-					}else{
-						$this->searchRestriction = false;
-					}
-				}else{
-					$this->searchRestriction = false;
-				}
 			}
 		}
-		
+
 		/**
 		 * Parses the incoming sort request and builds a MAPI sort order. Normally
 		 * properties are mapped from the XML to MAPI by the standard $this->properties mapping. However,
 		 * if you want other mappings, you can specify them in the optional $map mapping.
 		 * 
 		 * $allow_multi_instance is used for creating multiple instance of MV property related items.
+		 * $properties is used for using a custom set of properties instead of properties stored in module
 		 */
-		function parseSortOrder($action, $map = false, $allow_multi_instance = false)
+		function parseSortOrder($action, $map = false, $allow_multi_instance = false, $properties = false)
 		{
 			if(isset($action["sort"]) && isset($action["sort"]["column"])) {
 				$this->sort = array();
-				
+
+				if(!$properties) {
+					$properties = $this->properties;
+				}
+
 				// Unshift MVI_FLAG of MV properties. So the table is not sort on it anymore.
 				// Otherwise the server would generate multiple rows for one item (categories).
-				foreach($this->properties as $id => $property)
+				foreach($properties as $id => $property)
 				{
 					switch(mapi_prop_type($property)) 
 					{
 						case (PT_MV_STRING8 | MVI_FLAG):
 						case (PT_MV_LONG | MVI_FLAG):
-							$this->properties[$id] = $this->properties[$id] &~ MV_INSTANCE;
+							$properties[$id] = $properties[$id] &~ MV_INSTANCE;
 							break;
 					}
 				}
@@ -300,11 +682,11 @@
 				foreach($action["sort"]["column"] as $column)
 				{
 					if(isset($column["attributes"]) && isset($column["attributes"]["direction"])) {
-						if(isset($this->properties[$column["_content"]]) || ($map && isset($map[$column["_content"]]))) {
+						if(isset($properties[$column["_content"]]) || ($map && isset($map[$column["_content"]]))) {
 							if($map && isset($map[$column["_content"]])) 
 								$property = $map[$column["_content"]];
 							else
-								$property = $this->properties[$column["_content"]];
+								$property = $properties[$column["_content"]];
 							
 							// Check if column is a MV property
 							switch(mapi_prop_type($property)) 
@@ -314,9 +696,9 @@
 									// Set MVI_FLAG.
 									// The server will generate multiple rows for one item (for example: categories)
 									if($allow_multi_instance){
-										$this->properties[$column["_content"]] = $this->properties[$column["_content"]] | MVI_FLAG;
+										$properties[$column["_content"]] = $properties[$column["_content"]] | MVI_FLAG;
 									}
-									$property = $this->properties[$column["_content"]];
+									$property = $properties[$column["_content"]];
 									break;
 							}
 
@@ -343,50 +725,24 @@
 		 * column headers. Takes an optional $map when mapping columns to something other than their
 		 * standard MAPI property. (same $map as parseSortOrder).
 		 *
+		 * $properties is used for using a custom set of properties instead of properties stored in module
 		 */
-		function generateSortOrder($map) {
+		function generateSortOrder($map, $properties = false) {
 			$data = array();
 			
+			if(!$properties) {
+				$properties = $this->properties;
+			}
+
 			$firstSortColumn = array_shift(array_keys($this->sort));
 			$data = array();
 			$data["attributes"] = array();
 			$data["attributes"]["direction"] = (isset($this->sort[$firstSortColumn]) && $this->sort[$firstSortColumn] == TABLE_SORT_ASCEND) ? "asc":"desc";
-			$data["_content"] = array_search($firstSortColumn, $map) ? array_search($firstSortColumn, $map) : array_search($firstSortColumn, $this->properties);
+			$data["_content"] = array_search($firstSortColumn, $map) ? array_search($firstSortColumn, $map) : array_search($firstSortColumn, $properties);
 			
 			return $data;
 		}
 
-		function parseVisibleColumns($action) 
-		{
-			if(isset($action["columns"]) && isset($action["columns"]["column"])) {
-				// Loop through the columns
-				foreach($action["columns"]["column"] as $column)
-				{
-					if(isset($column["attributes"]) && isset($column["attributes"]["action"])) {
-						$tablecolumnkey = $this->getColumn($this->tablecolumns, $column["_content"]);
-
-						// Add or delete the column
-						if($tablecolumnkey !== false) {
-							switch(strtolower($column["attributes"]["action"]))
-							{
-								case "add":
-									$this->tablecolumns[$tablecolumnkey]["visible"] = true;
-
-									if(isset($column["attributes"]["order"])) {
-										$this->tablecolumns[$tablecolumnkey]["order"] = (int) $column["attributes"]["order"];
-									}
-									break;
-								case "delete":
-									$this->tablecolumns[$tablecolumnkey]["visible"] = false;
-									break;
-							}
-						}
-					}
-				}
-			}
-
-		}
-		
 		/**
 		 * Function which saves an item.
 		 * @param object $store MAPI Message Store Object
@@ -457,8 +813,11 @@
 
 				$storeprops = mapi_getprops($store, array(PR_ENTRYID));
 				$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
+
+				// Check for soft delete (Shift + Del)
+				$softDelete = isset($action["softdelete"]) && $action["softdelete"] ? $action["softdelete"] : false;
 				
-				$result = $GLOBALS["operations"]->deleteMessages($store, $parententryid, $entryids);
+				$result = $GLOBALS["operations"]->deleteMessages($store, $parententryid, $entryids, $softDelete);
 
 				if($result) {
 					$GLOBALS["bus"]->notify($this->entryid, TABLE_DELETE, $props);
@@ -466,7 +825,8 @@
 					// because we don't have real notifications and we know that most of the time deleted items are going to
 					// the "Deleted Items"-folder, we notify the bus that that folder is changed to update the counters
 					$msgprops = mapi_getprops($store, array(PR_IPM_WASTEBASKET_ENTRYID));
-					if ($msgprops[PR_IPM_WASTEBASKET_ENTRYID]!=$this->entryid){ // only when we are not deleting within the trash itself
+
+					if ($msgprops[PR_IPM_WASTEBASKET_ENTRYID]!=$this->entryid && !$softDelete){ // only when we are not deleting within the trash itself
 
 						$props[PR_PARENT_ENTRYID] = $msgprops[PR_IPM_WASTEBASKET_ENTRYID];
 						$GLOBALS["bus"]->notify(bin2hex($msgprops[PR_IPM_WASTEBASKET_ENTRYID]), TABLE_SAVE, $props);
@@ -536,95 +896,6 @@
 			return $result;
 		}
 
-		/**
-		 * Function which sets the column properties. This function is used for setting
-		 * column information, like name and if it is visible in the client view.		 
-		 * @param array $columns reference to an array, which the column will be added
-		 * @param string $id id of the column
-		 * @param boolean $visible true - column is visible, false - column is not visible		 
-		 * @param integer $order the order in which the columns are visible
-		 * @param string $name the name of the column
-		 * @param string $title the title of the column
-		 * @param string $type the type of column
-		 * @param integer $length the length of the column (pixels)	
-		 */
-		function addColumn(&$columns, $id, $visible, $order = false, $name = false, $title = false, $length = false, $type = false)
-		{
-			$column = array();
-			
-			$column["id"] = $id;
-			$column["visible"] = $visible;
-			
-			if($order !== false && $name && $title) {
-				$column["name"] = $name;
-				$column["title"] = $title;
-				$column["order"] = $order;
-				
-				if($length) {
-					$column["length"] = $length;
-				}
-			}
-			if ($type)
-				$column["type"] = $type;
-			
-			array_push($columns, $column);
-		}
-
-		
-		/**
-		 * Function which sets the column properties. This function is used for setting
-		 * column information, like name and if it is visible in the client view.		 
-		 * @param array 	$columns 	reference to an array, which the column will be added
-		 * @param string 	$id 		id of the input type fields
-		 * @param string 	$type 		the type of column
-		 * @param boolean 	$visible 	true - column is visible, false - column is not visible		 
-		 * @param boolean 	$readonly	true - column is readonly, false - column is not editable
-		 * @param integer 	$order 		the order in which the columns are visible
-		 * @param string 	$name 		the id` of the corresponding column in the header row
-		 * @param string 	$title 		the title of the column
-		 * @param integer 	$length 	the length of the column (pixels)
-		 */
-		function addInputColumn(&$columns, $id, $type, $visible, $readonly, $order = false, $name = false, $title = false, $length = false)
-		{
-			$column = array();
-			
-			$column["id"] = $id;
-			$column["type"] = $type;
-			$column["visible"] = $visible;
-			$column["readonly"] = $readonly;
-			$column["name"] = $name;
-			
-			if($order !== false) {
-				$column["title"] = $title;				
-				$column["order"] = $order;
-			}	
-			
-			if($length) {				
-				$column["length"] = $length;
-			}						
-			array_push($columns, $column);
-		}		
-		
-		/**
-		 * Function which returns the column array key (0, 1, 2, ...) of a column.		 
-		 * @param array $columns list of columns
-		 * @param string $id id of the column
-		 * @return integer key in the $columns array (0, 1, 2, ...)	
-		 */
-		function getColumn($columns, $id)
-		{
-			$key = false;
-			
-			foreach($columns as $columnkey => $column)
-			{
-				if($column["id"] == $id) {
-					$key = $columnkey;
-				}
-			}
-			
-			return $key;
-		}
-		
 		/**
 		 * If an event elsewhere has occurred, it enters in this methode. This method
 		 * executes one ore more actions, depends on the event.
@@ -657,7 +928,7 @@
 					if(!$this->searchFolderList){
 						$folderEntryID = (isset($props[PR_PARENT_ENTRYID]))?$props[PR_PARENT_ENTRYID]:false;
 					}else{
-						$folderEntryID = (isset($this->searchFolder))?hex2bin($this->searchFolder):false;
+						$folderEntryID = (isset($this->searchFolderEntryId))?hex2bin($this->searchFolderEntryId):false;
 					}
 
 					if(isset($props[PR_ENTRYID]) && $folderEntryID) {
@@ -678,7 +949,7 @@
 							if(!$this->searchFolderList){
 								$data["attributes"] = array ("type" => "item");
 							}else{
-								$data["attributes"] = array("type" => "item", "searchfolder" => $this->searchFolder);
+								$data["attributes"] = array("type" => "item", "searchfolder" => $this->searchFolderEntryId);
 							}
 							$data["item"] = $newItems["item"];
 						
