@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -124,8 +126,84 @@
 			return $result;
 		}
 
-	
+		/**
+		 * checks user store for over qouta restrictions, if qouta limit is exceeded then it will block some operations
+		 * @param object $store MAPI Message Store Object
+		 * @param array $action the action data, sent by the client
+		 * @return string qouta name which is exceeded or a blank string
+		 */
+		function checkOverQoutaRestriction($store, $action)
+		{
+			$result = "";
+			$actionType = "";
 
+			switch($action["attributes"]["type"]) {
+				/*case "acceptMeetingRequest":
+				case "cancelMeetingRequest":
+				case "declineMeetingRequest":
+				case "cancelInvitation":
+					$actionType = "send";
+					break;*/
+				case "save":
+					if(isset($action["send"]) && $action["send"]) {
+						$actionType = "send";
+					} else {
+						$actionType = "save";
+					}
+					break;
+			}
+
+			if(empty($actionType)) {
+				// for other action types don't check for qouta limits
+				return false;
+			}
+
+			$quotaDetails = $GLOBALS["operations"]->getQuotaDetails($store);
+
+			if($quotaDetails !== false) {
+				if($quotaDetails["quota_hard"] !== 0 && $quotaDetails["store_size"] > $quotaDetails["quota_hard"]) {
+					if($actionType == "save" || $actionType == "send") {
+						// hard quota is not handled yet
+						//$result = "quota_hard";
+					}
+				}
+
+				// if hard quota limit doesn't restrict the operation then check for soft qouta limit
+				if($quotaDetails["quota_soft"] !== 0 && $quotaDetails["store_size"] > $quotaDetails["quota_soft"] && empty($result)) {
+					if($actionType == "send") {
+						$result = "quota_soft";
+					}
+				}
+			}
+
+			return $result;
+		}
+
+		/**
+		 * sends a success or error message to client based on parameters passed
+		 * @param boolean $success operation completed successfully or not
+		 * @param string $message the error message which will be shown to client on any failure of operation
+		 */
+		function sendFeedback($success = false, $message = "")
+		{
+			if($success == true) {
+				// Send success message to client
+				$data = array();
+				$data["attributes"] = array("type" => "success");
+
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+			} else {
+				// send error message to client
+				$data = array();
+				$data["attributes"] = array("type" => "error");
+				$data["error"] = array();
+				$data["error"]["message"] = $message;
+				
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+			}
+		}
 
 		/**
 		 * Function which returns an entryid, which is used to register this module. It
