@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -93,7 +95,7 @@
 						case "save":
 							$store = $GLOBALS["mapisession"]->openMessageStore(hex2bin($action["store"]));
 							$folder = mapi_msgstore_openentry($store, hex2bin($action["entryid"]));
-							
+
 							$result = $this->save($folder,$action);
 
 							if($result != NOERROR) {
@@ -103,7 +105,13 @@
 								$data["error"] = array();
 								$data["error"]["hresult"] = $result;
 								$data["error"]["hresult_name"] = get_mapi_error_name($result);
-								$data["error"]["message"] = _("Unable to set the permission on folder.");
+								if($result == (int) MAPI_E_NO_ACCESS) {
+									$data["error"]["message"] = _("You have insufficient permissions to set permissions.");
+								} else if($result == (int) MAPI_W_PARTIAL_COMPLETION) {
+									$data["error"]["message"] = _("Unable to set some permissions. Permissions are only allowed on users and security groups.");
+								} else {
+									$data["error"]["message"] = _("Unable to set all permissions.");
+								}
 
 								array_push($this->responseData["action"], $data);
 								$GLOBALS["bus"]->addData($this->responseData);
@@ -280,7 +288,7 @@
 			}
 
 			$acls = array();
-			if (is_array($permissions)){
+			if (is_array($permissions) && count($permissions) > 0){
 				foreach($permissions as $type=>$perms){
 					switch($type){
 						case "denied":
@@ -312,10 +320,12 @@
 			// Merge new permissions in to old permissions
 			$acls = array_merge($delete_acls, $acls);
 
-			mapi_zarafa_setpermissionrules($folder, $acls);
-			if(mapi_last_hresult() != NOERROR) {
-				// unable to set permissions
-				return mapi_last_hresult(); 
+			if(count($acls) > 0) {
+				mapi_zarafa_setpermissionrules($folder, $acls);
+				if(mapi_last_hresult() != NOERROR) {
+					// unable to set permissions
+					return mapi_last_hresult(); 
+				}
 			}
 
 			if (isset($freebusy)){
