@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -66,10 +68,7 @@
 			$this->properties = $GLOBALS["properties"]->getReminderProperties();
 		
 			// Default Columns
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "icon_index", true, 0, _("Icon"), _("Sort on Icon"));
-			$this->addColumn($this->tablecolumns, "subject", true, 1, _("Subject"), _("Sort on subject"));
-			$this->addColumn($this->tablecolumns, "remindertime", true, 2, _("Due in"), _("Sort on Due in"));
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getReminderListTableColumns();
 
 			parent::ListModule($id, $data, array());
 
@@ -273,51 +272,55 @@
 								)
 			);
 
-            $reminderfolder = mapi_msgstore_openentry($store, $this->reminderEntryId);
-            if(!$reminderfolder)
-                return false;
-                
-            $remindertable = mapi_folder_getcontentstable($reminderfolder);
-            if(!$remindertable)
-                return false;
-                
-            mapi_table_restrict($remindertable, $restriction);
-            mapi_table_sort($remindertable, array($this->properties["flagdueby"] => TABLE_SORT_DESCEND));
+			$reminderfolder = mapi_msgstore_openentry($store, $this->reminderEntryId);
+			if(!$reminderfolder)
+				return false;
+				
+			$remindertable = mapi_folder_getcontentstable($reminderfolder);
+			if(!$remindertable)
+				return false;
+				
+			mapi_table_restrict($remindertable, $restriction);
+			mapi_table_sort($remindertable, array($this->properties["flagdueby"] => TABLE_SORT_DESCEND));
 
-            $rows = mapi_table_queryrows($remindertable, $this->properties, 0, /* all rows */0x7ffffff);
-            
-            $data["item"] = array();
+			$rows = mapi_table_queryrows($remindertable, $this->properties, 0, /* all rows */0x7ffffff);
+			
+			$data["item"] = array();
 
-            foreach($rows as $row) {
-                if(isset($row[$this->properties["appointment_recurring"]]) && $row[$this->properties["appointment_recurring"]]) {
-                    // Do extra checks for recurring items:
-                    // - Check if there really is a reminder between the flagdueby and now. If not, there's no reminder yet. If there
-                    // are more than one reminder, use the last.
-                    $recur = new Recurrence($store, $row);
-                    
+			foreach($rows as $row) {
+				if(isset($row[$this->properties["appointment_recurring"]]) && $row[$this->properties["appointment_recurring"]]) {
+					// Do extra checks for recurring items:
+					// - Check if there really is a reminder between the flagdueby and now. If not, there's no reminder yet. If there
+					// are more than one reminder, use the last.
+					$recur = new Recurrence($store, $row);
+					
 					/**
 					 * Fetch occurences of reminder which taken place between remindertime and currenttime.
+					 * Here reminder_minutes is added in current time to also get
+					 * those occurrences for which reminder is activated.
 					 * remindertime property returns a Date indicating the date and time
 					 * at which the reminder should occur for the specified item.
 					 * For recurring event it will save the time of first reminder of recurrence.
 					 */
-                    $occurrences = $recur->getItems($row[$this->properties["remindertime"]], time(), 0, true);
-                    
-                    if(count($occurrences) == 0)
-                        continue;
-                        
-                    // Update the reminder time to show as the last occurrence since 'remindertime' until now
-                    $lastocc = $occurrences[count($occurrences)-1];
-                    $row[$this->properties["remindertime"]] = $lastocc[$this->properties["appointment_startdate"]] - ($lastocc[$this->properties["reminder_minutes"]] * 60);
-                }        
+					$occurrences = $recur->getItems($row[$this->properties["remindertime"]], time() + ($row[$this->properties["reminder_minutes"]] * 60), 0, true);
 
-                // Add the non-bogus rows
-                 array_push($data["item"], Conversion::mapMAPI2XML($this->properties, $row));
-            }
-            
-            // Generate this handy MD5 so that the client can easily detect changes
-            $data["rowchecksum"] = md5(serialize($data["item"]));
-            
+					if(count($occurrences) == 0)
+						continue;
+						
+					// Update the reminder time to show as the last occurrence since 'remindertime' until now
+					$lastocc = $occurrences[count($occurrences)-1];
+					$row[$this->properties["remindertime"]] = $lastocc[$this->properties["appointment_startdate"]];
+					$row[$this->properties["appointment_startdate"]] = $lastocc[$this->properties["appointment_startdate"]];
+					$row[$this->properties["appointment_enddate"]] = $lastocc[$this->properties["appointment_startdate"]];
+				}
+
+				// Add the non-bogus rows
+				 array_push($data["item"], Conversion::mapMAPI2XML($this->properties, $row));
+			}
+			
+			// Generate this handy MD5 so that the client can easily detect changes
+			$data["rowchecksum"] = md5(serialize($data["item"]));
+			
 			array_push($this->responseData["action"], $data);
 			$GLOBALS["bus"]->addData($this->responseData);
 
