@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -109,11 +111,30 @@
 					$names = array($names);
 				} 
 				
-				// open contact folder
+				// get all contact folders from own store, exclude subfolders
 				$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
-				$inbox = mapi_msgstore_getreceivefolder($store);
-				$inboxProps = mapi_getprops($inbox, array(PR_IPM_CONTACT_ENTRYID));
-				$contactfolder = mapi_msgstore_openentry($store,$inboxProps[PR_IPM_CONTACT_ENTRYID]);
+				$subtreeEntryid = mapi_getprops($store, array(PR_IPM_SUBTREE_ENTRYID));
+				$ipmSubtree = mapi_msgstore_openentry($store, $subtreeEntryid[PR_IPM_SUBTREE_ENTRYID]);
+				$hierarchyTable = mapi_folder_gethierarchytable($ipmSubtree, MAPI_DEFERRED_ERRORS);
+
+				$restriction = array(
+									RES_CONTENT,
+										array(
+											FUZZYLEVEL => FL_FULLSTRING,
+											ULPROPTAG => PR_CONTAINER_CLASS,
+											VALUE => array(
+														PR_CONTAINER_CLASS => "IPF.Contact"
+													)
+										)
+								);
+
+				mapi_table_restrict($hierarchyTable, $restriction, TBL_BATCH);
+				$contactFolderEntryIds = mapi_table_queryrows($hierarchyTable, array(PR_ENTRYID), 0, 0x7fffffff);
+
+				$contactFolders = array();
+				for($index = 0; $index < count($contactFolderEntryIds); $index++) {
+					array_push($contactFolders, mapi_msgstore_openentry($store, $contactFolderEntryIds[$index][PR_ENTRYID]));
+				}
 
 				// open addressbook
 				$ab = $GLOBALS["mapisession"]->getAddressbook();
@@ -129,8 +150,10 @@
 						$result = $this->searchAddressBook($ab, $ab_dir, $id, $type);
 						$data["name"] = array_merge($data["name"], $result);
 
-						$result = $this->searchContactFolder($contactfolder, $id, $type);
-						$data["name"] = array_merge($data["name"], $result);
+						for($index = 0; $index < count($contactFolders); $index++) {
+							$result = $this->searchContactFolder($contactFolders[$index], $id, $type, $store);
+							$data["name"] = array_merge($data["name"], $result);
+						}
 					}
 				}
 
@@ -181,19 +204,30 @@
                                                     ),
                                             ), // RES_OR
                                         ),
-                                        array(
-                                            RES_PROPERTY,
-                                                array(RELOP=>RELOP_EQ,
-                                                    ULPROPTAG=>PR_OBJECT_TYPE,
-                                                    VALUE=>MAPI_MAILUSER
-                                                )
-                                            )
+										array(RES_OR,
+											array(
+												array(
+													RES_PROPERTY,
+														array(RELOP=>RELOP_EQ,
+															ULPROPTAG=>PR_OBJECT_TYPE,
+															VALUE=>MAPI_MAILUSER
+														)
+													),
+												array(
+													RES_PROPERTY,
+														array(RELOP=>RELOP_EQ,
+															ULPROPTAG=>PR_OBJECT_TYPE,
+															VALUE=>MAPI_DISTLIST
+													)
+												)
+											)
+										)
                                     ) // RES_AND
                                 );
                 mapi_table_restrict($table, $restriction);
                 mapi_table_sort($table, array(PR_DISPLAY_NAME => TABLE_SORT_ASCEND));
                 
-				$tableItems = mapi_table_queryrows($table, array(PR_ACCOUNT, PR_DISPLAY_NAME, PR_ENTRYID, PR_OBJECT_TYPE, PR_SMTP_ADDRESS), 0, 0x7fffffff);
+				$tableItems = mapi_table_queryrows($table, array(PR_ACCOUNT, PR_DISPLAY_NAME, PR_ENTRYID, PR_OBJECT_TYPE, PR_SMTP_ADDRESS, PR_OBJECT_TYPE), 0, 0x7fffffff);
 
 				$items = array();
 				foreach($tableItems as $user_data) {
@@ -202,6 +236,7 @@
 					$item["username"] = w2u($user_data[PR_ACCOUNT]);
 					$item["fullname"] = w2u($user_data[PR_DISPLAY_NAME]);
 					$item["emailaddress"] = w2u($user_data[PR_SMTP_ADDRESS]);
+					$item["objecttype"] = $user_data[PR_OBJECT_TYPE];
 					$item["nameid"] = $query;
 					$item["nametype"] = $type;
 
@@ -212,12 +247,13 @@
 			} else {
 				// Item found, get details from AB
 				$abitem = mapi_ab_openentry($ab, $rows[0][PR_ENTRYID]);
-				$user_data = mapi_getprops($abitem, array(PR_ACCOUNT, PR_DISPLAY_NAME, PR_ENTRYID, PR_EMAIL_ADDRESS, PR_SMTP_ADDRESS));
+				$user_data = mapi_getprops($abitem, array(PR_ACCOUNT, PR_DISPLAY_NAME, PR_ENTRYID, PR_EMAIL_ADDRESS, PR_SMTP_ADDRESS, PR_OBJECT_TYPE));
 				
 				$item = array();
 				$item["username"] = w2u($user_data[PR_ACCOUNT]);
 				$item["fullname"] = w2u($user_data[PR_DISPLAY_NAME]);
 				$item["emailaddress"] = w2u($user_data[PR_SMTP_ADDRESS]);
+				$item["objecttype"] = $user_data[PR_OBJECT_TYPE];
 				$item["nameid"] = $query;
 				$item["nametype"] = $type;
 
@@ -235,7 +271,7 @@
 		*@param $query The search query, case is ignored
 		*@param $type The type of search, this is returned in the result array
 		*/
-		function searchContactFolder($folder, $query, $type)
+		function searchContactFolder($folder, $query, $type, $store=false)
 		{
 			$table = mapi_folder_getcontentstable($folder);
 			
@@ -284,11 +320,22 @@
 												),
 										), // RES_OR
 									),
-									array(
-										RES_PROPERTY,
-											array(RELOP=>RELOP_EQ,
-												ULPROPTAG=>$properties["message_class"],
-												VALUE=>"IPM.Contact"
+									array(RES_OR,
+										array(
+											array(
+												RES_PROPERTY,
+													array(RELOP=>RELOP_EQ,
+														ULPROPTAG=>$properties["message_class"],
+														VALUE=>"IPM.Contact"
+													)
+												),
+											array(
+												RES_PROPERTY,
+													array(RELOP=>RELOP_EQ,
+														ULPROPTAG=>$properties["message_class"],
+														VALUE=>"IPM.DistList"
+													)
+												)
 											)
 										)
 								) // RES_AND
@@ -301,21 +348,129 @@
 
 			$items = array();
 			foreach ($rows as $row) {
-				for ($email=1; $email<=3; $email++){
-					if (isset($row[$properties["email_address_".$email]]) && !empty($row[$properties["email_address_".$email]])){
-						$item = array();
+				if($row[$properties["message_class"]] == "IPM.DistList"){
+					$item = array();
+					$item["username"] = w2u($row[$properties["fileas"]]);
+					$item["fullname"] = w2u($row[$properties["display_name"]]);
+					$item["message_class"] = $row[$properties["message_class"]];
+					$members = $this->getMembersFromDistributionList($store, $row[$properties["entryid"]], array(), $properties);
+					$item["members"] = array("member"=>$members);
+					$item["nameid"] = $query;
+					$item["nametype"] = $type;
+					array_push($items, $item);
+				}else{
+					for ($email=1; $email<=3; $email++){
+						if (isset($row[$properties["email_address_".$email]]) && !empty($row[$properties["email_address_".$email]])){
+							$item = array();
 
-						$item["username"] = w2u($row[$properties["fileas"]]);
-						if (isset($row["email_address_display_name_".$email])){
-							$item["fullname"] = w2u($row[$properties["email_address_display_name_".$email]]);
-						}else{
-							$item["fullname"] = w2u($row[$properties["display_name"]]);
+							$item["username"] = w2u($row[$properties["fileas"]]);
+							if (isset($row["email_address_display_name_".$email])){
+								$item["fullname"] = w2u($row[$properties["email_address_display_name_".$email]]);
+							}else{
+								$item["fullname"] = w2u($row[$properties["display_name"]]);
+							}
+							$item["emailaddress"] = w2u($row[$properties["email_address_".$email]]);
+							$item["nameid"] = $query;
+							$item["nametype"] = $type;
+							$item["objecttype"] = MAPI_MAILUSER;
+
+							array_push($items, $item);
 						}
-						$item["emailaddress"] = w2u($row[$properties["email_address_".$email]]);
-						$item["nameid"] = $query;
-						$item["nametype"] = $type;
+					}
+				}
+			}
+			return $items;
+		}
 
-						array_push($items, $item);
+		/**
+		 * Function which fetches all members of a distribution list recursively.
+		 * @param object $store MAPI Message Store Object
+		 * @param string $entryid entryid of the distribution list
+		 * @return object $items all members of a distlist.
+		 */
+		function getMembersFromDistributionList($store, $entryid, $listEntryIDs = array(), $properties)
+		{
+			if (in_array($entryid, $listEntryIDs)){ // don't expand a distlist that is already expanded
+				return array();
+			}
+
+			$listEntryIDs[] = $entryid;
+
+			$message = mapi_msgstore_openentry($store, $entryid);
+			$items = array();
+			if($message) {
+				$props = mapi_getprops($message, array($properties["oneoff_members"], $properties["members"]));
+				if(isset($props[$properties["oneoff_members"]])) {
+					$members = $props[$properties["members"]];
+				}
+
+				// parse oneoff members
+				$oneoffmembers = array();
+				foreach($props[$properties["oneoff_members"]] as $key=>$item){
+					$oneoffmembers[$key] = mapi_parseoneoff($item);
+				}
+				
+				foreach($members as $key=>$item){
+					$parts = unpack("Vnull/A16guid/Ctype/A*entryid", $item);
+					if ($parts["guid"]==hex2bin("812b1fa4bea310199d6e00dd010f5402")){ // custom e-mail address (no user or contact)
+						$oneoff = mapi_parseoneoff($item);
+						$item = array();
+						$item["fileas"] = w2u($oneoff["name"]);
+						$item["display_name"] = $item["fileas"];
+						$item["type"] = w2u($oneoff["type"]);
+						$item["emailaddress"] = w2u($oneoff["address"]);
+						$items[] = $item;
+					}else{
+						switch($parts["type"]){
+							case DL_USER: // contact
+								$msg = mapi_msgstore_openentry($store, $parts["entryid"]);
+								if (mapi_last_hresult()!=NOERROR) // contact could be deleted, skip item
+									continue;
+								$msgProps = mapi_getprops($msg, $properties);
+								$item = array();
+								$item["entryid"] = bin2hex($parts["entryid"]);
+								$item["display_name"] = w2u($msgProps[$properties["display_name"]]);
+								$item["emailaddress"] = w2u($oneoffmembers[$key]["address"]);
+
+								// use the email adress from the OneOff entry	
+								$item["type"] = w2u($oneoffmembers[$key]["type"]);
+								$items[] = $item;	
+								break;
+							case DL_USER_AB: // ab user
+								$ab = $GLOBALS["mapisession"]->getAddressbook();
+								$msg = mapi_ab_openentry($ab,$parts["entryid"]);
+								if (mapi_last_hresult()!=NOERROR) // user could be deleted, skip item
+									continue;
+								$properties = array_merge($properties, array("smtp_address" => PR_SMTP_ADDRESS));
+								$msgProps = mapi_getprops($msg, $properties);
+								$item = array();
+								$item["entryid"] = bin2hex($parts["entryid"]);
+								$item["display_name"] = w2u($msgProps[$properties["display_name"]]);
+
+								// don't use the email adress from the OneOff entry because 
+								// it will give a ZARAFA mail address, and in the webaccess we currently only support SMTP addresses
+								$item["type"] = "SMTP";
+								$item["emailaddress"] = w2u($msgProps[$properties["smtp_address"]]);
+
+								$items[] = $item;
+								break;
+
+							case DL_DIST: // dist list
+								$items = array_merge($items, $this->getMembersFromDistributionList($store, $parts["entryid"], $listEntryIDs, $properties));
+								break;
+
+							case DL_DIST_AB: // group
+								$group = mapi_ab_openentry($GLOBALS["mapisession"]->getAddressbook(), $parts["entryid"]);
+								$groupProps = mapi_getprops($group, $properties);
+								$item = array();
+								$item["entryid"] = bin2hex($parts["entryid"]);
+								$item["display_name"] = w2u($groupProps[$properties["display_name"]]);
+								$item["type"] = "ZARAFA";
+								if(isset($groupProps[PR_EMAIL_ADDRESS])) 
+									$item["emailaddress"] = w2u($groupProps[PR_EMAIL_ADDRESS]);
+								$items[] = $item;
+								break;
+						}
 					}
 				}
 			}
