@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -61,21 +63,9 @@
 		function TaskListModule($id, $data)
 		{
 			$this->properties = $GLOBALS["properties"]->getTaskProperties();
-			
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "icon_index", true, 0, _("Icon"), _("Sort On Icon"), 25);
-			$this->addColumn($this->tablecolumns, "complete", true, 1, _("Complete"), _("Sort On Complete"), 25);
-			$this->addColumn($this->tablecolumns, "importance", true, 2, _("Priority"), _("Sort On Priority"));
-			$this->addColumn($this->tablecolumns, "subject", true, 3, _("Subject"), _("Sort On Subject"), PERCENTAGE);
-			$this->addColumn($this->tablecolumns, "duedate", true, 4, _("Due Date"), _("Sort On Due Date"));
-			
-			$this->addColumn($this->tablecolumns, "owner", true, 5, _("Owner"), _("Sort On Owner"));
-			$this->addColumn($this->tablecolumns, "categories", false, 6, _("Categories"), _("Sort On Categories"));
-			$this->addColumn($this->tablecolumns, "percent_complete", false, 7, _("% Completed"), _("Sort On Percent Completed"), 100);
-			$this->addColumn($this->tablecolumns, "hidden_column", true, 8);
-			$this->addColumn($this->tablecolumns, "startdate", true, 9, _("Start Date"), _("Sort On Start Date"));
-			
-			
+
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getTaskListTableColumns();
+
 			/*
 			*NOTE:
 			*1)If value of visibility of any column in above table(i.e tablecolumns) is modifyed,
@@ -102,19 +92,14 @@
 			}
 			
 			$username = mapi_zarafa_getuser_by_name($store,$userdata);			
-			
-			$this->insertcolumns = array();
-			$this->addInputColumn($this->insertcolumns, "icon", "null", true, "", 0, "icon_index",false,  23);
-			$this->addInputColumn($this->insertcolumns, "status", "checkbox", true, "", 1, "complete",false,  23);
-			$this->addInputColumn($this->insertcolumns, "importance", "importance", true, "", 2, "importance",false);
-			$this->addInputColumn($this->insertcolumns, "subject", "textbox", true, "", 3, "subject",_("Click here to add a new item"),PERCENTAGE);
-			$this->addInputColumn($this->insertcolumns, "text_duedate", "datepicker", true, "readonly", 4,"duedate",false,150);
 
-			$this->addInputColumn($this->insertcolumns, "owner", "textbox", true, $readonly, 5, "owner", w2u($username["fullname"]), 150);
-			$this->addInputColumn($this->insertcolumns, "categories", "categories", false, "", 6, "categories",false, 150);
-			$this->addInputColumn($this->insertcolumns, "text_percent_complete", "percent", false, "readonly", 7,"percent_complete",_("0%"), 100);
-			$this->addInputColumn($this->insertcolumns, "hiddencolumn", "hidden", false, "", 8,"hidden_column");
-			$this->addInputColumn($this->insertcolumns, "text_startdate", "datepicker", true, "readonly", 9, "startdate", false, 150);
+			// create array to pass data to inputcolumns
+			$columnData = array();
+			$columnData["owner"] = array();
+			$columnData["owner"]["readonly"] = $readonly;
+			$columnData{"owner"}["title"] = w2u($username["fullname"]);
+
+			$this->insertcolumns = $GLOBALS["TableColumns"]->getTaskListInputColumns($columnData);
 
 			parent::ListModule($id, $data, array(OBJECT_SAVE, TABLE_SAVE, TABLE_DELETE));
 
