@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -391,7 +393,7 @@ $calFolder = mapi_msgstore_openentry($store, $rootProps[PR_IPM_APPOINTMENT_ENTRY
 				$numOfRecipients = mapi_table_getrowcount($recipTbl);
 				if($numOfRecipients > 0){
 					$userRowIDs = Array();
-					for($i=1;$i<=$numOfRecipients;$i++){
+					for($i=0;$i<$numOfRecipients;$i++){
 						$userRowIDs[] = Array(
 							PR_ROWID => $i
 						);
