@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -204,6 +206,22 @@
 			return "=''";
 		}
 	}
+
+	/**
+	 * Function which adds a download url for inline attachments in mail body's.
+	 * The regular expression written for this replacement works for only 'img' tags. We search for all parts of img tag,
+	 * replace link for src part and put together with all other parts in img tag. This is done after filtering html in filter class.
+	 * @param array $match the information which part of the body is found.
+	 * @return string download string	 	 	 
+	 */
+	function inline_img_attachments($match)
+	{
+		if (array_key_exists("2", $match)) {
+			return $match[1] . BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachCid=" . $match[2] . "&amp;openType=inline" . $match[3];
+		} else {
+			return "=''";
+		}
+	}
 	
 	/**
 	 * Function which adds a new mail popup on links which are mail addresses in mail body's.
@@ -384,4 +402,36 @@
 		}
 	}
 
+	/**
+	 * checkTrialVersion
+	 * Checks whether the zarafa-server we are connected to has a trial license or not, based on the
+	 * capabilities list.
+	 * @return Boolean returns true on a trial license, false when otherwise.
+	 */
+	function checkTrialVersion(){
+		$capabilities = mapi_zarafa_getcapabilities($GLOBALS['mapisession']->getDefaultMessageStore());
+		return (is_array($capabilities)&&array_search('TRIAL', $capabilities)!==false?true:false);
+	}
+
+	/**
+	 * getDaysLeftOnTrialPeriod
+	 * Returns the number of days left on the trial of the connected zarafa-server. This number is 
+	 * based on the remaining seconds left in the trial and rounded up to whole days.
+	 * @return Integer Number of days remaining on trial. Returns 0 when not on a trial license.
+	 */
+	function getDaysLeftOnTrialPeriod(){
+		$secondsLeft = 0;
+		$capabilities = mapi_zarafa_getcapabilities($GLOBALS['mapisession']->getDefaultMessageStore());
+		if(is_array($capabilities)){
+			for($i=0;$i<count($capabilities);$i++){
+				if(substr($capabilities[$i], 0, 6) == 'TRIAL.'){
+					$secondsLeft = substr($capabilities[$i], 6);
+					break;
+				}
+			}
+		}
+
+		return ceil($secondsLeft/60/60/24);
+	}
+
 ?>
