@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -56,6 +58,7 @@
 	// Include files
 	include("config.php");
 	include("server/util.php");
+	require("server/PEAR/JSON.php");
 	
 	require("mapi/mapi.util.php");
 	require("mapi/mapicode.php");
@@ -75,6 +78,7 @@
 	include("server/modules/class.itemmodule.php");
 	include("server/core/class.operations.php");
 	include("server/core/class.properties.php");
+	include("server/core/class.tablecolumns.php");
 	include("server/core/class.bus.php");
 	include("server/core/class.settings.php");
 	include("server/core/class.language.php");
@@ -141,6 +145,8 @@
 		$GLOBALS["operations"] = new Operations();
 		// Create global properties object
 		$GLOBALS["properties"] = new Properties();
+		// Create global tablecolumns object
+		$GLOBALS["TableColumns"] = new TableColumns();
 		// Create global settings object
 		$GLOBALS["settings"] = new Settings();
 
